/*
Exemplo retirado do lilvro "Web Database Applications with PHP and MySQL, 2nd Edition"
Author: Hugh E. Williams, David Lane, Jakub Korab, Derryn Grabowski, 2001-3
Modificações feitas por José Aser para cadeira de bases de dados do curso CVCM da Universidade Lusófona
*/

create schema if not exists winestore 
  default character set utf8
  default collate utf8_general_ci;

use winestore;

DROP TABLE IF EXISTS items;
DROP TABLE IF EXISTS orders;
DROP TABLE IF EXISTS users;
DROP TABLE IF EXISTS customer;
DROP TABLE IF EXISTS countries;
DROP TABLE IF EXISTS titles;
DROP TABLE IF EXISTS inventory;
DROP TABLE IF EXISTS wine_variety;
DROP TABLE IF EXISTS wine;
DROP TABLE IF EXISTS grape_variety;
DROP TABLE IF EXISTS region;
DROP TABLE IF EXISTS wine_type;
DROP TABLE IF EXISTS winery;


CREATE TABLE users (
  cust_id INT(5) NOT NULL,
  user_name VARCHAR(50) NOT NULL,
  PASSWORD VARCHAR(32) NOT NULL,
  PRIMARY KEY (user_name),
  KEY PASSWORD (PASSWORD),
  KEY cust_id (cust_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE customer (
  cust_id INT(5) NOT NULL,
  surname VARCHAR(50),
  firstname VARCHAR(50),
  initial CHAR(1),
  title_id INT(3),
  address VARCHAR(50),
  city VARCHAR(50),
  state VARCHAR(20),
  zipcode VARCHAR(10),
  country_id INT(4),
  phone VARCHAR(15),
  birth_date CHAR(10),
  PRIMARY KEY (cust_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE grape_variety (
  variety_id INT(3) NOT NULL,
  variety VARCHAR(50) DEFAULT '' NOT NULL,
  PRIMARY KEY (variety_id),
  KEY var (variety)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE inventory (
  wine_id INT(5) NOT NULL,
  inventory_id INT(3) NOT NULL,
  on_hand INT(5) NOT NULL,
  cost DECIMAL(5,2) NOT NULL,
  date_added DATE,
  PRIMARY KEY (wine_id,inventory_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE items (
  cust_id INT(5) NOT NULL,
  order_id INT(5) NOT NULL,
  item_id INT(3) NOT NULL,
  wine_id INT(4) NOT NULL,
  qty INT(3),
  price DECIMAL(5,2),
  PRIMARY KEY (cust_id,order_id,item_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE orders (
  cust_id INT(5) NOT NULL,
  order_id INT(5) NOT NULL,
  DATE TIMESTAMP,
  instructions VARCHAR(128),
  creditcard CHAR(16),
  expirydate CHAR(5),
  PRIMARY KEY (cust_id,order_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE region (
  region_id INT(4) NOT NULL,
  region_name VARCHAR(100) NOT NULL,
  PRIMARY KEY (region_id),
  KEY region (region_name)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE wine_type(
  wine_type_id INT(2) NOT NULL,
  wine_type VARCHAR(32) NOT NULL,
  PRIMARY KEY (wine_type_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE wine (
  wine_id INT(5) NOT NULL,
  wine_name VARCHAR(50) NOT NULL,
  wine_type INT(2) NOT NULL,
  YEAR INT(4) NOT NULL,
  winery_id INT(4) NOT NULL,
  description BLOB,
  PRIMARY KEY (wine_id),
  KEY NAME (wine_name),
  KEY winery (winery_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE wine_variety (
  wine_id INT(5) DEFAULT '0' NOT NULL,
  variety_id INT(3) DEFAULT '0' NOT NULL,
  id INT(1) DEFAULT '0' NOT NULL,
  PRIMARY KEY (wine_id,variety_id),
  KEY wine (wine_id,variety_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE winery (
  winery_id INT(4) NOT NULL,
  winery_name VARCHAR(100) NOT NULL,
  region_id INT(4) NOT NULL,
  PRIMARY KEY (winery_id),
  KEY NAME (winery_name),
  KEY region (region_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE titles (
  title_id INT(2) NOT NULL,
  title CHAR(10),
  PRIMARY KEY (title_id)
)ENGINE=INNODB DEFAULT CHARSET=utf8;

CREATE TABLE countries (
  country_id INT(4) NOT NULL,
  country CHAR(30) NOT NULL,
  PRIMARY KEY (country_id),
  KEY (country)
)ENGINE=INNODB DEFAULT CHARSET=utf8;


INSERT INTO customer VALUES (1,'Rosenthal','Joshua','B',1,'34 Mellili Ln','Earlwood','VIC','6750',12,'(613)83008460','1969-01-26');
INSERT INTO customer VALUES (2,'Serrong','Martin','P',1,'45 Rosenthal Ccl','Doveton','VIC','6779',12,'(613)87783583','1980-12-17');
INSERT INTO customer VALUES (3,'Leramonth','Jacob','I',1,'59 Dalion Pl','Belmont','SA','7664',12,'(618)74731325','1975-01-01');
INSERT INTO customer VALUES (4,'Keisling','Perry','R',5,'146 Marzalla Ccl','Tara','NSW','7161',12,'(612)73572833','1970-04-28');
INSERT INTO customer VALUES (5,'Mockridge','Joel','',1,'138 Rosenthal St','Tottenham','WA','5518',12,'(618)86626713','1981-01-17');
INSERT INTO customer VALUES (6,'Ritterman','Richard','A',1,'14 Dalion Cres','Mohogany','NT','7143',12,'(618)86044644','1960-10-26');
INSERT INTO customer VALUES (7,'Morfooney','Sandra','V',4,'176 Holdenson Crt','Olinda','QLD','6962',12,'(617)75717701','1981-08-03');
INSERT INTO customer VALUES (8,'Krennan','Betty','V',2,'31 Dimitria Ccl','Underwood','VIC','7872',12,'(613)78027240','1970-04-04');
INSERT INTO customer VALUES (9,'Patton','Steven','',1,'197 Chester St','Torquay','WA','8868',12,'(618)87611686','1968-10-13');
INSERT INTO customer VALUES (10,'Dalion','Horacio','Y',1,'197 Barneshaw Ccl','Bauple','SA','7664',12,'(618)67524135','1922-11-26');
INSERT INTO customer VALUES (11,'Keisling','Betty','V',2,'173 Pattendon Ln','Eleker','NSW','6366',12,'(612)52868706','1977-07-01');
INSERT INTO customer VALUES (12,'Tonnibrook','Sandra','B',2,'158 Mettaxus Pl','Kadina','SA','6796',12,'(618)76574741','1967-01-04');
INSERT INTO customer VALUES (13,'Dalion','Chris','T',1,'36 Woodburne Cres','Essendon','WA','6950',12,'(618)71708855','1955-01-22');
INSERT INTO customer VALUES (14,'Sorrenti','Caitlyn','O',2,'21 Oaton Pl','Portsea','WA','7592',12,'(618)76353023','1968-02-11');
INSERT INTO customer VALUES (15,'Cassisi','Derryn','K',5,'9 Morfooney Cres','Portsea','QLD','5966',12,'(617)78202002','1961-08-01');
INSERT INTO customer VALUES (16,'Dimitria','Lynette','D',2,'172 Mellili Ccl','Lemont','WA','8855',12,'(618)87502528','1961-09-04');
INSERT INTO customer VALUES (17,'Tonkin','Hugh','D',1,'7 Taggendharf St','Bentley','QLD','7325',12,'(617)83660800','1971-01-11');
INSERT INTO customer VALUES (18,'Stribling','James','F',1,'155 Mellaseca Pl','Kulpi','NT','5400',12,'(618)87677740','1953-02-11');
INSERT INTO customer VALUES (19,'Mellili','Melissa','S',2,'91 Marzalla St','Tarneit','VIC','5698',12,'(613)67606578','1968-10-01');
INSERT INTO customer VALUES (20,'Leramonth','Harry','Y',5,'117 Barneshaw Cres','Eleker','VIC','5605',12,'(613)77524715','1966-08-14');
INSERT INTO customer VALUES (21,'Ruscina','Jasmine','W',4,'92 Skerry Ln','Karumba','WA','7892',12,'(618)67752312','1971-01-11');
INSERT INTO customer VALUES (22,'Patton','Penelope','E',2,'11 Tonkin St','Coonawarra','WA','8022',12,'(618)80700641','1974-12-11');
INSERT INTO customer VALUES (23,'Lombardi','Hugh','T',1,'174 Woodestock Ln','Alexandra','QLD','8018',12,'(617)82808434','1953-11-21');
INSERT INTO customer VALUES (24,'Patton','Richard','P',1,'190 Mettaxus Ccl','McLaren','NSW','5418',12,'(612)70851445','1980-02-04');
INSERT INTO customer VALUES (25,'Pattendon','Megan','S',2,'140 Serrong Ccl','Doveton','QLD','5501',12,'(617)65380456','1966-08-26');
INSERT INTO customer VALUES (26,'Titshall','Richard','P',5,'100 Mellili Ln','Berala','WA','5817',12,'(618)64544413','1974-12-11');
INSERT INTO customer VALUES (27,'Marzalla','Sandra','F',4,'148 Leramonth Ln','Underwood','NT','8466',12,'(618)81235750','1964-10-01');
INSERT INTO customer VALUES (28,'Chester','Jasmine','B',2,'158 Ruscina St','Ellendale','QLD','7327',12,'(617)75303516','1943-04-24');
INSERT INTO customer VALUES (29,'Triskit','Perry','I',1,'56 Marzalla Crt','Earlwood','NSW','8804',12,'(612)64475386','1981-02-03');
INSERT INTO customer VALUES (30,'Marzalla','George','I',1,'155 Woodestock St','Tarneit','NSW','5965',12,'(612)64157468','1966-08-11');
INSERT INTO customer VALUES (31,'Dalion','Sandra','U',4,'169 Triskit Cres','Coburg','WA','5446',12,'(618)78544248','1938-04-01');
INSERT INTO customer VALUES (32,'Archibald','Joshua','M',1,'94 Tonkin Cres','Olinda','NT','8815',12,'(618)86032738','1971-01-04');
INSERT INTO customer VALUES (33,'Galti','Lynette','S',4,'38 Skerry Cres','Hedley','TAS','7654',12,'(613)77686341','1967-01-22');
INSERT INTO customer VALUES (34,'Woodestock','Patty','T',2,'127 Rosenthal Ccl','Mepunga','WA','6831',12,'(618)71145830','1968-02-11');
INSERT INTO customer VALUES (35,'Rosenthal','Jacob','Y',5,'42 Lombardi Crt','Kidman','NSW','6539',12,'(612)74320342','1966-08-01');
INSERT INTO customer VALUES (36,'Mellili','Cynthia','T',4,'106 Eggelston Cres','Belmont','SA','5177',12,'(618)71065081','1971-01-04');
INSERT INTO customer VALUES (37,'Tonnibrook','Penelope','F',4,'139 Oaton Pl','Ormond','TAS','8146',12,'(613)64380866','1943-04-04');
INSERT INTO customer VALUES (38,'Sears','Hugh','H',1,'32 Pattendon Ln','Kalimna','TAS','5806',12,'(613)58657348','1974-12-11');
INSERT INTO customer VALUES (39,'Nancarral','David','Q',1,'65 Marzalla Ln','Semaphore','NT','7165',12,'(618)82365228','1968-10-01');
INSERT INTO customer VALUES (40,'Cassisi','Chris','W',5,'106 Taggendharf Crt','Portsea','NSW','7674',12,'(612)80143316','1962-08-04');
INSERT INTO customer VALUES (41,'Mockridge','Megan','',4,'108 Dalion Ln','Tara','NSW','5185',12,'(612)58643827','1943-04-04');
INSERT INTO customer VALUES (42,'Chester','Melissa','N',4,'115 Holdenson Pl','Garvoc','SA','8640',12,'(618)71403176','1974-12-11');
INSERT INTO customer VALUES (43,'Belcombe','Rhiannon','J',4,'38 Mockridge Rd','Kidman','SA','7239',12,'(618)83225052','1943-04-21');
INSERT INTO customer VALUES (44,'Mellili','Michelle','E',4,'67 Cassisi Cres','Hedley','VIC','7494',12,'(613)81640164','1955-06-04');
INSERT INTO customer VALUES (45,'Serrong','Dimitria','D',4,'130 Titshall Crt','Milvale','NT','6745',12,'(618)78621875','1970-11-01');
INSERT INTO customer VALUES (46,'Tonnibrook','Nicholas','N',1,'188 Eggelston Ln','Mepunga','NSW','5970',12,'(612)70108833','1980-02-11');
INSERT INTO customer VALUES (47,'Chemnis','Kym','T',4,'49 Eggelston Ln','Stormlea','NT','7251',12,'(618)67125337','1971-01-01');
INSERT INTO customer VALUES (48,'Eggelston','Bronwyn','F',2,'140 Eggelston St','Mohogany','WA','6817',12,'(618)72013132','1943-04-24');
INSERT INTO customer VALUES (49,'Morfooney','Anna','O',2,'6 Oaton Pl','Richmond','VIC','7173',12,'(613)67472553','1968-10-13');
INSERT INTO customer VALUES (50,'Nancarral','Robyn','G',4,'23 Mellaseca St','Athlone','WA','8136',12,'(618)71827807','1966-08-11');
INSERT INTO customer VALUES (51,'Kinsala','Bronwyn','G',4,'81 Leramonth St','McLaren','TAS','6925',12,'(613)84344486','1981-01-01');
INSERT INTO customer VALUES (52,'Marzalla','Karen','V',2,'183 Eggelston Rd','Montague','NT','6939',12,'(618)68433312','1943-04-04');
INSERT INTO customer VALUES (53,'Leramonth','Anthony','D',1,'86 Cassisi Pl','Broadmeadows','QLD','5961',12,'(617)60573031','1971-01-22');
INSERT INTO customer VALUES (54,'Woodestock','George','I',1,'143 Oaton Cres','Richmond','SA','6697',12,'(618)74584227','1968-02-11');
INSERT INTO customer VALUES (55,'Mellaseca','Rochelle','I',4,'155 Eggelston Pl','Huntly','VIC','8872',12,'(613)66718351','1967-01-01');
INSERT INTO customer VALUES (56,'Lombardi','Jasmine','F',2,'141 Woodburne Ccl','Alexandra','QLD','8552',12,'(617)53311402','1943-04-04');
INSERT INTO customer VALUES (57,'Tonkin','Nicholas','C',1,'13 Mellili St','Bentley','QLD','7050',12,'(617)66121222','1943-04-04');
INSERT INTO customer VALUES (58,'Chester','Betty','B',2,'189 Keisling Pl','McLaren','VIC','8814',12,'(613)72562481','1974-12-11');
INSERT INTO customer VALUES (59,'Mellaseca','Dimitria','D',5,'115 Mellaseca Rd','Umina','SA','5715',12,'(618)57227745','1955-10-01');
INSERT INTO customer VALUES (60,'Oaton','Caitlyn','U',2,'72 Oaton Pl','Sunbury','QLD','8654',12,'(617)73501775','1966-08-04');
INSERT INTO customer VALUES (61,'Archibald','Melissa','W',4,'93 Sears St','Armidale','NSW','8355',12,'(612)71584827','1943-04-04');
INSERT INTO customer VALUES (62,'Woodburne','Harry','P',1,'141 Cassisi Ccl','Semaphore','SA','7947',12,'(618)73282244','1962-02-11');
INSERT INTO customer VALUES (63,'Skerry','Robyn','K',4,'155 Oaton Ln','Seabrook','NSW','7991',12,'(612)62157248','1971-01-21');
INSERT INTO customer VALUES (64,'Krennan','Andrew','I',1,'191 Rosenthal Crt','Hedley','WA','5005',12,'(618)61115427','1968-06-14');
INSERT INTO customer VALUES (65,'Stribling','Anna','N',2,'163 Barneshaw Ccl','Eleker','NSW','8782',12,'(612)88343531','1966-08-01');
INSERT INTO customer VALUES (66,'Tonkin','Michelle','Z',2,'2 Leramonth Ln','Longwood','NT','6072',12,'(618)51730188','1974-12-11');
INSERT INTO customer VALUES (67,'Nancarral','Patty','E',2,'142 Kinsala Pl','Kulpi','NT','8979',12,'(618)55300371','1970-11-01');
INSERT INTO customer VALUES (68,'Sorrenti','Jasmine','H',2,'96 Kinsala Ccl','Fitzroy','VIC','8709',12,'(613)63848463','1980-02-24');
INSERT INTO customer VALUES (69,'Mellili','Patty','Q',2,'121 Galti Pl','Singleton','WA','8442',12,'(618)68174421','1968-10-13');
INSERT INTO customer VALUES (70,'Archibald','Derryn','H',5,'107 Krennan Cres','Tabbita','TAS','8983',12,'(613)80128451','1966-08-11');
INSERT INTO customer VALUES (71,'Mellaseca','Lynette','T',4,'102 Dimitria Ccl','Gray','NSW','8957',12,'(612)86073018','1962-10-01');
INSERT INTO customer VALUES (72,'Titshall','William','J',1,'61 Krennan Ccl','Karumba','TAS','6860',12,'(613)84444532','1943-04-04');
INSERT INTO customer VALUES (73,'Krennan','Samantha','M',2,'81 Tonkin Ln','Bauple','NSW','6908',12,'(612)64371220','1981-06-23');
INSERT INTO customer VALUES (74,'Leramonth','Cynthia','L',5,'26 Krennan Ln','Pambulah','TAS','7201',12,'(613)78352882','1968-02-11');
INSERT INTO customer VALUES (75,'Triskit','Jasmine','K',4,'111 Eggelston St','Portsea','VIC','7219',12,'(613)80232320','1955-08-01');
INSERT INTO customer VALUES (76,'Ritterman','Betty','G',2,'150 Cassisi Cres','Bentley','VIC','7095',12,'(613)52834232','1943-04-04');
INSERT INTO customer VALUES (77,'Stribling','Perry','F',5,'122 Mettaxus Cres','Eleker','NSW','7676',12,'(612)86040165','1943-04-04');
INSERT INTO customer VALUES (78,'Leramonth','James','K',1,'167 Kinsala Rd','Portsea','TAS','8737',12,'(613)63236780','1971-01-11');
INSERT INTO customer VALUES (79,'Woodburne','Michelle','D',2,'62 Galti Ccl','Portsea','VIC','7380',12,'(613)70344857','1968-10-01');
INSERT INTO customer VALUES (80,'Belcombe','Horacio','D',5,'73 Stribling Crt','Nyah','NT','7253',12,'(618)68772275','1962-08-04');
INSERT INTO customer VALUES (81,'Archibald','Hugh','A',1,'195 Serrong Rd','Stormlea','NT','6087',12,'(618)56424183','1943-04-04');
INSERT INTO customer VALUES (82,'Stribling','Patty','M',2,'79 Woodburne St','Broadmeadows','WA','5761',12,'(618)61488231','1970-01-11');
INSERT INTO customer VALUES (83,'Mockridge','Michael','L',1,'196 Holdenson Cres','St Albans','SA','5407',12,'(618)74541348','1943-04-21');
INSERT INTO customer VALUES (84,'Sears','Andrew','Z',1,'143 Archibald Ccl','Tarneit','QLD','6500',12,'(617)55414635','1968-06-04');
INSERT INTO customer VALUES (85,'Lombardi','Michael','V',1,'149 Patton Ln','Kalimna','WA','7102',12,'(618)71758846','1966-08-01');
INSERT INTO customer VALUES (86,'Holdenson','Cynthia','Z',4,'112 Serrong Crt','Karumba','VIC','6476',12,'(613)53502477','1974-12-11');
INSERT INTO customer VALUES (87,'Ritterman','Nicholas','B',1,'100 Mellili Rd','Coburg','NSW','8542',12,'(612)54528126','1938-04-01');
INSERT INTO customer VALUES (88,'Barneshaw','Lynette','S',4,'112 Mellili Rd','Armidale','SA','8209',12,'(618)85160470','1943-04-24');
INSERT INTO customer VALUES (89,'Morfooney','Chris','K',1,'54 Marzalla Ccl','Coonawarra','NT','6030',12,'(618)74768053','1968-11-26');
INSERT INTO customer VALUES (90,'Eggelston','Caitlyn','P',4,'122 Ruscina Pl','St Albans','VIC','5976',12,'(613)84514654','1980-08-11');
INSERT INTO customer VALUES (91,'Dalion','Robyn','Y',4,'174 Triskit Ccl','St Albans','VIC','8577',12,'(613)52744123','1962-10-01');
INSERT INTO customer VALUES (92,'Florenini','Joel','Q',1,'125 Cassisi Cres','Eleker','QLD','5491',12,'(617)77623448','1943-04-04');
INSERT INTO customer VALUES (93,'Morfooney','Larry','C',1,'103 Woodestock Ccl','Alexandra','NT','6750',12,'(618)72280650','1979-02-32');
INSERT INTO customer VALUES (94,'Oaton','Joel','V',1,'144 Taggendharf Cres','Coonawarra','QLD','5093',12,'(617)68315683','1968-01-11');
INSERT INTO customer VALUES (95,'Nancarral','Craig','J',1,'190 Serrong Cres','Lucknow','WA','7230',12,'(618)56166080','1981-06-01');
INSERT INTO customer VALUES (96,'Woodburne','Betty','A',2,'120 Sorrenti Pl','Mohogany','VIC','5218',12,'(613)68528130','1943-04-04');
INSERT INTO customer VALUES (97,'Eggelston','Peter','G',5,'11 Tonnibrook Ccl','Kidman','QLD','5081',12,'(617)71183241','1943-04-04');
INSERT INTO customer VALUES (98,'Galti','Dimitria','L',2,'105 Chester Ccl','Eleker','NT','5732',12,'(618)64327532','1971-01-11');
INSERT INTO customer VALUES (99,'Holdenson','Michelle','Q',4,'115 Serrong Ln','Chatswood','TAS','8994',12,'(613)62218455','1968-10-01');
INSERT INTO customer VALUES (100,'Mellili','Melissa','',2,'135 Barneshaw Rd','Earlwood','WA','6025',12,'(618)63467365','1966-08-04');
INSERT INTO customer VALUES (101,'Chester','David','S',1,'196 Woodburne Crt','Mohogany','TAS','7898',12,'(613)66630137','1943-04-04');
INSERT INTO customer VALUES (102,'Serrong','Sandra','G',5,'114 Kinsala Rd','Gray','WA','5928',12,'(618)76858076','1962-02-11');
INSERT INTO customer VALUES (103,'Tonnibrook','Perry','K',1,'3 Galti Ln','Hedley','NSW','7045',12,'(612)81430320','1943-04-21');
INSERT INTO customer VALUES (104,'Krennan','Caitlyn','E',5,'161 Barneshaw St','Tara','VIC','7187',12,'(613)72716318','1961-12-04');
INSERT INTO customer VALUES (105,'Eggelston','Kym','R',4,'95 Morfooney Rd','Springfield','SA','7164',12,'(618)88286344','1966-08-26');
INSERT INTO customer VALUES (106,'Leramonth','Derryn','E',1,'180 Leramonth Ccl','Doveton','NSW','5368',12,'(612)67701614','1955-06-11');
INSERT INTO customer VALUES (107,'Tonkin','Anna','N',2,'5 Leramonth Cres','Langwarrin','NT','8842',12,'(618)71383438','1938-04-01');
INSERT INTO customer VALUES (108,'Skerry','Evonne','R',5,'36 Mockridge Ln','Gobur','WA','5362',12,'(618)85581314','1943-04-14');
INSERT INTO customer VALUES (109,'Patton','Samantha','',4,'39 Ritterman Ccl','Longwood','NT','8622',12,'(618)67820536','1968-01-26');
INSERT INTO customer VALUES (110,'Lombardi','Harry','F',1,'163 Lombardi Ccl','Nareen','SA','7600',12,'(618)78240780','1966-08-11');
INSERT INTO customer VALUES (111,'Holdenson','Peter','K',1,'85 Woodburne Ln','Halton','NSW','7065',12,'(612)61520211','1970-11-01');
INSERT INTO customer VALUES (112,'Chester','Betty','Y',5,'117 Barneshaw Ln','Lemont','VIC','6744',12,'(613)66440513','1980-02-04');
INSERT INTO customer VALUES (113,'Dimitria','David','D',1,'38 Patton Rd','Lucaston','TAS','8613',12,'(613)65735243','1962-01-22');
INSERT INTO customer VALUES (114,'Sorrenti','Jacob','S',1,'180 Ruscina Cres','Bentley','TAS','7201',12,'(613)54756104','1968-02-11');
INSERT INTO customer VALUES (115,'Ruscina','Rochelle','P',4,'114 Barneshaw Rd','Legana','TAS','6275',12,'(613)84141842','1979-08-01');
INSERT INTO customer VALUES (116,'Belcombe','David','R',1,'141 Chester St','Lucknow','NT','6001',12,'(618)72565881','1943-04-04');
INSERT INTO customer VALUES (117,'Mellili','Richard','S',5,'152 Dalion Rd','Lucaston','QLD','6348',12,'(617)71516178','1981-06-03');
INSERT INTO customer VALUES (118,'Chemnis','Anna','O',2,'125 Ruscina Ccl','Richmond','NSW','5418',12,'(612)76822848','1974-12-11');
INSERT INTO customer VALUES (119,'Woodestock','Sandra','Z',2,'176 Mettaxus Rd','Hedley','WA','6951',12,'(618)87306458','1968-10-01');
INSERT INTO customer VALUES (120,'Kinsala','Caitlyn','O',2,'199 Barneshaw Ln','Tottenham','QLD','7444',12,'(617)58484561','1966-08-04');
INSERT INTO customer VALUES (121,'Krennan','Jim','N',1,'109 Sears Rd','Broadmeadows','SA','7327',12,'(618)66666675','1955-10-13');
INSERT INTO customer VALUES (122,'Mettaxus','Sandra','Q',4,'161 Rosenthal Rd','Montague','TAS','6181',12,'(613)85703876','1974-12-11');
INSERT INTO customer VALUES (123,'Kinsala','Melinda','M',4,'134 Belcombe Ln','Huntly','NSW','7201',12,'(612)51440243','1943-04-21');
INSERT INTO customer VALUES (124,'Morfooney','Karen','L',2,'115 Rosenthal Ccl','Alexandra','SA','6894',12,'(618)84702672','1963-02-04');
INSERT INTO customer VALUES (125,'Florenini','Cynthia','',2,'54 Keisling Cres','Graman','TAS','6903',12,'(613)68361411','1971-01-26');
INSERT INTO customer VALUES (126,'Nancarral','Patty','B',2,'94 Skerry Ccl','Huntly','NSW','8253',12,'(612)57038336','1967-01-11');
INSERT INTO customer VALUES (127,'Dimitria','Caitlyn','O',4,'92 Pattendon Rd','Eleker','NT','6276',12,'(618)57004088','1938-04-01');
INSERT INTO customer VALUES (128,'Nancarral','Bronwyn','I',2,'178 Sears Cres','Milvale','SA','7148',12,'(618)83747253','1943-04-24');
INSERT INTO customer VALUES (129,'Serrong','Larry','R',1,'40 Ritterman Ln','Coburg','TAS','5774',12,'(613)71243043','1968-01-26');
INSERT INTO customer VALUES (130,'Tonnibrook','William','K',1,'2 Marzalla Ln','Ellendale','TAS','6419',12,'(613)73483586','1966-08-11');
INSERT INTO customer VALUES (131,'Lombardi','Nicholas','U',5,'89 Taggendharf Ccl','Kadina','WA','6299',12,'(618)73808058','1938-04-01');
INSERT INTO customer VALUES (132,'Mettaxus','George','I',1,'173 Eggelston Ln','Belmont','SA','8675',12,'(618)56582732','1943-04-04');
INSERT INTO customer VALUES (133,'Dimitria','Megan','U',4,'51 Titshall Ccl','Gobur','WA','7846',12,'(618)71467410','1962-11-22');
INSERT INTO customer VALUES (134,'Pattendon','Jasmine','R',4,'123 Rosenthal Ccl','Legana','VIC','6856',12,'(613)62367750','1980-02-11');
INSERT INTO customer VALUES (135,'Oaton','Chris','T',1,'4 Galti Cres','Gray','TAS','6626',12,'(613)86372534','1967-01-01');
INSERT INTO customer VALUES (136,'Ruscina','Patty','D',2,'77 Sears Ln','Halton','NT','6313',12,'(618)54126237','1943-04-04');
INSERT INTO customer VALUES (137,'Barneshaw','Joel','W',1,'34 Leramonth Rd','Evandale','SA','6914',12,'(618)62710277','1955-10-13');
INSERT INTO customer VALUES (138,'Triskit','Harry','B',1,'49 Chester Pl','Evandale','WA','8242',12,'(618)55207855','1974-12-11');
INSERT INTO customer VALUES (139,'Tonkin','James','P',1,'130 Sears Pl','Westleigh','NSW','5040',12,'(612)76144377','1981-10-01');
INSERT INTO customer VALUES (140,'Eggelston','Rhiannon','O',2,'81 Tonnibrook Rd','Rhodes','NSW','7584',12,'(612)83877675','1970-38-04');
INSERT INTO customer VALUES (141,'Dalion','Jim','O',1,'147 Pattendon St','Sunbury','NSW','7874',12,'(612)56205753','1971-01-26');
INSERT INTO customer VALUES (142,'Chemnis','Derryn','G',1,'87 Krennan Rd','Huntly','TAS','5587',12,'(613)87386417','1962-02-11');
INSERT INTO customer VALUES (143,'Galti','Jasmine','',2,'152 Archibald Ln','Murrabit','VIC','5280',12,'(613)51860718','1943-04-21');
INSERT INTO customer VALUES (144,'Nancarral','Joshua','D',1,'161 Keisling Ccl','Portsea','TAS','7068',12,'(613)53742507','1978-02-04');
INSERT INTO customer VALUES (145,'Nancarral','Chris','L',1,'66 Chester Ln','Richmond','VIC','5816',12,'(613)86873765','1971-01-26');
INSERT INTO customer VALUES (146,'Leramonth','Evonne','M',2,'14 Belcombe Pl','Mininera','WA','8976',12,'(618)85074516','1967-01-11');
INSERT INTO customer VALUES (147,'Kinsala','Sandra','V',4,'121 Ruscina St','Tara','WA','8183',12,'(618)56763881','1938-04-01');
INSERT INTO customer VALUES (148,'Dimitria','Melissa','V',4,'156 Mockridge Ccl','Culgoa','WA','5532',12,'(618)51054660','1943-04-24');
INSERT INTO customer VALUES (149,'Taggendharf','Mark','O',1,'140 Leramonth Rd','Earlwood','NT','8989',12,'(618)57557112','1968-10-13');
INSERT INTO customer VALUES (150,'Morfooney','Jim','G',1,'104 Cassisi Crt','Lucknow','QLD','5250',12,'(617)81702264','1966-08-11');
INSERT INTO customer VALUES (151,'Tonkin','Perry','',1,'66 Tonnibrook Ln','Semaphore','NT','5422',12,'(618)63565451','1938-04-01');
INSERT INTO customer VALUES (152,'Woodestock','Derryn','O',1,'39 Rosenthal St','Mininera','SA','6507',12,'(618)57322816','1943-04-14');
INSERT INTO customer VALUES (153,'Mockridge','Andrew','S',1,'160 Woodburne St','Kalimna','VIC','5829',12,'(613)64134525','1955-01-22');
INSERT INTO customer VALUES (154,'Archibald','Horacio','J',5,'84 Belcombe Ln','Tabbita','WA','8423',12,'(618)75711388','1968-02-11');
INSERT INTO customer VALUES (155,'Mellaseca','Derryn','U',1,'180 Cassisi Crt','St Albans','NSW','8153',12,'(612)74587068','1970-11-01');
INSERT INTO customer VALUES (156,'Cassisi','Joshua','E',1,'110 Chester Rd','Mepunga','NSW','8783',12,'(612)67027076','1980-01-04');
INSERT INTO customer VALUES (157,'Pattendon','Hugh','Q',1,'186 Mockridge Ln','Athlone','SA','6012',12,'(618)53103766','1967-01-26');
INSERT INTO customer VALUES (158,'Lombardi','Patty','E',2,'165 Leramonth Cres','Mininera','TAS','7670',12,'(613)77465370','1974-12-11');
INSERT INTO customer VALUES (159,'Ritterman','Martin','G',1,'165 Chemnis St','Singleton','NSW','8596',12,'(612)55210021','1968-10-01');
INSERT INTO customer VALUES (160,'Woodburne','Martin','V',5,'91 Barneshaw Crt','Culgoa','WA','8658',12,'(618)67038260','1971-01-04');
INSERT INTO customer VALUES (161,'Chemnis','Hugh','O',1,'115 Keisling Cres','Pambulah','NSW','5914',12,'(612)81773048','1981-02-03');
INSERT INTO customer VALUES (162,'Florenini','Richard','M',1,'178 Cassisi Crt','Kadina','NT','6291',12,'(618)67878813','1974-12-11');
INSERT INTO customer VALUES (163,'Ruscina','Penelope','U',4,'38 Tonnibrook Cres','Doveton','NT','8762',12,'(618)75045778','1943-04-21');
INSERT INTO customer VALUES (164,'Taggendharf','Chris','J',1,'118 Tonnibrook Cres','Gray','WA','5727',12,'(618)62282530','1962-02-04');
INSERT INTO customer VALUES (165,'Ruscina','James','T',1,'57 Kinsala St','Stormlea','WA','5315',12,'(618)71767108','1966-08-26');
INSERT INTO customer VALUES (166,'Sears','Samantha','I',4,'77 Morfooney Crt','Westleigh','VIC','6156',12,'(613)53304168','1943-04-11');
INSERT INTO customer VALUES (167,'Serrong','Jasmine','B',4,'155 Pattendon St','Belmont','VIC','5362',12,'(613)70217803','1938-04-01');
INSERT INTO customer VALUES (168,'Chester','Jim','M',1,'109 Ruscina Ccl','Fernvale','QLD','7905',12,'(617)52351633','1955-06-24');
INSERT INTO customer VALUES (169,'Leramonth','Sandra','Q',2,'121 Cassisi Crt','Coburg','WA','6944',12,'(618)58037400','1968-10-01');
INSERT INTO customer VALUES (170,'Ritterman','Samantha','B',2,'93 Morfooney Pl','Nareen','WA','7849',12,'(618)85263858','1966-08-11');
INSERT INTO customer VALUES (171,'Mellaseca','Michelle','R',2,'86 Cassisi Pl','Kalimna','NSW','5008',12,'(612)66105565','1970-30-01');
INSERT INTO customer VALUES (172,'Dimitria','Patty','',2,'157 Rosenthal Rd','Springfield','QLD','5859',12,'(617)55562363','1971-01-04');
INSERT INTO customer VALUES (173,'Ritterman','Joshua','R',1,'187 Dimitria Cres','Lemont','NT','6834',12,'(618)68160556','1971-01-22');
INSERT INTO customer VALUES (174,'Mellili','Belinda','I',2,'171 Chester St','Langwarrin','WA','6633',12,'(618)80435000','1968-02-11');
INSERT INTO customer VALUES (175,'Taggendharf','Larry','C',1,'36 Leramonth Cres','Vasey','VIC','8988',12,'(613)62462616','1962-08-01');
INSERT INTO customer VALUES (176,'Taggendharf','Karen','D',2,'126 Patton Pl','Olinda','QLD','7279',12,'(617)74162877','1971-01-04');
INSERT INTO customer VALUES (177,'Stribling','Penelope','O',2,'67 Pattendon Rd','Sunbury','SA','8845',12,'(618)52711023','1970-11-10');
INSERT INTO customer VALUES (178,'Chester','Larry','E',1,'154 Keisling Ccl','Tarneit','QLD','8088',12,'(617)55030884','1980-02-11');
INSERT INTO customer VALUES (179,'Triskit','Jim','W',1,'150 Marzalla Ccl','Singleton','TAS','8395',12,'(613)63542348','1968-06-01');
INSERT INTO customer VALUES (180,'Patton','Nicholas','Z',5,'192 Leramonth Cres','Bauple','SA','6317',12,'(618)85080453','1966-08-04');
INSERT INTO customer VALUES (181,'Sorrenti','Cynthia','T',2,'143 Mockridge Cres','Tabbita','WA','8816',12,'(618)87667104','1943-04-04');
INSERT INTO customer VALUES (182,'Dimitria','William','W',1,'199 Ritterman Pl','Essendon','NT','7023',12,'(618)88063736','1974-12-11');
INSERT INTO customer VALUES (183,'Taggendharf','Chris','T',1,'98 Sears Pl','Gray','QLD','8429',12,'(617)78367044','1981-02-21');
INSERT INTO customer VALUES (184,'Mockridge','Dimitria','I',4,'15 Mettaxus Ln','Coonawarra','WA','8938',12,'(618)60611636','1955-02-04');
INSERT INTO customer VALUES (185,'Mettaxus','Samantha','R',2,'63 Holdenson Cres','Lemont','TAS','8109',12,'(613)82070243','1966-08-26');
INSERT INTO customer VALUES (186,'Cassisi','Megan','Z',4,'93 Eggelston Pl','Mininera','TAS','8240',12,'(613)62004588','1962-02-11');
INSERT INTO customer VALUES (187,'Titshall','Nicholas','',1,'147 Galti Crt','Singleton','QLD','8570',12,'(617)77403016','1971-01-01');
INSERT INTO customer VALUES (188,'Belcombe','Martin','U',1,'24 Nancarral Ln','St Albans','NSW','6971',12,'(612)67567775','1968-02-24');
INSERT INTO customer VALUES (189,'Dimitria','Belinda','K',2,'21 Mellaseca Crt','McLaren','NSW','6038',12,'(612)88460442','1968-10-13');
INSERT INTO customer VALUES (190,'Pattendon','Belinda','B',4,'96 Belcombe Cres','Bauple','VIC','8697',12,'(613)56841817','1967-01-11');
INSERT INTO customer VALUES (191,'Rosenthal','Chris','A',1,'29 Mellili Ccl','Longwood','TAS','7246',12,'(613)83012326','1971-01-01');
INSERT INTO customer VALUES (192,'Tonkin','Michelle','I',2,'52 Ruscina Ln','Belmont','NSW','5315',12,'(612)62645788','1943-04-04');
INSERT INTO customer VALUES (193,'Galti','Jim','W',1,'164 Marzalla Crt','Portsea','SA','7121',12,'(618)60602713','1971-01-22');
INSERT INTO customer VALUES (194,'Woodburne','David','',5,'64 Stribling Pl','Richmond','VIC','5141',12,'(613)84332583','1968-02-11');
INSERT INTO customer VALUES (195,'Mockridge','Horacio','D',1,'95 Galti Pl','Seabrook','NSW','8670',12,'(612)71483507','1966-08-01');
INSERT INTO customer VALUES (196,'Nancarral','Joshua','Y',1,'32 Dimitria Ln','Olinda','VIC','6118',12,'(613)65766107','1943-04-14');
INSERT INTO customer VALUES (197,'Skerry','Marie','H',2,'109 Woodestock Crt','Chatswood','TAS','7847',12,'(613)62417846','1962-10-13');
INSERT INTO customer VALUES (198,'Oaton','Mark','O',5,'191 Ritterman Ln','Rhodes','QLD','5285',12,'(617)78227785','1974-12-11');
INSERT INTO customer VALUES (199,'Leramonth','Harry','K',1,'197 Mellaseca Ccl','Murrabit','VIC','5158',12,'(613)57108558','1955-11-01');
INSERT INTO customer VALUES (200,'Dalion','Anthony','D',1,'198 Eggelston Crt','Portsea','TAS','6556',12,'(613)66526148','1980-08-04');
INSERT INTO customer VALUES (201,'Oaton','Michael','N',1,'168 Kinsala Rd','Mepunga','TAS','8905',12,'(613)72284445','1967-01-26');
INSERT INTO customer VALUES (202,'Nancarral','Derryn','V',1,'199 Stribling Ln','Chatswood','SA','7621',12,'(618)54148018','1974-12-11');
INSERT INTO customer VALUES (203,'Tonkin','Lynette','N',5,'25 Marzalla Cres','Culgoa','QLD','7831',12,'(617)57157653','1971-01-21');
INSERT INTO customer VALUES (204,'Rosenthal','George','F',1,'176 Taggendharf Ccl','Langwarrin','NSW','8547',12,'(612)65322620','1968-02-04');
INSERT INTO customer VALUES (205,'Tonkin','Mark','I',1,'177 Tonnibrook Ccl','Kalimna','WA','6578',12,'(618)50041388','1981-08-03');
INSERT INTO customer VALUES (206,'Titshall','Anna','Q',4,'106 Taggendharf St','Sunbury','VIC','7837',12,'(613)87861632','1974-12-11');
INSERT INTO customer VALUES (207,'Archibald','Derryn','C',1,'33 Oaton St','St Albans','QLD','6632',12,'(617)70306414','1971-01-01');
INSERT INTO customer VALUES (208,'Rosenthal','Betty','W',4,'99 Nancarral Ccl','Broadmeadows','VIC','7233',12,'(613)66386754','1962-02-24');
INSERT INTO customer VALUES (209,'Sorrenti','Melinda','J',5,'17 Triskit Rd','Kulpi','TAS','6596',12,'(613)53582787','1968-10-13');
INSERT INTO customer VALUES (210,'Krennan','Rhiannon','C',2,'45 Sorrenti St','Nyah','NT','7932',12,'(618)56808736','1967-01-11');
INSERT INTO customer VALUES (211,'Nancarral','Jasmine','Q',2,'155 Tonnibrook Crt','Mepunga','VIC','7524',12,'(613)62370203','1938-04-01');
INSERT INTO customer VALUES (212,'Keisling','Belinda','G',2,'114 Lombardi Ln','Lucaston','QLD','8671',12,'(617)56248475','1943-04-04');
INSERT INTO customer VALUES (213,'Tonkin','Bronwyn','V',4,'98 Florenini Cres','Murrabit','VIC','6529',12,'(613)76711015','1971-01-22');
INSERT INTO customer VALUES (214,'Belcombe','Evonne','H',4,'153 Tonkin Cres','Tottenham','NT','8157',12,'(618)83807301','1968-02-11');
INSERT INTO customer VALUES (215,'Florenini','Jasmine','F',5,'102 Cassisi Pl','Gobur','QLD','8507',12,'(617)88777823','1955-08-01');
INSERT INTO customer VALUES (216,'Mellaseca','Perry','S',1,'24 Dalion Cres','Rhodes','WA','5460',12,'(618)64826275','1943-04-04');
INSERT INTO customer VALUES (217,'Florenini','Mark','V',1,'60 Holdenson Pl','Montague','NSW','6369',12,'(612)68501817','1962-10-13');
INSERT INTO customer VALUES (218,'Patton','Caitlyn','P',2,'73 Dimitria Crt','Underwood','TAS','7259',12,'(613)51036245','1943-04-11');
INSERT INTO customer VALUES (219,'Triskit','Sandra','X',4,'40 Holdenson Ccl','Sunshine','WA','6815',12,'(618)85288465','1968-01-01');
INSERT INTO customer VALUES (220,'Florenini','Melinda','O',2,'60 Barneshaw Pl','Longwood','NT','7406',12,'(618)53584046','1966-08-04');
INSERT INTO customer VALUES (221,'Leramonth','David','P',1,'124 Stribling Ccl','Gray','TAS','6114',12,'(613)66387010','1970-11-26');
INSERT INTO customer VALUES (222,'Rosenthal','Karen','X',4,'165 Florenini Ln','Legana','TAS','8606',12,'(613)50341560','1980-02-11');
INSERT INTO customer VALUES (223,'Taggendharf','Chris','P',5,'61 Mockridge Ln','Kulpi','SA','7887',12,'(618)63880685','1971-01-21');
INSERT INTO customer VALUES (224,'Leramonth','William','B',1,'82 Dimitria Rd','Underwood','WA','8486',12,'(618)71452321','1968-02-04');
INSERT INTO customer VALUES (225,'Keisling','Rhiannon','M',4,'144 Rosenthal Ln','Doveton','VIC','5577',12,'(613)73386421','1966-08-26');
INSERT INTO customer VALUES (226,'Titshall','Jim','A',1,'64 Stribling Ln','Rhodes','VIC','5289',12,'(613)72720207','1974-12-11');
INSERT INTO customer VALUES (227,'Serrong','Larry','W',1,'109 Archibald Cres','Fernvale','QLD','6695',12,'(617)71584868','1981-10-01');
INSERT INTO customer VALUES (228,'Mockridge','Michael','P',1,'25 Oaton Ln','Ormond','NSW','6976',12,'(612)76246216','1962-02-24');
INSERT INTO customer VALUES (229,'Tonnibrook','Belinda','K',4,'1 Pattendon Rd','Semaphore','NT','5117',12,'(618)66468866','1968-10-13');
INSERT INTO customer VALUES (230,'Keisling','Kym','M',4,'12 Kinsala Pl','Vasey','NSW','8793',12,'(612)63023461','1967-01-11');
INSERT INTO customer VALUES (231,'Titshall','William','W',1,'6 Tonkin Rd','Langwarrin','NSW','8162',12,'(612)76586130','1955-10-01');
INSERT INTO customer VALUES (232,'Florenini','Mark','Z',1,'30 Sears Crt','Springfield','NT','8206',12,'(618)88381283','1943-04-04');
INSERT INTO customer VALUES (233,'Keisling','Marie','L',5,'155 Dimitria Ccl','Mohogany','NSW','5280',12,'(612)52031782','1971-01-22');
INSERT INTO customer VALUES (234,'Ritterman','Jacob','M',1,'148 Tonnibrook Cres','Essendon','QLD','7849',12,'(617)54337454','1968-30-11');
INSERT INTO customer VALUES (235,'Triskit','Kym','E',4,'73 Ritterman Ccl','Garvoc','QLD','8239',12,'(617)76248246','1971-01-01');
INSERT INTO customer VALUES (236,'Mockridge','Megan','D',5,'32 Morfooney Rd','Sunbury','WA','7962',12,'(618)51184432','1943-04-04');
INSERT INTO customer VALUES (237,'Tonkin','Samantha','K',4,'120 Florenini Rd','Tarneit','QLD','8409',12,'(617)72156113','1962-10-13');
INSERT INTO customer VALUES (238,'Stribling','Samantha','Q',2,'14 Serrong Crt','Ormond','TAS','8465',12,'(613)76144405','1974-12-11');
INSERT INTO customer VALUES (239,'Patton','Jim','Z',1,'178 Nancarral Pl','Tara','NT','6109',12,'(618)82336081','1968-01-01');
INSERT INTO customer VALUES (240,'Tonkin','David','P',1,'81 Holdenson Ln','Colac','WA','7689',12,'(618)52502842','1966-08-14');
INSERT INTO customer VALUES (241,'Chester','Nicholas','E',1,'189 Stribling Rd','Berala','TAS','8659',12,'(613)81815015','1943-04-04');
INSERT INTO customer VALUES (242,'Woodburne','Patty','C',4,'80 Keisling St','Lucknow','VIC','7198',12,'(613)50381102','1974-12-11');
INSERT INTO customer VALUES (243,'Mellaseca','Anthony','G',1,'63 Stribling Crt','Broadmeadows','VIC','5723',12,'(613)52453634','1970-11-21');
INSERT INTO customer VALUES (244,'Tonkin','James','X',1,'168 Mellili St','Greensborough','VIC','8149',12,'(613)67468121','1980-02-04');
INSERT INTO customer VALUES (245,'Woodburne','Rochelle','',4,'172 Tonnibrook Rd','Essendon','WA','6388',12,'(618)53515348','1966-08-26');
INSERT INTO customer VALUES (246,'Dalion','Marie','C',2,'60 Rosenthal Ln','Longwood','TAS','8141',12,'(613)70307833','1962-02-11');
INSERT INTO customer VALUES (247,'Morfooney','Rochelle','J',5,'198 Tonnibrook Crt','Essendon','QLD','8188',12,'(617)68618537','1955-10-01');
INSERT INTO customer VALUES (248,'Leramonth','Kym','W',5,'170 Belcombe Crt','Athlone','NT','5830',12,'(618)62751127','1943-04104');
INSERT INTO customer VALUES (249,'Taggendharf','Betty','L',2,'111 Barneshaw Cres','Portsea','NSW','6328',12,'(612)70378652','1981-02-03');
INSERT INTO customer VALUES (250,'Kinsala','Rhiannon','Y',2,'99 Cassisi Ccl','Greensborough','TAS','5733',12,'(613)51167265','1971-01-11');
INSERT INTO customer VALUES (251,'Woodburne','Michelle','F',4,'35 Mettaxus Rd','Nyah','NSW','6736',12,'(612)88422053','1938-04-01');
INSERT INTO customer VALUES (252,'Eggelston','Perry','X',1,'66 Dalion Cres','Singleton','NT','5811',12,'(618)85305585','1943-04-04');
INSERT INTO customer VALUES (253,'Titshall','Penelope','V',2,'172 Rosenthal Crt','Murrabit','NT','5459',12,'(618)58063756','1971-01-22');
INSERT INTO customer VALUES (254,'Lombardi','George','Q',1,'199 Florenini Pl','Karumba','WA','6103',12,'(618)56674366','1968-01-11');
INSERT INTO customer VALUES (255,'Lombardi','David','W',1,'62 Mettaxus Cres','Mohogany','SA','7207',12,'(618)87447516','1966-08-01');
INSERT INTO customer VALUES (256,'Galti','Sandra','N',4,'3 Mettaxus Rd','Umina','TAS','6361',12,'(613)82867811','1943-04-04');
INSERT INTO customer VALUES (257,'Woodburne','Robyn','Y',2,'40 Florenini Ln','Tara','SA','6655',12,'(618)72201151','1962-10-13');
INSERT INTO customer VALUES (258,'Sorrenti','Chris','R',1,'64 Mellili Pl','Westleigh','NT','6106',12,'(618)60772417','1974-12-11');
INSERT INTO customer VALUES (259,'Barneshaw','Rhiannon','H',2,'33 Woodestock Ln','Chatswood','TAS','8732',12,'(613)8110186010', '1968-10-01');
INSERT INTO customer VALUES (260,'Sears','Kym','V',4,'29 Dimitria St','Alexandra','VIC','8126',12,'(613)63740656','1966-08-04');
INSERT INTO customer VALUES (261,'Tonnibrook','Chris','U',1,'8 Nancarral Ln','Halton','NT','7320',12,'(618)78476587','1967-01-26');
INSERT INTO customer VALUES (262,'Ritterman','Hugh','C',5,'158 Ritterman Cres','Mepunga','NSW','8525',12,'(612)76228526','1955-02-11');
INSERT INTO customer VALUES (263,'Mellili','Anna','V',2,'82 Holdenson Ccl','Eleker','NT','7900',12,'(618)73352435','1943-04-21');
INSERT INTO customer VALUES (264,'Chester','Marie','S',2,'145 Ruscina St','Longwood','WA','5365',12,'(618)72757083','1968-02-04');
INSERT INTO customer VALUES (265,'Dalion','Hugh','H',5,'49 Titshall Crt','Karumba','VIC','7763',12,'(613)84068631','1970-11-26');
INSERT INTO customer VALUES (266,'Mettaxus','Caitlyn','I',2,'68 Tonnibrook St','Semaphore','WA','8127',12,'(618)72563542','1980-02-11');
INSERT INTO customer VALUES (267,'Florenini','Andrew','G',5,'96 Ruscina Ccl','Murrabit','SA','5657',12,'(618)80333262','1938-04-01');
INSERT INTO customer VALUES (268,'Cassisi','Larry','Q',1,'26 Archibald Pl','Seabrook','SA','8136',12,'(618)54048670','1962-02-24');
INSERT INTO customer VALUES (269,'Kinsala','Peter','C',1,'198 Oaton St','Sunshine','SA','6488',12,'(618)62648362','1968-01-26');
INSERT INTO customer VALUES (270,'Dalion','Michelle','D',4,'157 Galti Ccl','Stormlea','TAS','6349',12,'(613)72457761','1971-01-11');
INSERT INTO customer VALUES (271,'Mellili','Derryn','X',1,'174 Krennan Rd','Lucknow','VIC','7269',12,'(613)72640247','1981-10-01');
INSERT INTO customer VALUES (272,'Sorrenti','Steven','K',1,'135 Taggendharf Cres','Nabawa','SA','5334',12,'(618)57330828','1967-01-04');
INSERT INTO customer VALUES (273,'Krennan','Dimitria','D',2,'131 Oaton Rd','Alexandra','WA','7205',12,'(618)74513345','1943-04-21');
INSERT INTO customer VALUES (274,'Eggelston','Melissa','Z',4,'44 Chester Rd','Bentley','NSW','6397',12,'(612)80144865','1968-02-11');
INSERT INTO customer VALUES (275,'Keisling','Penelope','Q',2,'144 Taggendharf Ln','Fitzroy','SA','8869',12,'(618)86337218','1966-08-01');
INSERT INTO customer VALUES (276,'Stribling','Kym','Q',2,'48 Eggelston Ln','Legana','QLD','6120',12,'(617)76888135','1943-04-04');
INSERT INTO customer VALUES (277,'Triskit','Patty','L',2,'189 Barneshaw St','Mininera','QLD','5537',12,'(617)62516871','1955-10-13');
INSERT INTO customer VALUES (278,'Titshall','Sandra','U',4,'160 Chester Crt','Essendon','TAS','8690',12,'(613)61700800','1974-12-11');
INSERT INTO customer VALUES (279,'Mellaseca','Hugh','W',1,'52 Triskit St','Springfield','TAS','5091',12,'(613)80178768','1962-10-01');
INSERT INTO customer VALUES (280,'Skerry','Jacob','X',1,'176 Morfooney Pl','Seabrook','SA','8496',12,'(618)60437266','1971-01-04');
INSERT INTO customer VALUES (281,'Triskit','David','Q',1,'77 Woodburne Pl','Kulpi','WA','7838',12,'(618)66568380','1967-01-26');
INSERT INTO customer VALUES (282,'Krennan','Samantha','T',2,'59 Mellaseca Pl','Lemont','NT','7530',12,'(618)60622335','1974-12-11');
INSERT INTO customer VALUES (283,'Sorrenti','Rhiannon','U',2,'125 Sears Rd','Kidman','WA','8500',12,'(618)76378025','1943-04-21');
INSERT INTO customer VALUES (284,'Florenini','Harry','K',1,'131 Sorrenti Pl','Pambulah','QLD','8595',12,'(617)87467032','1968-01-14');
INSERT INTO customer VALUES (285,'Galti','Caitlyn','A',4,'176 Barneshaw Pl','Eleker','NT','7244',12,'(618)81251811','1966-08-26');
INSERT INTO customer VALUES (286,'Mettaxus','George','V',1,'120 Holdenson Ln','Mininera','WA','5772',12,'(618)53382017','1974-12-11');
INSERT INTO customer VALUES (287,'Florenini','Kym','M',4,'29 Sorrenti St','Langwarrin','TAS','8471',12,'(613)85466846','1970-11-01');
INSERT INTO customer VALUES (288,'Sorrenti','Patty','V',4,'179 Patton Ccl','Doveton','SA','7852',12,'(618)62881443','1980-02-24');
INSERT INTO customer VALUES (289,'Dalion','Jacob','D',1,'104 Lombardi St','Lucknow','QLD','8873',12,'(617)56224436','1968-10-13');
INSERT INTO customer VALUES (290,'Taggendharf','Dimitria','I',4,'25 Belcombe Pl','Tara','VIC','7236',12,'(613)86844520','1972-08-11');
INSERT INTO customer VALUES (291,'Barneshaw','Dimitria','A',4,'38 Archibald Ln','Mohogany','TAS','8638',12,'(613)62366520','1938-04-01');
INSERT INTO customer VALUES (292,'Woodestock','Derryn','K',1,'20 Mellaseca St','Springfield','QLD','6877',12,'(617)64320543','1955-06-04');
INSERT INTO customer VALUES (293,'Nancarral','George','D',1,'61 Oaton Crt','Garvoc','NT','5475',12,'(618)80535856','1981-02-23');
INSERT INTO customer VALUES (294,'Skerry','Craig','L',1,'17 Holdenson Ccl','Underwood','SA','6322',12,'(618)67680430','1968-02-11');
INSERT INTO customer VALUES (295,'Lombardi','Penelope','X',4,'161 Keisling Ccl','Kulpi','SA','6411',12,'(618)50175170','1971-01-01');
INSERT INTO customer VALUES (296,'Rosenthal','Caitlyn','A',4,'95 Mellili Ln','Langwarrin','VIC','5322',12,'(613)63082753','1943-04-04');
INSERT INTO customer VALUES (297,'Dimitria','Nicholas','R',1,'63 Mellili Rd','Ormond','NSW','6758',12,'(612)84002548','1943-04-04');
INSERT INTO customer VALUES (298,'Oaton','Rochelle','F',2,'20 Krennan Rd','Longwood','NSW','8896',12,'(612)60651750','1974-12-11');
INSERT INTO customer VALUES (299,'Eggelston','Martin','E',1,'75 Krennan Ccl','Longwood','TAS','8999',12,'(613)74102683','1962-01-01');
INSERT INTO customer VALUES (300,'Dalion','Sandra','N',4,'59 Woodestock Ln','Sunshine','NSW','7713',12,'(612)63352636','1966-08-04');
INSERT INTO customer VALUES (301,'Patton','Michelle','T',4,'86 Belcombe Ln','Gobur','WA','8422',12,'(618)87485231','1967-01-26');
INSERT INTO customer VALUES (302,'Mockridge','Penelope','I',2,'92 Serrong St','Milvale','SA','6592',12,'(618)64101633','1974-12-11');
INSERT INTO customer VALUES (303,'Lombardi','Sandra','',4,'181 Nancarral Pl','Chatswood','VIC','6648',12,'(613)55721746','1943-04-21');
INSERT INTO customer VALUES (304,'Marzalla','Harry','H',1,'197 Marzalla St','Hedley','VIC','7588',12,'(613)56022605','1968-02-04');
INSERT INTO customer VALUES (305,'Cassisi','Kym','V',2,'186 Chemnis St','Culgoa','NSW','8525',12,'(612)75743511','1966-08-26');
INSERT INTO customer VALUES (306,'Tonkin','Martin','F',1,'55 Lombardi Pl','Huntly','NSW','5686',12,'(612)63088006','1974-12-11');
INSERT INTO customer VALUES (307,'Ritterman','Peter','R',1,'89 Morfooney Cres','Evandale','SA','5656',12,'(618)85584145','1955-10-01');
INSERT INTO customer VALUES (308,'Chemnis','Samantha','N',2,'51 Pattendon Crt','Gray','SA','5630',12,'(618)58855182','1962-02-24');
INSERT INTO customer VALUES (309,'Ritterman','Penelope','G',4,'139 Dimitria Pl','Doveton','SA','5702',12,'(618)76767623','1968-11-26');
INSERT INTO customer VALUES (310,'Mockridge','Belinda','E',2,'14 Dalion Cres','McLaren','SA','6531',12,'(618)60037501','1980-11-11');
INSERT INTO customer VALUES (311,'Sorrenti','Michelle','C',4,'30 Krennan Cres','St Albans','NSW','8243',12,'(612)64610180','1938-04-01');
INSERT INTO customer VALUES (312,'Triskit','Michael','C',1,'117 Kinsala Rd','Tarneit','QLD','7970',12,'(617)78180832','1967-01-04');
INSERT INTO customer VALUES (313,'Galti','Horacio','C',1,'63 Keisling Ln','Coburg','NSW','6982',12,'(612)57246787','1943-04-21');
INSERT INTO customer VALUES (314,'Eggelston','Michelle','H',5,'137 Woodburne Crt','Sunbury','SA','6804',12,'(618)73830028','1968-01-11');
INSERT INTO customer VALUES (315,'Nancarral','Melinda','Z',4,'130 Patton Cres','Umina','NSW','8423',12,'(612)56356545','1981-08-01');
INSERT INTO customer VALUES (316,'Chemnis','Joel','V',1,'82 Morfooney Rd','Mininera','NSW','7632',12,'(612)58824612','1943-04-04');
INSERT INTO customer VALUES (317,'Mellaseca','Larry','X',1,'123 Pattendon Rd','Athlone','VIC','8130',12,'(613)82247557','1943-04-04');
INSERT INTO customer VALUES (318,'Sears','Nicholas','G',1,'113 Mettaxus Ccl','Tabbita','NT','6555',12,'(618)80376325','1974-12-11');
INSERT INTO customer VALUES (319,'Oaton','Perry','F',1,'129 Dalion Ccl','Karumba','QLD','7683',12,'(617)72135003','1962-10-01');
INSERT INTO customer VALUES (320,'Mellaseca','Craig','Y',1,'194 Serrong Ln','Longwood','QLD','6170',12,'(617)67303806','1966-08-04');
INSERT INTO customer VALUES (321,'Stribling','Betty','U',2,'136 Holdenson Rd','Hedley','WA','6897',12,'(618)73707407','1972-10-13');
INSERT INTO customer VALUES (322,'Rosenthal','Perry','C',1,'61 Sorrenti Ln','Umina','TAS','7330',12,'(613)53887853','1955-02-11');
INSERT INTO customer VALUES (323,'Dimitria','Peter','Y',1,'147 Keisling St','Nareen','VIC','6705',12,'(613)58407153','1967-01-21');
INSERT INTO customer VALUES (324,'Mettaxus','Mark','E',1,'119 Skerry Ccl','Westleigh','NSW','7788',12,'(612)72746843','1968-02-04');
INSERT INTO customer VALUES (325,'Morfooney','Jim','F',5,'31 Taggendharf Crt','Alexandra','NSW','6695',12,'(612)63243807','1962-08-26');
INSERT INTO customer VALUES (326,'Galti','Rhiannon','C',2,'134 Chester Ln','Broadmeadows','QLD','6887',12,'(617)61266404','1971-01-11');
INSERT INTO customer VALUES (327,'Pattendon','Mark','E',1,'53 Sorrenti Crt','Underwood','VIC','5484',12,'(613)71123101','1938-04-01');
INSERT INTO customer VALUES (328,'Triskit','Sandra','B',5,'176 Woodestock Pl','Sunbury','NT','6898',12,'(618)81127688','1943-04-14');
INSERT INTO customer VALUES (329,'Pattendon','Anthony','Q',1,'104 Chemnis St','Seabrook','NSW','6312',12,'(612)62351267','1968-10-13');
INSERT INTO customer VALUES (330,'Rosenthal','Karen','L',2,'105 Nancarral Ccl','Sunshine','WA','5024',12,'(618)77411726','1962-01-11');
INSERT INTO customer VALUES (331,'Tonkin','Rhiannon','B',4,'16 Kinsala Crt','Legana','NSW','7574',12,'(612)58557765','1970-11-01');
INSERT INTO customer VALUES (332,'Mellili','Jasmine','C',4,'57 Keisling Crt','Tabbita','WA','8240',12,'(618)50500415','1980-06-04');
INSERT INTO customer VALUES (333,'Sears','Melissa','I',4,'145 Mettaxus Cres','Doveton','QLD','8140',12,'(617)50124173','1943-04-21');
INSERT INTO customer VALUES (334,'Serrong','Caitlyn','X',4,'88 Archibald Crt','Lucaston','NSW','8348',12,'(612)67318043','1968-02-11');
INSERT INTO customer VALUES (335,'Oaton','Anthony','Q',1,'13 Titshall Crt','Tottenham','QLD','8775',12,'(617)58438861','1966-08-01');
INSERT INTO customer VALUES (336,'Stribling','Belinda','Q',5,'129 Galti Crt','Greensborough','WA','5753',12,'(618)70653302','1943-04-04');
INSERT INTO customer VALUES (337,'Kinsala','Rochelle','A',4,'53 Marzalla St','Lemont','SA','8704',12,'(618)87023207','1981-02-03');
INSERT INTO customer VALUES (338,'Holdenson','David','U',1,'166 Mellili Pl','Underwood','TAS','8046',12,'(613)56848420','1955-02-11');
INSERT INTO customer VALUES (339,'Holdenson','Caitlyn','S',4,'89 Sears St','Lucknow','QLD','7832',12,'(617)87223488','1962-10-01');
INSERT INTO customer VALUES (340,'Dimitria','Betty','S',4,'167 Woodburne Cres','Nabawa','QLD','8637',12,'(617)85161555','1966-08-04');
INSERT INTO customer VALUES (341,'Eggelston','Peter','S',5,'55 Cassisi St','Legana','WA','6989',12,'(618)54171472','1971-01-26');
INSERT INTO customer VALUES (342,'Ritterman','Betty','N',4,'185 Mettaxus Crt','Broadmeadows','SA','6784',12,'(618)68231328','1974-12-11');
INSERT INTO customer VALUES (343,'Titshall','Penelope','H',4,'147 Galti Crt','Tara','TAS','5303',12,'(613)63641362','1943-04-21');
INSERT INTO customer VALUES (344,'Patton','Perry','C',1,'71 Titshall Rd','Greensborough','VIC','7048',12,'(613)61252000','1968-02-04');
INSERT INTO customer VALUES (345,'Cassisi','Derryn','',1,'36 Marzalla Cres','Doveton','TAS','8510',12,'(613)86247530','1971-01-26');
INSERT INTO customer VALUES (346,'Krennan','Perry','K',1,'16 Belcombe Pl','Belmont','VIC','6901',12,'(613)73645561','1974-12-11');
INSERT INTO customer VALUES (347,'Triskit','Kym','',4,'160 Oaton Cres','Huntly','NT','7228',12,'(618)86423062','1938-04-01');
INSERT INTO customer VALUES (348,'Woodestock','Michael','S',1,'30 Dimitria Crt','Chatswood','NT','7542',12,'(618)56657208','1962-02-24');
INSERT INTO customer VALUES (349,'Nancarral','Jasmine','M',4,'163 Sorrenti Pl','Murrabit','QLD','5649',12,'(617)60702138','1968-10-13');
INSERT INTO customer VALUES (350,'Mockridge','Caitlyn','K',4,'43 Sorrenti Pl','Rhodes','NT','5482',12,'(618)68460035','1967-01-11');
INSERT INTO customer VALUES (351,'Ritterman','Richard','',1,'167 Tonkin Ccl','Mininera','NT','6176',12,'(618)52315657','1938-04-01');
INSERT INTO customer VALUES (352,'Galti','Richard','S',1,'136 Woodburne St','Gray','TAS','8771',12,'(613)57744058','1943-04-04');
INSERT INTO customer VALUES (353,'Ritterman','Bronwyn','D',2,'52 Pattendon Cres','Hedley','QLD','6241',12,'(617)58670440','1955-11-22');
INSERT INTO customer VALUES (354,'Rosenthal','Martin','S',1,'60 Nancarral Crt','Earlwood','WA','7017',12,'(618)57503602','1980-02-11');
INSERT INTO customer VALUES (355,'Stribling','Sandra','E',2,'120 Nancarral Ln','Mohogany','SA','8985',12,'(618)78855613','1966-08-01');
INSERT INTO customer VALUES (356,'Dalion','Joel','S',5,'79 Dimitria Rd','Kidman','NSW','5779',12,'(612)73450616','1971-01-04');
INSERT INTO customer VALUES (357,'Triskit','Harry','Y',1,'33 Marzalla St','Milvale','TAS','8055',12,'(613)60148154','1962-10-13');
INSERT INTO customer VALUES (358,'Triskit','Andrew','W',1,'195 Woodburne Crt','Bauple','NT','5391',12,'(618)74045151','1974-12-11');
INSERT INTO customer VALUES (359,'Skerry','Belinda','A',4,'113 Lombardi Rd','Kadina','SA','7191',12,'(618)78520614','1981-26101');
INSERT INTO customer VALUES (360,'Cassisi','Joshua','S',1,'186 Stribling Rd','Singleton','VIC','5660',12,'(613)68106230','1971-01-04');
INSERT INTO customer VALUES (361,'Mockridge','James','P',1,'170 Taggendharf Pl','Portsea','NSW','6043',12,'(612)55017453','1967-01-26');
INSERT INTO customer VALUES (362,'Ruscina','Cynthia','S',2,'105 Florenini Ccl','Fitzroy','NT','6379',12,'(618)67703644','1974-12-11');
INSERT INTO customer VALUES (363,'Ruscina','Kym','J',2,'171 Mockridge Pl','Nareen','NT','5145',12,'(618)51532850','1943-04-21');
INSERT INTO customer VALUES (364,'Titshall','Samantha','V',4,'126 Barneshaw Pl','Alexandra','NSW','5324',12,'(612)85524740','1968-02-04');
INSERT INTO customer VALUES (365,'Dalion','Larry','R',1,'137 Mettaxus Ccl','Berala','TAS','6003',12,'(613)76410103','1966-08-26');
INSERT INTO customer VALUES (366,'Leramonth','Derryn','B',1,'99 Woodburne Ccl','Huntly','WA','8116',12,'(618)86780423','1974-12-11');
INSERT INTO customer VALUES (367,'Holdenson','Anthony','V',1,'152 Mellaseca Crt','Fernvale','WA','7382',12,'(618)56321486','1938-04-01');
INSERT INTO customer VALUES (368,'Titshall','Harry','R',1,'105 Titshall St','Singleton','NT','6376',12,'(618)51716212','1955-02-24');
INSERT INTO customer VALUES (369,'Rosenthal','Michelle','O',4,'122 Lombardi Ln','Halton','VIC','6715',12,'(613)73285035','1968-10-13');
INSERT INTO customer VALUES (370,'Sears','Michelle','O',2,'71 Holdenson Pl','Pambulah','NSW','6570',12,'(612)80051128','1966-08111');
INSERT INTO customer VALUES (371,'Mettaxus','Kym','M',2,'50 Tonkin St','Olinda','SA','7186',12,'(618)67138817','1971-01-01');
INSERT INTO customer VALUES (372,'Chemnis','Nicholas','C',1,'80 Rosenthal Ccl','Kalimna','WA','5953',12,'(618)86760854','1967-01-14');
INSERT INTO customer VALUES (373,'Pattendon','Michelle','R',4,'189 Tonkin Ln','Tottenham','QLD','7473',12,'(617)54022468','1943-04-21');
INSERT INTO customer VALUES (374,'Tonkin','Nicholas','Q',1,'187 Leramonth St','McLaren','VIC','7047',12,'(613)74073747','1968-02-11');
INSERT INTO customer VALUES (375,'Florenini','Nicholas','P',1,'135 Woodestock Pl','Legana','QLD','5996',12,'(617)87045888','1970-11-01');
INSERT INTO customer VALUES (376,'Oaton','Jim','P',1,'190 Sorrenti St','Mininera','WA','5250',12,'(618)55466816','1980-02-04');
INSERT INTO customer VALUES (377,'Keisling','Jacob','K',5,'45 Belcombe Pl','Kidman','NSW','8710',12,'(612)65600651','1943-04-04');
INSERT INTO customer VALUES (378,'Pattendon','Jasmine','',4,'46 Krennan Rd','Nabawa','WA','5102',12,'(618)66846221','1974-12-11');
INSERT INTO customer VALUES (379,'Sears','James','X',1,'133 Skerry Cres','Torquay','VIC','7630',12,'(613)62407041','1962-10-01');
INSERT INTO customer VALUES (380,'Galti','Marie','G',2,'157 Dimitria Pl','Nabawa','SA','5413',12,'(618)82162238','1966-08-04');
INSERT INTO customer VALUES (381,'Dimitria','Craig','X',1,'23 Mellaseca Ccl','Sunbury','WA','6123',12,'(618)63065251','1981-10-03');
INSERT INTO customer VALUES (382,'Mellaseca','Patty','W',2,'137 Keisling Ln','Underwood','SA','8711',12,'(618)52875731','1974-12-11');
INSERT INTO customer VALUES (383,'Mellili','Bronwyn','G',4,'137 Barneshaw Ln','Semaphore','SA','6695',12,'(618)88340614','1955-06-21');
INSERT INTO customer VALUES (384,'Woodburne','Lynette','O',2,'41 Krennan Ln','Westleigh','QLD','7225',12,'(617)76574850','1968-02-04');
INSERT INTO customer VALUES (385,'Ruscina','Kym','E',2,'191 Patton Rd','Mepunga','WA','6559',12,'(618)61662137','1966-08-26');
INSERT INTO customer VALUES (386,'Ritterman','David','B',1,'54 Chemnis Ln','Earlwood','NSW','5543',12,'(612)61502320','1971-01-11');
INSERT INTO customer VALUES (387,'Barneshaw','Anthony','H',1,'191 Keisling Pl','Huntly','NT','6587',12,'(618)73687436','1938-04-01');
INSERT INTO customer VALUES (388,'Pattendon','Jasmine','T',4,'121 Krennan St','Springfield','QLD','8793',12,'(617)68154087','1943-04-24');
INSERT INTO customer VALUES (389,'Patton','Joel','Z',1,'148 Nancarral Crt','Coonawarra','NT','5085',12,'(618)80142465','1968-10-13');
INSERT INTO customer VALUES (390,'Mellaseca','Harry','M',1,'34 Tonnibrook Crt','Ellendale','NSW','6583',12,'(612)78771153','1962-01-11');
INSERT INTO customer VALUES (391,'Taggendharf','Belinda','I',2,'106 Ritterman Rd','Alexandra','WA','8624',12,'(618)70273612','1938-04-01');
INSERT INTO customer VALUES (392,'Leramonth','Samantha','T',2,'66 Patton Cres','Mohogany','NSW','5468',12,'(612)78573744','1967-01-04');
INSERT INTO customer VALUES (393,'Florenini','Megan','M',2,'175 Serrong Pl','Gobur','VIC','6788',12,'(613)74607450','1943-04-21');
INSERT INTO customer VALUES (394,'Mellili','Megan','K',4,'46 Stribling Rd','Tabbita','TAS','5326',12,'(613)52447088','1968-02-11');
INSERT INTO customer VALUES (395,'Nancarral','Samantha','W',4,'26 Pattendon Pl','Longwood','WA','5983',12,'(618)63123108','1966-08-01');
INSERT INTO customer VALUES (396,'Belcombe','Lynette','F',4,'200 Woodestock Crt','Halton','NSW','5365',12,'(612)77860646','1943-04-04');
INSERT INTO customer VALUES (397,'Lombardi','Anthony','U',1,'25 Sorrenti Ccl','Montague','WA','6959',12,'(618)84570862','1970-11-26');
INSERT INTO customer VALUES (398,'Florenini','Melissa','Y',2,'145 Sorrenti Rd','Ellendale','NSW','5219',12,'(612)87771341','1980-02-11');
INSERT INTO customer VALUES (399,'Ritterman','Perry','J',1,'39 Woodburne Crt','Murrabit','TAS','7564',12,'(613)64242434','1962-10-01');
INSERT INTO customer VALUES (400,'Florenini','Karen','T',4,'56 Serrong Pl','Greensborough','NT','6695',12,'(618)52038114','1966-08-04');
INSERT INTO customer VALUES (401,'Tonkin','Melissa','V',2,'148 Chester Ccl','Lemont','QLD','7186',12,'(617)68034688','1971-01-26');
INSERT INTO customer VALUES (402,'Woodburne','Hugh','U',1,'174 Sears Crt','Kulpi','SA','7059',12,'(618)54247115','1974-12-11');
INSERT INTO customer VALUES (403,'Ruscina','Jacob','H',1,'122 Krennan Cres','Rhodes','NSW','7916',12,'(612)74123044','1981-02-21');
INSERT INTO customer VALUES (404,'Archibald','Kym','L',2,'46 Morfooney Crt','Seabrook','QLD','6698',12,'(617)51145060','1968-02-04');
INSERT INTO customer VALUES (405,'Morfooney','Bronwyn','X',2,'120 Galti St','Broadmeadows','NT','7838',12,'(618)54355607','1971-01-26');
INSERT INTO customer VALUES (406,'Mellaseca','George','K',1,'100 Lombardi Pl','Lemont','TAS','5076',12,'(613)63270843','1974-12-11');
INSERT INTO customer VALUES (407,'Mellili','Peter','R',1,'97 Keisling Ccl','Kalimna','NT','8823',12,'(618)55222168','1938-04-01');
INSERT INTO customer VALUES (408,'Patton','Joshua','Z',1,'172 Nancarral Ln','Athlone','NT','8174',12,'(618)60641242','1962-02-24');
INSERT INTO customer VALUES (409,'Cassisi','Marie','X',2,'117 Eggelston Cres','Huntly','QLD','7889',12,'(617)85400864','1968-10-13');
INSERT INTO customer VALUES (410,'Woodestock','Andrew','',1,'95 Mellaseca Ccl','Gobur','TAS','8053',12,'(613)76425843','1938-04-11');
INSERT INTO customer VALUES (411,'Woodestock','Derryn','V',1,'150 Mellaseca Ccl','Stormlea','WA','6831',12,'(618)65635781','1938-04-01');
INSERT INTO customer VALUES (412,'Leramonth','Rhiannon','F',4,'14 Belcombe Ccl','Essendon','TAS','8371',12,'(613)84450750','1967-01-04');
INSERT INTO customer VALUES (413,'Triskit','Horacio','C',1,'49 Florenini Ccl','Armidale','NSW','6643',12,'(612)58822374','1955-02-21');
INSERT INTO customer VALUES (414,'Keisling','Samantha','L',2,'91 Marzalla Ccl','Belmont','NSW','6042',12,'(612)56570501','1968-02-11');
INSERT INTO customer VALUES (415,'Pattendon','Rochelle','J',2,'12 Galti Ln','Milvale','NT','8788',12,'(618)64550016','1966-08-01');
INSERT INTO customer VALUES (416,'Sears','Sandra','E',4,'179 Titshall Pl','Chatswood','SA','7421',12,'(618)57238400','1971-01-14');
INSERT INTO customer VALUES (417,'Kinsala','Nicholas','J',1,'42 Barneshaw Ccl','St Albans','NT','5061',12,'(618)68063630','1943-04-04');
INSERT INTO customer VALUES (418,'Kinsala','Kym','I',5,'67 Sorrenti Pl','Underwood','SA','6613',12,'(618)87704343','1974-12-11');
INSERT INTO customer VALUES (419,'Chemnis','Lynette','N',5,'68 Holdenson Pl','Kidman','NSW','6251',12,'(612)52256537','1962-11-01');
INSERT INTO customer VALUES (420,'Florenini','Chris','Z',1,'64 Belcombe Cres','Seabrook','NSW','8781',12,'(612)81338830','1980-01-04');
INSERT INTO customer VALUES (421,'Ritterman','Joel','I',1,'179 Dalion Rd','Sunshine','SA','8061',12,'(618)60048710','1967-01-26');
INSERT INTO customer VALUES (422,'Florenini','Dimitria','',2,'7 Titshall Pl','Armidale','WA','8402',12,'(618)60631242','1974-12-11');
INSERT INTO customer VALUES (423,'Eggelston','Horacio','H',1,'61 Chemnis Pl','Lucaston','QLD','6367',12,'(617)62157875','1943-04-21');
INSERT INTO customer VALUES (424,'Keisling','Anna','G',4,'187 Marzalla Cres','Montague','WA','8961',12,'(618)67613484','1968-02-04');
INSERT INTO customer VALUES (425,'Morfooney','Jasmine','X',2,'80 Skerry Ln','Kulpi','SA','6312',12,'(618)52466628','1981-08-03');
INSERT INTO customer VALUES (426,'Barneshaw','Derryn','N',1,'79 Morfooney St','Lemont','VIC','6324',12,'(613)77225030','1974-12-11');
INSERT INTO customer VALUES (427,'Mellaseca','Perry','Q',1,'136 Chemnis Ln','Graman','WA','8557',12,'(618)87268117','1938-04-01');
INSERT INTO customer VALUES (428,'Mellili','Patty','L',4,'26 Florenini Rd','Graman','WA','7875',12,'(618)54426432','1955-02-24');
INSERT INTO customer VALUES (429,'Stribling','Melinda','B',4,'54 Lombardi Rd','Portsea','TAS','8575',12,'(613)50244777','1968-10-13');
INSERT INTO customer VALUES (430,'Dimitria','Harry','L',1,'132 Taggendharf Ccl','Colac','VIC','7116',12,'(613)65184760','1979-08-11');
INSERT INTO customer VALUES (431,'Keisling','Jim','Y',1,'99 Chemnis Cres','Underwood','NSW','7782',12,'(612)60177774','1970-03-01');
INSERT INTO customer VALUES (432,'Patton','Betty','B',4,'146 Triskit Ccl','Fitzroy','TAS','7890',12,'(613)81870268','1971-01-04');
INSERT INTO customer VALUES (433,'Dimitria','Jacob','Q',1,'130 Dalion St','Murrabit','WA','5481',12,'(618)65218820','1943-04-21');
INSERT INTO customer VALUES (434,'Morfooney','Richard','T',1,'158 Lombardi Crt','Doveton','SA','7501',12,'(618)52315848','1968-02-11');
INSERT INTO customer VALUES (435,'Dimitria','Joel','W',1,'132 Ritterman Rd','Singleton','QLD','8549',12,'(617)87131188','1966-08-01');
INSERT INTO customer VALUES (436,'Kinsala','George','R',1,'183 Tonkin St','Eleker','SA','6663',12,'(618)80471726','1971-01-04');
INSERT INTO customer VALUES (437,'Woodburne','Bronwyn','E',2,'43 Ritterman Cres','Doveton','NSW','5000',12,'(612)77275034','1943-04-04');
INSERT INTO customer VALUES (438,'Holdenson','Caitlyn','I',4,'160 Pattendon Cres','Sunshine','TAS','7913',12,'(613)60870221','1974-12-11');
INSERT INTO customer VALUES (439,'Chester','Jasmine','G',2,'155 Woodestock Rd','Lucknow','NSW','6654',12,'(612)73536510','1962-10-01');
INSERT INTO customer VALUES (440,'Marzalla','Marie','B',2,'81 Pattendon Pl','Culgoa','WA','6140',12,'(618)70328677','1966-08-04');
INSERT INTO customer VALUES (441,'Taggendharf','Marie','B',5,'192 Marzalla Crt','Ormond','WA','8448',12,'(618)86784674','1970-11-26');
INSERT INTO customer VALUES (442,'Holdenson','James','S',1,'76 Mellaseca Rd','Mohogany','TAS','7645',12,'(613)62472115','1980-02-11');
INSERT INTO customer VALUES (443,'Galti','Nicholas','Q',1,'98 Mettaxus Pl','Kalimna','VIC','7669',12,'(613)81713154','1943-04-21');
INSERT INTO customer VALUES (444,'Tonkin','Jacob','L',5,'177 Mellaseca St','Portsea','QLD','7636',12,'(617)81721770','1955-02-04');
INSERT INTO customer VALUES (445,'Dimitria','Karen','R',5,'116 Holdenson Rd','Torquay','VIC','8236',12,'(613)55336223','1966-08-26');
INSERT INTO customer VALUES (446,'Galti','Jim','B',1,'167 Skerry Cres','Broadmeadows','SA','7348',12,'(618)88242811','1974-12-11');
INSERT INTO customer VALUES (447,'Cassisi','Melinda','Z',2,'167 Skerry Cres','Culgoa','NT','8146',12,'(618)56131740','1981-10-01');
INSERT INTO customer VALUES (448,'Triskit','Larry','N',1,'9 Mellaseca St','Berala','WA','6590',12,'(618)72271367','1962-01-24');
INSERT INTO customer VALUES (449,'Patton','Penelope','L',2,'59 Patton Crt','Lucaston','SA','8286',12,'(618)71477042','1968-10-13');
INSERT INTO customer VALUES (450,'Mellaseca','Peter','C',1,'96 Eggelston Ln','Mohogany','QLD','8105',12,'(617)65214626','1965-08-11');
INSERT INTO customer VALUES (451,'Chemnis','Steven','R',1,'28 Cassisi Crt','Tabbita','QLD','6577',12,'(617)50863668','1938-04-01');
INSERT INTO customer VALUES (452,'Mettaxus','Derryn','B',1,'90 Mellaseca St','Evandale','QLD','7508',12,'(617)78505664','1971-01-04');
INSERT INTO customer VALUES (453,'Titshall','David','N',1,'128 Keisling Cres','Mepunga','WA','6154',12,'(618)75002787','1943-04-21');
INSERT INTO customer VALUES (454,'Leramonth','Caitlyn','P',4,'14 Mellili Ccl','Torquay','VIC','6070',12,'(613)57355415','1968-02-11');
INSERT INTO customer VALUES (455,'Nancarral','Samantha','S',4,'139 Florenini St','Kulpi','NT','8256',12,'(618)71286118','1966-08-01');
INSERT INTO customer VALUES (456,'Skerry','Richard','T',1,'42 Marzalla Rd','Culgoa','NT','6210',12,'(618)64010070','1943-04-04');
INSERT INTO customer VALUES (457,'Lombardi','Evonne','T',5,'191 Marzalla Pl','Nareen','WA','8434',12,'(618)64454372','1943-04-04');
INSERT INTO customer VALUES (458,'Lombardi','Megan','T',4,'85 Ruscina Ln','Montague','WA','5634',12,'(618)57855003','1974-12-11');
INSERT INTO customer VALUES (459,'Krennan','Rhiannon','Z',2,'112 Nancarral Cres','Tarneit','QLD','8947',12,'(617)80320313','1962-10-01');
INSERT INTO customer VALUES (460,'Ritterman','Larry','X',1,'119 Marzalla Ln','Greensborough','NT','7436',12,'(618)75853880','1955-08-14');
INSERT INTO customer VALUES (461,'Cassisi','Larry','M',1,'44 Mellaseca Pl','Tottenham','NSW','5577',12,'(612)63172677','1967-01-26');
INSERT INTO customer VALUES (462,'Rosenthal','William','C',1,'190 Chester Ln','Legana','NSW','5996',12,'(612)60357112','1974-12-11');
INSERT INTO customer VALUES (463,'Dalion','Melissa','T',2,'69 Lombardi Ccl','Semaphore','SA','8000',12,'(618)75767773','1970-11-21');
INSERT INTO customer VALUES (464,'Pattendon','Rhiannon','J',4,'74 Pattendon Rd','Lucknow','TAS','5218',12,'(613)57555477','1980-02-04');
INSERT INTO customer VALUES (465,'Mellaseca','Rhiannon','H',5,'100 Rosenthal Ccl','Doveton','NT','5579',12,'(618)53557482','1966-08-26');
INSERT INTO customer VALUES (466,'Galti','Hugh','M',1,'2 Ritterman Cres','Ellendale','VIC','7285',12,'(613)61000405','1974-12-11');
INSERT INTO customer VALUES (467,'Mockridge','Jasmine','T',2,'55 Keisling Pl','Sunshine','TAS','7308',12,'(613)61756664','1971-01-01');
INSERT INTO customer VALUES (468,'Mettaxus','Nicholas','B',1,'177 Tonkin Rd','Tabbita','TAS','6314',12,'(613)57134123','1962-02-24');
INSERT INTO customer VALUES (469,'Mettaxus','Jacob','',1,'54 Chemnis Crt','Vasey','VIC','7023',12,'(613)56787183','1981-02-03');
INSERT INTO customer VALUES (470,'Chester','Peter','U',1,'43 Serrong Pl','Athlone','WA','5117',12,'(618)80541363','1967-01-11');
INSERT INTO customer VALUES (471,'Barneshaw','Evonne','U',2,'118 Sorrenti Cres','Colac','WA','7497',12,'(618)53827807','1938-04-01');
INSERT INTO customer VALUES (472,'Mellili','Robyn','W',4,'133 Woodburne Ln','Umina','NSW','5581',12,'(612)86364665','1943-04-04');
INSERT INTO customer VALUES (473,'Sears','Steven','I',5,'13 Ritterman Crt','Kidman','VIC','5209',12,'(613)77414751','1971-01-22');
INSERT INTO customer VALUES (474,'Rosenthal','Robyn','P',5,'132 Leramonth St','Armidale','TAS','5161',12,'(613)83588718','1968-02-11');
INSERT INTO customer VALUES (475,'Tonnibrook','Belinda','T',4,'86 Patton St','Longwood','WA','6354',12,'(618)68027086','1955-08-01');
INSERT INTO customer VALUES (476,'Dimitria','Larry','B',1,'85 Keisling Rd','Montague','TAS','7819',12,'(613)82158211','1943-04-04');
INSERT INTO customer VALUES (477,'Mettaxus','Melinda','T',5,'35 Rosenthal Cres','Berala','WA','6982',12,'(618)50712016','1962-10-13');
INSERT INTO customer VALUES (478,'Dimitria','Martin','E',1,'94 Skerry St','Nareen','QLD','5252',12,'(617)53345865','1971-01-11');
INSERT INTO customer VALUES (479,'Sorrenti','Nicholas','',1,'11 Mockridge Crt','Gray','QLD','8353',12,'(617)70718711','1968-06-01');
INSERT INTO customer VALUES (480,'Patton','Joshua','B',1,'45 Taggendharf Pl','Tarneit','NT','5078',12,'(618)55012614','1966-08-04');
INSERT INTO customer VALUES (481,'Chester','Martin','E',5,'150 Krennan Pl','Langwarrin','WA','8980',12,'(618)78177372','1943-04-04');
INSERT INTO customer VALUES (482,'Sears','William','E',1,'197 Florenini Cres','Tottenham','QLD','6730',12,'(617)74843517','1971-01-11');
INSERT INTO customer VALUES (483,'Mellaseca','Anthony','A',1,'106 Woodestock Pl','Sunbury','VIC','5065',12,'(613)81826305','1943-04-21');
INSERT INTO customer VALUES (484,'Marzalla','Craig','B',1,'85 Woodestock Crt','Rhodes','QLD','6193',12,'(617)68501402','1968-02-04');
INSERT INTO customer VALUES (485,'Marzalla','Andrew','',1,'65 Belcombe Pl','Culgoa','NSW','7047',12,'(612)74850632','1970-11-26');
INSERT INTO customer VALUES (486,'Dimitria','Joshua','W',1,'192 Taggendharf Ln','Kidman','NSW','7693',12,'(612)58810333','1980-02-11');
INSERT INTO customer VALUES (487,'Kinsala','Derryn','Y',1,'97 Krennan Cres','Garvoc','NT','5773',12,'(618)76463131','1938-04-01');
INSERT INTO customer VALUES (488,'Keisling','Betty','L',4,'39 Serrong Rd','Earlwood','VIC','8445',12,'(613)58257303','1967-01-24');
INSERT INTO customer VALUES (489,'Sears','Melissa','R',2,'171 Florenini Ln','Garvoc','SA','5301',12,'(618)75000168','1968-10-01');
INSERT INTO customer VALUES (490,'Rosenthal','Kym','',4,'94 Barneshaw Ccl','Mepunga','NSW','5338',12,'(612)83886418','1955-08-11');
INSERT INTO customer VALUES (491,'Cassisi','Lynette','R',4,'136 Krennan Ln','Bentley','WA','8289',12,'(618)76836785','1981-10-01');
INSERT INTO customer VALUES (492,'Mellili','Hugh','R',1,'90 Archibald Ccl','Ormond','VIC','5207',12,'(613)88063560','1943-04-04');
INSERT INTO customer VALUES (493,'Marzalla','Melinda','R',2,'120 Marzalla Ccl','Doveton','WA','8489',12,'(618)65232061','1970-03-22');
INSERT INTO customer VALUES (494,'Woodburne','Dimitria','J',2,'65 Belcombe Cres','McLaren','NT','6109',12,'(618)63214788','1968-01-11');
INSERT INTO customer VALUES (495,'Ritterman','Rhiannon','E',5,'149 Tonnibrook Crt','Kadina','QLD','6187',12,'(617)68217074','1962-08-01');
INSERT INTO customer VALUES (496,'Rosenthal','Lynette','D',2,'70 Ruscina Ln','Evandale','NSW','8601',12,'(612)72240063','1943-04-04');
INSERT INTO customer VALUES (497,'Barneshaw','Jim','O',1,'59 Woodburne Cres','Gray','VIC','6277',12,'(613)71772403','1967-01-26');
INSERT INTO customer VALUES (498,'Lombardi','Cynthia','O',4,'19 Eggelston Cres','Langwarrin','WA','8962',12,'(618)54031172','1971-01-11');
INSERT INTO customer VALUES (499,'Marzalla','Karen','A',2,'117 Sears Ln','Milvale','NSW','6537',12,'(612)76827042','1968-10-01');
INSERT INTO customer VALUES (500,'Woodburne','Chris','D',1,'150 Keisling Rd','Richmond','WA','6761',12,'(618)78880340','1966-08-04');
INSERT INTO customer VALUES (501,'Belcombe','Andrew','D',1,'113 Tonkin Pl','Tarneit','SA','7293',12,'(618)58121107','1943-04-04');
INSERT INTO customer VALUES (502,'Serrong','Rhiannon','',4,'58 Rosenthal Pl','Graman','SA','5012',12,'(618)83408581','1974-12-11');
INSERT INTO customer VALUES (503,'Oaton','Joel','',1,'55 Kinsala St','Hedley','NSW','5249',12,'(612)78046500','1943-04-21');
INSERT INTO customer VALUES (504,'Eggelston','Joel','U',1,'195 Mockridge St','Kulpi','NSW','6629',12,'(612)72428778','1962-02-14');
INSERT INTO customer VALUES (505,'Nancarral','Larry','S',1,'173 Oaton Pl','Gray','WA','6390',12,'(618)74345416','1966-08-26');
INSERT INTO customer VALUES (506,'Archibald','Dimitria','Q',2,'78 Sorrenti Ln','Athlone','VIC','7860',12,'(613)50544575','1955-12-11');
INSERT INTO customer VALUES (507,'Patton','Anna','Y',2,'105 Chester Pl','Graman','WA','6014',12,'(618)75062450','1970-11-01');
INSERT INTO customer VALUES (508,'Ruscina','Joel','E',1,'58 Woodburne Crt','Legana','WA','6341',12,'(618)84713208','1980-06-24');
INSERT INTO customer VALUES (509,'Woodestock','Peter','A',1,'117 Skerry Ln','Singleton','NSW','8938',12,'(612)61874854','1968-01-01');
INSERT INTO customer VALUES (510,'Sorrenti','Joel','F',1,'167 Rosenthal Ccl','Fernvale','NSW','5554',12,'(612)63862287','1966-08-11');
INSERT INTO customer VALUES (511,'Florenini','Craig','A',1,'184 Chester Rd','Kidman','TAS','8610',12,'(613)77280811','1938-04-01');
INSERT INTO customer VALUES (512,'Keisling','Steven','L',1,'137 Mettaxus Crt','Pambulah','VIC','6552',12,'(613)84313326','1943-04-04');
INSERT INTO customer VALUES (513,'Lombardi','Michelle','',2,'92 Mellaseca Rd','Seabrook','QLD','8056',12,'(617)78780113','1981-01-23');
INSERT INTO customer VALUES (514,'Krennan','Caitlyn','F',4,'12 Mellaseca Ln','Milvale','TAS','7921',12,'(613)80182102','1968-02-11');
INSERT INTO customer VALUES (515,'Oaton','Michael','R',1,'53 Chemnis Ln','St Albans','NT','8049',12,'(618)52144573','1962-08-01');
INSERT INTO customer VALUES (516,'Patton','Joshua','Q',1,'58 Ruscina Pl','Berala','SA','8271',12,'(618)78504083','1943-04-04');
INSERT INTO customer VALUES (517,'Mellaseca','Penelope','C',2,'18 Cassisi Ln','St Albans','NSW','8634',12,'(612)78501314','1922-13-26');
INSERT INTO customer VALUES (518,'Taggendharf','Betty','A',4,'85 Kinsala Ccl','Chatswood','VIC','7050',12,'(613)51117220','1974-12-11');
INSERT INTO customer VALUES (519,'Pattendon','Patty','A',2,'47 Taggendharf Ln','Mininera','VIC','7816',12,'(613)52877687','1968-06-01');
INSERT INTO customer VALUES (520,'Mellaseca','William','U',1,'97 Mellaseca St','Kidman','SA','6876',12,'(618)84482847','1966-08-04');
INSERT INTO customer VALUES (521,'Marzalla','Steven','D',1,'4 Chemnis Crt','Evandale','WA','5459',12,'(618)50826342','1955-10-13');
INSERT INTO customer VALUES (522,'Holdenson','Hugh','W',1,'41 Rosenthal Ccl','Nabawa','TAS','6375',12,'(613)50103457','1974-12-11');
INSERT INTO customer VALUES (523,'Chester','Robyn','O',2,'161 Woodburne St','Stormlea','WA','6246',12,'(618)66568207','1943-04-21');
INSERT INTO customer VALUES (524,'Titshall','James','Q',1,'145 Patton Crt','Huntly','TAS','8785',12,'(613)65447587','1968-01-04');
INSERT INTO customer VALUES (525,'Skerry','Rhiannon','F',4,'115 Mellaseca Ln','Nyah','TAS','6990',12,'(613)64740458','1966-08-26');
INSERT INTO customer VALUES (526,'Galti','Horacio','X',1,'147 Krennan Ccl','Mininera','NSW','8222',12,'(612)80777002','1962-02-11');
INSERT INTO customer VALUES (527,'Sears','Evonne','L',4,'40 Mockridge Ln','Olinda','VIC','8626',12,'(613)70542848','1938-04-01');
INSERT INTO customer VALUES (528,'Barneshaw','Caitlyn','I',2,'1 Eggelston Pl','Coburg','VIC','5681',12,'(613)53362261','1971-01-24');
INSERT INTO customer VALUES (529,'Mockridge','Anna','E',2,'134 Archibald Pl','Belmont','VIC','6626',12,'(613)85313518','1968-11-26');
INSERT INTO customer VALUES (530,'Lombardi','Penelope','R',2,'99 Triskit Ln','Coburg','NT','8555',12,'(618)86843674','1980-06-11');
INSERT INTO customer VALUES (531,'Nancarral','Michelle','G',4,'193 Dimitria Ln','St Albans','SA','5469',12,'(618)62228183','1938-04-01');
INSERT INTO customer VALUES (532,'Morfooney','Chris','U',1,'89 Sears Ln','Umina','SA','6505',12,'(618)82424213','1943-04-04');
INSERT INTO customer VALUES (533,'Patton','Jacob','T',1,'12 Woodburne Cres','Belmont','SA','5838',12,'(618)58056286','1971-01-22');
INSERT INTO customer VALUES (534,'Cassisi','Rhiannon','F',2,'148 Galti Cres','Torquay','NSW','6904',12,'(612)81854583','1968-02-11');
INSERT INTO customer VALUES (535,'Woodburne','Hugh','F',1,'152 Nancarral Pl','Gobur','TAS','8450',12,'(613)61577630','1981-08-01');
INSERT INTO customer VALUES (536,'Florenini','Melinda','A',4,'175 Mettaxus St','Belmont','WA','7848',12,'(618)61538776','1955-02-04');
INSERT INTO customer VALUES (537,'Marzalla','James','C',1,'45 Mellili Rd','Bentley','TAS','7618',12,'(613)65713875','1962-10-13');
INSERT INTO customer VALUES (538,'Stribling','Horacio','E',1,'81 Woodestock Cres','Richmond','VIC','7832',12,'(613)74563543','1974-12-11');
INSERT INTO customer VALUES (539,'Holdenson','Marie','N',5,'21 Ruscina St','Athlone','SA','6039',12,'(618)71256155','1968-01-07');
INSERT INTO customer VALUES (540,'Archibald','Bronwyn','Q',4,'147 Lombardi Ln','Tabbita','NT','5590',12,'(618)50376011','1966-08-04');
INSERT INTO customer VALUES (541,'Woodburne','Nicholas','I',1,'24 Mettaxus Cres','Chatswood','NT','5552',12,'(618)78134828','1967-01-26');
INSERT INTO customer VALUES (542,'Keisling','Joel','I',1,'163 Kinsala Ln','Bentley','SA','5131',12,'(618)66545722','1974-12-11');
INSERT INTO customer VALUES (543,'Mockridge','Cynthia','P',2,'152 Morfooney Pl','Singleton','WA','8803',12,'(618)76728818','1971-01-21');
INSERT INTO customer VALUES (544,'Mettaxus','Robyn','L',4,'34 Taggendharf Pl','Gray','NT','7182',12,'(618)85462878','1968-02-04');
INSERT INTO customer VALUES (545,'Mellili','Bronwyn','N',2,'18 Stribling Ln','Westleigh','NT','7475',12,'(618)52237811','1966-08-26');
INSERT INTO customer VALUES (546,'Woodburne','Patty','',4,'124 Cassisi Ccl','Montague','SA','7890',12,'(618)53743654','1974-12-11');
INSERT INTO customer VALUES (547,'Mellili','Derryn','H',1,'54 Galti Ln','Portsea','VIC','7029',12,'(613)86223707','1938-04-01');
INSERT INTO customer VALUES (548,'Sorrenti','Horacio','O',1,'37 Pattendon Rd','Fernvale','NT','6731',12,'(618)55544438','1962-02-14');
INSERT INTO customer VALUES (549,'Sears','Rochelle','M',5,'150 Nancarral Cres','Mohogany','QLD','8435',12,'(617)88043727','1968-10-13');
INSERT INTO customer VALUES (550,'Florenini','Karen','Y',4,'135 Galti Pl','Broadmeadows','TAS','7392',12,'(613)67372606','1971-01-11');
INSERT INTO customer VALUES (551,'Skerry','Joel','',5,'153 Mellili Cres','Ormond','NSW','7753',12,'(612)53560730','1955-11-01');
INSERT INTO customer VALUES (552,'Skerry','Chris','U',1,'130 Chemnis Pl','Berala','NSW','7355',12,'(612)71367764','1980-06-04');
INSERT INTO customer VALUES (553,'Tonkin','Melinda','I',4,'198 Triskit Rd','Kalimna','NT','7603',12,'(618)83165861','1943-04-21');
INSERT INTO customer VALUES (554,'Dimitria','Anthony','J',1,'69 Serrong St','Armidale','NT','8986',12,'(618)68388260','1968-30-11');
INSERT INTO customer VALUES (555,'Stribling','George','N',1,'85 Galti Rd','Essendon','WA','5865',12,'(618)80463302','1971-01-01');
INSERT INTO customer VALUES (556,'Dimitria','Rochelle','I',2,'112 Mettaxus Pl','Stormlea','TAS','7103',12,'(613)54142581','1943-04-04');
INSERT INTO customer VALUES (557,'Kinsala','Rochelle','Z',2,'156 Mellaseca Crt','Nareen','WA','6710',12,'(618)85241378','1981-02-03');
INSERT INTO customer VALUES (558,'Belcombe','Marie','K',2,'50 Serrong Ccl','Lemont','QLD','7346',12,'(617)56023271','1974-12-11');
INSERT INTO customer VALUES (559,'Chemnis','Horacio','C',1,'1 Titshall Cres','Nareen','SA','8838',12,'(618)73088055','1962-01-01');
INSERT INTO customer VALUES (560,'Dimitria','Joshua','L',1,'187 Morfooney Crt','Garvoc','NT','7501',12,'(618)78000538','1966-08-04');
INSERT INTO customer VALUES (561,'Chemnis','Lynette','I',2,'150 Pattendon St','Seabrook','NSW','5670',12,'(612)77143827','1939-10-13');
INSERT INTO customer VALUES (562,'Keisling','Penelope','Y',4,'3 Titshall Rd','Kadina','TAS','5128',12,'(613)67266865','1974-12-11');
INSERT INTO customer VALUES (563,'Taggendharf','George','Q',1,'176 Pattendon Ln','Broadmeadows','SA','5707',12,'(618)56486553','1967-01-21');
INSERT INTO customer VALUES (564,'Pattendon','Patty','',4,'114 Pattendon Crt','Mepunga','NT','5332',12,'(618)57177880','1968-02-04');
INSERT INTO customer VALUES (565,'Woodestock','Joel','D',1,'147 Dalion Ln','McLaren','NSW','5641',12,'(612)65023622','1966-08-26');
INSERT INTO customer VALUES (566,'Keisling','Chris','S',1,'73 Cassisi Pl','Nyah','VIC','5548',12,'(613)76143770','1974-12-11');
INSERT INTO customer VALUES (567,'Archibald','Megan','S',2,'109 Taggendharf Ln','Belmont','VIC','5579',12,'(613)82330144','1955-10-01');
INSERT INTO customer VALUES (568,'Tonnibrook','Cynthia','U',2,'93 Archibald Pl','Vasey','TAS','6547',12,'(613)87738724','1943-04-24');
INSERT INTO customer VALUES (569,'Mockridge','Jacob','L',1,'112 Serrong Cres','Mohogany','QLD','5718',12,'(617)78246312','1968-10-13');
INSERT INTO customer VALUES (570,'Dimitria','Richard','H',1,'43 Mellili St','Underwood','WA','8673',12,'(618)78730306','1962-01-11');
INSERT INTO customer VALUES (571,'Mellaseca','Sandra','D',4,'2 Eggelston Pl','St Albans','NSW','7651',12,'(612)73464858','1938-04-01');
INSERT INTO customer VALUES (572,'Mellaseca','Peter','A',1,'178 Kinsala Pl','Nyah','SA','6537',12,'(618)50288566','1967-01-04');
INSERT INTO customer VALUES (573,'Sorrenti','Steven','J',1,'48 Morfooney Ln','Westleigh','NSW','8330',12,'(612)72027032','1970-11-21');
INSERT INTO customer VALUES (574,'Nancarral','Peter','Z',5,'140 Leramonth St','Greensborough','NT','6249',12,'(618)74231723','1980-01-11');
INSERT INTO customer VALUES (575,'Sears','Sandra','G',4,'195 Cassisi Crt','Coburg','SA','8126',12,'(618)76818846','1966-08-01');
INSERT INTO customer VALUES (576,'Marzalla','Perry','N',1,'183 Serrong Pl','Evandale','TAS','5037',12,'(613)82764087','1943-04-04');
INSERT INTO customer VALUES (577,'Nancarral','Marie','N',2,'70 Cassisi Crt','Montague','QLD','7020',12,'(617)88468637','1943-04-04');
INSERT INTO customer VALUES (578,'Dimitria','Robyn','Z',2,'73 Pattendon Rd','Hedley','TAS','6153',12,'(613)73210588','1974-12-11');
INSERT INTO customer VALUES (579,'Morfooney','Patty','X',2,'93 Barneshaw St','Hedley','NT','5688',12,'(618)51001815','1981-10-01');
INSERT INTO customer VALUES (580,'Eggelston','James','J',1,'84 Nancarral Crt','Underwood','QLD','5443',12,'(617)74414326','1966-08-04');
INSERT INTO customer VALUES (581,'Sears','Evonne','D',5,'110 Woodburne Ln','Fernvale','WA','5045',12,'(618)75010324','1943-04-02');
INSERT INTO customer VALUES (582,'Ritterman','Bronwyn','N',5,'7 Pattendon Ln','Fitzroy','TAS','7412',12,'(613)52307280','1955-02-11');
INSERT INTO customer VALUES (583,'Holdenson','Jasmine','F',2,'58 Kinsala Ln','Longwood','SA','6795',12,'(618)82080171','1967-01-21');
INSERT INTO customer VALUES (584,'Tonnibrook','George','D',1,'153 Serrong St','Gobur','TAS','8642',12,'(613)73254357','1968-02-04');
INSERT INTO customer VALUES (585,'Chemnis','Horacio','X',5,'187 Archibald Cres','Coburg','SA','8143',12,'(618)60773305','1966-08-03');
INSERT INTO customer VALUES (586,'Krennan','Mark','Q',1,'115 Patton Rd','Singleton','VIC','5654',12,'(613)55378261','1971-01-11');
INSERT INTO customer VALUES (587,'Oaton','Samantha','G',2,'98 Krennan Ln','Westleigh','QLD','5147',12,'(617)62604741','1938-04-01');
INSERT INTO customer VALUES (588,'Eggelston','Anthony','S',5,'91 Chemnis St','Berala','SA','5266',12,'(618)73606288','1943-04-24');
INSERT INTO customer VALUES (589,'Ritterman','James','N',1,'32 Taggendharf Rd','Portsea','TAS','6639',12,'(613)80055766','1968-10-13');
INSERT INTO customer VALUES (590,'Keisling','George','W',1,'88 Ruscina Rd','Kalimna','QLD','8438',12,'(617)73416706','1962-01-11');
INSERT INTO customer VALUES (591,'Kinsala','Jim','K',1,'133 Serrong Ln','Tabbita','QLD','8394',12,'(617)81118120','1938-04-01');
INSERT INTO customer VALUES (592,'Florenini','Melissa','Q',2,'55 Serrong St','Lucaston','NSW','8611',12,'(612)83134568','1965-10-14');
INSERT INTO customer VALUES (593,'Mellaseca','Nicholas','D',1,'14 Archibald Pl','Milvale','VIC','6421',12,'(613)83430515','1971-01-22');
INSERT INTO customer VALUES (594,'Ruscina','Mark','Z',1,'15 Pattendon Rd','Kalimna','WA','7314',12,'(618)85777577','1968-06-11');
INSERT INTO customer VALUES (595,'Keisling','Mark','E',1,'78 Taggendharf Rd','Springfield','WA','6460',12,'(618)64851473','1970-11-01');
INSERT INTO customer VALUES (596,'Patton','Kym','R',2,'190 Dalion Pl','Mepunga','NT','6379',12,'(618)63028174','1980-02-04');
INSERT INTO customer VALUES (597,'Galti','James','A',1,'167 Keisling Crt','Lucknow','SA','5205',12,'(618)62463586','1943-04-04');
INSERT INTO customer VALUES (598,'Ritterman','Perry','Q',1,'10 Krennan Ccl','Alexandra','WA','5845',12,'(618)58253322','1955-02-11');
INSERT INTO customer VALUES (599,'Eggelston','David','D',1,'36 Skerry St','Nyah','SA','6984',12,'(618)54707236','1968-10-01');
INSERT INTO customer VALUES (600,'Woodburne','Perry','O',1,'88 Cassisi Cres','Karumba','SA','6025',12,'(618)60521125','1966-08-04');
INSERT INTO customer VALUES (601,'Rosenthal','Karen','O',2,'190 Sears Pl','Alexandra','TAS','8023',12,'(613)58527662','1981-01-03');
INSERT INTO customer VALUES (602,'Leramonth','George','H',5,'122 Krennan Pl','McLaren','TAS','8580',12,'(613)64223438','1974-12-11');
INSERT INTO customer VALUES (603,'Tonnibrook','Chris','M',1,'18 Triskit Cres','Nareen','NT','6944',12,'(618)68762122','1943-04101');
INSERT INTO customer VALUES (604,'Barneshaw','Penelope','R',4,'36 Chester St','Umina','VIC','6144',12,'(613)81663822','1968-02-04');
INSERT INTO customer VALUES (605,'Ruscina','Kym','P',2,'136 Leramonth St','Eleker','WA','5131',12,'(618)60760085','1971-01-26');
INSERT INTO customer VALUES (606,'Mettaxus','Robyn','W',4,'77 Taggendharf Pl','Montague','SA','8793',12,'(618)87075235','1974-12-11');
INSERT INTO customer VALUES (607,'Dalion','Jim','D',1,'2 Belcombe Ln','Fitzroy','SA','6262',12,'(618)64836712','1938-04-01');
INSERT INTO customer VALUES (608,'Chester','Peter','V',5,'189 Taggendharf St','Alexandra','VIC','6437',12,'(613)82166210','1943-04-24');
INSERT INTO customer VALUES (609,'Sears','Caitlyn','G',2,'165 Mellili Crt','Bentley','NSW','8198',12,'(612)61511844','1968-10-13');
INSERT INTO customer VALUES (610,'Galti','Nicholas','Y',1,'163 Dimitria Ccl','Graman','VIC','5084',12,'(613)54523558','1966-08-11');
INSERT INTO customer VALUES (611,'Tonkin','Melinda','C',2,'72 Stribling Ln','Olinda','WA','7348',12,'(618)80105875','1938-04-01');
INSERT INTO customer VALUES (612,'Dimitria','Martin','F',1,'32 Keisling Pl','Kalimna','VIC','5598',12,'(613)70816381','1962-02-04');
INSERT INTO customer VALUES (613,'Mockridge','Lynette','W',5,'55 Holdenson Rd','Montague','SA','8263',12,'(618)66405581','1955-01-22');
INSERT INTO customer VALUES (614,'Tonkin','Melissa','D',2,'85 Tonnibrook Ccl','Garvoc','VIC','7070',12,'(613)63530037','1968-01-11');
INSERT INTO customer VALUES (615,'Morfooney','Perry','L',1,'84 Taggendharf St','Huntly','NT','8181',12,'(618)82123553','1966-08-01');
INSERT INTO customer VALUES (616,'Skerry','Lynette','Y',5,'11 Archibald Ccl','Berala','NSW','8001',12,'(612)52488518','1971-01-04');
INSERT INTO customer VALUES (617,'Sorrenti','Joel','T',1,'163 Rosenthal St','Colac','NT','8650',12,'(618)87576351','1970-11-01');
INSERT INTO customer VALUES (618,'Ruscina','Joshua','B',1,'65 Galti Rd','Bauple','VIC','8316',12,'(613)56470036','1980-02-11');
INSERT INTO customer VALUES (619,'Ruscina','Karen','K',4,'114 Nancarral Cres','Nareen','VIC','7013',12,'(613)78438784','1968-10-01');
INSERT INTO customer VALUES (620,'Florenini','Michelle','H',2,'196 Mellaseca St','Fitzroy','NT','5085',12,'(618)53884037','1971-01-04');
INSERT INTO customer VALUES (621,'Chester','Perry','S',1,'147 Eggelston Rd','Alexandra','NT','5354',12,'(618)64815524','1943-04-04');
INSERT INTO customer VALUES (622,'Serrong','Peter','Q',5,'170 Holdenson St','Essendon','VIC','7441',12,'(613)65661832','1974-12-11');
INSERT INTO customer VALUES (623,'Mockridge','Anthony','T',1,'120 Belcombe Ln','Tara','NSW','6964',12,'(612)62204054','1981-02-21');
INSERT INTO customer VALUES (624,'Kinsala','Caitlyn','N',4,'131 Ruscina Pl','Bentley','NSW','7470',12,'(612)80021501','1968-02-04');
INSERT INTO customer VALUES (625,'Lombardi','William','B',1,'7 Keisling St','Mininera','VIC','7012',12,'(613)51422013','1971-01-12');
INSERT INTO customer VALUES (626,'Woodburne','James','Q',1,'134 Chemnis Crt','Kidman','SA','7487',12,'(618)81802164','1974-12-11');
INSERT INTO customer VALUES (627,'Rosenthal','Jasmine','N',2,'187 Taggendharf Crt','Rhodes','WA','5193',12,'(618)58541255','1967-01-01');
INSERT INTO customer VALUES (628,'Oaton','Samantha','G',2,'142 Kinsala Pl','Greensborough','QLD','7346',12,'(617)88701573','1955-02-24');
INSERT INTO customer VALUES (629,'Sorrenti','Lynette','M',2,'130 Eggelston Cres','Sunbury','NSW','8477',12,'(612)65757214','1968-10-13');
INSERT INTO customer VALUES (630,'Archibald','Belinda','Q',2,'36 Florenini Ccl','Coonawarra','WA','8833',12,'(618)78101124','1966-08-11');
INSERT INTO customer VALUES (631,'Ruscina','Rochelle','K',2,'172 Morfooney Ln','Garvoc','NT','6080',12,'(618)58027027','1971-01-01');
INSERT INTO customer VALUES (632,'Mettaxus','Hugh','C',1,'165 Holdenson St','McLaren','NSW','5021',12,'(612)52374807','1943-04-04');
INSERT INTO customer VALUES (633,'Mellaseca','Horacio','X',1,'124 Mettaxus St','Athlone','NT','5062',12,'(618)60074577','1971-01-22');
INSERT INTO customer VALUES (634,'Pattendon','Lynette','Z',4,'77 Morfooney Rd','Tottenham','WA','6516',12,'(618)72402546','1962-02-11');
INSERT INTO customer VALUES (635,'Dalion','Steven','Q',1,'69 Tonnibrook Ccl','Lucaston','NT','6410',12,'(618)75105015','1971-01-01');
INSERT INTO customer VALUES (636,'Krennan','Harry','Q',1,'161 Galti Rd','Lucknow','TAS','7372',12,'(613)87255625','1967-01-14');
INSERT INTO customer VALUES (637,'Dalion','Bronwyn','H',4,'103 Holdenson Crt','Kidman','QLD','8867',12,'(617)88332246','1938-04-01');
INSERT INTO customer VALUES (638,'Oaton','Lynette','E',5,'188 Keisling Cres','Lucaston','NSW','6891',12,'(612)82503556','1974-12-11');
INSERT INTO customer VALUES (639,'Lombardi','Derryn','S',1,'26 Mockridge Ln','Mepunga','NT','6272',12,'(618)72200811','1968-11-01');
INSERT INTO customer VALUES (640,'Ritterman','Evonne','D',2,'57 Lombardi St','Armidale','NSW','6549',12,'(612)86885646','1966-08-04');
INSERT INTO customer VALUES (641,'Skerry','James','A',1,'164 Galti Ccl','Halton','NT','7444',12,'(618)53361482','1943-04-04');
INSERT INTO customer VALUES (642,'Dalion','Richard','E',1,'37 Kinsala St','Evandale','TAS','7188',12,'(613)75051408','1974-12-11');
INSERT INTO customer VALUES (643,'Taggendharf','Martin','A',1,'24 Rosenthal Pl','Westleigh','QLD','7492',12,'(617)74328363','1955-01-22');
INSERT INTO customer VALUES (644,'Keisling','Mark','O',1,'75 Barneshaw Crt','Portsea','NT','6207',12,'(618)73636150','1968-10-13');
INSERT INTO customer VALUES (645,'Holdenson','Bronwyn','C',2,'27 Mettaxus Pl','Earlwood','SA','8754',12,'(618)52873382','1966-08-26');
INSERT INTO customer VALUES (646,'Stribling','Michelle','Q',4,'75 Patton Rd','McLaren','VIC','8810',12,'(613)70463665','1943-04-04');
INSERT INTO customer VALUES (647,'Skerry','Samantha','J',2,'120 Eggelston Ln','Montague','NSW','8497',12,'(612)85133166','1943-04-04');
INSERT INTO customer VALUES (648,'Cassisi','Betty','Y',4,'115 Morfooney Ln','Montague','VIC','7192',12,'(613)63535037','1971-01-22');
INSERT INTO customer VALUES (649,'Krennan','Jim','D',1,'166 Kinsala St','Pambulah','QLD','5764',12,'(617)60001301','1943-04-04');
INSERT INTO customer VALUES (650,'Woodburne','Lynette','H',2,'98 Marzalla St','Alexandra','SA','8412',12,'(618)71264774','1943-04-04');


INSERT INTO grape_variety VALUES (1,'Riesling');
INSERT INTO grape_variety VALUES (2,'Chardonnay');
INSERT INTO grape_variety VALUES (3,'Sauvignon');
INSERT INTO grape_variety VALUES (4,'Blanc');
INSERT INTO grape_variety VALUES (5,'Semillon');
INSERT INTO grape_variety VALUES (6,'Pinot');
INSERT INTO grape_variety VALUES (7,'Gris');
INSERT INTO grape_variety VALUES (8,'Verdelho');
INSERT INTO grape_variety VALUES (9,'Grenache');
INSERT INTO grape_variety VALUES (10,'Noir');
INSERT INTO grape_variety VALUES (11,'Cabernet');
INSERT INTO grape_variety VALUES (12,'Shiraz');
INSERT INTO grape_variety VALUES (13,'Merlot');
INSERT INTO grape_variety VALUES (14,'Dessert');
INSERT INTO grape_variety VALUES (15,'Muscat');
INSERT INTO grape_variety VALUES (16,'Sherry');
INSERT INTO grape_variety VALUES (17,'Port');
INSERT INTO grape_variety VALUES (18,'Champagne');
INSERT INTO grape_variety VALUES (19,'Sparkling');
INSERT INTO grape_variety VALUES (20,'Red');
INSERT INTO grape_variety VALUES (21,'White');


INSERT INTO inventory VALUES (1,1,956,21.18,'040313');
INSERT INTO inventory VALUES (2,1,468,28.15,'040313');
INSERT INTO inventory VALUES (3,1,601,9.94,'040313');
INSERT INTO inventory VALUES (4,1,518,21.16,'040313');
INSERT INTO inventory VALUES (5,1,280,6.67,'040313');
INSERT INTO inventory VALUES (6,1,813,20.25,'040313');
INSERT INTO inventory VALUES (7,1,713,12.20,'040313');
INSERT INTO inventory VALUES (8,1,287,10.06,'040313');
INSERT INTO inventory VALUES (9,1,850,24.47,'040313');
INSERT INTO inventory VALUES (10,1,221,17.82,'040313');
INSERT INTO inventory VALUES (11,1,381,16.48,'040313');
INSERT INTO inventory VALUES (12,1,564,27.42,'040313');
INSERT INTO inventory VALUES (13,1,720,17.60,'040313');
INSERT INTO inventory VALUES (14,1,666,5.27,'040313');
INSERT INTO inventory VALUES (15,1,836,12.33,'040313');
INSERT INTO inventory VALUES (16,1,507,8.95,'040313');
INSERT INTO inventory VALUES (17,1,762,25.23,'040313');
INSERT INTO inventory VALUES (18,1,964,8.45,'040313');
INSERT INTO inventory VALUES (19,1,33,29.22,'040313');
INSERT INTO inventory VALUES (20,1,505,9.70,'040313');
INSERT INTO inventory VALUES (21,1,333,19.14,'040313');
INSERT INTO inventory VALUES (22,1,817,8.05,'040313');
INSERT INTO inventory VALUES (23,1,247,26.56,'040313');
INSERT INTO inventory VALUES (24,1,849,18.60,'040313');
INSERT INTO inventory VALUES (25,1,120,14.91,'040313');
INSERT INTO inventory VALUES (26,1,456,26.03,'040313');
INSERT INTO inventory VALUES (27,1,408,20.87,'040313');
INSERT INTO inventory VALUES (28,1,645,19.99,'040313');
INSERT INTO inventory VALUES (29,1,99,20.97,'040313');
INSERT INTO inventory VALUES (30,1,322,8.16,'040313');
INSERT INTO inventory VALUES (31,1,30,16.74,'040313');
INSERT INTO inventory VALUES (32,1,178,12.88,'040313');
INSERT INTO inventory VALUES (33,1,237,18.75,'040313');
INSERT INTO inventory VALUES (34,1,806,14.28,'040313');
INSERT INTO inventory VALUES (35,1,407,17.64,'040313');
INSERT INTO inventory VALUES (36,1,317,29.51,'040313');
INSERT INTO inventory VALUES (37,1,352,14.15,'040313');
INSERT INTO inventory VALUES (38,1,223,5.75,'040313');
INSERT INTO inventory VALUES (39,1,220,7.38,'040313');
INSERT INTO inventory VALUES (40,1,191,15.52,'040313');
INSERT INTO inventory VALUES (41,1,359,16.99,'040313');
INSERT INTO inventory VALUES (42,1,106,21.28,'040313');
INSERT INTO inventory VALUES (43,1,995,27.82,'040313');
INSERT INTO inventory VALUES (44,1,747,22.20,'040313');
INSERT INTO inventory VALUES (45,1,27,7.71,'040313');
INSERT INTO inventory VALUES (46,1,673,15.67,'040313');
INSERT INTO inventory VALUES (47,1,192,24.04,'040313');
INSERT INTO inventory VALUES (48,1,346,29.06,'040313');
INSERT INTO inventory VALUES (49,1,99,10.18,'040313');
INSERT INTO inventory VALUES (50,1,485,15.62,'040313');
INSERT INTO inventory VALUES (51,1,10,24.09,'040313');
INSERT INTO inventory VALUES (52,1,5,26.73,'040313');
INSERT INTO inventory VALUES (53,1,290,26.62,'040313');
INSERT INTO inventory VALUES (54,1,110,20.31,'040313');
INSERT INTO inventory VALUES (55,1,316,21.41,'040313');
INSERT INTO inventory VALUES (56,1,28,12.83,'040313');
INSERT INTO inventory VALUES (57,1,701,17.60,'040313');
INSERT INTO inventory VALUES (58,1,700,26.60,'040313');
INSERT INTO inventory VALUES (59,1,801,28.81,'040313');
INSERT INTO inventory VALUES (60,1,995,16.21,'040313');
INSERT INTO inventory VALUES (61,1,615,16.98,'040313');
INSERT INTO inventory VALUES (62,1,706,16.85,'040313');
INSERT INTO inventory VALUES (63,1,445,23.72,'040313');
INSERT INTO inventory VALUES (64,1,71,26.33,'040313');
INSERT INTO inventory VALUES (65,1,390,9.98,'040313');
INSERT INTO inventory VALUES (66,1,809,10.29,'040313');
INSERT INTO inventory VALUES (67,1,646,27.80,'040313');
INSERT INTO inventory VALUES (68,1,252,21.66,'040313');
INSERT INTO inventory VALUES (69,1,853,16.61,'040313');
INSERT INTO inventory VALUES (70,1,667,16.05,'040313');
INSERT INTO inventory VALUES (71,1,887,7.50,'040313');
INSERT INTO inventory VALUES (72,1,871,24.96,'040313');
INSERT INTO inventory VALUES (73,1,728,10.70,'040313');
INSERT INTO inventory VALUES (74,1,452,12.56,'040313');
INSERT INTO inventory VALUES (75,1,791,22.73,'040313');
INSERT INTO inventory VALUES (76,1,772,17.94,'040313');
INSERT INTO inventory VALUES (77,1,69,8.84,'040313');
INSERT INTO inventory VALUES (78,1,875,15.50,'040313');
INSERT INTO inventory VALUES (79,1,536,11.97,'040313');
INSERT INTO inventory VALUES (80,1,152,28.44,'040313');
INSERT INTO inventory VALUES (81,1,207,25.52,'040313');
INSERT INTO inventory VALUES (82,1,713,22.30,'040313');
INSERT INTO inventory VALUES (83,1,676,15.54,'040313');
INSERT INTO inventory VALUES (84,1,384,26.84,'040313');
INSERT INTO inventory VALUES (85,1,950,21.54,'040313');
INSERT INTO inventory VALUES (86,1,690,15.04,'040313');
INSERT INTO inventory VALUES (87,1,632,17.19,'040313');
INSERT INTO inventory VALUES (88,1,480,14.59,'040313');
INSERT INTO inventory VALUES (89,1,985,27.85,'040313');
INSERT INTO inventory VALUES (90,1,960,6.77,'040313');
INSERT INTO inventory VALUES (91,1,401,11.58,'040313');
INSERT INTO inventory VALUES (92,1,922,29.26,'040313');
INSERT INTO inventory VALUES (93,1,231,21.67,'040313');
INSERT INTO inventory VALUES (94,1,773,6.53,'040313');
INSERT INTO inventory VALUES (95,1,619,29.19,'040313');
INSERT INTO inventory VALUES (96,1,159,22.62,'040313');
INSERT INTO inventory VALUES (97,1,203,12.11,'040313');
INSERT INTO inventory VALUES (98,1,396,24.49,'040313');
INSERT INTO inventory VALUES (99,1,992,24.40,'040313');
INSERT INTO inventory VALUES (100,1,843,23.46,'040313');
INSERT INTO inventory VALUES (101,1,617,8.73,'040313');
INSERT INTO inventory VALUES (102,1,201,6.71,'040313');
INSERT INTO inventory VALUES (103,1,466,12.37,'040313');
INSERT INTO inventory VALUES (104,1,142,6.42,'040313');
INSERT INTO inventory VALUES (105,1,681,22.41,'040313');
INSERT INTO inventory VALUES (106,1,876,26.10,'040313');
INSERT INTO inventory VALUES (107,1,498,6.41,'040313');
INSERT INTO inventory VALUES (108,1,616,16.21,'040313');
INSERT INTO inventory VALUES (109,1,93,16.00,'040313');
INSERT INTO inventory VALUES (110,1,510,12.74,'040313');
INSERT INTO inventory VALUES (111,1,973,27.88,'040313');
INSERT INTO inventory VALUES (112,1,706,7.95,'040313');
INSERT INTO inventory VALUES (113,1,422,19.25,'040313');
INSERT INTO inventory VALUES (114,1,799,22.32,'040313');
INSERT INTO inventory VALUES (115,1,219,14.02,'040313');
INSERT INTO inventory VALUES (116,1,635,11.87,'040313');
INSERT INTO inventory VALUES (117,1,736,24.93,'040313');
INSERT INTO inventory VALUES (118,1,155,14.38,'040313');
INSERT INTO inventory VALUES (119,1,372,17.82,'040313');
INSERT INTO inventory VALUES (120,1,373,5.11,'040313');
INSERT INTO inventory VALUES (121,1,117,29.02,'040313');
INSERT INTO inventory VALUES (122,1,7,22.13,'040313');
INSERT INTO inventory VALUES (123,1,963,7.70,'040313');
INSERT INTO inventory VALUES (124,1,220,27.42,'040313');
INSERT INTO inventory VALUES (125,1,549,8.82,'040313');
INSERT INTO inventory VALUES (126,1,571,24.09,'040313');
INSERT INTO inventory VALUES (127,1,445,17.86,'040313');
INSERT INTO inventory VALUES (128,1,376,21.25,'040313');
INSERT INTO inventory VALUES (129,1,759,5.75,'040313');
INSERT INTO inventory VALUES (130,1,587,15.76,'040313');
INSERT INTO inventory VALUES (131,1,705,18.74,'040313');
INSERT INTO inventory VALUES (132,1,729,18.43,'040313');
INSERT INTO inventory VALUES (133,1,860,17.54,'040313');
INSERT INTO inventory VALUES (134,1,566,22.45,'040313');
INSERT INTO inventory VALUES (135,1,988,11.58,'040313');
INSERT INTO inventory VALUES (136,1,808,25.35,'040313');
INSERT INTO inventory VALUES (137,1,904,12.85,'040313');
INSERT INTO inventory VALUES (138,1,772,21.51,'040313');
INSERT INTO inventory VALUES (139,1,30,15.54,'040313');
INSERT INTO inventory VALUES (140,1,786,5.95,'040313');
INSERT INTO inventory VALUES (141,1,551,22.47,'040313');
INSERT INTO inventory VALUES (142,1,299,15.00,'040313');
INSERT INTO inventory VALUES (143,1,735,12.49,'040313');
INSERT INTO inventory VALUES (144,1,282,26.21,'040313');
INSERT INTO inventory VALUES (145,1,741,26.47,'040313');
INSERT INTO inventory VALUES (146,1,330,21.30,'040313');
INSERT INTO inventory VALUES (147,1,685,19.58,'040313');
INSERT INTO inventory VALUES (148,1,543,13.24,'040313');
INSERT INTO inventory VALUES (149,1,60,14.66,'040313');
INSERT INTO inventory VALUES (150,1,607,8.66,'040313');
INSERT INTO inventory VALUES (151,1,560,22.37,'040313');
INSERT INTO inventory VALUES (152,1,35,5.81,'040313');
INSERT INTO inventory VALUES (153,1,39,23.11,'040313');
INSERT INTO inventory VALUES (154,1,537,5.97,'040313');
INSERT INTO inventory VALUES (155,1,749,24.83,'040313');
INSERT INTO inventory VALUES (156,1,224,7.49,'040313');
INSERT INTO inventory VALUES (157,1,533,24.06,'040313');
INSERT INTO inventory VALUES (158,1,123,13.39,'040313');
INSERT INTO inventory VALUES (159,1,369,14.76,'040313');
INSERT INTO inventory VALUES (160,1,30,29.92,'040313');
INSERT INTO inventory VALUES (161,1,695,18.63,'040313');
INSERT INTO inventory VALUES (162,1,69,19.64,'040313');
INSERT INTO inventory VALUES (163,1,882,20.38,'040313');
INSERT INTO inventory VALUES (164,1,994,9.40,'040313');
INSERT INTO inventory VALUES (165,1,971,27.17,'040313');
INSERT INTO inventory VALUES (166,1,802,8.26,'040313');
INSERT INTO inventory VALUES (167,1,296,21.05,'040313');
INSERT INTO inventory VALUES (168,1,357,24.37,'040313');
INSERT INTO inventory VALUES (169,1,756,9.75,'040313');
INSERT INTO inventory VALUES (170,1,525,9.75,'040313');
INSERT INTO inventory VALUES (171,1,451,27.30,'040313');
INSERT INTO inventory VALUES (172,1,85,29.89,'040313');
INSERT INTO inventory VALUES (173,1,724,26.52,'040313');
INSERT INTO inventory VALUES (174,1,93,25.68,'040313');
INSERT INTO inventory VALUES (175,1,514,25.60,'040313');
INSERT INTO inventory VALUES (176,1,687,20.74,'040313');
INSERT INTO inventory VALUES (177,1,956,27.41,'040313');
INSERT INTO inventory VALUES (178,1,6,11.21,'040313');
INSERT INTO inventory VALUES (179,1,381,5.38,'040313');
INSERT INTO inventory VALUES (180,1,141,18.57,'040313');
INSERT INTO inventory VALUES (181,1,894,5.47,'040313');
INSERT INTO inventory VALUES (182,1,199,7.43,'040313');
INSERT INTO inventory VALUES (183,1,93,25.27,'040313');
INSERT INTO inventory VALUES (184,1,614,27.11,'040313');
INSERT INTO inventory VALUES (185,1,301,15.92,'040313');
INSERT INTO inventory VALUES (186,1,904,8.53,'040313');
INSERT INTO inventory VALUES (187,1,647,6.44,'040313');
INSERT INTO inventory VALUES (188,1,65,7.71,'040313');
INSERT INTO inventory VALUES (189,1,280,16.73,'040313');
INSERT INTO inventory VALUES (190,1,661,20.28,'040313');
INSERT INTO inventory VALUES (191,1,228,17.29,'040313');
INSERT INTO inventory VALUES (191,2,12,17.50,'040313');
INSERT INTO inventory VALUES (192,1,710,22.37,'040313');
INSERT INTO inventory VALUES (193,1,143,24.18,'040313');
INSERT INTO inventory VALUES (194,1,408,15.10,'040313');
INSERT INTO inventory VALUES (195,1,535,22.53,'040313');
INSERT INTO inventory VALUES (196,1,461,20.65,'040313');
INSERT INTO inventory VALUES (197,1,999,11.73,'040313');
INSERT INTO inventory VALUES (198,1,447,13.81,'040313');
INSERT INTO inventory VALUES (199,1,163,20.28,'040313');
INSERT INTO inventory VALUES (200,1,903,11.88,'040313');
INSERT INTO inventory VALUES (201,1,193,17.38,'040313');
INSERT INTO inventory VALUES (202,1,484,10.08,'040313');
INSERT INTO inventory VALUES (203,1,861,14.87,'040313');
INSERT INTO inventory VALUES (204,1,48,24.28,'040313');
INSERT INTO inventory VALUES (205,1,154,12.99,'040313');
INSERT INTO inventory VALUES (206,1,692,24.60,'040313');
INSERT INTO inventory VALUES (207,1,349,24.87,'040313');
INSERT INTO inventory VALUES (208,1,84,10.19,'040313');
INSERT INTO inventory VALUES (209,1,901,14.80,'040313');
INSERT INTO inventory VALUES (210,1,183,12.07,'040313');
INSERT INTO inventory VALUES (211,1,70,17.58,'040313');
INSERT INTO inventory VALUES (212,1,457,29.80,'040313');
INSERT INTO inventory VALUES (213,1,544,25.17,'040313');
INSERT INTO inventory VALUES (214,1,423,27.95,'040313');
INSERT INTO inventory VALUES (215,1,709,5.27,'040313');
INSERT INTO inventory VALUES (216,1,705,23.05,'040313');
INSERT INTO inventory VALUES (217,1,315,6.83,'040313');
INSERT INTO inventory VALUES (218,1,187,9.06,'040313');
INSERT INTO inventory VALUES (219,1,386,6.45,'040313');
INSERT INTO inventory VALUES (220,1,193,11.74,'040313');
INSERT INTO inventory VALUES (221,1,270,12.23,'040313');
INSERT INTO inventory VALUES (222,1,856,24.20,'040313');
INSERT INTO inventory VALUES (223,1,662,13.04,'040313');
INSERT INTO inventory VALUES (224,1,832,23.92,'040313');
INSERT INTO inventory VALUES (225,1,786,16.96,'040313');
INSERT INTO inventory VALUES (226,1,60,8.68,'040313');
INSERT INTO inventory VALUES (227,1,115,16.76,'040313');
INSERT INTO inventory VALUES (228,1,950,21.93,'040313');
INSERT INTO inventory VALUES (229,1,14,6.99,'040313');
INSERT INTO inventory VALUES (230,1,468,11.24,'040313');
INSERT INTO inventory VALUES (231,1,218,17.56,'040313');
INSERT INTO inventory VALUES (232,1,455,14.33,'040313');
INSERT INTO inventory VALUES (233,1,664,5.65,'040313');
INSERT INTO inventory VALUES (234,1,706,26.40,'040313');
INSERT INTO inventory VALUES (235,1,631,21.85,'040313');
INSERT INTO inventory VALUES (236,1,592,22.01,'040313');
INSERT INTO inventory VALUES (237,1,281,25.48,'040313');
INSERT INTO inventory VALUES (238,1,49,24.15,'040313');
INSERT INTO inventory VALUES (239,1,980,24.19,'040313');
INSERT INTO inventory VALUES (240,1,976,11.44,'040313');
INSERT INTO inventory VALUES (241,1,219,16.95,'040313');
INSERT INTO inventory VALUES (242,1,781,28.32,'040313');
INSERT INTO inventory VALUES (243,1,119,19.35,'040313');
INSERT INTO inventory VALUES (244,1,777,12.21,'040313');
INSERT INTO inventory VALUES (245,1,179,28.86,'040313');
INSERT INTO inventory VALUES (246,1,34,18.57,'040313');
INSERT INTO inventory VALUES (247,1,49,25.40,'040313');
INSERT INTO inventory VALUES (248,1,539,26.18,'040313');
INSERT INTO inventory VALUES (249,1,690,25.97,'040313');
INSERT INTO inventory VALUES (250,1,890,25.23,'040313');
INSERT INTO inventory VALUES (251,1,332,5.71,'040313');
INSERT INTO inventory VALUES (252,1,286,25.65,'040313');
INSERT INTO inventory VALUES (253,1,609,28.24,'040313');
INSERT INTO inventory VALUES (254,1,964,22.55,'040313');
INSERT INTO inventory VALUES (255,1,181,27.48,'040313');
INSERT INTO inventory VALUES (256,1,50,28.01,'040313');
INSERT INTO inventory VALUES (257,1,630,29.82,'040313');
INSERT INTO inventory VALUES (258,1,37,17.68,'040313');
INSERT INTO inventory VALUES (259,1,221,10.52,'040313');
INSERT INTO inventory VALUES (260,1,198,7.34,'040313');
INSERT INTO inventory VALUES (261,1,436,15.37,'040313');
INSERT INTO inventory VALUES (262,1,152,22.19,'040313');
INSERT INTO inventory VALUES (263,1,803,13.12,'040313');
INSERT INTO inventory VALUES (264,1,51,12.84,'040313');
INSERT INTO inventory VALUES (265,1,604,16.73,'040313');
INSERT INTO inventory VALUES (266,1,92,18.66,'040313');
INSERT INTO inventory VALUES (267,1,108,8.63,'040313');
INSERT INTO inventory VALUES (268,1,933,9.15,'040313');
INSERT INTO inventory VALUES (269,1,618,15.36,'040313');
INSERT INTO inventory VALUES (270,1,141,20.46,'040313');
INSERT INTO inventory VALUES (271,1,481,6.89,'040313');
INSERT INTO inventory VALUES (272,1,857,9.60,'040313');
INSERT INTO inventory VALUES (273,1,50,5.93,'040313');
INSERT INTO inventory VALUES (274,1,179,6.22,'040313');
INSERT INTO inventory VALUES (275,1,20,21.69,'040313');
INSERT INTO inventory VALUES (276,1,755,23.22,'040313');
INSERT INTO inventory VALUES (277,1,416,26.37,'040313');
INSERT INTO inventory VALUES (278,1,55,24.56,'040313');
INSERT INTO inventory VALUES (279,1,211,15.97,'040313');
INSERT INTO inventory VALUES (280,1,574,18.58,'040313');
INSERT INTO inventory VALUES (281,1,34,5.63,'040313');
INSERT INTO inventory VALUES (282,1,925,27.83,'040313');
INSERT INTO inventory VALUES (283,1,532,28.83,'040313');
INSERT INTO inventory VALUES (284,1,466,8.89,'040313');
INSERT INTO inventory VALUES (285,1,691,8.54,'040313');
INSERT INTO inventory VALUES (286,1,388,27.29,'040313');
INSERT INTO inventory VALUES (287,1,608,12.15,'040313');
INSERT INTO inventory VALUES (288,1,982,14.95,'040313');
INSERT INTO inventory VALUES (289,1,546,19.36,'040313');
INSERT INTO inventory VALUES (290,1,522,8.91,'040313');
INSERT INTO inventory VALUES (291,1,109,9.95,'040313');
INSERT INTO inventory VALUES (292,1,743,7.84,'040313');
INSERT INTO inventory VALUES (293,1,577,21.79,'040313');
INSERT INTO inventory VALUES (294,1,413,7.91,'040313');
INSERT INTO inventory VALUES (295,1,303,25.05,'040313');
INSERT INTO inventory VALUES (296,1,852,9.95,'040313');
INSERT INTO inventory VALUES (297,1,152,25.27,'040313');
INSERT INTO inventory VALUES (298,1,312,24.64,'040313');
INSERT INTO inventory VALUES (299,1,265,13.23,'040313');
INSERT INTO inventory VALUES (300,1,631,26.38,'040313');
INSERT INTO inventory VALUES (301,1,550,29.58,'040313');
INSERT INTO inventory VALUES (302,1,505,22.70,'040313');
INSERT INTO inventory VALUES (303,1,353,12.35,'040313');
INSERT INTO inventory VALUES (304,1,145,22.46,'040313');
INSERT INTO inventory VALUES (305,1,61,5.27,'040313');
INSERT INTO inventory VALUES (306,1,120,26.47,'040313');
INSERT INTO inventory VALUES (307,1,79,5.28,'040313');
INSERT INTO inventory VALUES (308,1,354,13.06,'040313');
INSERT INTO inventory VALUES (309,1,1,19.40,'040313');
INSERT INTO inventory VALUES (310,1,232,10.26,'040313');
INSERT INTO inventory VALUES (311,1,621,24.22,'040313');
INSERT INTO inventory VALUES (312,1,203,11.93,'040313');
INSERT INTO inventory VALUES (313,1,904,20.22,'040313');
INSERT INTO inventory VALUES (314,1,255,24.92,'040313');
INSERT INTO inventory VALUES (315,1,724,25.93,'040313');
INSERT INTO inventory VALUES (316,1,1,28.78,'040313');
INSERT INTO inventory VALUES (317,1,475,5.79,'040313');
INSERT INTO inventory VALUES (318,1,755,14.12,'040313');
INSERT INTO inventory VALUES (319,1,824,14.70,'040313');
INSERT INTO inventory VALUES (320,1,227,20.92,'040313');
INSERT INTO inventory VALUES (321,1,488,11.69,'040313');
INSERT INTO inventory VALUES (322,1,717,16.97,'040313');
INSERT INTO inventory VALUES (323,1,655,13.60,'040313');
INSERT INTO inventory VALUES (324,1,882,20.37,'040313');
INSERT INTO inventory VALUES (325,1,809,13.21,'040313');
INSERT INTO inventory VALUES (326,1,742,13.16,'040313');
INSERT INTO inventory VALUES (327,1,531,25.20,'040313');
INSERT INTO inventory VALUES (328,1,331,19.59,'040313');
INSERT INTO inventory VALUES (329,1,453,14.98,'040313');
INSERT INTO inventory VALUES (330,1,163,20.60,'040313');
INSERT INTO inventory VALUES (331,1,92,7.84,'040313');
INSERT INTO inventory VALUES (332,1,790,25.29,'040313');
INSERT INTO inventory VALUES (333,1,763,16.64,'040313');
INSERT INTO inventory VALUES (334,1,364,14.25,'040313');
INSERT INTO inventory VALUES (335,1,740,9.58,'040313');
INSERT INTO inventory VALUES (336,1,950,27.91,'040313');
INSERT INTO inventory VALUES (337,1,117,16.72,'040313');
INSERT INTO inventory VALUES (338,1,318,24.28,'040313');
INSERT INTO inventory VALUES (339,1,908,10.67,'040313');
INSERT INTO inventory VALUES (340,1,889,14.29,'040313');
INSERT INTO inventory VALUES (341,1,492,17.40,'040313');
INSERT INTO inventory VALUES (342,1,339,11.22,'040313');
INSERT INTO inventory VALUES (343,1,633,5.70,'040313');
INSERT INTO inventory VALUES (344,1,279,15.06,'040313');
INSERT INTO inventory VALUES (345,1,531,8.23,'040313');
INSERT INTO inventory VALUES (346,1,114,7.14,'040313');
INSERT INTO inventory VALUES (347,1,30,10.59,'040313');
INSERT INTO inventory VALUES (348,1,755,18.36,'040313');
INSERT INTO inventory VALUES (349,1,44,15.59,'040313');
INSERT INTO inventory VALUES (350,1,723,13.99,'040313');
INSERT INTO inventory VALUES (351,1,19,25.47,'040313');
INSERT INTO inventory VALUES (352,1,421,9.75,'040313');
INSERT INTO inventory VALUES (353,1,645,24.79,'040313');
INSERT INTO inventory VALUES (354,1,348,6.19,'040313');
INSERT INTO inventory VALUES (355,1,412,20.33,'040313');
INSERT INTO inventory VALUES (356,1,647,22.43,'040313');
INSERT INTO inventory VALUES (357,1,794,23.64,'040313');
INSERT INTO inventory VALUES (358,1,387,17.17,'040313');
INSERT INTO inventory VALUES (359,1,755,18.61,'040313');
INSERT INTO inventory VALUES (360,1,354,11.94,'040313');
INSERT INTO inventory VALUES (361,1,346,12.76,'040313');
INSERT INTO inventory VALUES (362,1,823,22.92,'040313');
INSERT INTO inventory VALUES (363,1,575,14.72,'040313');
INSERT INTO inventory VALUES (364,1,367,22.79,'040313');
INSERT INTO inventory VALUES (365,1,563,8.40,'040313');
INSERT INTO inventory VALUES (366,1,903,24.12,'040313');
INSERT INTO inventory VALUES (367,1,338,19.87,'040313');
INSERT INTO inventory VALUES (368,1,984,28.37,'040313');
INSERT INTO inventory VALUES (369,1,161,22.92,'040313');
INSERT INTO inventory VALUES (370,1,777,6.20,'040313');
INSERT INTO inventory VALUES (371,1,722,15.49,'040313');
INSERT INTO inventory VALUES (372,1,489,10.21,'040313');
INSERT INTO inventory VALUES (373,1,417,25.57,'040313');
INSERT INTO inventory VALUES (374,1,141,9.28,'040313');
INSERT INTO inventory VALUES (375,1,939,23.40,'040313');
INSERT INTO inventory VALUES (376,1,343,21.17,'040313');
INSERT INTO inventory VALUES (377,1,466,29.73,'040313');
INSERT INTO inventory VALUES (378,1,340,29.68,'040313');
INSERT INTO inventory VALUES (379,1,719,8.39,'040313');
INSERT INTO inventory VALUES (380,1,648,27.45,'040313');
INSERT INTO inventory VALUES (381,1,852,20.86,'040313');
INSERT INTO inventory VALUES (382,1,349,7.09,'040313');
INSERT INTO inventory VALUES (383,1,561,18.89,'040313');
INSERT INTO inventory VALUES (384,1,133,21.07,'040313');
INSERT INTO inventory VALUES (385,1,415,20.81,'040313');
INSERT INTO inventory VALUES (386,1,817,28.45,'040313');
INSERT INTO inventory VALUES (387,1,989,15.43,'040313');
INSERT INTO inventory VALUES (388,1,724,24.39,'040313');
INSERT INTO inventory VALUES (389,1,410,17.52,'040313');
INSERT INTO inventory VALUES (390,1,803,8.43,'040313');
INSERT INTO inventory VALUES (391,1,257,29.05,'040313');
INSERT INTO inventory VALUES (392,1,119,13.17,'040313');
INSERT INTO inventory VALUES (393,1,212,27.70,'040313');
INSERT INTO inventory VALUES (394,1,111,5.38,'040313');
INSERT INTO inventory VALUES (395,1,185,16.99,'040313');
INSERT INTO inventory VALUES (396,1,998,11.95,'040313');
INSERT INTO inventory VALUES (397,1,452,11.38,'040313');
INSERT INTO inventory VALUES (398,1,886,29.14,'040313');
INSERT INTO inventory VALUES (399,1,285,14.63,'040313');
INSERT INTO inventory VALUES (400,1,811,9.76,'040313');
INSERT INTO inventory VALUES (401,1,241,16.75,'040313');
INSERT INTO inventory VALUES (402,1,298,19.08,'040313');
INSERT INTO inventory VALUES (403,1,471,24.98,'040313');
INSERT INTO inventory VALUES (404,1,178,27.01,'040313');
INSERT INTO inventory VALUES (405,1,560,6.46,'040313');
INSERT INTO inventory VALUES (406,1,558,6.72,'040313');
INSERT INTO inventory VALUES (407,1,514,18.98,'040313');
INSERT INTO inventory VALUES (408,1,896,15.95,'040313');
INSERT INTO inventory VALUES (409,1,43,22.34,'040313');
INSERT INTO inventory VALUES (410,1,675,17.54,'040313');
INSERT INTO inventory VALUES (411,1,440,23.99,'040313');
INSERT INTO inventory VALUES (412,1,192,6.56,'040313');
INSERT INTO inventory VALUES (413,1,278,18.34,'040313');
INSERT INTO inventory VALUES (414,1,263,22.23,'040313');
INSERT INTO inventory VALUES (415,1,278,11.31,'040313');
INSERT INTO inventory VALUES (416,1,740,25.39,'040313');
INSERT INTO inventory VALUES (417,1,467,13.92,'040313');
INSERT INTO inventory VALUES (418,1,447,10.33,'040313');
INSERT INTO inventory VALUES (419,1,405,11.04,'040313');
INSERT INTO inventory VALUES (420,1,753,28.55,'040313');
INSERT INTO inventory VALUES (421,1,294,14.30,'040313');
INSERT INTO inventory VALUES (422,1,286,19.36,'040313');
INSERT INTO inventory VALUES (423,1,847,26.88,'040313');
INSERT INTO inventory VALUES (424,1,190,8.58,'040313');
INSERT INTO inventory VALUES (425,1,426,15.85,'040313');
INSERT INTO inventory VALUES (426,1,742,8.67,'040313');
INSERT INTO inventory VALUES (427,1,135,20.01,'040313');
INSERT INTO inventory VALUES (428,1,58,6.24,'040313');
INSERT INTO inventory VALUES (429,1,397,16.52,'040313');
INSERT INTO inventory VALUES (430,1,437,10.47,'040313');
INSERT INTO inventory VALUES (431,1,991,17.86,'040313');
INSERT INTO inventory VALUES (432,1,300,25.45,'040313');
INSERT INTO inventory VALUES (433,1,662,21.31,'040313');
INSERT INTO inventory VALUES (434,1,548,25.44,'040313');
INSERT INTO inventory VALUES (435,1,137,11.85,'040313');
INSERT INTO inventory VALUES (436,1,991,5.99,'040313');
INSERT INTO inventory VALUES (437,1,666,8.61,'040313');
INSERT INTO inventory VALUES (438,1,679,10.67,'040313');
INSERT INTO inventory VALUES (439,1,926,19.13,'040313');
INSERT INTO inventory VALUES (440,1,449,5.35,'040313');
INSERT INTO inventory VALUES (441,1,925,5.87,'040313');
INSERT INTO inventory VALUES (442,1,794,13.67,'040313');
INSERT INTO inventory VALUES (443,1,248,29.32,'040313');
INSERT INTO inventory VALUES (444,1,566,18.16,'040313');
INSERT INTO inventory VALUES (445,1,11,21.43,'040313');
INSERT INTO inventory VALUES (446,1,862,21.44,'040313');
INSERT INTO inventory VALUES (447,1,860,13.58,'040313');
INSERT INTO inventory VALUES (448,1,471,5.78,'040313');
INSERT INTO inventory VALUES (449,1,144,28.38,'040313');
INSERT INTO inventory VALUES (450,1,283,14.42,'040313');
INSERT INTO inventory VALUES (451,1,643,12.45,'040313');
INSERT INTO inventory VALUES (452,1,518,7.78,'040313');
INSERT INTO inventory VALUES (453,1,195,14.77,'040313');
INSERT INTO inventory VALUES (454,1,521,28.31,'040313');
INSERT INTO inventory VALUES (455,1,686,28.99,'040313');
INSERT INTO inventory VALUES (456,1,117,25.66,'040313');
INSERT INTO inventory VALUES (457,1,558,21.00,'040313');
INSERT INTO inventory VALUES (458,1,142,8.01,'040313');
INSERT INTO inventory VALUES (459,1,929,11.96,'040313');
INSERT INTO inventory VALUES (460,1,316,19.35,'040313');
INSERT INTO inventory VALUES (461,1,741,10.66,'040313');
INSERT INTO inventory VALUES (462,1,195,23.78,'040313');
INSERT INTO inventory VALUES (463,1,980,27.14,'040313');
INSERT INTO inventory VALUES (464,1,757,15.07,'040313');
INSERT INTO inventory VALUES (465,1,74,8.00,'040313');
INSERT INTO inventory VALUES (466,1,70,11.81,'040313');
INSERT INTO inventory VALUES (467,1,736,25.47,'040313');
INSERT INTO inventory VALUES (468,1,738,28.60,'040313');
INSERT INTO inventory VALUES (469,1,757,26.88,'040313');
INSERT INTO inventory VALUES (470,1,717,9.44,'040313');
INSERT INTO inventory VALUES (471,1,69,28.64,'040313');
INSERT INTO inventory VALUES (472,1,739,8.36,'040313');
INSERT INTO inventory VALUES (473,1,521,7.28,'040313');
INSERT INTO inventory VALUES (474,1,664,26.72,'040313');
INSERT INTO inventory VALUES (475,1,735,28.84,'040313');
INSERT INTO inventory VALUES (476,1,744,5.09,'040313');
INSERT INTO inventory VALUES (477,1,554,23.89,'040313');
INSERT INTO inventory VALUES (478,1,25,17.83,'040313');
INSERT INTO inventory VALUES (479,1,630,11.70,'040313');
INSERT INTO inventory VALUES (480,1,512,28.89,'040313');
INSERT INTO inventory VALUES (481,1,954,5.82,'040313');
INSERT INTO inventory VALUES (482,1,600,24.95,'040313');
INSERT INTO inventory VALUES (483,1,968,12.06,'040313');
INSERT INTO inventory VALUES (484,1,253,28.92,'040313');
INSERT INTO inventory VALUES (485,1,976,22.86,'040313');
INSERT INTO inventory VALUES (486,1,824,15.87,'040313');
INSERT INTO inventory VALUES (487,1,915,29.62,'040313');
INSERT INTO inventory VALUES (488,1,807,5.10,'040313');
INSERT INTO inventory VALUES (489,1,641,21.35,'040313');
INSERT INTO inventory VALUES (490,1,349,8.31,'040313');
INSERT INTO inventory VALUES (491,1,246,7.33,'040313');
INSERT INTO inventory VALUES (492,1,74,22.10,'040313');
INSERT INTO inventory VALUES (493,1,28,22.39,'040313');
INSERT INTO inventory VALUES (494,1,90,28.35,'040313');
INSERT INTO inventory VALUES (495,1,16,27.04,'040313');
INSERT INTO inventory VALUES (496,1,882,23.47,'040313');
INSERT INTO inventory VALUES (497,1,757,21.46,'040313');
INSERT INTO inventory VALUES (498,1,379,16.48,'040313');
INSERT INTO inventory VALUES (499,1,487,7.12,'040313');
INSERT INTO inventory VALUES (500,1,837,16.28,'040313');
INSERT INTO inventory VALUES (501,1,147,22.39,'040313');
INSERT INTO inventory VALUES (502,1,487,24.11,'040313');
INSERT INTO inventory VALUES (503,1,596,24.79,'040313');
INSERT INTO inventory VALUES (504,1,995,27.72,'040313');
INSERT INTO inventory VALUES (505,1,349,27.63,'040313');
INSERT INTO inventory VALUES (506,1,394,24.37,'040313');
INSERT INTO inventory VALUES (507,1,873,18.02,'040313');
INSERT INTO inventory VALUES (508,1,342,28.48,'040313');
INSERT INTO inventory VALUES (509,1,825,15.58,'040313');
INSERT INTO inventory VALUES (510,1,955,11.03,'040313');
INSERT INTO inventory VALUES (511,1,242,14.72,'040313');
INSERT INTO inventory VALUES (512,1,642,27.49,'040313');
INSERT INTO inventory VALUES (513,1,754,17.29,'040313');
INSERT INTO inventory VALUES (514,1,548,16.18,'040313');
INSERT INTO inventory VALUES (515,1,275,25.09,'040313');
INSERT INTO inventory VALUES (516,1,913,10.87,'040313');
INSERT INTO inventory VALUES (517,1,287,7.42,'040313');
INSERT INTO inventory VALUES (518,1,311,15.35,'040313');
INSERT INTO inventory VALUES (519,1,793,11.76,'040313');
INSERT INTO inventory VALUES (520,1,376,10.01,'040313');
INSERT INTO inventory VALUES (521,1,407,16.41,'040313');
INSERT INTO inventory VALUES (522,1,134,7.30,'040313');
INSERT INTO inventory VALUES (523,1,631,26.78,'040313');
INSERT INTO inventory VALUES (524,1,927,15.26,'040313');
INSERT INTO inventory VALUES (525,1,112,22.09,'040313');
INSERT INTO inventory VALUES (526,1,203,19.31,'040313');
INSERT INTO inventory VALUES (527,1,83,27.40,'040313');
INSERT INTO inventory VALUES (528,1,509,9.84,'040313');
INSERT INTO inventory VALUES (529,1,861,29.10,'040313');
INSERT INTO inventory VALUES (530,1,627,14.32,'040313');
INSERT INTO inventory VALUES (531,1,644,24.78,'040313');
INSERT INTO inventory VALUES (532,1,60,27.88,'040313');
INSERT INTO inventory VALUES (533,1,362,18.74,'040313');
INSERT INTO inventory VALUES (534,1,147,16.15,'040313');
INSERT INTO inventory VALUES (535,1,410,19.83,'040313');
INSERT INTO inventory VALUES (536,1,500,24.42,'040313');
INSERT INTO inventory VALUES (537,1,811,26.30,'040313');
INSERT INTO inventory VALUES (538,1,217,14.50,'040313');
INSERT INTO inventory VALUES (539,1,60,10.48,'040313');
INSERT INTO inventory VALUES (540,1,166,26.85,'040313');
INSERT INTO inventory VALUES (541,1,489,17.62,'040313');
INSERT INTO inventory VALUES (542,1,273,19.52,'040313');
INSERT INTO inventory VALUES (543,1,160,28.06,'040313');
INSERT INTO inventory VALUES (544,1,905,6.53,'040313');
INSERT INTO inventory VALUES (545,1,55,17.10,'040313');
INSERT INTO inventory VALUES (546,1,887,29.88,'040313');
INSERT INTO inventory VALUES (547,1,314,24.75,'040313');
INSERT INTO inventory VALUES (548,1,622,5.12,'040313');
INSERT INTO inventory VALUES (549,1,124,6.36,'040313');
INSERT INTO inventory VALUES (550,1,613,11.22,'040313');
INSERT INTO inventory VALUES (551,1,466,23.73,'040313');
INSERT INTO inventory VALUES (552,1,89,5.30,'040313');
INSERT INTO inventory VALUES (553,1,617,9.23,'040313');
INSERT INTO inventory VALUES (554,1,672,6.30,'040313');
INSERT INTO inventory VALUES (555,1,204,8.79,'040313');
INSERT INTO inventory VALUES (556,1,323,5.78,'040313');
INSERT INTO inventory VALUES (557,1,188,13.58,'040313');
INSERT INTO inventory VALUES (558,1,965,28.59,'040313');
INSERT INTO inventory VALUES (559,1,91,6.67,'040313');
INSERT INTO inventory VALUES (560,1,453,22.91,'040313');
INSERT INTO inventory VALUES (561,1,678,8.64,'040313');
INSERT INTO inventory VALUES (562,1,411,11.65,'040313');
INSERT INTO inventory VALUES (563,1,712,26.82,'040313');
INSERT INTO inventory VALUES (564,1,942,18.89,'040313');
INSERT INTO inventory VALUES (565,1,250,24.02,'040313');
INSERT INTO inventory VALUES (566,1,44,7.04,'040313');
INSERT INTO inventory VALUES (567,1,827,12.37,'040313');
INSERT INTO inventory VALUES (568,1,408,11.32,'040313');
INSERT INTO inventory VALUES (569,1,5,13.40,'040313');
INSERT INTO inventory VALUES (570,1,680,25.09,'040313');
INSERT INTO inventory VALUES (571,1,597,17.25,'040313');
INSERT INTO inventory VALUES (572,1,247,27.49,'040313');
INSERT INTO inventory VALUES (573,1,903,20.36,'040313');
INSERT INTO inventory VALUES (574,1,726,18.91,'040313');
INSERT INTO inventory VALUES (575,1,622,25.67,'040313');
INSERT INTO inventory VALUES (576,1,646,26.76,'040313');
INSERT INTO inventory VALUES (577,1,686,21.06,'040313');
INSERT INTO inventory VALUES (578,1,57,7.32,'040313');
INSERT INTO inventory VALUES (579,1,381,7.68,'040313');
INSERT INTO inventory VALUES (580,1,783,24.49,'040313');
INSERT INTO inventory VALUES (581,1,877,14.98,'040313');
INSERT INTO inventory VALUES (582,1,128,20.88,'040313');
INSERT INTO inventory VALUES (583,1,627,18.49,'040313');
INSERT INTO inventory VALUES (584,1,991,11.05,'040313');
INSERT INTO inventory VALUES (585,1,904,26.85,'040313');
INSERT INTO inventory VALUES (586,1,581,17.70,'040313');
INSERT INTO inventory VALUES (587,1,345,10.38,'040313');
INSERT INTO inventory VALUES (588,1,409,11.46,'040313');
INSERT INTO inventory VALUES (589,1,737,21.56,'040313');
INSERT INTO inventory VALUES (590,1,421,15.33,'040313');
INSERT INTO inventory VALUES (591,1,914,12.70,'040313');
INSERT INTO inventory VALUES (592,1,896,15.32,'040313');
INSERT INTO inventory VALUES (593,1,779,6.84,'040313');
INSERT INTO inventory VALUES (594,1,274,6.08,'040313');
INSERT INTO inventory VALUES (595,1,324,28.95,'040313');
INSERT INTO inventory VALUES (596,1,180,18.47,'040313');
INSERT INTO inventory VALUES (597,1,886,27.67,'040313');
INSERT INTO inventory VALUES (598,1,270,12.93,'040313');
INSERT INTO inventory VALUES (599,1,740,5.57,'040313');
INSERT INTO inventory VALUES (600,1,301,16.99,'040313');
INSERT INTO inventory VALUES (601,1,635,14.29,'040313');
INSERT INTO inventory VALUES (602,1,339,11.72,'040313');
INSERT INTO inventory VALUES (603,1,659,5.78,'040313');
INSERT INTO inventory VALUES (604,1,500,12.83,'040313');
INSERT INTO inventory VALUES (605,1,588,20.78,'040313');
INSERT INTO inventory VALUES (606,1,544,25.31,'040313');
INSERT INTO inventory VALUES (607,1,16,22.19,'040313');
INSERT INTO inventory VALUES (608,1,689,29.48,'040313');
INSERT INTO inventory VALUES (609,1,622,22.51,'040313');
INSERT INTO inventory VALUES (610,1,194,5.96,'040313');
INSERT INTO inventory VALUES (611,1,190,21.32,'040313');
INSERT INTO inventory VALUES (612,1,486,29.58,'040313');
INSERT INTO inventory VALUES (613,1,211,21.62,'040313');
INSERT INTO inventory VALUES (614,1,993,8.93,'040313');
INSERT INTO inventory VALUES (615,1,823,23.57,'040313');
INSERT INTO inventory VALUES (616,1,608,12.39,'040313');
INSERT INTO inventory VALUES (617,1,927,12.09,'040313');
INSERT INTO inventory VALUES (618,1,126,29.07,'040313');
INSERT INTO inventory VALUES (619,1,615,20.79,'040313');
INSERT INTO inventory VALUES (620,1,132,25.80,'040313');
INSERT INTO inventory VALUES (621,1,96,29.46,'040313');
INSERT INTO inventory VALUES (622,1,423,17.45,'040313');
INSERT INTO inventory VALUES (623,1,11,22.10,'040313');
INSERT INTO inventory VALUES (624,1,637,22.25,'040313');
INSERT INTO inventory VALUES (625,1,576,17.99,'040313');
INSERT INTO inventory VALUES (626,1,153,8.28,'040313');
INSERT INTO inventory VALUES (627,1,548,6.58,'040313');
INSERT INTO inventory VALUES (628,1,648,9.57,'040313');
INSERT INTO inventory VALUES (629,1,723,24.19,'040313');
INSERT INTO inventory VALUES (630,1,513,28.00,'040313');
INSERT INTO inventory VALUES (631,1,320,5.00,'040313');
INSERT INTO inventory VALUES (632,1,780,16.48,'040313');
INSERT INTO inventory VALUES (633,1,233,16.18,'040313');
INSERT INTO inventory VALUES (634,1,337,7.87,'040313');
INSERT INTO inventory VALUES (635,1,594,21.39,'040313');
INSERT INTO inventory VALUES (636,1,592,25.51,'040313');
INSERT INTO inventory VALUES (637,1,876,14.56,'040313');
INSERT INTO inventory VALUES (638,1,462,5.73,'040313');
INSERT INTO inventory VALUES (639,1,41,23.53,'040313');
INSERT INTO inventory VALUES (640,1,234,11.45,'040313');
INSERT INTO inventory VALUES (641,1,237,19.47,'040313');
INSERT INTO inventory VALUES (642,1,240,13.91,'040313');
INSERT INTO inventory VALUES (643,1,728,19.37,'040313');
INSERT INTO inventory VALUES (644,1,914,28.46,'040313');
INSERT INTO inventory VALUES (645,1,790,18.13,'040313');
INSERT INTO inventory VALUES (646,1,181,7.95,'040313');
INSERT INTO inventory VALUES (647,1,694,29.32,'040313');
INSERT INTO inventory VALUES (648,1,256,16.34,'040313');
INSERT INTO inventory VALUES (649,1,994,17.09,'040313');
INSERT INTO inventory VALUES (650,1,525,23.34,'040313');
INSERT INTO inventory VALUES (651,1,979,29.92,'040313');
INSERT INTO inventory VALUES (652,1,453,10.28,'040313');
INSERT INTO inventory VALUES (653,1,372,28.87,'040313');
INSERT INTO inventory VALUES (654,1,747,26.80,'040313');
INSERT INTO inventory VALUES (655,1,215,21.32,'040313');
INSERT INTO inventory VALUES (656,1,352,25.43,'040313');
INSERT INTO inventory VALUES (657,1,311,17.43,'040313');
INSERT INTO inventory VALUES (658,1,640,24.88,'040313');
INSERT INTO inventory VALUES (659,1,990,24.38,'040313');
INSERT INTO inventory VALUES (660,1,81,12.11,'040313');
INSERT INTO inventory VALUES (661,1,428,11.08,'040313');
INSERT INTO inventory VALUES (662,1,352,23.29,'040313');
INSERT INTO inventory VALUES (663,1,633,7.23,'040313');
INSERT INTO inventory VALUES (664,1,505,26.08,'040313');
INSERT INTO inventory VALUES (665,1,306,6.72,'040313');
INSERT INTO inventory VALUES (666,1,630,15.55,'040313');
INSERT INTO inventory VALUES (667,1,70,23.07,'040313');
INSERT INTO inventory VALUES (668,1,503,14.85,'040313');
INSERT INTO inventory VALUES (669,1,390,13.62,'040313');
INSERT INTO inventory VALUES (670,1,774,16.91,'040313');
INSERT INTO inventory VALUES (671,1,890,26.19,'040313');
INSERT INTO inventory VALUES (672,1,976,10.92,'040313');
INSERT INTO inventory VALUES (673,1,270,26.02,'040313');
INSERT INTO inventory VALUES (674,1,503,14.87,'040313');
INSERT INTO inventory VALUES (675,1,589,21.93,'040313');
INSERT INTO inventory VALUES (676,1,319,12.35,'040313');
INSERT INTO inventory VALUES (677,1,874,14.08,'040313');
INSERT INTO inventory VALUES (678,1,949,26.45,'040313');
INSERT INTO inventory VALUES (679,1,799,11.81,'040313');
INSERT INTO inventory VALUES (680,1,420,5.25,'040313');
INSERT INTO inventory VALUES (681,1,337,28.12,'040313');
INSERT INTO inventory VALUES (682,1,529,27.34,'040313');
INSERT INTO inventory VALUES (683,1,450,9.19,'040313');
INSERT INTO inventory VALUES (684,1,473,22.55,'040313');
INSERT INTO inventory VALUES (685,1,345,11.22,'040313');
INSERT INTO inventory VALUES (686,1,283,19.52,'040313');
INSERT INTO inventory VALUES (687,1,637,16.89,'040313');
INSERT INTO inventory VALUES (688,1,719,15.77,'040313');
INSERT INTO inventory VALUES (689,1,170,10.03,'040313');
INSERT INTO inventory VALUES (690,1,981,20.07,'040313');
INSERT INTO inventory VALUES (691,1,232,29.00,'040313');
INSERT INTO inventory VALUES (692,1,352,17.90,'040313');
INSERT INTO inventory VALUES (693,1,694,28.08,'040313');
INSERT INTO inventory VALUES (694,1,892,15.76,'040313');
INSERT INTO inventory VALUES (695,1,452,24.03,'040313');
INSERT INTO inventory VALUES (696,1,680,6.62,'040313');
INSERT INTO inventory VALUES (697,1,207,22.09,'040313');
INSERT INTO inventory VALUES (698,1,104,15.50,'040313');
INSERT INTO inventory VALUES (699,1,875,19.71,'040313');
INSERT INTO inventory VALUES (700,1,909,19.35,'040313');
INSERT INTO inventory VALUES (701,1,982,24.32,'040313');
INSERT INTO inventory VALUES (702,1,985,8.82,'040313');
INSERT INTO inventory VALUES (703,1,894,26.77,'040313');
INSERT INTO inventory VALUES (704,1,979,23.19,'040313');
INSERT INTO inventory VALUES (705,1,744,9.97,'040313');
INSERT INTO inventory VALUES (706,1,779,26.02,'040313');
INSERT INTO inventory VALUES (707,1,405,6.71,'040313');
INSERT INTO inventory VALUES (708,1,495,9.12,'040313');
INSERT INTO inventory VALUES (709,1,0,6.71,'040313');
INSERT INTO inventory VALUES (710,1,717,29.27,'040313');
INSERT INTO inventory VALUES (711,1,68,28.07,'040313');
INSERT INTO inventory VALUES (712,1,389,28.21,'040313');
INSERT INTO inventory VALUES (713,1,212,25.06,'040313');
INSERT INTO inventory VALUES (714,1,987,25.79,'040313');
INSERT INTO inventory VALUES (715,1,186,18.98,'040313');
INSERT INTO inventory VALUES (716,1,157,13.85,'040313');
INSERT INTO inventory VALUES (717,1,182,23.92,'040313');
INSERT INTO inventory VALUES (718,1,899,10.10,'040313');
INSERT INTO inventory VALUES (719,1,27,10.16,'040313');
INSERT INTO inventory VALUES (720,1,738,28.12,'040313');
INSERT INTO inventory VALUES (721,1,12,5.07,'040313');
INSERT INTO inventory VALUES (722,1,82,15.00,'040313');
INSERT INTO inventory VALUES (723,1,301,20.83,'040313');
INSERT INTO inventory VALUES (724,1,362,20.63,'040313');
INSERT INTO inventory VALUES (725,1,159,24.18,'040313');
INSERT INTO inventory VALUES (726,1,143,28.51,'040313');
INSERT INTO inventory VALUES (727,1,995,8.25,'040313');
INSERT INTO inventory VALUES (728,1,922,5.48,'040313');
INSERT INTO inventory VALUES (729,1,29,6.71,'040313');
INSERT INTO inventory VALUES (730,1,191,24.66,'040313');
INSERT INTO inventory VALUES (731,1,317,25.68,'040313');
INSERT INTO inventory VALUES (732,1,391,27.09,'040313');
INSERT INTO inventory VALUES (733,1,397,9.71,'040313');
INSERT INTO inventory VALUES (734,1,231,18.31,'040313');
INSERT INTO inventory VALUES (735,1,871,22.11,'040313');
INSERT INTO inventory VALUES (736,1,60,26.06,'040313');
INSERT INTO inventory VALUES (737,1,580,26.19,'040313');
INSERT INTO inventory VALUES (738,1,836,24.22,'040313');
INSERT INTO inventory VALUES (739,1,323,25.28,'040313');
INSERT INTO inventory VALUES (740,1,42,5.08,'040313');
INSERT INTO inventory VALUES (741,1,709,12.89,'040313');
INSERT INTO inventory VALUES (742,1,394,22.79,'040313');
INSERT INTO inventory VALUES (743,1,485,7.98,'040313');
INSERT INTO inventory VALUES (744,1,197,13.54,'040313');
INSERT INTO inventory VALUES (745,1,514,10.26,'040313');
INSERT INTO inventory VALUES (746,1,626,11.12,'040313');
INSERT INTO inventory VALUES (747,1,687,26.98,'040313');
INSERT INTO inventory VALUES (748,1,883,22.76,'040313');
INSERT INTO inventory VALUES (749,1,111,5.57,'040313');
INSERT INTO inventory VALUES (750,1,399,6.57,'040313');
INSERT INTO inventory VALUES (751,1,486,24.89,'040313');
INSERT INTO inventory VALUES (752,1,384,8.59,'040313');
INSERT INTO inventory VALUES (753,1,177,21.70,'040313');
INSERT INTO inventory VALUES (754,1,165,25.04,'040313');
INSERT INTO inventory VALUES (755,1,712,13.25,'040313');
INSERT INTO inventory VALUES (756,1,977,29.52,'040313');
INSERT INTO inventory VALUES (757,1,104,21.37,'040313');
INSERT INTO inventory VALUES (758,1,88,18.06,'040313');
INSERT INTO inventory VALUES (759,1,852,21.07,'040313');
INSERT INTO inventory VALUES (760,1,424,6.12,'040313');
INSERT INTO inventory VALUES (761,1,997,18.88,'040313');
INSERT INTO inventory VALUES (762,1,887,28.04,'040313');
INSERT INTO inventory VALUES (763,1,487,7.68,'040313');
INSERT INTO inventory VALUES (764,1,193,11.52,'040313');
INSERT INTO inventory VALUES (765,1,237,29.88,'040313');
INSERT INTO inventory VALUES (766,1,491,29.86,'040313');
INSERT INTO inventory VALUES (767,1,15,6.53,'040313');
INSERT INTO inventory VALUES (768,1,390,8.08,'040313');
INSERT INTO inventory VALUES (769,1,452,5.74,'040313');
INSERT INTO inventory VALUES (770,1,524,15.81,'040313');
INSERT INTO inventory VALUES (771,1,649,15.35,'040313');
INSERT INTO inventory VALUES (772,1,537,13.29,'040313');
INSERT INTO inventory VALUES (773,1,581,25.40,'040313');
INSERT INTO inventory VALUES (774,1,268,5.68,'040313');
INSERT INTO inventory VALUES (775,1,795,10.66,'040313');
INSERT INTO inventory VALUES (776,1,677,23.63,'040313');
INSERT INTO inventory VALUES (777,1,539,23.70,'040313');
INSERT INTO inventory VALUES (778,1,71,8.86,'040313');
INSERT INTO inventory VALUES (779,1,155,19.87,'040313');
INSERT INTO inventory VALUES (780,1,903,7.31,'040313');
INSERT INTO inventory VALUES (781,1,713,24.74,'040313');
INSERT INTO inventory VALUES (782,1,72,12.06,'040313');
INSERT INTO inventory VALUES (783,1,365,27.87,'040313');
INSERT INTO inventory VALUES (784,1,768,8.87,'040313');
INSERT INTO inventory VALUES (785,1,449,28.11,'040313');
INSERT INTO inventory VALUES (786,1,118,20.84,'040313');
INSERT INTO inventory VALUES (787,1,754,9.59,'040313');
INSERT INTO inventory VALUES (788,1,460,10.73,'040313');
INSERT INTO inventory VALUES (789,1,326,14.31,'040313');
INSERT INTO inventory VALUES (790,1,203,12.43,'040313');
INSERT INTO inventory VALUES (791,1,515,5.19,'040313');
INSERT INTO inventory VALUES (792,1,262,6.49,'040313');
INSERT INTO inventory VALUES (793,1,330,16.37,'040313');
INSERT INTO inventory VALUES (794,1,206,10.52,'040313');
INSERT INTO inventory VALUES (795,1,84,21.46,'040313');
INSERT INTO inventory VALUES (796,1,202,24.09,'040313');
INSERT INTO inventory VALUES (797,1,50,18.25,'040313');
INSERT INTO inventory VALUES (798,1,645,29.48,'040313');
INSERT INTO inventory VALUES (799,1,376,13.87,'040313');
INSERT INTO inventory VALUES (800,1,696,18.16,'040313');
INSERT INTO inventory VALUES (801,1,128,5.17,'040313');
INSERT INTO inventory VALUES (802,1,323,12.24,'040313');
INSERT INTO inventory VALUES (803,1,817,20.69,'040313');
INSERT INTO inventory VALUES (804,1,193,25.90,'040313');
INSERT INTO inventory VALUES (805,1,717,28.56,'040313');
INSERT INTO inventory VALUES (806,1,187,8.34,'040313');
INSERT INTO inventory VALUES (807,1,277,9.87,'040313');
INSERT INTO inventory VALUES (808,1,530,25.86,'040313');
INSERT INTO inventory VALUES (809,1,16,9.19,'040313');
INSERT INTO inventory VALUES (810,1,891,27.71,'040313');
INSERT INTO inventory VALUES (811,1,58,5.75,'040313');
INSERT INTO inventory VALUES (812,1,231,13.05,'040313');
INSERT INTO inventory VALUES (813,1,480,9.68,'040313');
INSERT INTO inventory VALUES (814,1,173,13.52,'040313');
INSERT INTO inventory VALUES (815,1,76,6.44,'040313');
INSERT INTO inventory VALUES (816,1,639,11.57,'040313');
INSERT INTO inventory VALUES (817,1,982,18.75,'040313');
INSERT INTO inventory VALUES (818,1,857,6.57,'040313');
INSERT INTO inventory VALUES (819,1,727,7.77,'040313');
INSERT INTO inventory VALUES (820,1,917,29.66,'040313');
INSERT INTO inventory VALUES (821,1,631,5.69,'040313');
INSERT INTO inventory VALUES (822,1,384,11.03,'040313');
INSERT INTO inventory VALUES (823,1,440,23.20,'040313');
INSERT INTO inventory VALUES (824,1,127,28.56,'040313');
INSERT INTO inventory VALUES (825,1,654,29.63,'040313');
INSERT INTO inventory VALUES (826,1,103,20.90,'040313');
INSERT INTO inventory VALUES (827,1,679,20.44,'040313');
INSERT INTO inventory VALUES (828,1,431,16.51,'040313');
INSERT INTO inventory VALUES (829,1,6,10.60,'040313');
INSERT INTO inventory VALUES (830,1,780,8.58,'040313');
INSERT INTO inventory VALUES (831,1,449,23.61,'040313');
INSERT INTO inventory VALUES (832,1,142,8.88,'040313');
INSERT INTO inventory VALUES (833,1,182,19.63,'040313');
INSERT INTO inventory VALUES (834,1,386,22.56,'040313');
INSERT INTO inventory VALUES (835,1,949,14.56,'040313');
INSERT INTO inventory VALUES (836,1,588,16.19,'040313');
INSERT INTO inventory VALUES (837,1,489,8.82,'040313');
INSERT INTO inventory VALUES (838,1,932,19.30,'040313');
INSERT INTO inventory VALUES (839,1,446,19.50,'040313');
INSERT INTO inventory VALUES (840,1,48,14.63,'040313');
INSERT INTO inventory VALUES (841,1,629,25.38,'040313');
INSERT INTO inventory VALUES (842,1,248,28.53,'040313');
INSERT INTO inventory VALUES (843,1,136,8.11,'040313');
INSERT INTO inventory VALUES (844,1,774,18.82,'040313');
INSERT INTO inventory VALUES (845,1,335,16.18,'040313');
INSERT INTO inventory VALUES (846,1,895,6.65,'040313');
INSERT INTO inventory VALUES (847,1,95,18.79,'040313');
INSERT INTO inventory VALUES (848,1,917,17.37,'040313');
INSERT INTO inventory VALUES (849,1,219,28.96,'040313');
INSERT INTO inventory VALUES (850,1,727,29.32,'040313');
INSERT INTO inventory VALUES (851,1,361,20.13,'040313');
INSERT INTO inventory VALUES (852,1,750,26.09,'040313');
INSERT INTO inventory VALUES (853,1,281,29.23,'040313');
INSERT INTO inventory VALUES (854,1,394,24.75,'040313');
INSERT INTO inventory VALUES (855,1,216,7.23,'040313');
INSERT INTO inventory VALUES (856,1,401,5.29,'040313');
INSERT INTO inventory VALUES (857,1,54,7.84,'040313');
INSERT INTO inventory VALUES (858,1,853,5.33,'040313');
INSERT INTO inventory VALUES (859,1,229,10.26,'040313');
INSERT INTO inventory VALUES (860,1,189,29.24,'040313');
INSERT INTO inventory VALUES (861,1,514,13.85,'040313');
INSERT INTO inventory VALUES (862,1,653,6.71,'040313');
INSERT INTO inventory VALUES (863,1,747,13.71,'040313');
INSERT INTO inventory VALUES (864,1,980,23.48,'040313');
INSERT INTO inventory VALUES (865,1,739,29.58,'040313');
INSERT INTO inventory VALUES (866,1,972,14.59,'040313');
INSERT INTO inventory VALUES (867,1,268,15.68,'040313');
INSERT INTO inventory VALUES (868,1,117,11.70,'040313');
INSERT INTO inventory VALUES (869,1,451,17.93,'040313');
INSERT INTO inventory VALUES (870,1,718,22.89,'040313');
INSERT INTO inventory VALUES (871,1,965,10.22,'040313');
INSERT INTO inventory VALUES (872,1,823,26.29,'040313');
INSERT INTO inventory VALUES (873,1,541,20.65,'040313');
INSERT INTO inventory VALUES (874,1,254,19.40,'040313');
INSERT INTO inventory VALUES (875,1,737,13.36,'040313');
INSERT INTO inventory VALUES (876,1,326,12.73,'040313');
INSERT INTO inventory VALUES (877,1,917,19.15,'040313');
INSERT INTO inventory VALUES (878,1,605,22.43,'040313');
INSERT INTO inventory VALUES (879,1,309,8.93,'040313');
INSERT INTO inventory VALUES (880,1,247,26.62,'040313');
INSERT INTO inventory VALUES (881,1,147,25.83,'040313');
INSERT INTO inventory VALUES (882,1,369,21.69,'040313');
INSERT INTO inventory VALUES (883,1,666,9.30,'040313');
INSERT INTO inventory VALUES (884,1,318,16.89,'040313');
INSERT INTO inventory VALUES (885,1,719,9.22,'040313');
INSERT INTO inventory VALUES (886,1,87,17.53,'040313');
INSERT INTO inventory VALUES (887,1,821,15.10,'040313');
INSERT INTO inventory VALUES (888,1,977,5.78,'040313');
INSERT INTO inventory VALUES (889,1,408,13.92,'040313');
INSERT INTO inventory VALUES (890,1,343,19.78,'040313');
INSERT INTO inventory VALUES (891,1,972,23.60,'040313');
INSERT INTO inventory VALUES (892,1,810,7.25,'040313');
INSERT INTO inventory VALUES (893,1,509,24.44,'040313');
INSERT INTO inventory VALUES (894,1,818,7.88,'040313');
INSERT INTO inventory VALUES (895,1,717,25.06,'040313');
INSERT INTO inventory VALUES (896,1,946,27.56,'040313');
INSERT INTO inventory VALUES (897,1,476,22.99,'040313');
INSERT INTO inventory VALUES (898,1,577,22.02,'040313');
INSERT INTO inventory VALUES (899,1,366,7.35,'040313');
INSERT INTO inventory VALUES (900,1,294,16.94,'040313');
INSERT INTO inventory VALUES (901,1,79,15.67,'040313');
INSERT INTO inventory VALUES (902,1,687,10.77,'040313');
INSERT INTO inventory VALUES (903,1,942,23.54,'040313');
INSERT INTO inventory VALUES (904,1,384,18.63,'040313');
INSERT INTO inventory VALUES (905,1,268,11.44,'040313');
INSERT INTO inventory VALUES (906,1,332,10.33,'040313');
INSERT INTO inventory VALUES (907,1,901,22.05,'040313');
INSERT INTO inventory VALUES (908,1,893,11.74,'040313');
INSERT INTO inventory VALUES (909,1,914,21.84,'040313');
INSERT INTO inventory VALUES (910,1,273,28.29,'040313');
INSERT INTO inventory VALUES (911,1,217,5.71,'040313');
INSERT INTO inventory VALUES (912,1,894,22.94,'040313');
INSERT INTO inventory VALUES (913,1,673,21.68,'040313');
INSERT INTO inventory VALUES (914,1,221,5.23,'040313');
INSERT INTO inventory VALUES (915,1,856,12.51,'040313');
INSERT INTO inventory VALUES (916,1,298,20.73,'040313');
INSERT INTO inventory VALUES (917,1,634,18.43,'040313');
INSERT INTO inventory VALUES (918,1,686,15.70,'040313');
INSERT INTO inventory VALUES (919,1,432,13.35,'040313');
INSERT INTO inventory VALUES (920,1,279,20.28,'040313');
INSERT INTO inventory VALUES (921,1,573,25.30,'040313');
INSERT INTO inventory VALUES (922,1,286,23.00,'040313');
INSERT INTO inventory VALUES (923,1,228,14.64,'040313');
INSERT INTO inventory VALUES (924,1,909,20.67,'040313');
INSERT INTO inventory VALUES (925,1,148,16.97,'040313');
INSERT INTO inventory VALUES (926,1,663,24.60,'040313');
INSERT INTO inventory VALUES (927,1,399,15.13,'040313');
INSERT INTO inventory VALUES (928,1,833,7.56,'040313');
INSERT INTO inventory VALUES (929,1,542,18.90,'040313');
INSERT INTO inventory VALUES (930,1,894,25.51,'040313');
INSERT INTO inventory VALUES (931,1,181,14.34,'040313');
INSERT INTO inventory VALUES (932,1,484,21.07,'040313');
INSERT INTO inventory VALUES (933,1,489,27.47,'040313');
INSERT INTO inventory VALUES (934,1,139,25.09,'040313');
INSERT INTO inventory VALUES (935,1,817,28.56,'040313');
INSERT INTO inventory VALUES (936,1,793,20.34,'040313');
INSERT INTO inventory VALUES (937,1,400,5.75,'040313');
INSERT INTO inventory VALUES (938,1,538,26.85,'040313');
INSERT INTO inventory VALUES (939,1,103,14.37,'040313');
INSERT INTO inventory VALUES (940,1,7,12.18,'040313');
INSERT INTO inventory VALUES (941,1,525,16.57,'040313');
INSERT INTO inventory VALUES (942,1,874,28.23,'040313');
INSERT INTO inventory VALUES (943,1,947,16.13,'040313');
INSERT INTO inventory VALUES (944,1,419,19.94,'040313');
INSERT INTO inventory VALUES (945,1,512,15.89,'040313');
INSERT INTO inventory VALUES (946,1,80,9.51,'040313');
INSERT INTO inventory VALUES (947,1,424,19.53,'040313');
INSERT INTO inventory VALUES (948,1,178,8.38,'040313');
INSERT INTO inventory VALUES (949,1,28,10.77,'040313');
INSERT INTO inventory VALUES (950,1,407,11.06,'040313');
INSERT INTO inventory VALUES (951,1,595,24.53,'040313');
INSERT INTO inventory VALUES (952,1,165,21.48,'040313');
INSERT INTO inventory VALUES (953,1,404,19.93,'040313');
INSERT INTO inventory VALUES (954,1,539,5.51,'040313');
INSERT INTO inventory VALUES (955,1,481,18.91,'040313');
INSERT INTO inventory VALUES (956,1,379,20.11,'040313');
INSERT INTO inventory VALUES (957,1,894,5.70,'040313');
INSERT INTO inventory VALUES (958,1,427,10.83,'040313');
INSERT INTO inventory VALUES (959,1,810,10.07,'040313');
INSERT INTO inventory VALUES (960,1,587,21.31,'040313');
INSERT INTO inventory VALUES (961,1,652,10.08,'040313');
INSERT INTO inventory VALUES (962,1,186,15.72,'040313');
INSERT INTO inventory VALUES (963,1,675,25.32,'040313');
INSERT INTO inventory VALUES (964,1,608,13.33,'040313');
INSERT INTO inventory VALUES (965,1,125,25.85,'040313');
INSERT INTO inventory VALUES (966,1,41,10.45,'040313');
INSERT INTO inventory VALUES (967,1,152,7.48,'040313');
INSERT INTO inventory VALUES (968,1,857,18.69,'040313');
INSERT INTO inventory VALUES (969,1,694,13.93,'040313');
INSERT INTO inventory VALUES (970,1,768,28.57,'040313');
INSERT INTO inventory VALUES (971,1,86,19.81,'040313');
INSERT INTO inventory VALUES (972,1,172,24.21,'040313');
INSERT INTO inventory VALUES (973,1,902,16.02,'040313');
INSERT INTO inventory VALUES (974,1,223,6.37,'040313');
INSERT INTO inventory VALUES (975,1,554,9.20,'040313');
INSERT INTO inventory VALUES (976,1,409,10.41,'040313');
INSERT INTO inventory VALUES (977,1,868,14.51,'040313');
INSERT INTO inventory VALUES (978,1,355,10.05,'040313');
INSERT INTO inventory VALUES (979,1,49,28.39,'040313');
INSERT INTO inventory VALUES (980,1,980,22.32,'040313');
INSERT INTO inventory VALUES (981,1,553,24.90,'040313');
INSERT INTO inventory VALUES (982,1,366,28.67,'040313');
INSERT INTO inventory VALUES (983,1,583,26.11,'040313');
INSERT INTO inventory VALUES (984,1,609,6.17,'040313');
INSERT INTO inventory VALUES (985,1,983,20.34,'040313');
INSERT INTO inventory VALUES (986,1,189,6.56,'040313');
INSERT INTO inventory VALUES (987,1,603,27.94,'040313');
INSERT INTO inventory VALUES (988,1,122,11.17,'040313');
INSERT INTO inventory VALUES (989,1,173,12.09,'040313');
INSERT INTO inventory VALUES (990,1,565,12.78,'040313');
INSERT INTO inventory VALUES (991,1,888,26.56,'040313');
INSERT INTO inventory VALUES (992,1,792,10.51,'040313');
INSERT INTO inventory VALUES (993,1,465,24.37,'040313');
INSERT INTO inventory VALUES (994,1,583,15.44,'040313');
INSERT INTO inventory VALUES (995,1,754,14.08,'040313');
INSERT INTO inventory VALUES (996,1,103,19.12,'040313');
INSERT INTO inventory VALUES (997,1,672,9.03,'040313');
INSERT INTO inventory VALUES (998,1,613,12.30,'040313');
INSERT INTO inventory VALUES (999,1,784,17.61,'040313');
INSERT INTO inventory VALUES (1000,1,879,6.91,'040313');
INSERT INTO inventory VALUES (1001,1,666,28.76,'040313');
INSERT INTO inventory VALUES (1002,1,232,23.97,'040313');
INSERT INTO inventory VALUES (1003,1,750,9.77,'040313');
INSERT INTO inventory VALUES (1004,1,122,24.18,'040313');
INSERT INTO inventory VALUES (1005,1,572,18.57,'040313');
INSERT INTO inventory VALUES (1006,1,654,20.16,'040313');
INSERT INTO inventory VALUES (1007,1,778,12.34,'040313');
INSERT INTO inventory VALUES (1008,1,812,28.65,'040313');
INSERT INTO inventory VALUES (1009,1,112,22.13,'040313');
INSERT INTO inventory VALUES (1010,1,728,19.18,'040313');
INSERT INTO inventory VALUES (1011,1,639,11.12,'040313');
INSERT INTO inventory VALUES (1012,1,400,17.85,'040313');
INSERT INTO inventory VALUES (1013,1,377,10.04,'040313');
INSERT INTO inventory VALUES (1014,1,154,13.82,'040313');
INSERT INTO inventory VALUES (1015,1,340,28.35,'040313');
INSERT INTO inventory VALUES (1016,1,918,19.99,'040313');
INSERT INTO inventory VALUES (1017,1,79,14.30,'040313');
INSERT INTO inventory VALUES (1018,1,425,9.22,'040313');
INSERT INTO inventory VALUES (1019,1,81,12.93,'040313');
INSERT INTO inventory VALUES (1020,1,219,5.51,'040313');
INSERT INTO inventory VALUES (1021,1,404,21.77,'040313');
INSERT INTO inventory VALUES (1022,1,526,6.25,'040313');
INSERT INTO inventory VALUES (1023,1,378,15.49,'040313');
INSERT INTO inventory VALUES (1024,1,424,19.85,'040313');
INSERT INTO inventory VALUES (1025,1,249,28.78,'040313');
INSERT INTO inventory VALUES (1026,1,606,26.36,'040313');
INSERT INTO inventory VALUES (1027,1,600,28.73,'040313');
INSERT INTO inventory VALUES (1028,1,902,13.90,'040313');
INSERT INTO inventory VALUES (1029,1,127,15.19,'040313');
INSERT INTO inventory VALUES (1030,1,60,21.21,'040313');
INSERT INTO inventory VALUES (1031,1,578,6.87,'040313');
INSERT INTO inventory VALUES (1032,1,349,19.93,'040313');
INSERT INTO inventory VALUES (1033,1,606,29.37,'040313');
INSERT INTO inventory VALUES (1034,1,98,14.96,'040313');
INSERT INTO inventory VALUES (1035,1,950,20.89,'040313');
INSERT INTO inventory VALUES (1036,1,733,11.74,'040313');
INSERT INTO inventory VALUES (1037,1,101,26.67,'040313');
INSERT INTO inventory VALUES (1038,1,834,23.02,'040313');
INSERT INTO inventory VALUES (1039,1,743,26.46,'040313');
INSERT INTO inventory VALUES (1040,1,942,28.12,'040313');
INSERT INTO inventory VALUES (1041,1,159,17.18,'040313');
INSERT INTO inventory VALUES (1042,1,34,26.76,'040313');
INSERT INTO inventory VALUES (1043,1,968,16.73,'040313');
INSERT INTO inventory VALUES (1044,1,339,19.12,'040313');
INSERT INTO inventory VALUES (1045,1,302,18.76,'040313');
INSERT INTO inventory VALUES (1046,1,196,11.00,'040313');
INSERT INTO inventory VALUES (1047,1,940,13.85,'040313');
INSERT INTO inventory VALUES (1048,1,614,9.60,'040313');

INSERT INTO items VALUES (1,1,1,888,2,11.56);
INSERT INTO items VALUES (1,2,1,206,3,73.80);
INSERT INTO items VALUES (1,2,2,517,12,81.62);
INSERT INTO items VALUES (1,2,3,521,3,49.23);
INSERT INTO items VALUES (1,2,4,332,3,75.87);
INSERT INTO items VALUES (1,2,5,225,3,50.88);
INSERT INTO items VALUES (1,2,6,697,2,44.18);
INSERT INTO items VALUES (1,3,1,706,1,26.02);
INSERT INTO items VALUES (1,3,2,390,3,25.29);
INSERT INTO items VALUES (1,4,1,883,12,102.30);
INSERT INTO items VALUES (1,4,2,460,2,38.70);
INSERT INTO items VALUES (1,4,3,842,12,313.83);
INSERT INTO items VALUES (1,4,4,965,1,25.85);
INSERT INTO items VALUES (1,4,5,559,1,6.67);
INSERT INTO items VALUES (2,1,1,636,12,280.61);
INSERT INTO items VALUES (2,1,2,57,3,52.80);
INSERT INTO items VALUES (2,1,3,178,3,33.63);
INSERT INTO items VALUES (2,2,1,652,12,113.08);
INSERT INTO items VALUES (2,2,2,105,12,246.51);
INSERT INTO items VALUES (2,2,3,731,1,25.68);
INSERT INTO items VALUES (2,2,4,919,12,146.85);
INSERT INTO items VALUES (2,3,1,801,12,56.87);
INSERT INTO items VALUES (2,3,2,224,2,47.84);
INSERT INTO items VALUES (2,3,3,696,2,13.24);
INSERT INTO items VALUES (2,3,4,49,12,111.98);
INSERT INTO items VALUES (2,3,5,882,1,21.69);
INSERT INTO items VALUES (2,4,1,1031,12,75.57);
INSERT INTO items VALUES (2,5,1,46,2,31.34);
INSERT INTO items VALUES (2,5,2,380,2,54.90);
INSERT INTO items VALUES (2,5,3,90,1,6.77);
INSERT INTO items VALUES (2,5,4,260,2,14.68);
INSERT INTO items VALUES (2,5,5,521,12,180.51);
INSERT INTO items VALUES (2,5,6,593,3,20.52);
INSERT INTO items VALUES (3,1,1,706,12,286.22);
INSERT INTO items VALUES (3,1,2,615,3,70.71);
INSERT INTO items VALUES (3,1,3,988,2,22.34);
INSERT INTO items VALUES (3,1,4,507,12,198.22);
INSERT INTO items VALUES (3,2,1,327,1,25.20);
INSERT INTO items VALUES (3,2,2,458,3,24.03);
INSERT INTO items VALUES (3,3,1,526,1,19.31);
INSERT INTO items VALUES (3,4,1,227,3,50.28);
INSERT INTO items VALUES (3,5,1,964,2,26.66);
INSERT INTO items VALUES (3,5,2,153,1,23.11);
INSERT INTO items VALUES (3,5,3,791,12,57.09);
INSERT INTO items VALUES (3,5,4,937,1,5.75);
INSERT INTO items VALUES (3,5,5,977,1,14.51);
INSERT INTO items VALUES (3,5,6,204,3,72.84);
INSERT INTO items VALUES (4,1,1,627,12,72.38);
INSERT INTO items VALUES (4,1,2,567,1,12.37);
INSERT INTO items VALUES (4,2,1,340,12,157.19);
INSERT INTO items VALUES (4,2,2,103,2,24.74);
INSERT INTO items VALUES (4,2,3,703,12,294.47);
INSERT INTO items VALUES (4,2,4,393,12,304.70);
INSERT INTO items VALUES (4,2,5,824,3,85.68);
INSERT INTO items VALUES (4,2,6,1014,2,27.64);
INSERT INTO items VALUES (5,1,1,862,2,13.42);
INSERT INTO items VALUES (5,2,1,47,1,24.04);
INSERT INTO items VALUES (5,2,2,948,12,92.18);
INSERT INTO items VALUES (5,2,3,157,2,48.12);
INSERT INTO items VALUES (5,2,4,663,1,7.23);
INSERT INTO items VALUES (5,3,1,35,1,17.64);
INSERT INTO items VALUES (5,4,1,376,1,21.17);
INSERT INTO items VALUES (5,5,1,18,2,16.90);
INSERT INTO items VALUES (6,1,1,921,1,25.30);
INSERT INTO items VALUES (6,1,2,557,12,149.38);
INSERT INTO items VALUES (6,1,3,188,2,15.42);
INSERT INTO items VALUES (6,2,1,492,1,22.10);
INSERT INTO items VALUES (6,2,2,346,12,78.54);
INSERT INTO items VALUES (6,2,3,138,2,43.02);
INSERT INTO items VALUES (6,2,4,467,2,50.94);
INSERT INTO items VALUES (6,2,5,481,12,64.02);
INSERT INTO items VALUES (7,1,1,427,1,20.01);
INSERT INTO items VALUES (7,1,2,25,2,29.82);
INSERT INTO items VALUES (7,1,3,348,2,36.72);
INSERT INTO items VALUES (7,2,1,686,3,58.56);
INSERT INTO items VALUES (7,2,2,565,3,72.06);
INSERT INTO items VALUES (7,3,1,314,12,274.12);
INSERT INTO items VALUES (7,3,2,478,2,35.66);
INSERT INTO items VALUES (7,3,3,524,2,30.52);
INSERT INTO items VALUES (7,3,4,854,12,272.25);
INSERT INTO items VALUES (7,4,1,890,3,59.34);
INSERT INTO items VALUES (7,4,2,875,2,26.72);
INSERT INTO items VALUES (7,4,3,862,2,13.42);
INSERT INTO items VALUES (7,4,4,1021,2,43.54);
INSERT INTO items VALUES (8,1,1,85,1,21.54);
INSERT INTO items VALUES (8,1,2,738,2,48.44);
INSERT INTO items VALUES (9,1,1,410,12,192.94);
INSERT INTO items VALUES (9,1,2,293,1,21.79);
INSERT INTO items VALUES (9,1,3,502,1,24.11);
INSERT INTO items VALUES (9,1,4,666,2,31.10);
INSERT INTO items VALUES (9,2,1,1014,12,152.02);
INSERT INTO items VALUES (9,2,2,897,1,22.99);
INSERT INTO items VALUES (9,2,3,906,12,113.63);
INSERT INTO items VALUES (9,2,4,962,2,31.44);
INSERT INTO items VALUES (9,2,5,447,1,13.58);
INSERT INTO items VALUES (9,3,1,421,3,42.90);
INSERT INTO items VALUES (9,3,2,179,12,59.18);
INSERT INTO items VALUES (9,3,3,826,12,229.90);
INSERT INTO items VALUES (9,3,4,189,2,33.46);
INSERT INTO items VALUES (9,3,5,434,12,279.84);
INSERT INTO items VALUES (9,3,6,73,3,32.10);
INSERT INTO items VALUES (9,4,1,636,12,280.61);
INSERT INTO items VALUES (9,4,2,796,1,24.09);
INSERT INTO items VALUES (9,4,3,896,1,27.56);
INSERT INTO items VALUES (10,1,1,927,3,45.39);
INSERT INTO items VALUES (10,1,2,502,3,72.33);
INSERT INTO items VALUES (10,1,3,940,12,133.98);
INSERT INTO items VALUES (10,1,4,108,3,48.63);
INSERT INTO items VALUES (10,1,5,983,12,287.21);
INSERT INTO items VALUES (10,2,1,126,1,24.09);
INSERT INTO items VALUES (10,2,2,485,1,22.86);
INSERT INTO items VALUES (10,2,3,30,3,24.48);
INSERT INTO items VALUES (10,2,4,57,3,52.80);
INSERT INTO items VALUES (10,2,5,512,2,54.98);
INSERT INTO items VALUES (10,3,1,812,12,143.55);
INSERT INTO items VALUES (10,3,2,737,12,288.09);
INSERT INTO items VALUES (10,3,3,711,3,84.21);
INSERT INTO items VALUES (10,3,4,720,2,56.24);
INSERT INTO items VALUES (10,3,5,460,1,19.35);
INSERT INTO items VALUES (10,3,6,494,12,311.85);
INSERT INTO items VALUES (10,4,1,358,2,34.34);
INSERT INTO items VALUES (10,4,2,409,12,245.74);
INSERT INTO items VALUES (10,4,3,807,1,9.87);
INSERT INTO items VALUES (10,4,4,34,1,14.28);
INSERT INTO items VALUES (10,4,5,431,1,17.86);
INSERT INTO items VALUES (10,5,1,618,2,58.14);
INSERT INTO items VALUES (10,5,2,23,1,26.56);
INSERT INTO items VALUES (10,5,3,654,2,53.60);
INSERT INTO items VALUES (10,5,4,1027,1,28.73);
INSERT INTO items VALUES (10,5,5,698,1,15.50);
INSERT INTO items VALUES (10,6,1,496,2,46.94);
INSERT INTO items VALUES (11,1,1,678,3,79.35);
INSERT INTO items VALUES (11,1,2,295,2,50.10);
INSERT INTO items VALUES (11,1,3,265,3,50.19);
INSERT INTO items VALUES (11,1,4,449,2,56.76);
INSERT INTO items VALUES (12,1,1,615,1,23.57);
INSERT INTO items VALUES (12,1,2,556,1,5.78);
INSERT INTO items VALUES (12,1,3,12,1,27.42);
INSERT INTO items VALUES (12,1,4,490,1,8.31);
INSERT INTO items VALUES (12,1,5,533,12,206.14);
INSERT INTO items VALUES (12,1,6,566,1,7.04);
INSERT INTO items VALUES (12,2,1,180,3,55.71);
INSERT INTO items VALUES (12,2,2,980,2,44.64);
INSERT INTO items VALUES (12,2,3,18,12,92.95);
INSERT INTO items VALUES (12,2,4,745,3,30.78);
INSERT INTO items VALUES (12,3,1,785,12,309.21);
INSERT INTO items VALUES (12,3,2,903,1,23.54);
INSERT INTO items VALUES (12,3,3,21,2,38.28);
INSERT INTO items VALUES (12,3,4,111,3,83.64);
INSERT INTO items VALUES (12,3,5,522,3,21.90);
INSERT INTO items VALUES (12,3,6,854,1,24.75);
INSERT INTO items VALUES (13,1,1,772,12,146.19);
INSERT INTO items VALUES (13,1,2,71,2,15.00);
INSERT INTO items VALUES (13,1,3,414,1,22.23);
INSERT INTO items VALUES (13,2,1,462,3,71.34);
INSERT INTO items VALUES (13,3,1,468,12,314.60);
INSERT INTO items VALUES (13,3,2,228,3,65.79);
INSERT INTO items VALUES (13,3,3,153,1,23.11);
INSERT INTO items VALUES (13,4,1,623,3,66.30);
INSERT INTO items VALUES (13,4,2,461,2,21.32);
INSERT INTO items VALUES (14,1,1,152,1,5.81);
INSERT INTO items VALUES (14,1,2,475,2,57.68);
INSERT INTO items VALUES (14,1,3,540,12,295.35);
INSERT INTO items VALUES (14,1,4,941,2,33.14);
INSERT INTO items VALUES (14,1,5,161,2,37.26);
INSERT INTO items VALUES (14,2,1,314,12,274.12);
INSERT INTO items VALUES (15,1,1,550,1,11.22);
INSERT INTO items VALUES (15,2,1,729,3,20.13);
INSERT INTO items VALUES (15,2,2,694,12,173.36);
INSERT INTO items VALUES (15,3,1,286,1,27.29);
INSERT INTO items VALUES (15,3,2,189,12,184.03);
INSERT INTO items VALUES (15,3,3,117,2,49.86);
INSERT INTO items VALUES (15,4,1,905,1,11.44);
INSERT INTO items VALUES (15,5,1,361,2,25.52);
INSERT INTO items VALUES (15,5,2,88,3,43.77);
INSERT INTO items VALUES (15,5,3,589,12,237.16);
INSERT INTO items VALUES (15,5,4,875,2,26.72);
INSERT INTO items VALUES (15,5,5,195,1,22.53);
INSERT INTO items VALUES (15,5,6,648,2,32.68);
INSERT INTO items VALUES (16,1,1,993,12,268.07);
INSERT INTO items VALUES (16,1,2,383,1,18.89);
INSERT INTO items VALUES (16,1,3,338,12,267.08);
INSERT INTO items VALUES (16,1,4,1021,3,65.31);
INSERT INTO items VALUES (17,1,1,471,2,57.28);
INSERT INTO items VALUES (17,1,2,2,3,84.45);
INSERT INTO items VALUES (17,1,3,518,3,46.05);
INSERT INTO items VALUES (17,1,4,1,3,63.54);
INSERT INTO items VALUES (17,2,1,927,2,30.26);
INSERT INTO items VALUES (17,2,2,331,12,86.24);
INSERT INTO items VALUES (17,2,3,641,1,19.47);
INSERT INTO items VALUES (17,2,4,984,1,6.17);
INSERT INTO items VALUES (17,2,5,795,3,64.38);
INSERT INTO items VALUES (17,2,6,743,3,23.94);
INSERT INTO items VALUES (17,3,1,425,1,15.85);
INSERT INTO items VALUES (17,4,1,168,3,73.11);
INSERT INTO items VALUES (17,4,2,450,1,14.42);
INSERT INTO items VALUES (17,4,3,935,3,85.68);
INSERT INTO items VALUES (18,1,1,381,12,229.46);
INSERT INTO items VALUES (18,1,2,745,3,30.78);
INSERT INTO items VALUES (18,1,3,11,2,32.96);
INSERT INTO items VALUES (19,1,1,538,1,14.50);
INSERT INTO items VALUES (19,1,2,280,3,55.74);
INSERT INTO items VALUES (19,1,3,789,3,42.93);
INSERT INTO items VALUES (19,1,4,751,3,74.67);
INSERT INTO items VALUES (19,1,5,461,3,31.98);
INSERT INTO items VALUES (19,2,1,461,1,10.66);
INSERT INTO items VALUES (19,2,2,973,1,16.02);
INSERT INTO items VALUES (20,1,1,460,3,58.05);
INSERT INTO items VALUES (20,1,2,102,3,20.13);
INSERT INTO items VALUES (20,1,3,1007,12,135.74);
INSERT INTO items VALUES (20,1,4,357,3,70.92);
INSERT INTO items VALUES (21,1,1,577,12,231.66);
INSERT INTO items VALUES (21,1,2,186,12,93.83);
INSERT INTO items VALUES (21,1,3,65,1,9.98);
INSERT INTO items VALUES (21,1,4,11,1,16.48);
INSERT INTO items VALUES (21,1,5,539,1,10.48);
INSERT INTO items VALUES (21,1,6,300,12,290.18);
INSERT INTO items VALUES (21,2,1,887,2,30.20);
INSERT INTO items VALUES (21,2,2,88,3,43.77);
INSERT INTO items VALUES (21,2,3,777,1,23.70);
INSERT INTO items VALUES (21,2,4,626,12,91.08);
INSERT INTO items VALUES (21,2,5,208,1,10.19);
INSERT INTO items VALUES (21,3,1,460,3,58.05);
INSERT INTO items VALUES (21,3,2,26,12,286.33);
INSERT INTO items VALUES (21,3,3,880,2,53.24);
INSERT INTO items VALUES (21,3,4,796,3,72.27);
INSERT INTO items VALUES (21,3,5,526,1,19.31);
INSERT INTO items VALUES (21,3,6,745,2,20.52);
INSERT INTO items VALUES (22,1,1,347,3,31.77);
INSERT INTO items VALUES (22,1,2,843,2,16.22);
INSERT INTO items VALUES (22,1,3,433,12,234.41);
INSERT INTO items VALUES (22,1,4,23,1,26.56);
INSERT INTO items VALUES (22,2,1,95,2,58.38);
INSERT INTO items VALUES (22,2,2,467,3,76.41);
INSERT INTO items VALUES (22,2,3,1006,3,60.48);
INSERT INTO items VALUES (22,2,4,374,2,18.56);
INSERT INTO items VALUES (22,2,5,242,12,311.52);
INSERT INTO items VALUES (22,3,1,357,12,260.04);
INSERT INTO items VALUES (22,3,2,46,12,172.37);
INSERT INTO items VALUES (22,3,3,755,1,13.25);
INSERT INTO items VALUES (22,3,4,1039,1,26.46);
INSERT INTO items VALUES (22,4,1,757,12,235.07);
INSERT INTO items VALUES (23,1,1,867,1,15.68);
INSERT INTO items VALUES (23,1,2,961,3,30.24);
INSERT INTO items VALUES (23,1,3,159,3,44.28);
INSERT INTO items VALUES (23,1,4,970,12,314.27);
INSERT INTO items VALUES (23,2,1,821,2,11.38);
INSERT INTO items VALUES (23,2,2,327,1,25.20);
INSERT INTO items VALUES (23,2,3,866,2,29.18);
INSERT INTO items VALUES (23,3,1,924,12,227.37);
INSERT INTO items VALUES (23,3,2,86,3,45.12);
INSERT INTO items VALUES (23,3,3,125,12,97.02);
INSERT INTO items VALUES (23,4,1,849,12,318.56);
INSERT INTO items VALUES (23,4,2,591,2,25.40);
INSERT INTO items VALUES (23,4,3,200,2,23.76);
INSERT INTO items VALUES (23,4,4,886,3,52.59);
INSERT INTO items VALUES (23,4,5,413,3,55.02);
INSERT INTO items VALUES (23,4,6,892,1,7.25);
INSERT INTO items VALUES (23,5,1,918,1,15.70);
INSERT INTO items VALUES (23,5,2,151,12,246.07);
INSERT INTO items VALUES (23,5,3,179,2,10.76);
INSERT INTO items VALUES (24,1,1,118,3,43.14);
INSERT INTO items VALUES (24,1,2,949,2,21.54);
INSERT INTO items VALUES (24,1,3,578,2,14.64);
INSERT INTO items VALUES (24,1,4,894,1,7.88);
INSERT INTO items VALUES (24,1,5,270,1,20.46);
INSERT INTO items VALUES (24,2,1,1016,12,219.89);
INSERT INTO items VALUES (24,2,2,769,12,63.14);
INSERT INTO items VALUES (24,2,3,62,1,16.85);
INSERT INTO items VALUES (24,2,4,237,12,280.28);
INSERT INTO items VALUES (25,1,1,308,12,143.66);
INSERT INTO items VALUES (25,1,2,188,3,23.13);
INSERT INTO items VALUES (25,1,3,833,2,39.26);
INSERT INTO items VALUES (25,1,4,1003,12,107.47);
INSERT INTO items VALUES (25,2,1,167,1,21.05);
INSERT INTO items VALUES (25,2,2,500,1,16.28);
INSERT INTO items VALUES (25,2,3,105,3,67.23);
INSERT INTO items VALUES (25,2,4,364,12,250.69);
INSERT INTO items VALUES (25,2,5,493,1,22.39);
INSERT INTO items VALUES (25,3,1,283,3,86.49);
INSERT INTO items VALUES (25,3,2,988,1,11.17);
INSERT INTO items VALUES (25,4,1,194,2,30.20);
INSERT INTO items VALUES (25,4,2,46,2,31.34);
INSERT INTO items VALUES (25,5,1,668,12,163.35);
INSERT INTO items VALUES (25,5,2,54,2,40.62);
INSERT INTO items VALUES (25,5,3,802,1,12.24);
INSERT INTO items VALUES (26,1,1,87,1,17.19);
INSERT INTO items VALUES (26,1,2,383,1,18.89);
INSERT INTO items VALUES (26,2,1,240,1,11.44);
INSERT INTO items VALUES (26,2,2,941,2,33.14);
INSERT INTO items VALUES (26,3,1,462,2,47.56);
INSERT INTO items VALUES (26,3,2,843,3,24.33);
INSERT INTO items VALUES (26,3,3,415,12,124.41);
INSERT INTO items VALUES (26,4,1,917,1,18.43);
INSERT INTO items VALUES (26,5,1,894,2,15.76);
INSERT INTO items VALUES (26,5,2,891,1,23.60);
INSERT INTO items VALUES (26,5,3,515,3,75.27);
INSERT INTO items VALUES (26,5,4,714,1,25.79);
INSERT INTO items VALUES (26,5,5,35,1,17.64);
INSERT INTO items VALUES (26,5,6,339,12,117.37);
INSERT INTO items VALUES (27,1,1,288,3,44.85);
INSERT INTO items VALUES (27,1,2,712,2,56.42);
INSERT INTO items VALUES (27,1,3,984,2,12.34);
INSERT INTO items VALUES (27,1,4,248,12,287.98);
INSERT INTO items VALUES (27,1,5,312,2,23.86);
INSERT INTO items VALUES (27,2,1,76,2,35.88);
INSERT INTO items VALUES (27,2,2,258,1,17.68);
INSERT INTO items VALUES (27,3,1,640,2,22.90);
INSERT INTO items VALUES (27,3,2,371,12,170.39);
INSERT INTO items VALUES (27,3,3,979,1,28.39);
INSERT INTO items VALUES (27,3,4,299,12,145.53);
INSERT INTO items VALUES (27,4,1,607,1,22.19);
INSERT INTO items VALUES (27,4,2,225,12,186.56);
INSERT INTO items VALUES (27,4,3,395,2,33.98);
INSERT INTO items VALUES (27,4,4,87,3,51.57);
INSERT INTO items VALUES (27,4,5,502,3,72.33);
INSERT INTO items VALUES (27,5,1,446,12,235.84);
INSERT INTO items VALUES (28,1,1,980,3,66.96);
INSERT INTO items VALUES (28,1,2,470,12,103.84);
INSERT INTO items VALUES (28,1,3,212,3,89.40);
INSERT INTO items VALUES (28,1,4,1018,1,9.22);
INSERT INTO items VALUES (28,1,5,1036,2,23.48);
INSERT INTO items VALUES (28,1,6,118,3,43.14);
INSERT INTO items VALUES (28,2,1,237,12,280.28);
INSERT INTO items VALUES (28,2,2,812,1,13.05);
INSERT INTO items VALUES (28,2,3,971,1,19.81);
INSERT INTO items VALUES (28,3,1,663,3,21.69);
INSERT INTO items VALUES (28,4,1,1024,12,218.35);
INSERT INTO items VALUES (28,5,1,732,1,27.09);
INSERT INTO items VALUES (28,5,2,230,12,123.64);
INSERT INTO items VALUES (28,5,3,992,2,21.02);
INSERT INTO items VALUES (28,6,1,834,12,248.16);
INSERT INTO items VALUES (29,1,1,458,12,88.11);
INSERT INTO items VALUES (29,1,2,228,3,65.79);
INSERT INTO items VALUES (29,1,3,100,3,70.38);
INSERT INTO items VALUES (30,1,1,958,12,119.13);
INSERT INTO items VALUES (30,2,1,109,3,48.00);
INSERT INTO items VALUES (30,2,2,780,1,7.31);
INSERT INTO items VALUES (30,2,3,1048,1,9.60);
INSERT INTO items VALUES (30,2,4,187,2,12.88);
INSERT INTO items VALUES (30,3,1,851,12,221.43);
INSERT INTO items VALUES (30,3,2,1038,3,69.06);
INSERT INTO items VALUES (30,4,1,794,2,21.04);
INSERT INTO items VALUES (30,4,2,809,3,27.57);
INSERT INTO items VALUES (30,4,3,1019,12,142.23);
INSERT INTO items VALUES (30,4,4,148,3,39.72);
INSERT INTO items VALUES (30,4,5,986,1,6.56);
INSERT INTO items VALUES (30,5,1,595,3,86.85);
INSERT INTO items VALUES (30,5,2,142,2,30.00);
INSERT INTO items VALUES (30,5,3,454,1,28.31);
INSERT INTO items VALUES (30,5,4,995,2,28.16);
INSERT INTO items VALUES (30,5,5,924,3,62.01);
INSERT INTO items VALUES (30,5,6,214,3,83.85);
INSERT INTO items VALUES (31,1,1,95,1,29.19);
INSERT INTO items VALUES (31,1,2,551,1,23.73);
INSERT INTO items VALUES (31,1,3,128,3,63.75);
INSERT INTO items VALUES (31,1,4,880,3,79.86);
INSERT INTO items VALUES (32,1,1,990,12,140.58);
INSERT INTO items VALUES (32,1,2,629,12,266.09);
INSERT INTO items VALUES (32,2,1,472,3,25.08);
INSERT INTO items VALUES (32,3,1,213,12,276.87);
INSERT INTO items VALUES (32,3,2,625,1,17.99);
INSERT INTO items VALUES (32,3,3,985,2,40.68);
INSERT INTO items VALUES (32,3,4,680,3,15.75);
INSERT INTO items VALUES (32,3,5,104,3,19.26);
INSERT INTO items VALUES (32,3,6,1031,1,6.87);
INSERT INTO items VALUES (32,4,1,134,12,246.95);
INSERT INTO items VALUES (32,4,2,567,3,37.11);
INSERT INTO items VALUES (32,4,3,622,1,17.45);
INSERT INTO items VALUES (32,5,1,105,2,44.82);
INSERT INTO items VALUES (32,5,2,542,1,19.52);
INSERT INTO items VALUES (32,5,3,651,1,29.92);
INSERT INTO items VALUES (32,6,1,661,12,121.88);
INSERT INTO items VALUES (32,6,2,772,12,146.19);
INSERT INTO items VALUES (32,6,3,354,12,68.09);
INSERT INTO items VALUES (33,1,1,235,1,21.85);
INSERT INTO items VALUES (33,1,2,633,3,48.54);
INSERT INTO items VALUES (33,1,3,152,12,63.91);
INSERT INTO items VALUES (33,1,4,122,1,22.13);
INSERT INTO items VALUES (33,1,5,592,2,30.64);
INSERT INTO items VALUES (33,1,6,1016,2,39.98);
INSERT INTO items VALUES (33,2,1,862,3,20.13);
INSERT INTO items VALUES (33,2,2,298,3,73.92);
INSERT INTO items VALUES (33,2,3,403,1,24.98);
INSERT INTO items VALUES (33,2,4,132,12,202.73);
INSERT INTO items VALUES (33,2,5,160,1,29.92);
INSERT INTO items VALUES (33,2,6,583,1,18.49);
INSERT INTO items VALUES (33,3,1,974,1,6.37);
INSERT INTO items VALUES (33,4,1,756,1,29.52);
INSERT INTO items VALUES (33,4,2,390,3,25.29);
INSERT INTO items VALUES (33,4,3,717,3,71.76);
INSERT INTO items VALUES (33,5,1,450,12,158.62);
INSERT INTO items VALUES (33,5,2,979,1,28.39);
INSERT INTO items VALUES (33,5,3,624,12,244.75);
INSERT INTO items VALUES (33,5,4,812,1,13.05);
INSERT INTO items VALUES (34,1,1,141,2,44.94);
INSERT INTO items VALUES (34,1,2,1003,2,19.54);
INSERT INTO items VALUES (35,1,1,931,1,14.34);
INSERT INTO items VALUES (35,2,1,128,12,233.75);
INSERT INTO items VALUES (35,2,2,558,12,314.49);
INSERT INTO items VALUES (35,2,3,74,12,138.16);
INSERT INTO items VALUES (35,3,1,157,3,72.18);
INSERT INTO items VALUES (35,3,2,124,1,27.42);
INSERT INTO items VALUES (35,3,3,1002,12,263.67);
INSERT INTO items VALUES (35,3,4,115,1,14.02);
INSERT INTO items VALUES (35,4,1,694,12,173.36);
INSERT INTO items VALUES (36,1,1,442,12,150.37);
INSERT INTO items VALUES (36,2,1,580,3,73.47);
INSERT INTO items VALUES (36,2,2,294,3,23.73);
INSERT INTO items VALUES (36,2,3,656,1,25.43);
INSERT INTO items VALUES (36,3,1,743,2,15.96);
INSERT INTO items VALUES (36,3,2,442,2,27.34);
INSERT INTO items VALUES (36,3,3,517,1,7.42);
INSERT INTO items VALUES (36,3,4,1023,3,46.47);
INSERT INTO items VALUES (36,4,1,172,1,29.89);
INSERT INTO items VALUES (37,1,1,1006,3,60.48);
INSERT INTO items VALUES (37,2,1,921,2,50.60);
INSERT INTO items VALUES (37,3,1,1004,12,265.98);
INSERT INTO items VALUES (37,3,2,15,1,12.33);
INSERT INTO items VALUES (37,3,3,955,3,56.73);
INSERT INTO items VALUES (37,3,4,878,3,67.29);
INSERT INTO items VALUES (37,3,5,342,1,11.22);
INSERT INTO items VALUES (37,3,6,757,2,42.74);
INSERT INTO items VALUES (37,4,1,123,3,23.10);
INSERT INTO items VALUES (37,4,2,1044,12,210.32);
INSERT INTO items VALUES (37,4,3,97,1,12.11);
INSERT INTO items VALUES (37,4,4,890,1,19.78);
INSERT INTO items VALUES (37,4,5,282,1,27.83);
INSERT INTO items VALUES (37,4,6,654,1,26.80);
INSERT INTO items VALUES (38,1,1,75,1,22.73);
INSERT INTO items VALUES (38,1,2,683,2,18.38);
INSERT INTO items VALUES (38,1,3,510,2,22.06);
INSERT INTO items VALUES (38,1,4,501,12,246.29);
INSERT INTO items VALUES (38,1,5,920,1,20.28);
INSERT INTO items VALUES (38,1,6,711,12,308.77);
INSERT INTO items VALUES (39,1,1,984,3,18.51);
INSERT INTO items VALUES (39,2,1,198,2,27.62);
INSERT INTO items VALUES (39,2,2,288,2,29.90);
INSERT INTO items VALUES (39,3,1,298,2,49.28);
INSERT INTO items VALUES (39,3,2,347,1,10.59);
INSERT INTO items VALUES (39,3,3,15,2,24.66);
INSERT INTO items VALUES (39,4,1,80,1,28.44);
INSERT INTO items VALUES (39,4,2,625,3,53.97);
INSERT INTO items VALUES (39,4,3,277,1,26.37);
INSERT INTO items VALUES (39,5,1,816,1,11.57);
INSERT INTO items VALUES (39,5,2,881,2,51.66);
INSERT INTO items VALUES (39,5,3,566,1,7.04);
INSERT INTO items VALUES (39,5,4,818,12,72.27);
INSERT INTO items VALUES (39,5,5,174,12,282.48);
INSERT INTO items VALUES (40,1,1,513,3,51.87);
INSERT INTO items VALUES (40,1,2,6,1,20.25);
INSERT INTO items VALUES (40,1,3,834,1,22.56);
INSERT INTO items VALUES (40,2,1,943,3,48.39);
INSERT INTO items VALUES (40,2,2,319,2,29.40);
INSERT INTO items VALUES (40,2,3,263,2,26.24);
INSERT INTO items VALUES (41,1,1,613,12,237.82);
INSERT INTO items VALUES (41,1,2,102,12,73.81);
INSERT INTO items VALUES (41,1,3,418,3,30.99);
INSERT INTO items VALUES (41,1,4,1047,2,27.70);
INSERT INTO items VALUES (42,1,1,447,3,40.74);
INSERT INTO items VALUES (42,1,2,136,3,76.05);
INSERT INTO items VALUES (42,1,3,36,2,59.02);
INSERT INTO items VALUES (42,2,1,591,2,25.40);
INSERT INTO items VALUES (42,2,2,1037,2,53.34);
INSERT INTO items VALUES (42,2,3,591,12,139.70);
INSERT INTO items VALUES (42,3,1,304,1,22.46);
INSERT INTO items VALUES (42,3,2,463,1,27.14);
INSERT INTO items VALUES (42,3,3,475,12,317.24);
INSERT INTO items VALUES (43,1,1,534,1,16.15);
INSERT INTO items VALUES (43,1,2,286,12,300.19);
INSERT INTO items VALUES (43,1,3,624,3,66.75);
INSERT INTO items VALUES (43,2,1,244,1,12.21);
INSERT INTO items VALUES (43,2,2,1037,3,80.01);
INSERT INTO items VALUES (43,2,3,420,1,28.55);
INSERT INTO items VALUES (43,2,4,162,2,39.28);
INSERT INTO items VALUES (43,2,5,500,1,16.28);
INSERT INTO items VALUES (43,2,6,274,1,6.22);
INSERT INTO items VALUES (43,3,1,71,12,82.50);
INSERT INTO items VALUES (43,3,2,837,3,26.46);
INSERT INTO items VALUES (43,3,3,517,3,22.26);
INSERT INTO items VALUES (43,3,4,764,12,126.72);
INSERT INTO items VALUES (43,3,5,612,3,88.74);
INSERT INTO items VALUES (43,3,6,304,2,44.92);
INSERT INTO items VALUES (43,4,1,298,12,271.04);
INSERT INTO items VALUES (43,4,2,826,3,62.70);
INSERT INTO items VALUES (43,4,3,1045,2,37.52);
INSERT INTO items VALUES (43,4,4,646,1,7.95);
INSERT INTO items VALUES (43,4,5,823,3,69.60);
INSERT INTO items VALUES (43,5,1,178,1,11.21);
INSERT INTO items VALUES (43,5,2,568,12,124.52);
INSERT INTO items VALUES (43,5,3,815,12,70.84);
INSERT INTO items VALUES (43,5,4,211,3,52.74);
INSERT INTO items VALUES (43,5,5,244,3,36.63);
INSERT INTO items VALUES (44,1,1,33,2,37.50);
INSERT INTO items VALUES (44,1,2,500,1,16.28);
INSERT INTO items VALUES (44,1,3,37,1,14.15);
INSERT INTO items VALUES (44,1,4,574,3,56.73);
INSERT INTO items VALUES (44,1,5,889,12,153.12);
INSERT INTO items VALUES (44,1,6,184,1,27.11);
INSERT INTO items VALUES (44,2,1,313,12,222.42);
INSERT INTO items VALUES (44,2,2,160,12,329.12);
INSERT INTO items VALUES (44,2,3,85,1,21.54);
INSERT INTO items VALUES (44,2,4,34,1,14.28);
INSERT INTO items VALUES (44,2,5,525,1,22.09);
INSERT INTO items VALUES (44,2,6,1024,2,39.70);
INSERT INTO items VALUES (45,1,1,853,2,58.46);
INSERT INTO items VALUES (45,1,2,150,1,8.66);
INSERT INTO items VALUES (45,1,3,42,2,42.56);
INSERT INTO items VALUES (45,1,4,399,1,14.63);
INSERT INTO items VALUES (45,1,5,613,2,43.24);
INSERT INTO items VALUES (45,1,6,51,12,264.99);
INSERT INTO items VALUES (46,1,1,961,2,20.16);
INSERT INTO items VALUES (46,1,2,259,1,10.52);
INSERT INTO items VALUES (46,1,3,740,1,5.08);
INSERT INTO items VALUES (46,1,4,168,12,268.07);
INSERT INTO items VALUES (46,1,5,53,12,292.82);
INSERT INTO items VALUES (46,1,6,981,12,273.90);
INSERT INTO items VALUES (46,2,1,158,12,147.29);
INSERT INTO items VALUES (46,2,2,588,1,11.46);
INSERT INTO items VALUES (46,2,3,72,12,274.56);
INSERT INTO items VALUES (46,2,4,892,2,14.50);
INSERT INTO items VALUES (47,1,1,129,2,11.50);
INSERT INTO items VALUES (47,1,2,831,1,23.61);
INSERT INTO items VALUES (47,1,3,431,3,53.58);
INSERT INTO items VALUES (47,1,4,27,2,41.74);
INSERT INTO items VALUES (48,1,1,261,2,30.74);
INSERT INTO items VALUES (48,1,2,893,2,48.88);
INSERT INTO items VALUES (48,1,3,218,3,27.18);
INSERT INTO items VALUES (48,1,4,789,2,28.62);
INSERT INTO items VALUES (48,1,5,423,3,80.64);
INSERT INTO items VALUES (48,2,1,467,2,50.94);
INSERT INTO items VALUES (48,3,1,477,1,23.89);
INSERT INTO items VALUES (48,3,2,367,2,39.74);
INSERT INTO items VALUES (48,3,3,983,3,78.33);
INSERT INTO items VALUES (48,3,4,827,12,224.84);
INSERT INTO items VALUES (48,3,5,959,12,110.77);
INSERT INTO items VALUES (48,3,6,516,3,32.61);
INSERT INTO items VALUES (48,4,1,595,3,86.85);
INSERT INTO items VALUES (48,4,2,425,1,15.85);
INSERT INTO items VALUES (48,4,3,14,12,57.97);
INSERT INTO items VALUES (48,5,1,970,12,314.27);
INSERT INTO items VALUES (48,5,2,1025,12,316.58);
INSERT INTO items VALUES (48,5,3,384,12,231.77);
INSERT INTO items VALUES (48,5,4,684,2,45.10);
INSERT INTO items VALUES (48,6,1,1000,12,76.01);
INSERT INTO items VALUES (48,6,2,242,3,84.96);
INSERT INTO items VALUES (48,6,3,485,3,68.58);
INSERT INTO items VALUES (48,6,4,560,2,45.82);
INSERT INTO items VALUES (48,6,5,492,3,66.30);
INSERT INTO items VALUES (48,6,6,874,1,19.40);
INSERT INTO items VALUES (49,1,1,582,1,20.88);
INSERT INTO items VALUES (49,1,2,84,12,295.24);
INSERT INTO items VALUES (49,1,3,1006,1,20.16);
INSERT INTO items VALUES (49,2,1,152,3,17.43);
INSERT INTO items VALUES (49,2,2,335,12,105.38);
INSERT INTO items VALUES (49,2,3,283,12,317.13);
INSERT INTO items VALUES (49,2,4,262,12,244.09);
INSERT INTO items VALUES (49,2,5,659,2,48.76);
INSERT INTO items VALUES (49,2,6,757,2,42.74);
INSERT INTO items VALUES (49,3,1,841,2,50.76);
INSERT INTO items VALUES (49,3,2,265,12,184.03);
INSERT INTO items VALUES (49,3,3,592,1,15.32);
INSERT INTO items VALUES (49,4,1,815,2,12.88);
INSERT INTO items VALUES (49,4,2,704,1,23.19);
INSERT INTO items VALUES (49,4,3,96,12,248.82);
INSERT INTO items VALUES (49,4,4,999,3,52.83);
INSERT INTO items VALUES (49,4,5,183,3,75.81);
INSERT INTO items VALUES (49,4,6,1036,12,129.14);
INSERT INTO items VALUES (49,5,1,445,2,42.86);
INSERT INTO items VALUES (49,5,2,19,12,321.42);
INSERT INTO items VALUES (50,1,1,662,12,256.19);
INSERT INTO items VALUES (50,1,2,168,3,73.11);
INSERT INTO items VALUES (50,1,3,950,1,11.06);
INSERT INTO items VALUES (50,2,1,457,12,231.00);
INSERT INTO items VALUES (50,3,1,975,3,27.60);
INSERT INTO items VALUES (50,3,2,768,3,24.24);
INSERT INTO items VALUES (50,3,3,299,2,26.46);
INSERT INTO items VALUES (50,3,4,627,12,72.38);
INSERT INTO items VALUES (50,3,5,856,1,5.29);
INSERT INTO items VALUES (50,3,6,647,12,322.52);
INSERT INTO items VALUES (51,1,1,434,12,279.84);
INSERT INTO items VALUES (51,1,2,209,1,14.80);
INSERT INTO items VALUES (51,1,3,637,3,43.68);
INSERT INTO items VALUES (51,1,4,183,2,50.54);
INSERT INTO items VALUES (51,1,5,692,3,53.70);
INSERT INTO items VALUES (51,2,1,975,2,18.40);
INSERT INTO items VALUES (51,2,2,243,1,19.35);
INSERT INTO items VALUES (51,2,3,997,1,9.03);
INSERT INTO items VALUES (51,3,1,408,12,175.45);
INSERT INTO items VALUES (51,3,2,470,3,28.32);
INSERT INTO items VALUES (51,3,3,228,1,21.93);
INSERT INTO items VALUES (51,4,1,146,12,234.30);
INSERT INTO items VALUES (51,4,2,930,3,76.53);
INSERT INTO items VALUES (51,4,3,402,12,209.88);
INSERT INTO items VALUES (51,4,4,5,3,20.01);
INSERT INTO items VALUES (51,5,1,58,3,79.80);
INSERT INTO items VALUES (51,5,2,101,2,17.46);
INSERT INTO items VALUES (51,5,3,677,3,42.24);
INSERT INTO items VALUES (51,5,4,33,12,206.25);
INSERT INTO items VALUES (51,6,1,896,2,55.12);
INSERT INTO items VALUES (52,1,1,958,12,119.13);
INSERT INTO items VALUES (52,1,2,602,2,23.44);
INSERT INTO items VALUES (52,1,3,922,1,23.00);
INSERT INTO items VALUES (52,1,4,419,3,33.12);
INSERT INTO items VALUES (52,2,1,219,2,12.90);
INSERT INTO items VALUES (52,2,2,612,3,88.74);
INSERT INTO items VALUES (52,2,3,466,3,35.43);
INSERT INTO items VALUES (52,3,1,674,12,163.57);
INSERT INTO items VALUES (52,3,2,203,3,44.61);
INSERT INTO items VALUES (52,3,3,728,12,60.28);
INSERT INTO items VALUES (52,3,4,944,3,59.82);
INSERT INTO items VALUES (52,4,1,16,2,17.90);
INSERT INTO items VALUES (52,5,1,101,12,96.03);
INSERT INTO items VALUES (52,5,2,381,1,20.86);
INSERT INTO items VALUES (52,5,3,518,2,30.70);
INSERT INTO items VALUES (52,5,4,902,1,10.77);
INSERT INTO items VALUES (52,5,5,197,1,11.73);
INSERT INTO items VALUES (52,6,1,592,1,15.32);
INSERT INTO items VALUES (52,6,2,37,12,155.65);
INSERT INTO items VALUES (52,6,3,293,1,21.79);
INSERT INTO items VALUES (52,6,4,206,12,270.60);
INSERT INTO items VALUES (52,6,5,286,12,300.19);
INSERT INTO items VALUES (52,6,6,113,1,19.25);
INSERT INTO items VALUES (53,1,1,169,2,19.50);
INSERT INTO items VALUES (53,1,2,779,1,19.87);
INSERT INTO items VALUES (53,1,3,53,3,79.86);
INSERT INTO items VALUES (53,1,4,39,3,22.14);
INSERT INTO items VALUES (53,2,1,254,3,67.65);
INSERT INTO items VALUES (53,2,2,730,1,24.66);
INSERT INTO items VALUES (53,2,3,935,3,85.68);
INSERT INTO items VALUES (53,2,4,263,12,144.32);
INSERT INTO items VALUES (53,3,1,1023,2,30.98);
INSERT INTO items VALUES (53,3,2,786,3,62.52);
INSERT INTO items VALUES (53,3,3,705,12,109.67);
INSERT INTO items VALUES (53,4,1,544,3,19.59);
INSERT INTO items VALUES (53,5,1,163,12,224.18);
INSERT INTO items VALUES (53,5,2,247,2,50.80);
INSERT INTO items VALUES (53,5,3,999,2,35.22);
INSERT INTO items VALUES (53,5,4,766,1,29.86);
INSERT INTO items VALUES (53,5,5,838,3,57.90);
INSERT INTO items VALUES (53,6,1,827,1,20.44);
INSERT INTO items VALUES (54,1,1,77,12,97.24);
INSERT INTO items VALUES (54,1,2,567,12,136.07);
INSERT INTO items VALUES (54,1,3,1031,2,13.74);
INSERT INTO items VALUES (54,2,1,764,2,23.04);
INSERT INTO items VALUES (54,2,2,892,1,7.25);
INSERT INTO items VALUES (54,3,1,790,2,24.86);
INSERT INTO items VALUES (54,3,2,720,1,28.12);
INSERT INTO items VALUES (54,3,3,180,3,55.71);
INSERT INTO items VALUES (54,3,4,576,1,26.76);
INSERT INTO items VALUES (54,4,1,36,3,88.53);
INSERT INTO items VALUES (54,4,2,775,3,31.98);
INSERT INTO items VALUES (54,4,3,13,2,35.20);
INSERT INTO items VALUES (54,4,4,147,12,215.38);
INSERT INTO items VALUES (54,4,5,651,12,329.12);
INSERT INTO items VALUES (55,1,1,12,12,301.62);
INSERT INTO items VALUES (56,1,1,98,3,73.47);
INSERT INTO items VALUES (56,1,2,213,1,25.17);
INSERT INTO items VALUES (56,1,3,465,12,88.00);
INSERT INTO items VALUES (56,2,1,397,3,34.14);
INSERT INTO items VALUES (56,2,2,764,2,23.04);
INSERT INTO items VALUES (56,2,3,228,1,21.93);
INSERT INTO items VALUES (56,2,4,239,1,24.19);
INSERT INTO items VALUES (56,2,5,68,1,21.66);
INSERT INTO items VALUES (56,2,6,420,3,85.65);
INSERT INTO items VALUES (57,1,1,461,1,10.66);
INSERT INTO items VALUES (57,2,1,858,1,5.33);
INSERT INTO items VALUES (57,2,2,714,2,51.58);
INSERT INTO items VALUES (57,3,1,452,1,7.78);
INSERT INTO items VALUES (57,3,2,588,12,126.06);
INSERT INTO items VALUES (57,3,3,55,2,42.82);
INSERT INTO items VALUES (57,3,4,1013,2,20.08);
INSERT INTO items VALUES (57,3,5,574,1,18.91);
INSERT INTO items VALUES (57,3,6,515,12,275.99);
INSERT INTO items VALUES (57,4,1,325,12,145.31);
INSERT INTO items VALUES (57,4,2,578,12,80.52);
INSERT INTO items VALUES (57,4,3,380,2,54.90);
INSERT INTO items VALUES (57,4,4,102,12,73.81);
INSERT INTO items VALUES (58,1,1,81,12,280.72);
INSERT INTO items VALUES (58,1,2,812,2,26.10);
INSERT INTO items VALUES (58,1,3,428,12,68.64);
INSERT INTO items VALUES (58,1,4,1019,2,25.86);
INSERT INTO items VALUES (58,1,5,185,12,175.12);
INSERT INTO items VALUES (59,1,1,314,2,49.84);
INSERT INTO items VALUES (59,1,2,1027,2,57.46);
INSERT INTO items VALUES (59,1,3,234,1,26.40);
INSERT INTO items VALUES (59,1,4,869,1,17.93);
INSERT INTO items VALUES (59,1,5,88,3,43.77);
INSERT INTO items VALUES (59,2,1,946,1,9.51);
INSERT INTO items VALUES (59,2,2,602,2,23.44);
INSERT INTO items VALUES (59,2,3,319,3,44.10);
INSERT INTO items VALUES (59,2,4,62,12,185.35);
INSERT INTO items VALUES (59,3,1,132,3,55.29);
INSERT INTO items VALUES (59,3,2,602,2,23.44);
INSERT INTO items VALUES (59,4,1,621,3,88.38);
INSERT INTO items VALUES (59,4,2,1032,12,219.23);
INSERT INTO items VALUES (59,4,3,143,12,137.39);
INSERT INTO items VALUES (59,5,1,887,1,15.10);
INSERT INTO items VALUES (59,5,2,234,3,79.20);
INSERT INTO items VALUES (60,1,1,920,12,223.08);
INSERT INTO items VALUES (60,1,2,238,12,265.65);
INSERT INTO items VALUES (60,1,3,359,3,55.83);
INSERT INTO items VALUES (61,1,1,807,3,29.61);
INSERT INTO items VALUES (61,1,2,1,1,21.18);
INSERT INTO items VALUES (61,1,3,957,12,62.70);
INSERT INTO items VALUES (61,1,4,241,1,16.95);
INSERT INTO items VALUES (61,1,5,598,2,25.86);
INSERT INTO items VALUES (61,2,1,863,1,13.71);
INSERT INTO items VALUES (61,3,1,821,2,11.38);
INSERT INTO items VALUES (61,3,2,268,1,9.15);
INSERT INTO items VALUES (61,3,3,1020,1,5.51);
INSERT INTO items VALUES (61,3,4,962,12,172.92);
INSERT INTO items VALUES (61,3,5,38,12,63.25);
INSERT INTO items VALUES (61,4,1,119,3,53.46);
INSERT INTO items VALUES (61,4,2,847,1,18.79);
INSERT INTO items VALUES (61,4,3,735,3,66.33);
INSERT INTO items VALUES (61,4,4,238,12,265.65);
INSERT INTO items VALUES (61,4,5,445,3,64.29);
INSERT INTO items VALUES (61,4,6,966,12,114.95);
INSERT INTO items VALUES (62,1,1,717,1,23.92);
INSERT INTO items VALUES (62,1,2,949,3,32.31);
INSERT INTO items VALUES (62,1,3,888,1,5.78);
INSERT INTO items VALUES (62,1,4,505,1,27.63);
INSERT INTO items VALUES (62,1,5,789,3,42.93);
INSERT INTO items VALUES (62,1,6,103,12,136.07);
INSERT INTO items VALUES (62,2,1,1007,12,135.74);
INSERT INTO items VALUES (62,2,2,792,3,19.47);
INSERT INTO items VALUES (62,2,3,753,2,43.40);
INSERT INTO items VALUES (62,2,4,318,12,155.32);
INSERT INTO items VALUES (62,2,5,200,1,11.88);
INSERT INTO items VALUES (62,2,6,893,1,24.44);
INSERT INTO items VALUES (62,3,1,1008,12,315.15);
INSERT INTO items VALUES (62,3,2,264,1,12.84);
INSERT INTO items VALUES (62,3,3,789,2,28.62);
INSERT INTO items VALUES (62,3,4,1012,12,196.35);
INSERT INTO items VALUES (62,3,5,329,3,44.94);
INSERT INTO items VALUES (62,4,1,260,3,22.02);
INSERT INTO items VALUES (62,4,2,552,2,10.60);
INSERT INTO items VALUES (62,4,3,600,2,33.98);
INSERT INTO items VALUES (62,4,4,522,2,14.60);
INSERT INTO items VALUES (62,4,5,269,2,30.72);
INSERT INTO items VALUES (62,5,1,3,1,9.94);
INSERT INTO items VALUES (62,5,2,24,12,204.60);
INSERT INTO items VALUES (62,5,3,63,2,47.44);
INSERT INTO items VALUES (62,5,4,492,1,22.10);
INSERT INTO items VALUES (63,1,1,466,1,11.81);
INSERT INTO items VALUES (63,1,2,217,12,75.13);
INSERT INTO items VALUES (63,1,3,595,3,86.85);
INSERT INTO items VALUES (63,1,4,82,1,22.30);
INSERT INTO items VALUES (63,2,1,5,2,13.34);
INSERT INTO items VALUES (63,3,1,388,12,268.29);
INSERT INTO items VALUES (63,3,2,295,3,75.15);
INSERT INTO items VALUES (63,3,3,728,12,60.28);
INSERT INTO items VALUES (63,3,4,142,1,15.00);
INSERT INTO items VALUES (63,3,5,1032,2,39.86);
INSERT INTO items VALUES (63,3,6,1007,3,37.02);
INSERT INTO items VALUES (64,1,1,332,3,75.87);
INSERT INTO items VALUES (64,2,1,687,12,185.79);
INSERT INTO items VALUES (64,2,2,930,2,51.02);
INSERT INTO items VALUES (64,2,3,188,2,15.42);
INSERT INTO items VALUES (64,2,4,132,1,18.43);
INSERT INTO items VALUES (64,3,1,276,1,23.22);
INSERT INTO items VALUES (64,3,2,768,2,16.16);
INSERT INTO items VALUES (64,3,3,436,1,5.99);
INSERT INTO items VALUES (64,3,4,483,3,36.18);
INSERT INTO items VALUES (64,3,5,737,3,78.57);
INSERT INTO items VALUES (64,4,1,200,1,11.88);
INSERT INTO items VALUES (64,5,1,565,12,264.22);
INSERT INTO items VALUES (64,5,2,173,1,26.52);
INSERT INTO items VALUES (64,5,3,584,2,22.10);
INSERT INTO items VALUES (64,5,4,393,2,55.40);
INSERT INTO items VALUES (64,5,5,825,12,325.93);
INSERT INTO items VALUES (64,5,6,503,1,24.79);
INSERT INTO items VALUES (64,6,1,803,3,62.07);
INSERT INTO items VALUES (64,6,2,523,12,294.58);
INSERT INTO items VALUES (64,6,3,689,1,10.03);
INSERT INTO items VALUES (65,1,1,869,2,35.86);
INSERT INTO items VALUES (65,1,2,446,2,42.88);
INSERT INTO items VALUES (65,1,3,908,3,35.22);
INSERT INTO items VALUES (65,1,4,45,3,23.13);
INSERT INTO items VALUES (65,1,5,203,2,29.74);
INSERT INTO items VALUES (65,1,6,186,2,17.06);
INSERT INTO items VALUES (65,2,1,1020,3,16.53);
INSERT INTO items VALUES (66,1,1,9,12,269.17);
INSERT INTO items VALUES (66,1,2,252,3,76.95);
INSERT INTO items VALUES (66,1,3,266,2,37.32);
INSERT INTO items VALUES (66,2,1,560,12,252.01);
INSERT INTO items VALUES (66,2,2,307,2,10.56);
INSERT INTO items VALUES (66,3,1,799,2,27.74);
INSERT INTO items VALUES (66,3,2,406,3,20.16);
INSERT INTO items VALUES (66,3,3,152,2,11.62);
INSERT INTO items VALUES (66,4,1,20,2,19.40);
INSERT INTO items VALUES (66,4,2,202,1,10.08);
INSERT INTO items VALUES (66,4,3,584,1,11.05);
INSERT INTO items VALUES (66,4,4,251,1,5.71);
INSERT INTO items VALUES (66,5,1,42,1,21.28);
INSERT INTO items VALUES (67,1,1,831,2,47.22);
INSERT INTO items VALUES (67,1,2,407,2,37.96);
INSERT INTO items VALUES (67,2,1,267,3,25.89);
INSERT INTO items VALUES (67,2,2,986,1,6.56);
INSERT INTO items VALUES (67,2,3,289,2,38.72);
INSERT INTO items VALUES (67,2,4,669,3,40.86);
INSERT INTO items VALUES (67,2,5,924,3,62.01);
INSERT INTO items VALUES (67,2,6,644,12,313.06);
INSERT INTO items VALUES (67,3,1,999,12,193.71);
INSERT INTO items VALUES (67,3,2,1025,2,57.56);
INSERT INTO items VALUES (67,3,3,300,12,290.18);
INSERT INTO items VALUES (67,3,4,401,3,50.25);
INSERT INTO items VALUES (67,4,1,79,2,23.94);
INSERT INTO items VALUES (67,4,2,388,3,73.17);
INSERT INTO items VALUES (67,4,3,888,2,11.56);
INSERT INTO items VALUES (67,4,4,455,2,57.98);
INSERT INTO items VALUES (67,4,5,174,3,77.04);
INSERT INTO items VALUES (67,4,6,918,3,47.10);
INSERT INTO items VALUES (68,1,1,787,2,19.18);
INSERT INTO items VALUES (68,1,2,290,3,26.73);
INSERT INTO items VALUES (68,1,3,481,12,64.02);
INSERT INTO items VALUES (68,1,4,790,2,24.86);
INSERT INTO items VALUES (68,1,5,801,12,56.87);
INSERT INTO items VALUES (68,1,6,453,12,162.47);
INSERT INTO items VALUES (68,2,1,228,3,65.79);
INSERT INTO items VALUES (68,2,2,216,12,253.55);
INSERT INTO items VALUES (68,3,1,265,3,50.19);
INSERT INTO items VALUES (68,3,2,818,3,19.71);
INSERT INTO items VALUES (68,3,3,138,1,21.51);
INSERT INTO items VALUES (68,4,1,691,12,319.00);
INSERT INTO items VALUES (68,5,1,68,1,21.66);
INSERT INTO items VALUES (68,5,2,929,12,207.90);
INSERT INTO items VALUES (68,6,1,234,1,26.40);
INSERT INTO items VALUES (68,6,2,70,2,32.10);
INSERT INTO items VALUES (68,6,3,454,12,311.41);
INSERT INTO items VALUES (68,6,4,185,3,47.76);
INSERT INTO items VALUES (68,6,5,616,2,24.78);
INSERT INTO items VALUES (68,6,6,676,1,12.35);
INSERT INTO items VALUES (69,1,1,732,2,54.18);
INSERT INTO items VALUES (69,2,1,292,1,7.84);
INSERT INTO items VALUES (69,2,2,575,2,51.34);
INSERT INTO items VALUES (70,1,1,1033,1,29.37);
INSERT INTO items VALUES (70,1,2,812,1,13.05);
INSERT INTO items VALUES (70,1,3,814,1,13.52);
INSERT INTO items VALUES (70,1,4,1039,2,52.92);
INSERT INTO items VALUES (70,2,1,886,2,35.06);
INSERT INTO items VALUES (70,2,2,145,1,26.47);
INSERT INTO items VALUES (70,2,3,787,2,19.18);
INSERT INTO items VALUES (70,2,4,754,1,25.04);
INSERT INTO items VALUES (70,2,5,530,3,42.96);
INSERT INTO items VALUES (70,2,6,797,3,54.75);
INSERT INTO items VALUES (71,1,1,217,1,6.83);
INSERT INTO items VALUES (71,1,2,296,3,29.85);
INSERT INTO items VALUES (71,2,1,128,12,233.75);
INSERT INTO items VALUES (71,2,2,868,2,23.40);
INSERT INTO items VALUES (71,2,3,656,1,25.43);
INSERT INTO items VALUES (71,2,4,11,3,49.44);
INSERT INTO items VALUES (71,2,5,651,3,89.76);
INSERT INTO items VALUES (71,3,1,162,2,39.28);
INSERT INTO items VALUES (71,3,2,945,2,31.78);
INSERT INTO items VALUES (71,3,3,534,1,16.15);
INSERT INTO items VALUES (71,3,4,1026,2,52.72);
INSERT INTO items VALUES (71,4,1,1026,3,79.08);
INSERT INTO items VALUES (71,4,2,198,3,41.43);
INSERT INTO items VALUES (71,4,3,702,1,8.82);
INSERT INTO items VALUES (71,4,4,281,2,11.26);
INSERT INTO items VALUES (71,4,5,984,3,18.51);
INSERT INTO items VALUES (71,4,6,614,3,26.79);
INSERT INTO items VALUES (71,5,1,864,2,46.96);
INSERT INTO items VALUES (71,5,2,957,12,62.70);
INSERT INTO items VALUES (71,5,3,751,2,49.78);
INSERT INTO items VALUES (71,5,4,530,12,157.52);
INSERT INTO items VALUES (71,5,5,196,3,61.95);
INSERT INTO items VALUES (71,6,1,494,2,56.70);
INSERT INTO items VALUES (71,6,2,1040,2,56.24);
INSERT INTO items VALUES (71,6,3,161,3,55.89);
INSERT INTO items VALUES (71,6,4,2,2,56.30);
INSERT INTO items VALUES (71,6,5,929,3,56.70);
INSERT INTO items VALUES (72,1,1,814,1,13.52);
INSERT INTO items VALUES (72,1,2,503,3,74.37);
INSERT INTO items VALUES (72,1,3,458,1,8.01);
INSERT INTO items VALUES (72,1,4,7,3,36.60);
INSERT INTO items VALUES (72,1,5,711,1,28.07);
INSERT INTO items VALUES (72,1,6,831,12,259.71);
INSERT INTO items VALUES (72,2,1,706,12,286.22);
INSERT INTO items VALUES (72,2,2,204,2,48.56);
INSERT INTO items VALUES (73,1,1,827,1,20.44);
INSERT INTO items VALUES (73,1,2,180,2,37.14);
INSERT INTO items VALUES (73,1,3,524,2,30.52);
INSERT INTO items VALUES (73,1,4,339,1,10.67);
INSERT INTO items VALUES (73,1,5,984,2,12.34);
INSERT INTO items VALUES (74,1,1,143,2,24.98);
INSERT INTO items VALUES (74,1,2,498,2,32.96);
INSERT INTO items VALUES (74,1,3,798,3,88.44);
INSERT INTO items VALUES (74,1,4,916,3,62.19);
INSERT INTO items VALUES (74,2,1,473,12,80.08);
INSERT INTO items VALUES (74,2,2,921,3,75.90);
INSERT INTO items VALUES (74,2,3,162,12,216.04);
INSERT INTO items VALUES (74,3,1,463,3,81.42);
INSERT INTO items VALUES (74,3,2,230,3,33.72);
INSERT INTO items VALUES (74,3,3,993,3,73.11);
INSERT INTO items VALUES (74,3,4,952,3,64.44);
INSERT INTO items VALUES (74,4,1,683,3,27.57);
INSERT INTO items VALUES (74,5,1,487,1,29.62);
INSERT INTO items VALUES (74,5,2,943,12,177.43);
INSERT INTO items VALUES (75,1,1,454,3,84.93);
INSERT INTO items VALUES (75,2,1,429,3,49.56);
INSERT INTO items VALUES (75,2,2,104,12,70.62);
INSERT INTO items VALUES (75,2,3,637,3,43.68);
INSERT INTO items VALUES (75,3,1,847,1,18.79);
INSERT INTO items VALUES (75,3,2,932,2,42.14);
INSERT INTO items VALUES (75,4,1,130,1,15.76);
INSERT INTO items VALUES (75,4,2,394,2,10.76);
INSERT INTO items VALUES (75,4,3,550,1,11.22);
INSERT INTO items VALUES (75,4,4,889,12,153.12);
INSERT INTO items VALUES (75,4,5,770,12,173.91);
INSERT INTO items VALUES (75,4,6,794,2,21.04);
INSERT INTO items VALUES (75,5,1,407,2,37.96);
INSERT INTO items VALUES (75,5,2,386,2,56.90);
INSERT INTO items VALUES (76,1,1,793,3,49.11);
INSERT INTO items VALUES (76,1,2,233,1,5.65);
INSERT INTO items VALUES (76,1,3,28,2,39.98);
INSERT INTO items VALUES (76,1,4,17,12,277.53);
INSERT INTO items VALUES (76,1,5,196,12,227.15);
INSERT INTO items VALUES (76,1,6,752,3,25.77);
INSERT INTO items VALUES (76,2,1,169,2,19.50);
INSERT INTO items VALUES (76,2,2,882,2,43.38);
INSERT INTO items VALUES (76,2,3,193,3,72.54);
INSERT INTO items VALUES (76,3,1,930,3,76.53);
INSERT INTO items VALUES (76,3,2,387,12,169.73);
INSERT INTO items VALUES (76,4,1,892,1,7.25);
INSERT INTO items VALUES (76,4,2,92,1,29.26);
INSERT INTO items VALUES (76,4,3,998,1,12.30);
INSERT INTO items VALUES (76,4,4,640,1,11.45);
INSERT INTO items VALUES (76,4,5,448,2,11.56);
INSERT INTO items VALUES (76,5,1,33,1,18.75);
INSERT INTO items VALUES (76,5,2,8,12,110.66);
INSERT INTO items VALUES (76,5,3,685,2,22.44);
INSERT INTO items VALUES (76,5,4,870,3,68.67);
INSERT INTO items VALUES (76,5,5,797,3,54.75);
INSERT INTO items VALUES (77,1,1,442,12,150.37);
INSERT INTO items VALUES (78,1,1,623,12,243.10);
INSERT INTO items VALUES (78,1,2,263,3,39.36);
INSERT INTO items VALUES (78,1,3,898,2,44.04);
INSERT INTO items VALUES (78,2,1,256,3,84.03);
INSERT INTO items VALUES (78,3,1,874,2,38.80);
INSERT INTO items VALUES (78,3,2,825,1,29.63);
INSERT INTO items VALUES (78,4,1,592,2,30.64);
INSERT INTO items VALUES (78,4,2,339,12,117.37);
INSERT INTO items VALUES (78,4,3,924,12,227.37);
INSERT INTO items VALUES (78,5,1,724,2,41.26);
INSERT INTO items VALUES (78,5,2,854,3,74.25);
INSERT INTO items VALUES (78,5,3,295,2,50.10);
INSERT INTO items VALUES (79,1,1,720,3,84.36);
INSERT INTO items VALUES (79,1,2,126,1,24.09);
INSERT INTO items VALUES (79,1,3,325,2,26.42);
INSERT INTO items VALUES (79,2,1,463,12,298.54);
INSERT INTO items VALUES (79,2,2,738,12,266.42);
INSERT INTO items VALUES (79,2,3,640,1,11.45);
INSERT INTO items VALUES (79,3,1,493,3,67.17);
INSERT INTO items VALUES (79,3,2,695,12,264.33);
INSERT INTO items VALUES (79,3,3,158,2,26.78);
INSERT INTO items VALUES (79,3,4,679,2,23.62);
INSERT INTO items VALUES (79,4,1,713,3,75.18);
INSERT INTO items VALUES (79,4,2,705,1,9.97);
INSERT INTO items VALUES (79,5,1,821,3,17.07);
INSERT INTO items VALUES (79,5,2,242,1,28.32);
INSERT INTO items VALUES (80,1,1,427,3,60.03);
INSERT INTO items VALUES (80,1,2,218,1,9.06);
INSERT INTO items VALUES (81,1,1,468,12,314.60);
INSERT INTO items VALUES (81,2,1,201,2,34.76);
INSERT INTO items VALUES (81,3,1,782,12,132.66);
INSERT INTO items VALUES (81,4,1,242,1,28.32);
INSERT INTO items VALUES (81,4,2,827,2,40.88);
INSERT INTO items VALUES (82,1,1,984,2,12.34);
INSERT INTO items VALUES (82,1,2,730,1,24.66);
INSERT INTO items VALUES (82,2,1,596,12,203.17);
INSERT INTO items VALUES (82,2,2,489,3,64.05);
INSERT INTO items VALUES (82,2,3,163,3,61.14);
INSERT INTO items VALUES (82,2,4,971,2,39.62);
INSERT INTO items VALUES (82,3,1,937,1,5.75);
INSERT INTO items VALUES (82,3,2,540,1,26.85);
INSERT INTO items VALUES (82,3,3,315,2,51.86);
INSERT INTO items VALUES (82,3,4,487,12,325.82);
INSERT INTO items VALUES (82,4,1,20,2,19.40);
INSERT INTO items VALUES (82,4,2,600,2,33.98);
INSERT INTO items VALUES (82,4,3,973,3,48.06);
INSERT INTO items VALUES (82,4,4,213,12,276.87);
INSERT INTO items VALUES (82,4,5,106,1,26.10);
INSERT INTO items VALUES (83,1,1,598,3,38.79);
INSERT INTO items VALUES (83,1,2,496,1,23.47);
INSERT INTO items VALUES (83,2,1,285,12,93.94);
INSERT INTO items VALUES (83,2,2,307,3,15.84);
INSERT INTO items VALUES (83,3,1,138,2,43.02);
INSERT INTO items VALUES (83,3,2,619,3,62.37);
INSERT INTO items VALUES (83,4,1,412,1,6.56);
INSERT INTO items VALUES (83,4,2,978,12,110.55);
INSERT INTO items VALUES (83,4,3,828,3,49.53);
INSERT INTO items VALUES (83,4,4,439,12,210.43);
INSERT INTO items VALUES (83,4,5,1022,3,18.75);
INSERT INTO items VALUES (83,4,6,950,2,22.12);
INSERT INTO items VALUES (83,5,1,1006,1,20.16);
INSERT INTO items VALUES (83,6,1,229,3,20.97);
INSERT INTO items VALUES (83,6,2,433,3,63.93);
INSERT INTO items VALUES (83,6,3,759,2,42.14);
INSERT INTO items VALUES (83,6,4,496,3,70.41);
INSERT INTO items VALUES (84,1,1,844,2,37.64);
INSERT INTO items VALUES (84,1,2,577,2,42.12);
INSERT INTO items VALUES (84,1,3,374,3,27.84);
INSERT INTO items VALUES (84,1,4,415,3,33.93);
INSERT INTO items VALUES (84,1,5,983,12,287.21);
INSERT INTO items VALUES (85,1,1,75,12,250.03);
INSERT INTO items VALUES (85,2,1,16,1,8.95);
INSERT INTO items VALUES (85,2,2,775,12,117.26);
INSERT INTO items VALUES (85,2,3,6,1,20.25);
INSERT INTO items VALUES (86,1,1,172,1,29.89);
INSERT INTO items VALUES (86,1,2,25,3,44.73);
INSERT INTO items VALUES (86,1,3,712,2,56.42);
INSERT INTO items VALUES (86,1,4,831,3,70.83);
INSERT INTO items VALUES (86,1,5,582,3,62.64);
INSERT INTO items VALUES (86,2,1,575,12,282.37);
INSERT INTO items VALUES (86,2,2,752,2,17.18);
INSERT INTO items VALUES (86,2,3,948,12,92.18);
INSERT INTO items VALUES (86,2,4,815,2,12.88);
INSERT INTO items VALUES (86,2,5,226,12,95.48);
INSERT INTO items VALUES (86,2,6,192,1,22.37);
INSERT INTO items VALUES (86,3,1,494,12,311.85);
INSERT INTO items VALUES (86,3,2,177,1,27.41);
INSERT INTO items VALUES (86,3,3,437,2,17.22);
INSERT INTO items VALUES (87,1,1,514,3,48.54);
INSERT INTO items VALUES (87,1,2,853,2,58.46);
INSERT INTO items VALUES (87,1,3,389,1,17.52);
INSERT INTO items VALUES (87,1,4,517,1,7.42);
INSERT INTO items VALUES (87,1,5,359,3,55.83);
INSERT INTO items VALUES (87,1,6,913,2,43.36);
INSERT INTO items VALUES (88,1,1,827,1,20.44);
INSERT INTO items VALUES (88,1,2,557,12,149.38);
INSERT INTO items VALUES (88,2,1,617,2,24.18);
INSERT INTO items VALUES (88,2,2,306,12,291.17);
INSERT INTO items VALUES (88,2,3,776,2,47.26);
INSERT INTO items VALUES (88,3,1,425,2,31.70);
INSERT INTO items VALUES (88,3,2,1015,3,85.05);
INSERT INTO items VALUES (88,3,3,161,12,204.93);
INSERT INTO items VALUES (88,3,4,802,12,134.64);
INSERT INTO items VALUES (88,3,5,45,2,15.42);
INSERT INTO items VALUES (88,3,6,895,3,75.18);
INSERT INTO items VALUES (88,4,1,597,12,304.37);
INSERT INTO items VALUES (88,4,2,182,2,14.86);
INSERT INTO items VALUES (88,5,1,531,2,49.56);
INSERT INTO items VALUES (88,5,2,701,2,48.64);
INSERT INTO items VALUES (88,6,1,646,12,87.45);
INSERT INTO items VALUES (88,6,2,573,1,20.36);
INSERT INTO items VALUES (88,6,3,88,2,29.18);
INSERT INTO items VALUES (88,6,4,251,3,17.13);
INSERT INTO items VALUES (88,6,5,600,12,186.89);
INSERT INTO items VALUES (88,6,6,701,3,72.96);
INSERT INTO items VALUES (89,1,1,338,3,72.84);
INSERT INTO items VALUES (89,1,2,193,12,265.98);
INSERT INTO items VALUES (89,1,3,529,1,29.10);
INSERT INTO items VALUES (89,1,4,73,1,10.70);
INSERT INTO items VALUES (90,1,1,913,3,65.04);
INSERT INTO items VALUES (90,1,2,118,2,28.76);
INSERT INTO items VALUES (90,1,3,494,12,311.85);
INSERT INTO items VALUES (90,2,1,187,3,19.32);
INSERT INTO items VALUES (90,2,2,632,12,181.28);
INSERT INTO items VALUES (90,3,1,893,3,73.32);
INSERT INTO items VALUES (90,3,2,976,1,10.41);
INSERT INTO items VALUES (90,3,3,127,2,35.72);
INSERT INTO items VALUES (90,3,4,558,12,314.49);
INSERT INTO items VALUES (90,4,1,277,1,26.37);
INSERT INTO items VALUES (90,5,1,742,2,45.58);
INSERT INTO items VALUES (90,5,2,308,2,26.12);
INSERT INTO items VALUES (90,5,3,881,3,77.49);
INSERT INTO items VALUES (90,5,4,38,3,17.25);
INSERT INTO items VALUES (90,5,5,277,12,290.07);
INSERT INTO items VALUES (90,5,6,883,2,18.60);
INSERT INTO items VALUES (91,1,1,454,12,311.41);
INSERT INTO items VALUES (91,1,2,741,3,38.67);
INSERT INTO items VALUES (91,1,3,920,1,20.28);
INSERT INTO items VALUES (91,2,1,313,1,20.22);
INSERT INTO items VALUES (91,2,2,78,1,15.50);
INSERT INTO items VALUES (92,1,1,76,12,197.34);
INSERT INTO items VALUES (92,1,2,1048,12,105.60);
INSERT INTO items VALUES (92,1,3,696,2,13.24);
INSERT INTO items VALUES (92,1,4,331,3,23.52);
INSERT INTO items VALUES (92,1,5,156,12,82.39);
INSERT INTO items VALUES (92,1,6,463,1,27.14);
INSERT INTO items VALUES (92,2,1,814,1,13.52);
INSERT INTO items VALUES (92,2,2,940,12,133.98);
INSERT INTO items VALUES (92,2,3,254,3,67.65);
INSERT INTO items VALUES (92,2,4,142,2,30.00);
INSERT INTO items VALUES (92,2,5,285,12,93.94);
INSERT INTO items VALUES (93,1,1,107,12,70.51);
INSERT INTO items VALUES (93,1,2,885,12,101.42);
INSERT INTO items VALUES (93,1,3,446,1,21.44);
INSERT INTO items VALUES (93,1,4,698,12,170.50);
INSERT INTO items VALUES (93,1,5,222,2,48.40);
INSERT INTO items VALUES (93,2,1,360,3,35.82);
INSERT INTO items VALUES (93,2,2,117,12,274.23);
INSERT INTO items VALUES (93,2,3,953,12,219.23);
INSERT INTO items VALUES (93,2,4,715,1,18.98);
INSERT INTO items VALUES (93,2,5,887,2,30.20);
INSERT INTO items VALUES (93,2,6,437,3,25.83);
INSERT INTO items VALUES (93,3,1,1043,2,33.46);
INSERT INTO items VALUES (93,3,2,174,1,25.68);
INSERT INTO items VALUES (93,4,1,701,3,72.96);
INSERT INTO items VALUES (93,4,2,293,12,239.69);
INSERT INTO items VALUES (93,4,3,505,1,27.63);
INSERT INTO items VALUES (93,4,4,756,1,29.52);
INSERT INTO items VALUES (93,5,1,976,2,20.82);
INSERT INTO items VALUES (93,5,2,876,3,38.19);
INSERT INTO items VALUES (93,5,3,597,12,304.37);
INSERT INTO items VALUES (93,5,4,985,3,61.02);
INSERT INTO items VALUES (93,5,5,39,3,22.14);
INSERT INTO items VALUES (93,5,6,289,2,38.72);
INSERT INTO items VALUES (93,6,1,435,12,130.35);
INSERT INTO items VALUES (94,1,1,119,2,35.64);
INSERT INTO items VALUES (94,1,2,870,2,45.78);
INSERT INTO items VALUES (94,1,3,148,2,26.48);
INSERT INTO items VALUES (94,1,4,1032,12,219.23);
INSERT INTO items VALUES (94,1,5,390,3,25.29);
INSERT INTO items VALUES (94,1,6,9,12,269.17);
INSERT INTO items VALUES (94,2,1,437,1,8.61);
INSERT INTO items VALUES (94,2,2,12,2,54.84);
INSERT INTO items VALUES (94,2,3,389,1,17.52);
INSERT INTO items VALUES (94,2,4,376,1,21.17);
INSERT INTO items VALUES (95,1,1,944,1,19.94);
INSERT INTO items VALUES (95,1,2,551,12,261.03);
INSERT INTO items VALUES (95,1,3,398,1,29.14);
INSERT INTO items VALUES (95,1,4,922,2,46.00);
INSERT INTO items VALUES (95,2,1,656,2,50.86);
INSERT INTO items VALUES (95,2,2,844,12,207.02);
INSERT INTO items VALUES (95,2,3,794,12,115.72);
INSERT INTO items VALUES (95,2,4,305,12,57.97);
INSERT INTO items VALUES (95,2,5,836,2,32.38);
INSERT INTO items VALUES (95,3,1,133,2,35.08);
INSERT INTO items VALUES (95,3,2,812,3,39.15);
INSERT INTO items VALUES (95,3,3,774,3,17.04);
INSERT INTO items VALUES (95,3,4,827,12,224.84);
INSERT INTO items VALUES (95,3,5,896,1,27.56);
INSERT INTO items VALUES (95,3,6,181,1,5.47);
INSERT INTO items VALUES (95,4,1,757,12,235.07);
INSERT INTO items VALUES (95,4,2,448,3,17.34);
INSERT INTO items VALUES (95,4,3,225,3,50.88);
INSERT INTO items VALUES (95,4,4,65,3,29.94);
INSERT INTO items VALUES (95,5,1,854,12,272.25);
INSERT INTO items VALUES (95,5,2,4,3,63.48);
INSERT INTO items VALUES (95,5,3,859,12,112.86);
INSERT INTO items VALUES (95,6,1,765,1,29.88);
INSERT INTO items VALUES (96,1,1,1046,3,33.00);
INSERT INTO items VALUES (96,2,1,586,2,35.40);
INSERT INTO items VALUES (96,2,2,983,2,52.22);
INSERT INTO items VALUES (96,2,3,362,3,68.76);
INSERT INTO items VALUES (96,3,1,111,12,306.68);
INSERT INTO items VALUES (96,4,1,628,3,28.71);
INSERT INTO items VALUES (96,4,2,761,1,18.88);
INSERT INTO items VALUES (96,4,3,765,1,29.88);
INSERT INTO items VALUES (96,4,4,967,1,7.48);
INSERT INTO items VALUES (96,5,1,241,2,33.90);
INSERT INTO items VALUES (96,5,2,219,3,19.35);
INSERT INTO items VALUES (97,1,1,635,1,21.39);
INSERT INTO items VALUES (97,1,2,465,1,8.00);
INSERT INTO items VALUES (97,1,3,775,1,10.66);
INSERT INTO items VALUES (97,2,1,367,3,59.61);
INSERT INTO items VALUES (97,2,2,198,1,13.81);
INSERT INTO items VALUES (97,2,3,766,2,59.72);
INSERT INTO items VALUES (97,2,4,460,1,19.35);
INSERT INTO items VALUES (97,2,5,655,12,234.52);
INSERT INTO items VALUES (98,1,1,359,1,18.61);
INSERT INTO items VALUES (98,1,2,87,2,34.38);
INSERT INTO items VALUES (98,1,3,993,1,24.37);
INSERT INTO items VALUES (98,1,4,319,12,161.70);
INSERT INTO items VALUES (98,2,1,265,2,33.46);
INSERT INTO items VALUES (98,2,2,298,3,73.92);
INSERT INTO items VALUES (98,2,3,797,2,36.50);
INSERT INTO items VALUES (98,2,4,308,12,143.66);
INSERT INTO items VALUES (99,1,1,468,2,57.20);
INSERT INTO items VALUES (99,2,1,635,12,235.29);
INSERT INTO items VALUES (99,2,2,93,3,65.01);
INSERT INTO items VALUES (99,3,1,266,12,205.26);
INSERT INTO items VALUES (99,4,1,58,12,292.60);
INSERT INTO items VALUES (99,4,2,873,2,41.30);
INSERT INTO items VALUES (99,4,3,1018,3,27.66);
INSERT INTO items VALUES (100,1,1,236,12,242.11);
INSERT INTO items VALUES (100,1,2,264,1,12.84);
INSERT INTO items VALUES (100,1,3,386,1,28.45);
INSERT INTO items VALUES (100,1,4,774,3,17.04);
INSERT INTO items VALUES (100,2,1,418,1,10.33);
INSERT INTO items VALUES (100,3,1,453,3,44.31);
INSERT INTO items VALUES (100,3,2,284,12,97.79);
INSERT INTO items VALUES (100,3,3,197,1,11.73);
INSERT INTO items VALUES (100,4,1,312,1,11.93);
INSERT INTO items VALUES (100,4,2,443,12,322.52);
INSERT INTO items VALUES (100,4,3,490,3,24.93);
INSERT INTO items VALUES (100,4,4,720,1,28.12);
INSERT INTO items VALUES (100,4,5,854,1,24.75);
INSERT INTO items VALUES (100,4,6,315,1,25.93);
INSERT INTO items VALUES (100,5,1,582,2,41.76);
INSERT INTO items VALUES (100,5,2,795,3,64.38);
INSERT INTO items VALUES (100,5,3,432,2,50.90);
INSERT INTO items VALUES (100,5,4,163,3,61.14);
INSERT INTO items VALUES (100,5,5,142,3,45.00);
INSERT INTO items VALUES (101,1,1,649,3,51.27);
INSERT INTO items VALUES (101,1,2,32,3,38.64);
INSERT INTO items VALUES (102,1,1,134,3,67.35);
INSERT INTO items VALUES (102,1,2,956,12,221.21);
INSERT INTO items VALUES (102,1,3,512,2,54.98);
INSERT INTO items VALUES (102,1,4,217,3,20.49);
INSERT INTO items VALUES (103,1,1,316,3,86.34);
INSERT INTO items VALUES (103,2,1,602,3,35.16);
INSERT INTO items VALUES (103,2,2,1037,12,293.37);
INSERT INTO items VALUES (103,3,1,931,1,14.34);
INSERT INTO items VALUES (103,3,2,621,12,324.06);
INSERT INTO items VALUES (103,3,3,481,12,64.02);
INSERT INTO items VALUES (103,3,4,695,12,264.33);
INSERT INTO items VALUES (103,3,5,334,3,42.75);
INSERT INTO items VALUES (103,3,6,986,3,19.68);
INSERT INTO items VALUES (103,4,1,773,3,76.20);
INSERT INTO items VALUES (103,4,2,169,3,29.25);
INSERT INTO items VALUES (103,4,3,666,12,171.05);
INSERT INTO items VALUES (103,4,4,396,3,35.85);
INSERT INTO items VALUES (103,5,1,611,1,21.32);
INSERT INTO items VALUES (103,5,2,865,1,29.58);
INSERT INTO items VALUES (103,5,3,72,1,24.96);
INSERT INTO items VALUES (103,5,4,925,1,16.97);
INSERT INTO items VALUES (103,5,5,800,1,18.16);
INSERT INTO items VALUES (103,5,6,189,2,33.46);
INSERT INTO items VALUES (103,6,1,78,12,170.50);
INSERT INTO items VALUES (103,6,2,82,2,44.60);
INSERT INTO items VALUES (104,1,1,842,12,313.83);
INSERT INTO items VALUES (104,1,2,419,1,11.04);
INSERT INTO items VALUES (104,1,3,1013,3,30.12);
INSERT INTO items VALUES (104,1,4,976,12,114.51);
INSERT INTO items VALUES (104,2,1,427,1,20.01);
INSERT INTO items VALUES (104,3,1,106,1,26.10);
INSERT INTO items VALUES (104,3,2,732,12,297.99);
INSERT INTO items VALUES (104,3,3,264,2,25.68);
INSERT INTO items VALUES (104,3,4,390,1,8.43);
INSERT INTO items VALUES (104,4,1,649,12,187.99);
INSERT INTO items VALUES (104,4,2,469,1,26.88);
INSERT INTO items VALUES (105,1,1,752,1,8.59);
INSERT INTO items VALUES (105,1,2,159,2,29.52);
INSERT INTO items VALUES (105,1,3,170,1,9.75);
INSERT INTO items VALUES (105,1,4,47,12,264.44);
INSERT INTO items VALUES (105,2,1,173,2,53.04);
INSERT INTO items VALUES (105,2,2,657,2,34.86);
INSERT INTO items VALUES (105,2,3,38,3,17.25);
INSERT INTO items VALUES (105,2,4,947,2,39.06);
INSERT INTO items VALUES (105,3,1,998,12,135.30);
INSERT INTO items VALUES (106,1,1,801,3,15.51);
INSERT INTO items VALUES (106,1,2,217,3,20.49);
INSERT INTO items VALUES (106,1,3,770,12,173.91);
INSERT INTO items VALUES (106,1,4,814,1,13.52);
INSERT INTO items VALUES (106,1,5,445,1,21.43);
INSERT INTO items VALUES (106,2,1,799,3,41.61);
INSERT INTO items VALUES (107,1,1,31,3,50.22);
INSERT INTO items VALUES (107,1,2,728,3,16.44);
INSERT INTO items VALUES (107,1,3,326,2,26.32);
INSERT INTO items VALUES (107,2,1,976,2,20.82);
INSERT INTO items VALUES (107,2,2,232,1,14.33);
INSERT INTO items VALUES (108,1,1,681,1,28.12);
INSERT INTO items VALUES (108,1,2,982,2,57.34);
INSERT INTO items VALUES (108,1,3,405,2,12.92);
INSERT INTO items VALUES (108,1,4,444,12,199.76);
INSERT INTO items VALUES (108,1,5,28,1,19.99);
INSERT INTO items VALUES (108,1,6,255,2,54.96);
INSERT INTO items VALUES (108,2,1,833,1,19.63);
INSERT INTO items VALUES (108,3,1,194,12,166.10);
INSERT INTO items VALUES (108,3,2,419,12,121.44);
INSERT INTO items VALUES (108,3,3,938,2,53.70);
INSERT INTO items VALUES (108,3,4,240,2,22.88);
INSERT INTO items VALUES (108,4,1,994,3,46.32);
INSERT INTO items VALUES (108,5,1,163,1,20.38);
INSERT INTO items VALUES (108,6,1,618,2,58.14);
INSERT INTO items VALUES (108,6,2,400,12,107.36);
INSERT INTO items VALUES (108,6,3,594,3,18.24);
INSERT INTO items VALUES (109,1,1,1000,12,76.01);
INSERT INTO items VALUES (109,1,2,853,2,58.46);
INSERT INTO items VALUES (109,1,3,907,3,66.15);
INSERT INTO items VALUES (109,1,4,755,12,145.75);
INSERT INTO items VALUES (109,1,5,890,12,217.58);
INSERT INTO items VALUES (109,1,6,968,3,56.07);
INSERT INTO items VALUES (109,2,1,515,1,25.09);
INSERT INTO items VALUES (109,3,1,378,2,59.36);
INSERT INTO items VALUES (109,3,2,879,2,17.86);
INSERT INTO items VALUES (109,3,3,243,3,58.05);
INSERT INTO items VALUES (109,3,4,791,1,5.19);
INSERT INTO items VALUES (109,3,5,363,2,29.44);
INSERT INTO items VALUES (109,3,6,61,1,16.98);
INSERT INTO items VALUES (109,4,1,748,3,68.28);
INSERT INTO items VALUES (109,4,2,239,1,24.19);
INSERT INTO items VALUES (110,1,1,783,2,55.74);
INSERT INTO items VALUES (110,1,2,333,1,16.64);
INSERT INTO items VALUES (110,1,3,580,12,269.39);
INSERT INTO items VALUES (110,2,1,721,1,5.07);
INSERT INTO items VALUES (110,2,2,150,2,17.32);
INSERT INTO items VALUES (110,2,3,680,2,10.50);
INSERT INTO items VALUES (110,2,4,4,2,42.32);
INSERT INTO items VALUES (110,3,1,998,12,135.30);
INSERT INTO items VALUES (110,4,1,602,2,23.44);
INSERT INTO items VALUES (110,4,2,106,12,287.10);
INSERT INTO items VALUES (110,4,3,213,3,75.51);
INSERT INTO items VALUES (110,4,4,512,12,302.39);
INSERT INTO items VALUES (110,4,5,874,3,58.20);
INSERT INTO items VALUES (110,5,1,185,12,175.12);
INSERT INTO items VALUES (110,5,2,1004,2,48.36);
INSERT INTO items VALUES (110,5,3,1013,12,110.44);
INSERT INTO items VALUES (110,6,1,74,12,138.16);
INSERT INTO items VALUES (110,6,2,918,1,15.70);
INSERT INTO items VALUES (110,6,3,843,1,8.11);
INSERT INTO items VALUES (111,1,1,350,12,153.89);
INSERT INTO items VALUES (111,1,2,473,3,21.84);
INSERT INTO items VALUES (111,1,3,131,2,37.48);
INSERT INTO items VALUES (111,1,4,716,2,27.70);
INSERT INTO items VALUES (111,1,5,379,3,25.17);
INSERT INTO items VALUES (111,1,6,665,12,73.92);
INSERT INTO items VALUES (111,2,1,445,2,42.86);
INSERT INTO items VALUES (111,2,2,329,3,44.94);
INSERT INTO items VALUES (111,2,3,140,3,17.85);
INSERT INTO items VALUES (111,2,4,494,3,85.05);
INSERT INTO items VALUES (111,3,1,712,12,310.31);
INSERT INTO items VALUES (111,3,2,289,2,38.72);
INSERT INTO items VALUES (111,3,3,325,3,39.63);
INSERT INTO items VALUES (111,3,4,1000,12,76.01);
INSERT INTO items VALUES (111,3,5,486,1,15.87);
INSERT INTO items VALUES (111,3,6,117,3,74.79);
INSERT INTO items VALUES (111,4,1,614,1,8.93);
INSERT INTO items VALUES (111,4,2,159,1,14.76);
INSERT INTO items VALUES (111,4,3,1036,3,35.22);
INSERT INTO items VALUES (111,4,4,710,12,321.97);
INSERT INTO items VALUES (111,5,1,703,12,294.47);
INSERT INTO items VALUES (111,5,2,946,3,28.53);
INSERT INTO items VALUES (112,1,1,768,3,24.24);
INSERT INTO items VALUES (112,1,2,841,2,50.76);
INSERT INTO items VALUES (112,1,3,242,1,28.32);
INSERT INTO items VALUES (112,1,4,450,2,28.84);
INSERT INTO items VALUES (112,1,5,32,1,12.88);
INSERT INTO items VALUES (112,2,1,21,2,38.28);
INSERT INTO items VALUES (112,2,2,603,12,63.58);
INSERT INTO items VALUES (112,2,3,393,1,27.70);
INSERT INTO items VALUES (112,2,4,689,3,30.09);
INSERT INTO items VALUES (112,2,5,1025,3,86.34);
INSERT INTO items VALUES (112,2,6,712,2,56.42);
INSERT INTO items VALUES (112,3,1,228,12,241.23);
INSERT INTO items VALUES (112,3,2,297,1,25.27);
INSERT INTO items VALUES (112,3,3,29,1,20.97);
INSERT INTO items VALUES (112,3,4,113,1,19.25);
INSERT INTO items VALUES (112,3,5,884,3,50.67);
INSERT INTO items VALUES (112,3,6,475,3,86.52);
INSERT INTO items VALUES (112,4,1,42,2,42.56);
INSERT INTO items VALUES (112,5,1,280,3,55.74);
INSERT INTO items VALUES (112,5,2,600,2,33.98);
INSERT INTO items VALUES (112,5,3,629,12,266.09);
INSERT INTO items VALUES (112,5,4,766,3,89.58);
INSERT INTO items VALUES (113,1,1,261,1,15.37);
INSERT INTO items VALUES (114,1,1,19,1,29.22);
INSERT INTO items VALUES (114,1,2,418,1,10.33);
INSERT INTO items VALUES (114,2,1,922,1,23.00);
INSERT INTO items VALUES (114,3,1,186,3,25.59);
INSERT INTO items VALUES (114,3,2,947,3,58.59);
INSERT INTO items VALUES (114,3,3,112,2,15.90);
INSERT INTO items VALUES (114,3,4,343,3,17.10);
INSERT INTO items VALUES (114,3,5,503,3,74.37);
INSERT INTO items VALUES (114,3,6,2,2,56.30);
INSERT INTO items VALUES (114,4,1,225,1,16.96);
INSERT INTO items VALUES (114,4,2,997,1,9.03);
INSERT INTO items VALUES (114,4,3,208,1,10.19);
INSERT INTO items VALUES (114,4,4,849,1,28.96);
INSERT INTO items VALUES (114,4,5,410,12,192.94);
INSERT INTO items VALUES (115,1,1,148,12,145.64);
INSERT INTO items VALUES (115,1,2,108,12,178.31);
INSERT INTO items VALUES (115,1,3,894,3,23.64);
INSERT INTO items VALUES (115,1,4,626,2,16.56);
INSERT INTO items VALUES (115,2,1,913,3,65.04);
INSERT INTO items VALUES (115,2,2,191,1,17.29);
INSERT INTO items VALUES (115,2,3,456,2,51.32);
INSERT INTO items VALUES (115,2,4,482,2,49.90);
INSERT INTO items VALUES (115,2,5,901,3,47.01);
INSERT INTO items VALUES (115,2,6,540,12,295.35);
INSERT INTO items VALUES (115,3,1,281,12,61.93);
INSERT INTO items VALUES (115,3,2,255,12,302.28);
INSERT INTO items VALUES (115,3,3,23,3,79.68);
INSERT INTO items VALUES (115,3,4,1026,2,52.72);
INSERT INTO items VALUES (116,1,1,976,12,114.51);
INSERT INTO items VALUES (116,1,2,311,2,48.44);
INSERT INTO items VALUES (116,1,3,878,1,22.43);
INSERT INTO items VALUES (116,1,4,871,3,30.66);
INSERT INTO items VALUES (116,1,5,998,1,12.30);
INSERT INTO items VALUES (116,1,6,852,2,52.18);
INSERT INTO items VALUES (116,2,1,545,12,188.10);
INSERT INTO items VALUES (116,2,2,776,12,259.93);
INSERT INTO items VALUES (116,2,3,393,3,83.10);
INSERT INTO items VALUES (116,2,4,765,12,328.68);
INSERT INTO items VALUES (116,2,5,426,1,8.67);
INSERT INTO items VALUES (116,3,1,600,2,33.98);
INSERT INTO items VALUES (116,3,2,1027,3,86.19);
INSERT INTO items VALUES (117,1,1,558,12,314.49);
INSERT INTO items VALUES (117,2,1,669,3,40.86);
INSERT INTO items VALUES (117,3,1,718,12,111.10);
INSERT INTO items VALUES (117,3,2,302,3,68.10);
INSERT INTO items VALUES (117,3,3,433,12,234.41);
INSERT INTO items VALUES (117,3,4,478,2,35.66);
INSERT INTO items VALUES (117,3,5,885,12,101.42);
INSERT INTO items VALUES (117,3,6,610,12,65.56);
INSERT INTO items VALUES (118,1,1,213,1,25.17);
INSERT INTO items VALUES (118,1,2,46,3,47.01);
INSERT INTO items VALUES (118,1,3,435,1,11.85);
INSERT INTO items VALUES (118,2,1,206,12,270.60);
INSERT INTO items VALUES (118,2,2,140,12,65.45);
INSERT INTO items VALUES (118,2,3,372,3,30.63);
INSERT INTO items VALUES (118,2,4,830,2,17.16);
INSERT INTO items VALUES (118,2,5,150,3,25.98);
INSERT INTO items VALUES (118,3,1,244,2,24.42);
INSERT INTO items VALUES (118,3,2,898,2,44.04);
INSERT INTO items VALUES (118,3,3,236,2,44.02);
INSERT INTO items VALUES (118,3,4,392,3,39.51);
INSERT INTO items VALUES (118,3,5,205,12,142.89);
INSERT INTO items VALUES (118,4,1,260,2,14.68);
INSERT INTO items VALUES (118,4,2,1033,1,29.37);
INSERT INTO items VALUES (118,4,3,782,1,12.06);
INSERT INTO items VALUES (118,5,1,768,2,16.16);
INSERT INTO items VALUES (118,6,1,57,1,17.60);
INSERT INTO items VALUES (118,6,2,187,1,6.44);
INSERT INTO items VALUES (118,6,3,186,2,17.06);
INSERT INTO items VALUES (118,6,4,480,1,28.89);
INSERT INTO items VALUES (119,1,1,494,2,56.70);
INSERT INTO items VALUES (119,1,2,294,2,15.82);
INSERT INTO items VALUES (119,1,3,632,2,32.96);
INSERT INTO items VALUES (119,2,1,897,3,68.97);
INSERT INTO items VALUES (119,2,2,671,12,288.09);
INSERT INTO items VALUES (119,2,3,766,12,328.46);
INSERT INTO items VALUES (119,2,4,53,1,26.62);
INSERT INTO items VALUES (119,3,1,350,12,153.89);
INSERT INTO items VALUES (119,3,2,119,12,196.02);
INSERT INTO items VALUES (119,3,3,389,2,35.04);
INSERT INTO items VALUES (119,3,4,222,12,266.20);
INSERT INTO items VALUES (119,3,5,870,2,45.78);
INSERT INTO items VALUES (119,4,1,427,2,40.02);
INSERT INTO items VALUES (119,4,2,536,1,24.42);
INSERT INTO items VALUES (119,4,3,106,3,78.30);
INSERT INTO items VALUES (119,4,4,354,2,12.38);
INSERT INTO items VALUES (119,5,1,402,1,19.08);
INSERT INTO items VALUES (119,6,1,783,2,55.74);
INSERT INTO items VALUES (119,6,2,587,3,31.14);
INSERT INTO items VALUES (119,6,3,128,1,21.25);
INSERT INTO items VALUES (120,1,1,1030,1,21.21);
INSERT INTO items VALUES (121,1,1,949,12,118.47);
INSERT INTO items VALUES (121,1,2,1033,1,29.37);
INSERT INTO items VALUES (121,1,3,736,2,52.12);
INSERT INTO items VALUES (121,2,1,151,2,44.74);
INSERT INTO items VALUES (121,2,2,867,12,172.48);
INSERT INTO items VALUES (121,3,1,769,1,5.74);
INSERT INTO items VALUES (121,3,2,209,1,14.80);
INSERT INTO items VALUES (121,3,3,1042,2,53.52);
INSERT INTO items VALUES (122,1,1,570,2,50.18);
INSERT INTO items VALUES (122,1,2,560,3,68.73);
INSERT INTO items VALUES (122,1,3,189,12,184.03);
INSERT INTO items VALUES (122,2,1,308,3,39.18);
INSERT INTO items VALUES (122,2,2,718,3,30.30);
INSERT INTO items VALUES (122,2,3,296,3,29.85);
INSERT INTO items VALUES (122,2,4,897,2,45.98);
INSERT INTO items VALUES (122,3,1,801,1,5.17);
INSERT INTO items VALUES (122,3,2,1025,2,57.56);
INSERT INTO items VALUES (122,3,3,662,3,69.87);
INSERT INTO items VALUES (122,3,4,868,12,128.70);
INSERT INTO items VALUES (122,4,1,543,12,308.66);
INSERT INTO items VALUES (123,1,1,728,1,5.48);
INSERT INTO items VALUES (123,1,2,178,2,22.42);
INSERT INTO items VALUES (123,1,3,506,3,73.11);
INSERT INTO items VALUES (123,1,4,133,3,52.62);
INSERT INTO items VALUES (123,2,1,791,2,10.38);
INSERT INTO items VALUES (123,2,2,566,3,21.12);
INSERT INTO items VALUES (123,2,3,1020,3,16.53);
INSERT INTO items VALUES (123,2,4,261,12,169.07);
INSERT INTO items VALUES (123,3,1,975,3,27.60);
INSERT INTO items VALUES (123,3,2,758,1,18.06);
INSERT INTO items VALUES (123,3,3,969,1,13.93);
INSERT INTO items VALUES (123,3,4,830,1,8.58);
INSERT INTO items VALUES (123,4,1,182,3,22.29);
INSERT INTO items VALUES (123,4,2,659,3,73.14);
INSERT INTO items VALUES (123,5,1,976,1,10.41);
INSERT INTO items VALUES (123,5,2,293,12,239.69);
INSERT INTO items VALUES (123,5,3,616,1,12.39);
INSERT INTO items VALUES (123,5,4,376,2,42.34);
INSERT INTO items VALUES (123,5,5,323,2,27.20);
INSERT INTO items VALUES (123,5,6,540,1,26.85);
INSERT INTO items VALUES (124,1,1,396,1,11.95);
INSERT INTO items VALUES (124,1,2,471,1,28.64);
INSERT INTO items VALUES (124,1,3,317,1,5.79);
INSERT INTO items VALUES (124,1,4,490,12,91.41);
INSERT INTO items VALUES (124,1,5,561,1,8.64);
INSERT INTO items VALUES (124,2,1,652,1,10.28);
INSERT INTO items VALUES (124,2,2,536,12,268.62);
INSERT INTO items VALUES (125,1,1,652,2,20.56);
INSERT INTO items VALUES (125,1,2,789,3,42.93);
INSERT INTO items VALUES (125,1,3,838,12,212.30);
INSERT INTO items VALUES (125,2,1,893,3,73.32);
INSERT INTO items VALUES (125,2,2,509,1,15.58);
INSERT INTO items VALUES (125,2,3,464,3,45.21);
INSERT INTO items VALUES (125,3,1,103,12,136.07);
INSERT INTO items VALUES (125,3,2,979,3,85.17);
INSERT INTO items VALUES (125,3,3,370,3,18.60);
INSERT INTO items VALUES (125,3,4,1025,1,28.78);
INSERT INTO items VALUES (125,3,5,257,12,328.02);
INSERT INTO items VALUES (125,3,6,994,1,15.44);
INSERT INTO items VALUES (125,4,1,438,12,117.37);
INSERT INTO items VALUES (125,4,2,1027,12,316.03);
INSERT INTO items VALUES (125,4,3,708,3,27.36);
INSERT INTO items VALUES (125,4,4,401,12,184.25);
INSERT INTO items VALUES (125,4,5,375,2,46.80);
INSERT INTO items VALUES (125,4,6,714,1,25.79);
INSERT INTO items VALUES (126,1,1,1015,12,311.85);
INSERT INTO items VALUES (126,2,1,755,2,26.50);
INSERT INTO items VALUES (126,3,1,269,3,46.08);
INSERT INTO items VALUES (126,3,2,237,12,280.28);
INSERT INTO items VALUES (126,3,3,810,12,304.81);
INSERT INTO items VALUES (126,3,4,624,12,244.75);
INSERT INTO items VALUES (126,3,5,51,3,72.27);
INSERT INTO items VALUES (126,4,1,879,1,8.93);
INSERT INTO items VALUES (126,4,2,58,2,53.20);
INSERT INTO items VALUES (126,4,3,184,12,298.21);
INSERT INTO items VALUES (126,4,4,989,3,36.27);
INSERT INTO items VALUES (126,4,5,506,2,48.74);
INSERT INTO items VALUES (126,4,6,6,12,222.75);
INSERT INTO items VALUES (127,1,1,684,12,248.05);
INSERT INTO items VALUES (127,1,2,870,2,45.78);
INSERT INTO items VALUES (127,1,3,524,1,15.26);
INSERT INTO items VALUES (127,1,4,1028,1,13.90);
INSERT INTO items VALUES (127,1,5,327,12,277.20);
INSERT INTO items VALUES (127,2,1,577,3,63.18);
INSERT INTO items VALUES (127,2,2,295,12,275.55);
INSERT INTO items VALUES (127,2,3,750,1,6.57);
INSERT INTO items VALUES (127,2,4,570,2,50.18);
INSERT INTO items VALUES (127,2,5,281,3,16.89);
INSERT INTO items VALUES (127,3,1,247,12,279.40);
INSERT INTO items VALUES (127,4,1,897,1,22.99);
INSERT INTO items VALUES (127,4,2,174,12,282.48);
INSERT INTO items VALUES (127,4,3,858,3,15.99);
INSERT INTO items VALUES (127,4,4,644,1,28.46);
INSERT INTO items VALUES (128,1,1,879,2,17.86);
INSERT INTO items VALUES (128,1,2,386,12,312.95);
INSERT INTO items VALUES (128,2,1,932,1,21.07);
INSERT INTO items VALUES (128,2,2,797,2,36.50);
INSERT INTO items VALUES (128,2,3,109,12,176.00);
INSERT INTO items VALUES (128,2,4,642,1,13.91);
INSERT INTO items VALUES (128,2,5,628,2,19.14);
INSERT INTO items VALUES (128,3,1,479,1,11.70);
INSERT INTO items VALUES (128,3,2,952,2,42.96);
INSERT INTO items VALUES (128,3,3,569,2,26.80);
INSERT INTO items VALUES (128,3,4,116,2,23.74);
INSERT INTO items VALUES (128,3,5,692,1,17.90);
INSERT INTO items VALUES (128,4,1,500,12,179.08);
INSERT INTO items VALUES (128,4,2,443,1,29.32);
INSERT INTO items VALUES (128,4,3,826,1,20.90);
INSERT INTO items VALUES (128,4,4,436,2,11.98);
INSERT INTO items VALUES (128,5,1,768,12,88.88);
INSERT INTO items VALUES (129,1,1,75,1,22.73);
INSERT INTO items VALUES (129,1,2,690,1,20.07);
INSERT INTO items VALUES (129,1,3,829,2,21.20);
INSERT INTO items VALUES (129,1,4,606,3,75.93);
INSERT INTO items VALUES (129,1,5,757,3,64.11);
INSERT INTO items VALUES (129,2,1,129,1,5.75);
INSERT INTO items VALUES (129,3,1,191,12,190.19);
INSERT INTO items VALUES (129,3,2,439,12,210.43);
INSERT INTO items VALUES (129,3,3,598,2,25.86);
INSERT INTO items VALUES (130,1,1,874,3,58.20);
INSERT INTO items VALUES (130,1,2,1040,12,309.32);
INSERT INTO items VALUES (130,2,1,858,2,10.66);
INSERT INTO items VALUES (130,2,2,37,2,28.30);
INSERT INTO items VALUES (130,2,3,567,3,37.11);
INSERT INTO items VALUES (130,2,4,688,2,31.54);
INSERT INTO items VALUES (130,2,5,985,3,61.02);
INSERT INTO items VALUES (130,3,1,197,3,35.19);
INSERT INTO items VALUES (130,3,2,954,1,5.51);
INSERT INTO items VALUES (130,3,3,341,12,191.40);
INSERT INTO items VALUES (130,3,4,980,12,245.52);
INSERT INTO items VALUES (130,4,1,306,2,52.94);
INSERT INTO items VALUES (130,4,2,235,12,240.35);
INSERT INTO items VALUES (130,4,3,811,12,63.25);
INSERT INTO items VALUES (130,4,4,174,3,77.04);
INSERT INTO items VALUES (130,4,5,424,1,8.58);
INSERT INTO items VALUES (130,5,1,853,12,321.53);
INSERT INTO items VALUES (130,5,2,386,1,28.45);
INSERT INTO items VALUES (130,5,3,706,2,52.04);
INSERT INTO items VALUES (130,6,1,742,12,250.69);
INSERT INTO items VALUES (130,6,2,839,12,214.50);
INSERT INTO items VALUES (130,6,3,691,3,87.00);
INSERT INTO items VALUES (130,6,4,850,12,322.52);
INSERT INTO items VALUES (131,1,1,1005,12,204.27);
INSERT INTO items VALUES (131,1,2,135,3,34.74);
INSERT INTO items VALUES (131,2,1,559,2,13.34);
INSERT INTO items VALUES (131,2,2,830,1,8.58);
INSERT INTO items VALUES (132,1,1,778,1,8.86);
INSERT INTO items VALUES (133,1,1,652,12,113.08);
INSERT INTO items VALUES (133,1,2,1045,12,206.36);
INSERT INTO items VALUES (133,1,3,194,3,45.30);
INSERT INTO items VALUES (133,1,4,95,3,87.57);
INSERT INTO items VALUES (133,1,5,900,3,50.82);
INSERT INTO items VALUES (133,2,1,575,1,25.67);
INSERT INTO items VALUES (133,3,1,777,3,71.10);
INSERT INTO items VALUES (133,3,2,733,12,106.81);
INSERT INTO items VALUES (133,4,1,314,2,49.84);
INSERT INTO items VALUES (133,5,1,227,3,50.28);
INSERT INTO items VALUES (133,5,2,344,2,30.12);
INSERT INTO items VALUES (133,5,3,618,12,319.77);
INSERT INTO items VALUES (133,5,4,47,3,72.12);
INSERT INTO items VALUES (133,5,5,657,12,191.73);
INSERT INTO items VALUES (133,6,1,769,3,17.22);
INSERT INTO items VALUES (133,6,2,53,2,53.24);
INSERT INTO items VALUES (133,6,3,537,2,52.60);
INSERT INTO items VALUES (133,6,4,907,2,44.10);
INSERT INTO items VALUES (133,6,5,286,1,27.29);
INSERT INTO items VALUES (133,6,6,927,12,166.43);
INSERT INTO items VALUES (134,1,1,440,3,16.05);
INSERT INTO items VALUES (134,1,2,626,2,16.56);
INSERT INTO items VALUES (134,1,3,388,12,268.29);
INSERT INTO items VALUES (134,1,4,131,12,206.14);
INSERT INTO items VALUES (134,1,5,129,1,5.75);
INSERT INTO items VALUES (134,1,6,766,12,328.46);
INSERT INTO items VALUES (134,2,1,422,2,38.72);
INSERT INTO items VALUES (134,2,2,539,2,20.96);
INSERT INTO items VALUES (134,2,3,195,1,22.53);
INSERT INTO items VALUES (134,2,4,439,3,57.39);
INSERT INTO items VALUES (134,3,1,660,2,24.22);
INSERT INTO items VALUES (134,3,2,734,12,201.41);
INSERT INTO items VALUES (134,3,3,287,12,133.65);
INSERT INTO items VALUES (134,3,4,1037,1,26.67);
INSERT INTO items VALUES (134,3,5,710,3,87.81);
INSERT INTO items VALUES (134,4,1,725,1,24.18);
INSERT INTO items VALUES (134,4,2,647,12,322.52);
INSERT INTO items VALUES (134,5,1,44,12,244.20);
INSERT INTO items VALUES (134,5,2,375,3,70.20);
INSERT INTO items VALUES (134,5,3,283,1,28.83);
INSERT INTO items VALUES (134,5,4,447,3,40.74);
INSERT INTO items VALUES (135,1,1,255,12,302.28);
INSERT INTO items VALUES (135,2,1,221,12,134.53);
INSERT INTO items VALUES (135,2,2,725,1,24.18);
INSERT INTO items VALUES (135,3,1,763,1,7.68);
INSERT INTO items VALUES (135,3,2,379,3,25.17);
INSERT INTO items VALUES (135,3,3,623,12,243.10);
INSERT INTO items VALUES (135,3,4,172,3,89.67);
INSERT INTO items VALUES (135,3,5,249,3,77.91);
INSERT INTO items VALUES (135,4,1,223,2,26.08);
INSERT INTO items VALUES (135,4,2,791,2,10.38);
INSERT INTO items VALUES (135,4,3,258,2,35.36);
INSERT INTO items VALUES (135,4,4,484,12,318.12);
INSERT INTO items VALUES (135,5,1,497,3,64.38);
INSERT INTO items VALUES (135,6,1,730,2,49.32);
INSERT INTO items VALUES (135,6,2,244,2,24.42);
INSERT INTO items VALUES (135,6,3,315,2,51.86);
INSERT INTO items VALUES (135,6,4,931,3,43.02);
INSERT INTO items VALUES (135,6,5,791,3,15.57);
INSERT INTO items VALUES (136,1,1,286,1,27.29);
INSERT INTO items VALUES (136,1,2,678,2,52.90);
INSERT INTO items VALUES (136,1,3,742,2,45.58);
INSERT INTO items VALUES (136,2,1,298,12,271.04);
INSERT INTO items VALUES (136,2,2,20,3,29.10);
INSERT INTO items VALUES (136,2,3,184,2,54.22);
INSERT INTO items VALUES (136,2,4,541,3,52.86);
INSERT INTO items VALUES (136,2,5,77,1,8.84);
INSERT INTO items VALUES (136,3,1,368,2,56.74);
INSERT INTO items VALUES (136,3,2,199,12,223.08);
INSERT INTO items VALUES (136,3,3,827,12,224.84);
INSERT INTO items VALUES (136,3,4,296,12,109.45);
INSERT INTO items VALUES (136,3,5,706,1,26.02);
INSERT INTO items VALUES (136,3,6,98,2,48.98);
INSERT INTO items VALUES (136,4,1,228,3,65.79);
INSERT INTO items VALUES (136,4,2,487,2,59.24);
INSERT INTO items VALUES (136,4,3,885,1,9.22);
INSERT INTO items VALUES (136,4,4,381,1,20.86);
INSERT INTO items VALUES (136,4,5,108,2,32.42);
INSERT INTO items VALUES (136,5,1,152,12,63.91);
INSERT INTO items VALUES (136,5,2,323,12,149.60);
INSERT INTO items VALUES (136,6,1,188,12,84.81);
INSERT INTO items VALUES (136,6,2,204,2,48.56);
INSERT INTO items VALUES (136,6,3,501,3,67.17);
INSERT INTO items VALUES (137,1,1,947,1,19.53);
INSERT INTO items VALUES (137,1,2,138,1,21.51);
INSERT INTO items VALUES (137,1,3,825,2,59.26);
INSERT INTO items VALUES (137,1,4,311,12,266.42);
INSERT INTO items VALUES (137,2,1,852,1,26.09);
INSERT INTO items VALUES (137,2,2,659,3,73.14);
INSERT INTO items VALUES (137,2,3,292,1,7.84);
INSERT INTO items VALUES (137,3,1,550,1,11.22);
INSERT INTO items VALUES (137,3,2,426,2,17.34);
INSERT INTO items VALUES (137,3,3,263,3,39.36);
INSERT INTO items VALUES (137,3,4,607,1,22.19);
INSERT INTO items VALUES (137,3,5,1046,12,121.00);
INSERT INTO items VALUES (137,4,1,404,12,297.11);
INSERT INTO items VALUES (137,4,2,426,1,8.67);
INSERT INTO items VALUES (137,5,1,314,3,74.76);
INSERT INTO items VALUES (138,1,1,1003,12,107.47);
INSERT INTO items VALUES (138,1,2,739,12,278.08);
INSERT INTO items VALUES (138,1,3,635,3,64.17);
INSERT INTO items VALUES (138,1,4,431,3,53.58);
INSERT INTO items VALUES (138,1,5,917,3,55.29);
INSERT INTO items VALUES (138,2,1,152,2,11.62);
INSERT INTO items VALUES (138,2,2,761,1,18.88);
INSERT INTO items VALUES (138,2,3,777,1,23.70);
INSERT INTO items VALUES (138,2,4,134,3,67.35);
INSERT INTO items VALUES (138,2,5,950,2,22.12);
INSERT INTO items VALUES (138,2,6,854,12,272.25);
INSERT INTO items VALUES (138,3,1,45,12,84.81);
INSERT INTO items VALUES (138,3,2,271,12,75.79);
INSERT INTO items VALUES (138,3,3,716,1,13.85);
INSERT INTO items VALUES (138,3,4,822,12,121.33);
INSERT INTO items VALUES (138,3,5,127,1,17.86);
INSERT INTO items VALUES (138,4,1,64,3,78.99);
INSERT INTO items VALUES (138,4,2,408,12,175.45);
INSERT INTO items VALUES (138,4,3,189,1,16.73);
INSERT INTO items VALUES (138,4,4,829,2,21.20);
INSERT INTO items VALUES (138,4,5,887,3,45.30);
INSERT INTO items VALUES (138,5,1,161,3,55.89);
INSERT INTO items VALUES (138,5,2,762,12,308.44);
INSERT INTO items VALUES (138,5,3,592,12,168.52);
INSERT INTO items VALUES (138,5,4,195,1,22.53);
INSERT INTO items VALUES (138,6,1,993,3,73.11);
INSERT INTO items VALUES (138,6,2,833,1,19.63);
INSERT INTO items VALUES (138,6,3,742,3,68.37);
INSERT INTO items VALUES (138,6,4,610,3,17.88);
INSERT INTO items VALUES (138,6,5,165,1,27.17);
INSERT INTO items VALUES (139,1,1,739,1,25.28);
INSERT INTO items VALUES (139,2,1,279,1,15.97);
INSERT INTO items VALUES (139,3,1,497,3,64.38);
INSERT INTO items VALUES (139,3,2,24,3,55.80);
INSERT INTO items VALUES (139,3,3,885,12,101.42);
INSERT INTO items VALUES (139,4,1,1006,12,221.76);
INSERT INTO items VALUES (139,4,2,986,3,19.68);
INSERT INTO items VALUES (139,5,1,188,2,15.42);
INSERT INTO items VALUES (140,1,1,378,12,326.48);
INSERT INTO items VALUES (140,1,2,211,2,35.16);
INSERT INTO items VALUES (140,1,3,31,12,184.14);
INSERT INTO items VALUES (141,1,1,55,3,64.23);
INSERT INTO items VALUES (141,1,2,803,1,20.69);
INSERT INTO items VALUES (141,1,3,461,1,10.66);
INSERT INTO items VALUES (141,1,4,245,3,86.58);
INSERT INTO items VALUES (141,1,5,428,2,12.48);
INSERT INTO items VALUES (141,2,1,793,1,16.37);
INSERT INTO items VALUES (141,2,2,626,1,8.28);
INSERT INTO items VALUES (141,2,3,240,3,34.32);
INSERT INTO items VALUES (141,3,1,538,2,29.00);
INSERT INTO items VALUES (142,1,1,1013,1,10.04);
INSERT INTO items VALUES (142,1,2,411,3,71.97);
INSERT INTO items VALUES (142,1,3,121,12,319.22);
INSERT INTO items VALUES (142,1,4,1002,3,71.91);
INSERT INTO items VALUES (142,1,5,570,1,25.09);
INSERT INTO items VALUES (142,2,1,368,3,85.11);
INSERT INTO items VALUES (142,3,1,919,12,146.85);
INSERT INTO items VALUES (142,3,2,642,2,27.82);
INSERT INTO items VALUES (142,3,3,514,3,48.54);
INSERT INTO items VALUES (142,3,4,647,12,322.52);
INSERT INTO items VALUES (142,3,5,90,3,20.31);
INSERT INTO items VALUES (142,3,6,703,1,26.77);
INSERT INTO items VALUES (142,4,1,873,2,41.30);
INSERT INTO items VALUES (143,1,1,777,12,260.70);
INSERT INTO items VALUES (143,1,2,349,3,46.77);
INSERT INTO items VALUES (143,1,3,558,12,314.49);
INSERT INTO items VALUES (144,1,1,410,12,192.94);
INSERT INTO items VALUES (144,1,2,455,3,86.97);
INSERT INTO items VALUES (144,2,1,651,1,29.92);
INSERT INTO items VALUES (144,2,2,106,12,287.10);
INSERT INTO items VALUES (144,2,3,152,3,17.43);
INSERT INTO items VALUES (144,2,4,690,1,20.07);
INSERT INTO items VALUES (144,3,1,35,12,194.04);
INSERT INTO items VALUES (144,4,1,916,3,62.19);
INSERT INTO items VALUES (144,4,2,144,1,26.21);
INSERT INTO items VALUES (144,4,3,82,12,245.30);
INSERT INTO items VALUES (144,5,1,287,2,24.30);
INSERT INTO items VALUES (144,5,2,351,2,50.94);
INSERT INTO items VALUES (144,5,3,1018,1,9.22);
INSERT INTO items VALUES (144,6,1,750,1,6.57);
INSERT INTO items VALUES (144,6,2,573,2,40.72);
INSERT INTO items VALUES (145,1,1,682,3,82.02);
INSERT INTO items VALUES (145,1,2,354,2,12.38);
INSERT INTO items VALUES (145,1,3,1043,12,184.03);
INSERT INTO items VALUES (145,2,1,18,2,16.90);
INSERT INTO items VALUES (145,2,2,203,3,44.61);
INSERT INTO items VALUES (145,2,3,686,2,39.04);
INSERT INTO items VALUES (145,2,4,324,3,61.11);
INSERT INTO items VALUES (145,3,1,440,1,5.35);
INSERT INTO items VALUES (146,1,1,229,3,20.97);
INSERT INTO items VALUES (146,1,2,894,3,23.64);
INSERT INTO items VALUES (146,1,3,894,2,15.76);
INSERT INTO items VALUES (146,1,4,604,1,12.83);
INSERT INTO items VALUES (146,1,5,643,1,19.37);
INSERT INTO items VALUES (146,1,6,816,1,11.57);
INSERT INTO items VALUES (146,2,1,219,2,12.90);
INSERT INTO items VALUES (146,2,2,1009,2,44.26);
INSERT INTO items VALUES (146,2,3,861,1,13.85);
INSERT INTO items VALUES (146,2,4,241,3,50.85);
INSERT INTO items VALUES (146,3,1,895,12,275.66);
INSERT INTO items VALUES (147,1,1,159,1,14.76);
INSERT INTO items VALUES (147,2,1,309,3,58.20);
INSERT INTO items VALUES (147,2,2,721,3,15.21);
INSERT INTO items VALUES (147,2,3,234,1,26.40);
INSERT INTO items VALUES (147,2,4,630,2,56.00);
INSERT INTO items VALUES (147,3,1,188,1,7.71);
INSERT INTO items VALUES (147,3,2,49,12,111.98);
INSERT INTO items VALUES (147,3,3,815,1,6.44);
INSERT INTO items VALUES (147,3,4,897,12,252.89);
INSERT INTO items VALUES (147,3,5,303,1,12.35);
INSERT INTO items VALUES (147,3,6,669,3,40.86);
INSERT INTO items VALUES (147,4,1,394,2,10.76);
INSERT INTO items VALUES (148,1,1,315,3,77.79);
INSERT INTO items VALUES (148,1,2,840,2,29.26);
INSERT INTO items VALUES (148,1,3,797,3,54.75);
INSERT INTO items VALUES (148,1,4,172,12,328.79);
INSERT INTO items VALUES (149,1,1,448,2,11.56);
INSERT INTO items VALUES (149,1,2,145,2,52.94);
INSERT INTO items VALUES (149,2,1,381,3,62.58);
INSERT INTO items VALUES (149,3,1,383,3,56.67);
INSERT INTO items VALUES (149,3,2,279,12,175.67);
INSERT INTO items VALUES (150,1,1,927,12,166.43);
INSERT INTO items VALUES (150,1,2,393,2,55.40);
INSERT INTO items VALUES (150,1,3,282,1,27.83);
INSERT INTO items VALUES (150,1,4,74,12,138.16);
INSERT INTO items VALUES (150,1,5,731,1,25.68);
INSERT INTO items VALUES (150,1,6,128,2,42.50);
INSERT INTO items VALUES (150,2,1,270,1,20.46);
INSERT INTO items VALUES (150,2,2,101,1,8.73);
INSERT INTO items VALUES (150,2,3,800,3,54.48);
INSERT INTO items VALUES (150,2,4,314,1,24.92);
INSERT INTO items VALUES (150,2,5,51,3,72.27);
INSERT INTO items VALUES (150,3,1,488,1,5.10);
INSERT INTO items VALUES (150,3,2,515,1,25.09);
INSERT INTO items VALUES (150,3,3,187,3,19.32);
INSERT INTO items VALUES (150,3,4,543,1,28.06);
INSERT INTO items VALUES (150,3,5,753,12,238.70);
INSERT INTO items VALUES (150,4,1,969,2,27.86);
INSERT INTO items VALUES (150,4,2,185,1,15.92);
INSERT INTO items VALUES (150,4,3,532,1,27.88);
INSERT INTO items VALUES (150,4,4,950,1,11.06);
INSERT INTO items VALUES (151,1,1,947,1,19.53);
INSERT INTO items VALUES (151,1,2,744,3,40.62);
INSERT INTO items VALUES (151,1,3,624,12,244.75);
INSERT INTO items VALUES (151,1,4,245,2,57.72);
INSERT INTO items VALUES (152,1,1,1025,3,86.34);
INSERT INTO items VALUES (152,1,2,900,2,33.88);
INSERT INTO items VALUES (152,1,3,998,12,135.30);
INSERT INTO items VALUES (152,1,4,736,1,26.06);
INSERT INTO items VALUES (152,2,1,730,3,73.98);
INSERT INTO items VALUES (152,2,2,992,1,10.51);
INSERT INTO items VALUES (152,3,1,274,12,68.42);
INSERT INTO items VALUES (152,3,2,40,12,170.72);
INSERT INTO items VALUES (152,3,3,666,1,15.55);
INSERT INTO items VALUES (153,1,1,612,1,29.58);
INSERT INTO items VALUES (153,1,2,212,2,59.60);
INSERT INTO items VALUES (153,1,3,639,2,47.06);
INSERT INTO items VALUES (153,2,1,891,2,47.20);
INSERT INTO items VALUES (153,2,2,20,2,19.40);
INSERT INTO items VALUES (153,2,3,756,1,29.52);
INSERT INTO items VALUES (153,2,4,379,3,25.17);
INSERT INTO items VALUES (153,2,5,684,2,45.10);
INSERT INTO items VALUES (153,3,1,943,3,48.39);
INSERT INTO items VALUES (153,4,1,967,2,14.96);
INSERT INTO items VALUES (154,1,1,175,12,281.60);
INSERT INTO items VALUES (154,1,2,850,12,322.52);
INSERT INTO items VALUES (154,2,1,639,2,47.06);
INSERT INTO items VALUES (154,2,2,923,12,161.04);
INSERT INTO items VALUES (154,3,1,456,1,25.66);
INSERT INTO items VALUES (154,3,2,971,3,59.43);
INSERT INTO items VALUES (154,3,3,465,2,16.00);
INSERT INTO items VALUES (154,3,4,747,12,296.78);
INSERT INTO items VALUES (154,3,5,798,12,324.28);
INSERT INTO items VALUES (155,1,1,33,2,37.50);
INSERT INTO items VALUES (155,1,2,541,2,35.24);
INSERT INTO items VALUES (155,1,3,371,2,30.98);
INSERT INTO items VALUES (155,1,4,699,2,39.42);
INSERT INTO items VALUES (155,1,5,265,3,50.19);
INSERT INTO items VALUES (155,1,6,325,1,13.21);
INSERT INTO items VALUES (155,2,1,23,12,292.16);
INSERT INTO items VALUES (155,2,2,602,12,128.92);
INSERT INTO items VALUES (155,2,3,681,1,28.12);
INSERT INTO items VALUES (155,2,4,627,12,72.38);
INSERT INTO items VALUES (155,2,5,631,2,10.00);
INSERT INTO items VALUES (155,3,1,473,2,14.56);
INSERT INTO items VALUES (155,3,2,129,3,17.25);
INSERT INTO items VALUES (155,3,3,870,2,45.78);
INSERT INTO items VALUES (155,3,4,887,1,15.10);
INSERT INTO items VALUES (155,3,5,185,1,15.92);
INSERT INTO items VALUES (155,3,6,591,2,25.40);
INSERT INTO items VALUES (155,4,1,101,1,8.73);
INSERT INTO items VALUES (155,4,2,279,3,47.91);
INSERT INTO items VALUES (155,4,3,278,2,49.12);
INSERT INTO items VALUES (155,5,1,421,12,157.30);
INSERT INTO items VALUES (155,5,2,403,1,24.98);
INSERT INTO items VALUES (155,5,3,193,1,24.18);
INSERT INTO items VALUES (155,5,4,487,2,59.24);
INSERT INTO items VALUES (155,5,5,481,1,5.82);
INSERT INTO items VALUES (155,6,1,906,2,20.66);
INSERT INTO items VALUES (155,6,2,795,1,21.46);
INSERT INTO items VALUES (155,6,3,154,1,5.97);
INSERT INTO items VALUES (155,6,4,437,2,17.22);
INSERT INTO items VALUES (155,6,5,607,1,22.19);
INSERT INTO items VALUES (156,1,1,799,12,152.57);
INSERT INTO items VALUES (156,1,2,861,1,13.85);
INSERT INTO items VALUES (156,1,3,352,12,107.25);
INSERT INTO items VALUES (156,2,1,83,1,15.54);
INSERT INTO items VALUES (156,3,1,863,1,13.71);
INSERT INTO items VALUES (156,3,2,160,3,89.76);
INSERT INTO items VALUES (156,3,3,416,2,50.78);
INSERT INTO items VALUES (156,4,1,269,2,30.72);
INSERT INTO items VALUES (157,1,1,226,2,17.36);
INSERT INTO items VALUES (157,1,2,636,2,51.02);
INSERT INTO items VALUES (157,1,3,143,1,12.49);
INSERT INTO items VALUES (158,1,1,979,3,85.17);
INSERT INTO items VALUES (158,1,2,659,12,268.18);
INSERT INTO items VALUES (158,1,3,485,1,22.86);
INSERT INTO items VALUES (158,1,4,38,3,17.25);
INSERT INTO items VALUES (158,1,5,406,1,6.72);
INSERT INTO items VALUES (158,1,6,864,12,258.28);
INSERT INTO items VALUES (158,2,1,155,3,74.49);
INSERT INTO items VALUES (158,2,2,403,2,49.96);
INSERT INTO items VALUES (158,3,1,691,1,29.00);
INSERT INTO items VALUES (158,3,2,884,2,33.78);
INSERT INTO items VALUES (158,4,1,889,3,41.76);
INSERT INTO items VALUES (158,5,1,713,12,275.66);
INSERT INTO items VALUES (158,5,2,254,1,22.55);
INSERT INTO items VALUES (158,5,3,579,1,7.68);
INSERT INTO items VALUES (158,5,4,516,2,21.74);
INSERT INTO items VALUES (158,5,5,896,3,82.68);
INSERT INTO items VALUES (158,5,6,688,3,47.31);
INSERT INTO items VALUES (158,6,1,869,12,197.23);
INSERT INTO items VALUES (158,6,2,910,3,84.87);
INSERT INTO items VALUES (158,6,3,656,3,76.29);
INSERT INTO items VALUES (158,6,4,701,2,48.64);
INSERT INTO items VALUES (158,6,5,129,1,5.75);
INSERT INTO items VALUES (159,1,1,452,2,15.56);
INSERT INTO items VALUES (159,1,2,279,1,15.97);
INSERT INTO items VALUES (159,1,3,1004,12,265.98);
INSERT INTO items VALUES (159,2,1,95,3,87.57);
INSERT INTO items VALUES (159,2,2,49,12,111.98);
INSERT INTO items VALUES (159,3,1,696,3,19.86);
INSERT INTO items VALUES (159,3,2,701,12,267.52);
INSERT INTO items VALUES (159,4,1,919,2,26.70);
INSERT INTO items VALUES (159,4,2,744,2,27.08);
INSERT INTO items VALUES (159,4,3,966,1,10.45);
INSERT INTO items VALUES (159,4,4,624,3,66.75);
INSERT INTO items VALUES (159,4,5,359,3,55.83);
INSERT INTO items VALUES (159,4,6,365,2,16.80);
INSERT INTO items VALUES (160,1,1,310,1,10.26);
INSERT INTO items VALUES (160,1,2,335,1,9.58);
INSERT INTO items VALUES (160,1,3,525,12,242.99);
INSERT INTO items VALUES (160,1,4,499,2,14.24);
INSERT INTO items VALUES (160,2,1,315,1,25.93);
INSERT INTO items VALUES (160,3,1,1015,12,311.85);
INSERT INTO items VALUES (160,3,2,717,2,47.84);
INSERT INTO items VALUES (160,3,3,549,1,6.36);
INSERT INTO items VALUES (160,3,4,1045,12,206.36);
INSERT INTO items VALUES (160,3,5,263,2,26.24);
INSERT INTO items VALUES (161,1,1,878,12,246.73);
INSERT INTO items VALUES (161,1,2,552,12,58.30);
INSERT INTO items VALUES (161,1,3,202,3,30.24);
INSERT INTO items VALUES (161,2,1,472,1,8.36);
INSERT INTO items VALUES (161,2,2,400,12,107.36);
INSERT INTO items VALUES (161,2,3,679,3,35.43);
INSERT INTO items VALUES (161,2,4,831,2,47.22);
INSERT INTO items VALUES (161,2,5,880,1,26.62);
INSERT INTO items VALUES (161,3,1,220,2,23.48);
INSERT INTO items VALUES (161,3,2,365,3,25.20);
INSERT INTO items VALUES (161,3,3,217,3,20.49);
INSERT INTO items VALUES (161,4,1,385,3,62.43);
INSERT INTO items VALUES (161,4,2,125,3,26.46);
INSERT INTO items VALUES (161,4,3,451,12,136.95);
INSERT INTO items VALUES (161,4,4,354,1,6.19);
INSERT INTO items VALUES (161,4,5,244,1,12.21);
INSERT INTO items VALUES (161,4,6,348,3,55.08);
INSERT INTO items VALUES (161,5,1,489,2,42.70);
INSERT INTO items VALUES (161,5,2,465,3,24.00);
INSERT INTO items VALUES (161,5,3,1031,12,75.57);
INSERT INTO items VALUES (161,5,4,460,3,58.05);
INSERT INTO items VALUES (161,5,5,713,1,25.06);
INSERT INTO items VALUES (161,6,1,588,3,34.38);
INSERT INTO items VALUES (161,6,2,166,12,90.86);
INSERT INTO items VALUES (161,6,3,772,2,26.58);
INSERT INTO items VALUES (161,6,4,515,3,75.27);
INSERT INTO items VALUES (161,6,5,191,1,17.29);
INSERT INTO items VALUES (161,6,6,2,2,56.30);
INSERT INTO items VALUES (162,1,1,964,2,26.66);
INSERT INTO items VALUES (162,2,1,757,3,64.11);
INSERT INTO items VALUES (162,2,2,814,2,27.04);
INSERT INTO items VALUES (163,1,1,547,12,272.25);
INSERT INTO items VALUES (163,1,2,439,1,19.13);
INSERT INTO items VALUES (163,2,1,86,1,15.04);
INSERT INTO items VALUES (163,3,1,691,3,87.00);
INSERT INTO items VALUES (163,3,2,588,2,22.92);
INSERT INTO items VALUES (163,4,1,649,1,17.09);
INSERT INTO items VALUES (163,4,2,887,12,166.10);
INSERT INTO items VALUES (163,4,3,731,12,282.48);
INSERT INTO items VALUES (163,5,1,942,1,28.23);
INSERT INTO items VALUES (163,5,2,507,2,36.04);
INSERT INTO items VALUES (163,5,3,60,2,32.42);
INSERT INTO items VALUES (163,5,4,772,3,39.87);
INSERT INTO items VALUES (163,5,5,967,2,14.96);
INSERT INTO items VALUES (163,5,6,192,1,22.37);
INSERT INTO items VALUES (164,1,1,640,2,22.90);
INSERT INTO items VALUES (164,1,2,1002,3,71.91);
INSERT INTO items VALUES (164,2,1,529,1,29.10);
INSERT INTO items VALUES (164,2,2,727,12,90.75);
INSERT INTO items VALUES (164,3,1,31,12,184.14);
INSERT INTO items VALUES (164,3,2,973,2,32.04);
INSERT INTO items VALUES (164,3,3,880,1,26.62);
INSERT INTO items VALUES (164,3,4,135,2,23.16);
INSERT INTO items VALUES (164,3,5,396,3,35.85);
INSERT INTO items VALUES (164,3,6,910,2,56.58);
INSERT INTO items VALUES (164,4,1,90,1,6.77);
INSERT INTO items VALUES (164,4,2,528,12,108.24);
INSERT INTO items VALUES (164,4,3,176,3,62.22);
INSERT INTO items VALUES (164,5,1,760,2,12.24);
INSERT INTO items VALUES (164,5,2,117,3,74.79);
INSERT INTO items VALUES (164,5,3,431,1,17.86);
INSERT INTO items VALUES (164,5,4,1042,12,294.36);
INSERT INTO items VALUES (164,5,5,1025,12,316.58);
INSERT INTO items VALUES (164,6,1,252,2,51.30);
INSERT INTO items VALUES (164,6,2,135,3,34.74);
INSERT INTO items VALUES (164,6,3,144,2,52.42);
INSERT INTO items VALUES (164,6,4,345,12,90.53);
INSERT INTO items VALUES (164,6,5,167,3,63.15);
INSERT INTO items VALUES (164,6,6,672,1,10.92);
INSERT INTO items VALUES (165,1,1,313,3,60.66);
INSERT INTO items VALUES (165,1,2,749,1,5.57);
INSERT INTO items VALUES (165,1,3,719,12,111.76);
INSERT INTO items VALUES (165,1,4,585,12,295.35);
INSERT INTO items VALUES (165,1,5,772,12,146.19);
INSERT INTO items VALUES (166,1,1,260,2,14.68);
INSERT INTO items VALUES (166,2,1,811,2,11.50);
INSERT INTO items VALUES (166,2,2,1025,3,86.34);
INSERT INTO items VALUES (166,3,1,138,12,236.61);
INSERT INTO items VALUES (166,3,2,330,12,226.60);
INSERT INTO items VALUES (166,3,3,956,3,60.33);
INSERT INTO items VALUES (166,4,1,460,12,212.85);
INSERT INTO items VALUES (166,4,2,1031,2,13.74);
INSERT INTO items VALUES (166,4,3,251,1,5.71);
INSERT INTO items VALUES (166,4,4,497,1,21.46);
INSERT INTO items VALUES (166,5,1,232,12,157.63);
INSERT INTO items VALUES (166,5,2,828,2,33.02);
INSERT INTO items VALUES (167,1,1,386,1,28.45);
INSERT INTO items VALUES (167,1,2,532,12,306.68);
INSERT INTO items VALUES (167,1,3,570,2,50.18);
INSERT INTO items VALUES (167,2,1,778,1,8.86);
INSERT INTO items VALUES (167,2,2,52,3,80.19);
INSERT INTO items VALUES (167,2,3,1044,2,38.24);
INSERT INTO items VALUES (167,2,4,1003,12,107.47);
INSERT INTO items VALUES (167,2,5,151,2,44.74);
INSERT INTO items VALUES (167,3,1,300,1,26.38);
INSERT INTO items VALUES (167,4,1,1022,1,6.25);
INSERT INTO items VALUES (167,4,2,843,3,24.33);
INSERT INTO items VALUES (167,4,3,802,3,36.72);
INSERT INTO items VALUES (167,4,4,991,12,292.16);
INSERT INTO items VALUES (167,5,1,748,3,68.28);
INSERT INTO items VALUES (167,5,2,168,2,48.74);
INSERT INTO items VALUES (167,5,3,432,12,279.95);
INSERT INTO items VALUES (167,5,4,404,3,81.03);
INSERT INTO items VALUES (167,6,1,786,3,62.52);
INSERT INTO items VALUES (167,6,2,464,3,45.21);
INSERT INTO items VALUES (167,6,3,448,1,5.78);
INSERT INTO items VALUES (168,1,1,525,1,22.09);
INSERT INTO items VALUES (168,1,2,955,1,18.91);
INSERT INTO items VALUES (169,1,1,689,12,110.33);
INSERT INTO items VALUES (169,1,2,426,2,17.34);
INSERT INTO items VALUES (169,2,1,847,12,206.69);
INSERT INTO items VALUES (169,2,2,867,1,15.68);
INSERT INTO items VALUES (169,2,3,264,1,12.84);
INSERT INTO items VALUES (169,2,4,843,2,16.22);
INSERT INTO items VALUES (169,2,5,540,12,295.35);
INSERT INTO items VALUES (170,1,1,98,2,48.98);
INSERT INTO items VALUES (170,1,2,910,12,311.19);
INSERT INTO items VALUES (170,2,1,1034,2,29.92);
INSERT INTO items VALUES (170,2,2,509,12,171.38);
INSERT INTO items VALUES (170,2,3,298,3,73.92);
INSERT INTO items VALUES (170,2,4,185,2,31.84);
INSERT INTO items VALUES (170,2,5,499,3,21.36);
INSERT INTO items VALUES (170,3,1,341,12,191.40);
INSERT INTO items VALUES (170,3,2,674,2,29.74);
INSERT INTO items VALUES (170,3,3,246,3,55.71);
INSERT INTO items VALUES (171,1,1,206,2,49.20);
INSERT INTO items VALUES (171,1,2,186,1,8.53);
INSERT INTO items VALUES (171,1,3,804,12,284.90);
INSERT INTO items VALUES (171,1,4,312,1,11.93);
INSERT INTO items VALUES (171,1,5,341,12,191.40);
INSERT INTO items VALUES (171,2,1,860,2,58.48);
INSERT INTO items VALUES (171,2,2,360,1,11.94);
INSERT INTO items VALUES (171,2,3,589,12,237.16);
INSERT INTO items VALUES (171,2,4,582,3,62.64);
INSERT INTO items VALUES (171,2,5,674,12,163.57);
INSERT INTO items VALUES (172,1,1,212,2,59.60);
INSERT INTO items VALUES (172,1,2,489,2,42.70);
INSERT INTO items VALUES (172,2,1,835,1,14.56);
INSERT INTO items VALUES (172,2,2,784,1,8.87);
INSERT INTO items VALUES (172,2,3,483,12,132.66);
INSERT INTO items VALUES (172,2,4,717,2,47.84);
INSERT INTO items VALUES (172,2,5,568,2,22.64);
INSERT INTO items VALUES (172,2,6,1004,2,48.36);
INSERT INTO items VALUES (172,3,1,29,1,20.97);
INSERT INTO items VALUES (172,3,2,68,2,43.32);
INSERT INTO items VALUES (172,3,3,342,3,33.66);
INSERT INTO items VALUES (172,3,4,926,2,49.20);
INSERT INTO items VALUES (172,3,5,172,1,29.89);
INSERT INTO items VALUES (172,4,1,866,12,160.49);
INSERT INTO items VALUES (172,4,2,823,2,46.40);
INSERT INTO items VALUES (172,4,3,78,3,46.50);
INSERT INTO items VALUES (173,1,1,457,1,21.00);
INSERT INTO items VALUES (173,1,2,7,12,134.20);
INSERT INTO items VALUES (173,1,3,520,3,30.03);
INSERT INTO items VALUES (173,1,4,852,12,286.99);
INSERT INTO items VALUES (173,1,5,944,12,219.34);
INSERT INTO items VALUES (173,1,6,904,12,204.93);
INSERT INTO items VALUES (173,2,1,134,1,22.45);
INSERT INTO items VALUES (173,2,2,966,12,114.95);
INSERT INTO items VALUES (173,2,3,902,12,118.47);
INSERT INTO items VALUES (173,2,4,441,1,5.87);
INSERT INTO items VALUES (173,2,5,136,12,278.85);
INSERT INTO items VALUES (173,2,6,240,1,11.44);
INSERT INTO items VALUES (173,3,1,908,3,35.22);
INSERT INTO items VALUES (173,4,1,988,1,11.17);
INSERT INTO items VALUES (173,5,1,376,1,21.17);
INSERT INTO items VALUES (173,5,2,879,1,8.93);
INSERT INTO items VALUES (173,5,3,444,12,199.76);
INSERT INTO items VALUES (173,5,4,475,12,317.24);
INSERT INTO items VALUES (173,5,5,1034,3,44.88);
INSERT INTO items VALUES (173,6,1,230,3,33.72);
INSERT INTO items VALUES (173,6,2,955,12,208.01);
INSERT INTO items VALUES (174,1,1,260,1,7.34);
INSERT INTO items VALUES (174,1,2,231,2,35.12);
INSERT INTO items VALUES (174,1,3,920,2,40.56);
INSERT INTO items VALUES (174,1,4,908,12,129.14);
INSERT INTO items VALUES (174,1,5,902,3,32.31);
INSERT INTO items VALUES (174,1,6,811,3,17.25);
INSERT INTO items VALUES (174,2,1,322,2,33.94);
INSERT INTO items VALUES (174,2,2,224,1,23.92);
INSERT INTO items VALUES (174,3,1,892,2,14.50);
INSERT INTO items VALUES (174,3,2,1030,1,21.21);
INSERT INTO items VALUES (174,3,3,916,12,228.03);
INSERT INTO items VALUES (174,3,4,501,3,67.17);
INSERT INTO items VALUES (174,3,5,678,2,52.90);
INSERT INTO items VALUES (174,3,6,449,2,56.76);
INSERT INTO items VALUES (174,4,1,134,2,44.90);
INSERT INTO items VALUES (174,4,2,271,2,13.78);
INSERT INTO items VALUES (174,4,3,472,2,16.72);
INSERT INTO items VALUES (174,4,4,428,2,12.48);
INSERT INTO items VALUES (174,4,5,1004,2,48.36);
INSERT INTO items VALUES (175,1,1,833,3,58.89);
INSERT INTO items VALUES (175,1,2,408,1,15.95);
INSERT INTO items VALUES (175,1,3,124,12,301.62);
INSERT INTO items VALUES (175,1,4,1026,12,289.96);
INSERT INTO items VALUES (175,1,5,840,12,160.93);
INSERT INTO items VALUES (175,2,1,753,2,43.40);
INSERT INTO items VALUES (175,2,2,687,1,16.89);
INSERT INTO items VALUES (175,3,1,648,12,179.74);
INSERT INTO items VALUES (175,4,1,549,3,19.08);
INSERT INTO items VALUES (176,1,1,577,12,231.66);
INSERT INTO items VALUES (176,1,2,842,1,28.53);
INSERT INTO items VALUES (176,1,3,990,1,12.78);
INSERT INTO items VALUES (176,2,1,567,2,24.74);
INSERT INTO items VALUES (176,2,2,616,1,12.39);
INSERT INTO items VALUES (176,3,1,173,12,291.72);
INSERT INTO items VALUES (176,3,2,570,2,50.18);
INSERT INTO items VALUES (176,3,3,79,3,35.91);
INSERT INTO items VALUES (176,3,4,918,3,47.10);
INSERT INTO items VALUES (176,3,5,367,3,59.61);
INSERT INTO items VALUES (176,4,1,786,12,229.24);
INSERT INTO items VALUES (176,4,2,858,2,10.66);
INSERT INTO items VALUES (176,4,3,404,2,54.02);
INSERT INTO items VALUES (176,4,4,397,1,11.38);
INSERT INTO items VALUES (176,5,1,295,2,50.10);
INSERT INTO items VALUES (176,5,2,883,2,18.60);
INSERT INTO items VALUES (176,5,3,980,3,66.96);
INSERT INTO items VALUES (176,6,1,679,3,35.43);
INSERT INTO items VALUES (176,6,2,564,2,37.78);
INSERT INTO items VALUES (176,6,3,453,2,29.54);
INSERT INTO items VALUES (176,6,4,720,12,309.32);
INSERT INTO items VALUES (176,6,5,798,1,29.48);
INSERT INTO items VALUES (176,6,6,1029,2,30.38);
INSERT INTO items VALUES (177,1,1,721,2,10.14);
INSERT INTO items VALUES (177,1,2,108,2,32.42);
INSERT INTO items VALUES (177,2,1,643,3,58.11);
INSERT INTO items VALUES (178,1,1,859,12,112.86);
INSERT INTO items VALUES (178,1,2,1008,12,315.15);
INSERT INTO items VALUES (178,1,3,493,3,67.17);
INSERT INTO items VALUES (178,1,4,690,2,40.14);
INSERT INTO items VALUES (178,1,5,692,12,196.90);
INSERT INTO items VALUES (178,2,1,488,2,10.20);
INSERT INTO items VALUES (178,2,2,272,2,19.20);
INSERT INTO items VALUES (178,3,1,742,3,68.37);
INSERT INTO items VALUES (178,3,2,380,3,82.35);
INSERT INTO items VALUES (178,3,3,680,2,10.50);
INSERT INTO items VALUES (178,3,4,382,1,7.09);
INSERT INTO items VALUES (178,4,1,816,12,127.27);
INSERT INTO items VALUES (178,4,2,1037,1,26.67);
INSERT INTO items VALUES (178,4,3,59,2,57.62);
INSERT INTO items VALUES (178,4,4,395,2,33.98);
INSERT INTO items VALUES (179,1,1,776,3,70.89);
INSERT INTO items VALUES (179,1,2,145,2,52.94);
INSERT INTO items VALUES (179,1,3,325,2,26.42);
INSERT INTO items VALUES (179,1,4,662,2,46.58);
INSERT INTO items VALUES (179,1,5,476,3,15.27);
INSERT INTO items VALUES (179,2,1,792,2,12.98);
INSERT INTO items VALUES (179,3,1,175,1,25.60);
INSERT INTO items VALUES (179,3,2,746,1,11.12);
INSERT INTO items VALUES (179,3,3,1023,2,30.98);
INSERT INTO items VALUES (179,3,4,861,1,13.85);
INSERT INTO items VALUES (179,3,5,754,1,25.04);
INSERT INTO items VALUES (179,4,1,531,3,74.34);
INSERT INTO items VALUES (179,5,1,958,3,32.49);
INSERT INTO items VALUES (179,5,2,24,12,204.60);
INSERT INTO items VALUES (179,5,3,278,1,24.56);
INSERT INTO items VALUES (179,5,4,144,12,288.31);
INSERT INTO items VALUES (179,5,5,366,1,24.12);
INSERT INTO items VALUES (179,5,6,449,1,28.38);
INSERT INTO items VALUES (179,6,1,526,2,38.62);
INSERT INTO items VALUES (179,6,2,1010,1,19.18);
INSERT INTO items VALUES (179,6,3,1047,12,152.35);
INSERT INTO items VALUES (179,6,4,832,12,97.68);
INSERT INTO items VALUES (179,6,5,545,12,188.10);
INSERT INTO items VALUES (180,1,1,989,12,132.99);
INSERT INTO items VALUES (180,1,2,990,1,12.78);
INSERT INTO items VALUES (180,1,3,197,1,11.73);
INSERT INTO items VALUES (180,1,4,296,2,19.90);
INSERT INTO items VALUES (180,2,1,917,2,36.86);
INSERT INTO items VALUES (180,2,2,575,3,77.01);
INSERT INTO items VALUES (180,2,3,140,2,11.90);
INSERT INTO items VALUES (180,2,4,272,1,9.60);
INSERT INTO items VALUES (180,3,1,676,3,37.05);
INSERT INTO items VALUES (180,3,2,427,3,60.03);
INSERT INTO items VALUES (180,3,3,797,3,54.75);
INSERT INTO items VALUES (180,3,4,737,1,26.19);
INSERT INTO items VALUES (180,4,1,983,12,287.21);
INSERT INTO items VALUES (180,5,1,257,3,89.46);
INSERT INTO items VALUES (180,5,2,638,1,5.73);
INSERT INTO items VALUES (180,5,3,630,2,56.00);
INSERT INTO items VALUES (180,5,4,794,1,10.52);
INSERT INTO items VALUES (180,6,1,720,3,84.36);
INSERT INTO items VALUES (180,6,2,2,2,56.30);
INSERT INTO items VALUES (180,6,3,43,1,27.82);
INSERT INTO items VALUES (180,6,4,565,12,264.22);
INSERT INTO items VALUES (180,6,5,993,12,268.07);
INSERT INTO items VALUES (180,6,6,485,3,68.58);
INSERT INTO items VALUES (181,1,1,690,1,20.07);
INSERT INTO items VALUES (181,1,2,497,12,236.06);
INSERT INTO items VALUES (181,1,3,252,3,76.95);
INSERT INTO items VALUES (181,1,4,773,1,25.40);
INSERT INTO items VALUES (181,1,5,416,2,50.78);
INSERT INTO items VALUES (181,2,1,72,12,274.56);
INSERT INTO items VALUES (181,2,2,982,1,28.67);
INSERT INTO items VALUES (181,2,3,427,3,60.03);
INSERT INTO items VALUES (181,2,4,603,12,63.58);
INSERT INTO items VALUES (181,2,5,41,12,186.89);
INSERT INTO items VALUES (181,2,6,393,1,27.70);
INSERT INTO items VALUES (181,3,1,214,2,55.90);
INSERT INTO items VALUES (181,3,2,42,3,63.84);
INSERT INTO items VALUES (181,3,3,699,12,216.81);
INSERT INTO items VALUES (181,3,4,716,3,41.55);
INSERT INTO items VALUES (181,3,5,989,1,12.09);
INSERT INTO items VALUES (181,3,6,587,12,114.18);
INSERT INTO items VALUES (181,4,1,712,2,56.42);
INSERT INTO items VALUES (181,4,2,687,1,16.89);
INSERT INTO items VALUES (181,4,3,561,1,8.64);
INSERT INTO items VALUES (181,4,4,153,2,46.22);
INSERT INTO items VALUES (181,4,5,983,3,78.33);
INSERT INTO items VALUES (181,4,6,989,12,132.99);
INSERT INTO items VALUES (182,1,1,918,2,31.40);
INSERT INTO items VALUES (182,1,2,164,12,103.40);
INSERT INTO items VALUES (182,1,3,720,3,84.36);
INSERT INTO items VALUES (182,1,4,709,1,6.71);
INSERT INTO items VALUES (182,2,1,56,12,141.13);
INSERT INTO items VALUES (182,2,2,471,2,57.28);
INSERT INTO items VALUES (182,3,1,614,3,26.79);
INSERT INTO items VALUES (182,3,2,502,12,265.21);
INSERT INTO items VALUES (182,3,3,229,2,13.98);
INSERT INTO items VALUES (182,3,4,198,2,27.62);
INSERT INTO items VALUES (182,4,1,813,12,106.48);
INSERT INTO items VALUES (182,4,2,454,2,56.62);
INSERT INTO items VALUES (182,4,3,167,2,42.10);
INSERT INTO items VALUES (182,4,4,97,3,36.33);
INSERT INTO items VALUES (182,4,5,865,12,325.38);
INSERT INTO items VALUES (182,4,6,804,1,25.90);
INSERT INTO items VALUES (182,5,1,217,3,20.49);
INSERT INTO items VALUES (182,5,2,816,2,23.14);
INSERT INTO items VALUES (182,5,3,989,12,132.99);
INSERT INTO items VALUES (182,6,1,459,1,11.96);
INSERT INTO items VALUES (182,6,2,262,3,66.57);
INSERT INTO items VALUES (182,6,3,639,2,47.06);
INSERT INTO items VALUES (182,6,4,214,2,55.90);
INSERT INTO items VALUES (182,6,5,143,12,137.39);
INSERT INTO items VALUES (182,6,6,570,3,75.27);
INSERT INTO items VALUES (183,1,1,719,12,111.76);
INSERT INTO items VALUES (183,1,2,141,3,67.41);
INSERT INTO items VALUES (183,2,1,138,1,21.51);
INSERT INTO items VALUES (183,2,2,447,3,40.74);
INSERT INTO items VALUES (183,3,1,461,3,31.98);
INSERT INTO items VALUES (183,3,2,81,12,280.72);
INSERT INTO items VALUES (183,3,3,994,3,46.32);
INSERT INTO items VALUES (183,3,4,869,2,35.86);
INSERT INTO items VALUES (183,3,5,932,3,63.21);
INSERT INTO items VALUES (183,4,1,868,3,35.10);
INSERT INTO items VALUES (183,4,2,801,12,56.87);
INSERT INTO items VALUES (183,4,3,897,1,22.99);
INSERT INTO items VALUES (183,4,4,719,3,30.48);
INSERT INTO items VALUES (183,5,1,242,12,311.52);
INSERT INTO items VALUES (183,5,2,232,1,14.33);
INSERT INTO items VALUES (184,1,1,138,3,64.53);
INSERT INTO items VALUES (184,1,2,259,3,31.56);
INSERT INTO items VALUES (184,1,3,419,12,121.44);
INSERT INTO items VALUES (184,1,4,506,2,48.74);
INSERT INTO items VALUES (184,1,5,774,3,17.04);
INSERT INTO items VALUES (184,2,1,122,12,243.43);
INSERT INTO items VALUES (184,2,2,428,12,68.64);
INSERT INTO items VALUES (184,3,1,997,2,18.06);
INSERT INTO items VALUES (184,3,2,345,1,8.23);
INSERT INTO items VALUES (184,3,3,933,3,82.41);
INSERT INTO items VALUES (184,3,4,840,2,29.26);
INSERT INTO items VALUES (184,4,1,612,2,59.16);
INSERT INTO items VALUES (184,4,2,1032,1,19.93);
INSERT INTO items VALUES (184,4,3,552,1,5.30);
INSERT INTO items VALUES (184,4,4,902,12,118.47);
INSERT INTO items VALUES (185,1,1,655,3,63.96);
INSERT INTO items VALUES (185,1,2,925,3,50.91);
INSERT INTO items VALUES (185,1,3,629,2,48.38);
INSERT INTO items VALUES (185,1,4,532,12,306.68);
INSERT INTO items VALUES (186,1,1,601,3,42.87);
INSERT INTO items VALUES (186,1,2,421,1,14.30);
INSERT INTO items VALUES (186,2,1,64,1,26.33);
INSERT INTO items VALUES (186,2,2,797,3,54.75);
INSERT INTO items VALUES (186,2,3,891,2,47.20);
INSERT INTO items VALUES (186,3,1,896,2,55.12);
INSERT INTO items VALUES (186,3,2,1028,3,41.70);
INSERT INTO items VALUES (186,3,3,752,3,25.77);
INSERT INTO items VALUES (186,3,4,973,2,32.04);
INSERT INTO items VALUES (186,3,5,445,2,42.86);
INSERT INTO items VALUES (186,3,6,408,1,15.95);
INSERT INTO items VALUES (186,4,1,208,1,10.19);
INSERT INTO items VALUES (186,4,2,418,1,10.33);
INSERT INTO items VALUES (186,4,3,728,12,60.28);
INSERT INTO items VALUES (186,4,4,634,12,86.57);
INSERT INTO items VALUES (186,4,5,890,3,59.34);
INSERT INTO items VALUES (186,5,1,429,1,16.52);
INSERT INTO items VALUES (186,5,2,234,12,290.40);
INSERT INTO items VALUES (186,5,3,399,3,43.89);
INSERT INTO items VALUES (186,5,4,76,12,197.34);
INSERT INTO items VALUES (186,5,5,34,1,14.28);
INSERT INTO items VALUES (186,5,6,727,1,8.25);
INSERT INTO items VALUES (186,6,1,808,12,284.46);
INSERT INTO items VALUES (186,6,2,327,3,75.60);
INSERT INTO items VALUES (186,6,3,550,1,11.22);
INSERT INTO items VALUES (186,6,4,354,1,6.19);
INSERT INTO items VALUES (187,1,1,629,1,24.19);
INSERT INTO items VALUES (187,1,2,367,3,59.61);
INSERT INTO items VALUES (187,2,1,2,3,84.45);
INSERT INTO items VALUES (187,2,2,534,3,48.45);
INSERT INTO items VALUES (188,1,1,152,2,11.62);
INSERT INTO items VALUES (188,1,2,111,2,55.76);
INSERT INTO items VALUES (188,1,3,864,2,46.96);
INSERT INTO items VALUES (188,1,4,769,1,5.74);
INSERT INTO items VALUES (188,1,5,970,12,314.27);
INSERT INTO items VALUES (188,1,6,474,2,53.44);
INSERT INTO items VALUES (188,2,1,124,1,27.42);
INSERT INTO items VALUES (188,3,1,441,12,64.57);
INSERT INTO items VALUES (188,3,2,852,3,78.27);
INSERT INTO items VALUES (188,3,3,248,12,287.98);
INSERT INTO items VALUES (188,3,4,936,1,20.34);
INSERT INTO items VALUES (188,3,5,255,3,82.44);
INSERT INTO items VALUES (188,3,6,172,1,29.89);
INSERT INTO items VALUES (189,1,1,969,1,13.93);
INSERT INTO items VALUES (189,1,2,858,1,5.33);
INSERT INTO items VALUES (189,1,3,803,2,41.38);
INSERT INTO items VALUES (189,1,4,575,12,282.37);
INSERT INTO items VALUES (189,1,5,11,1,16.48);
INSERT INTO items VALUES (189,2,1,931,1,14.34);
INSERT INTO items VALUES (189,2,2,629,3,72.57);
INSERT INTO items VALUES (189,2,3,398,12,320.54);
INSERT INTO items VALUES (189,3,1,294,12,87.01);
INSERT INTO items VALUES (190,1,1,451,2,24.90);
INSERT INTO items VALUES (190,1,2,25,2,29.82);
INSERT INTO items VALUES (190,1,3,870,1,22.89);
INSERT INTO items VALUES (190,1,4,528,1,9.84);
INSERT INTO items VALUES (190,2,1,98,12,269.39);
INSERT INTO items VALUES (190,2,2,400,3,29.28);
INSERT INTO items VALUES (191,1,1,663,12,79.53);
INSERT INTO items VALUES (191,1,2,523,1,26.78);
INSERT INTO items VALUES (191,1,3,247,12,279.40);
INSERT INTO items VALUES (191,1,4,261,3,46.11);
INSERT INTO items VALUES (191,1,5,754,2,50.08);
INSERT INTO items VALUES (191,2,1,262,12,244.09);
INSERT INTO items VALUES (191,2,2,1044,1,19.12);
INSERT INTO items VALUES (191,2,3,307,3,15.84);
INSERT INTO items VALUES (191,2,4,79,12,131.67);
INSERT INTO items VALUES (191,2,5,650,3,70.02);
INSERT INTO items VALUES (191,2,6,525,3,66.27);
INSERT INTO items VALUES (191,3,1,654,12,294.80);
INSERT INTO items VALUES (191,3,2,790,2,24.86);
INSERT INTO items VALUES (191,4,1,575,1,25.67);
INSERT INTO items VALUES (191,4,2,764,3,34.56);
INSERT INTO items VALUES (191,4,3,448,1,5.78);
INSERT INTO items VALUES (191,4,4,222,3,72.60);
INSERT INTO items VALUES (191,4,5,834,12,248.16);
INSERT INTO items VALUES (191,5,1,279,2,31.94);
INSERT INTO items VALUES (191,5,2,450,12,158.62);
INSERT INTO items VALUES (191,6,1,700,2,38.70);
INSERT INTO items VALUES (191,6,2,198,1,13.81);
INSERT INTO items VALUES (191,6,3,643,12,213.07);
INSERT INTO items VALUES (192,1,1,29,2,41.94);
INSERT INTO items VALUES (192,1,2,63,3,71.16);
INSERT INTO items VALUES (192,1,3,108,2,32.42);
INSERT INTO items VALUES (192,1,4,865,2,59.16);
INSERT INTO items VALUES (192,1,5,783,3,83.61);
INSERT INTO items VALUES (192,2,1,649,12,187.99);
INSERT INTO items VALUES (192,3,1,590,1,15.33);
INSERT INTO items VALUES (192,4,1,802,1,12.24);
INSERT INTO items VALUES (192,4,2,259,1,10.52);
INSERT INTO items VALUES (192,4,3,946,12,104.61);
INSERT INTO items VALUES (192,5,1,423,1,26.88);
INSERT INTO items VALUES (192,5,2,770,1,15.81);
INSERT INTO items VALUES (192,5,3,668,12,163.35);
INSERT INTO items VALUES (193,1,1,734,2,36.62);
INSERT INTO items VALUES (193,1,2,832,1,8.88);
INSERT INTO items VALUES (193,1,3,191,12,190.19);
INSERT INTO items VALUES (193,1,4,386,2,56.90);
INSERT INTO items VALUES (193,1,5,893,2,48.88);
INSERT INTO items VALUES (193,1,6,120,3,15.33);
INSERT INTO items VALUES (193,2,1,797,1,18.25);
INSERT INTO items VALUES (193,2,2,396,3,35.85);
INSERT INTO items VALUES (193,2,3,982,3,86.01);
INSERT INTO items VALUES (193,2,4,694,2,31.52);
INSERT INTO items VALUES (193,2,5,726,2,57.02);
INSERT INTO items VALUES (193,3,1,411,3,71.97);
INSERT INTO items VALUES (193,3,2,64,1,26.33);
INSERT INTO items VALUES (193,3,3,16,1,8.95);
INSERT INTO items VALUES (193,3,4,971,1,19.81);
INSERT INTO items VALUES (193,3,5,749,2,11.14);
INSERT INTO items VALUES (193,4,1,168,2,48.74);
INSERT INTO items VALUES (193,4,2,466,12,129.91);
INSERT INTO items VALUES (193,4,3,663,1,7.23);
INSERT INTO items VALUES (193,4,4,335,3,28.74);
INSERT INTO items VALUES (193,4,5,824,3,85.68);
INSERT INTO items VALUES (193,4,6,226,1,8.68);
INSERT INTO items VALUES (193,5,1,139,12,170.94);
INSERT INTO items VALUES (193,5,2,827,12,224.84);
INSERT INTO items VALUES (193,5,3,189,3,50.19);
INSERT INTO items VALUES (193,5,4,615,2,47.14);
INSERT INTO items VALUES (194,1,1,779,3,59.61);
INSERT INTO items VALUES (195,1,1,310,2,20.52);
INSERT INTO items VALUES (195,1,2,553,1,9.23);
INSERT INTO items VALUES (195,1,3,847,3,56.37);
INSERT INTO items VALUES (195,1,4,991,3,79.68);
INSERT INTO items VALUES (195,2,1,391,2,58.10);
INSERT INTO items VALUES (195,2,2,444,2,36.32);
INSERT INTO items VALUES (195,3,1,819,2,15.54);
INSERT INTO items VALUES (196,1,1,117,1,24.93);
INSERT INTO items VALUES (196,1,2,204,3,72.84);
INSERT INTO items VALUES (196,1,3,281,2,11.26);
INSERT INTO items VALUES (196,1,4,742,12,250.69);
INSERT INTO items VALUES (196,2,1,837,12,97.02);
INSERT INTO items VALUES (196,3,1,1025,12,316.58);
INSERT INTO items VALUES (196,3,2,634,12,86.57);
INSERT INTO items VALUES (196,3,3,350,12,153.89);
INSERT INTO items VALUES (196,3,4,385,2,41.62);
INSERT INTO items VALUES (196,4,1,723,3,62.49);
INSERT INTO items VALUES (196,5,1,772,2,26.58);
INSERT INTO items VALUES (196,5,2,477,3,71.67);
INSERT INTO items VALUES (196,5,3,930,2,51.02);
INSERT INTO items VALUES (196,5,4,123,12,84.70);
INSERT INTO items VALUES (196,5,5,304,3,67.38);
INSERT INTO items VALUES (196,5,6,664,3,78.24);
INSERT INTO items VALUES (197,1,1,939,3,43.11);
INSERT INTO items VALUES (197,1,2,211,3,52.74);
INSERT INTO items VALUES (197,1,3,1029,1,15.19);
INSERT INTO items VALUES (197,1,4,533,12,206.14);
INSERT INTO items VALUES (197,2,1,614,3,26.79);
INSERT INTO items VALUES (197,2,2,477,2,47.78);
INSERT INTO items VALUES (197,2,3,980,1,22.32);
INSERT INTO items VALUES (197,3,1,789,12,157.41);
INSERT INTO items VALUES (197,3,2,162,3,58.92);
INSERT INTO items VALUES (197,3,3,610,2,11.92);
INSERT INTO items VALUES (197,3,4,206,3,73.80);
INSERT INTO items VALUES (197,4,1,700,3,58.05);
INSERT INTO items VALUES (197,4,2,613,2,43.24);
INSERT INTO items VALUES (198,1,1,911,2,11.42);
INSERT INTO items VALUES (198,1,2,89,3,83.55);
INSERT INTO items VALUES (198,1,3,15,12,135.63);
INSERT INTO items VALUES (198,1,4,700,3,58.05);
INSERT INTO items VALUES (198,1,5,543,1,28.06);
INSERT INTO items VALUES (198,1,6,900,1,16.94);
INSERT INTO items VALUES (199,1,1,351,3,76.41);
INSERT INTO items VALUES (199,1,2,473,2,14.56);
INSERT INTO items VALUES (199,2,1,848,2,34.74);
INSERT INTO items VALUES (199,2,2,1034,2,29.92);
INSERT INTO items VALUES (199,2,3,493,12,246.29);
INSERT INTO items VALUES (199,2,4,1036,1,11.74);
INSERT INTO items VALUES (199,2,5,462,1,23.78);
INSERT INTO items VALUES (199,2,6,1039,3,79.38);
INSERT INTO items VALUES (199,3,1,297,2,50.54);
INSERT INTO items VALUES (199,3,2,237,3,76.44);
INSERT INTO items VALUES (199,3,3,771,12,168.85);
INSERT INTO items VALUES (200,1,1,912,12,252.34);
INSERT INTO items VALUES (200,1,2,434,12,279.84);
INSERT INTO items VALUES (200,1,3,991,3,79.68);
INSERT INTO items VALUES (200,1,4,245,12,317.46);
INSERT INTO items VALUES (200,1,5,564,12,207.79);
INSERT INTO items VALUES (200,1,6,423,1,26.88);
INSERT INTO items VALUES (200,2,1,494,1,28.35);
INSERT INTO items VALUES (200,3,1,349,3,46.77);
INSERT INTO items VALUES (200,3,2,505,1,27.63);
INSERT INTO items VALUES (200,3,3,525,12,242.99);
INSERT INTO items VALUES (200,3,4,1043,2,33.46);
INSERT INTO items VALUES (200,4,1,867,3,47.04);
INSERT INTO items VALUES (200,5,1,390,3,25.29);
INSERT INTO items VALUES (200,5,2,1027,2,57.46);
INSERT INTO items VALUES (200,5,3,196,12,227.15);
INSERT INTO items VALUES (200,5,4,1006,3,60.48);
INSERT INTO items VALUES (200,5,5,453,2,29.54);
INSERT INTO items VALUES (200,5,6,757,12,235.07);
INSERT INTO items VALUES (200,6,1,973,3,48.06);
INSERT INTO items VALUES (200,6,2,871,12,112.42);
INSERT INTO items VALUES (200,6,3,148,1,13.24);
INSERT INTO items VALUES (200,6,4,364,12,250.69);
INSERT INTO items VALUES (200,6,5,821,12,62.59);
INSERT INTO items VALUES (201,1,1,750,3,19.71);
INSERT INTO items VALUES (201,1,2,1030,1,21.21);
INSERT INTO items VALUES (201,1,3,398,12,320.54);
INSERT INTO items VALUES (201,1,4,518,1,15.35);
INSERT INTO items VALUES (201,2,1,905,3,34.32);
INSERT INTO items VALUES (201,2,2,837,12,97.02);
INSERT INTO items VALUES (201,2,3,75,3,68.19);
INSERT INTO items VALUES (201,2,4,760,1,6.12);
INSERT INTO items VALUES (202,1,1,876,3,38.19);
INSERT INTO items VALUES (202,1,2,630,12,308.00);
INSERT INTO items VALUES (202,1,3,85,3,64.62);
INSERT INTO items VALUES (202,1,4,510,1,11.03);
INSERT INTO items VALUES (202,2,1,687,12,185.79);
INSERT INTO items VALUES (202,2,2,356,3,67.29);
INSERT INTO items VALUES (202,2,3,1028,1,13.90);
INSERT INTO items VALUES (202,2,4,337,1,16.72);
INSERT INTO items VALUES (202,3,1,436,2,11.98);
INSERT INTO items VALUES (202,3,2,715,1,18.98);
INSERT INTO items VALUES (202,3,3,344,12,165.66);
INSERT INTO items VALUES (202,3,4,559,12,73.37);
INSERT INTO items VALUES (202,3,5,984,2,12.34);
INSERT INTO items VALUES (202,3,6,600,1,16.99);
INSERT INTO items VALUES (202,4,1,645,1,18.13);
INSERT INTO items VALUES (202,5,1,483,1,12.06);
INSERT INTO items VALUES (202,6,1,446,3,64.32);
INSERT INTO items VALUES (202,6,2,543,12,308.66);
INSERT INTO items VALUES (202,6,3,184,3,81.33);
INSERT INTO items VALUES (202,6,4,1040,3,84.36);
INSERT INTO items VALUES (203,1,1,113,12,211.75);
INSERT INTO items VALUES (204,1,1,1013,2,20.08);
INSERT INTO items VALUES (204,2,1,559,1,6.67);
INSERT INTO items VALUES (204,2,2,192,1,22.37);
INSERT INTO items VALUES (205,1,1,952,3,64.44);
INSERT INTO items VALUES (205,1,2,128,3,63.75);
INSERT INTO items VALUES (205,1,3,73,3,32.10);
INSERT INTO items VALUES (205,1,4,955,3,56.73);
INSERT INTO items VALUES (205,1,5,109,1,16.00);
INSERT INTO items VALUES (205,1,6,566,2,14.08);
INSERT INTO items VALUES (206,1,1,52,12,294.03);
INSERT INTO items VALUES (206,1,2,270,1,20.46);
INSERT INTO items VALUES (207,1,1,290,3,26.73);
INSERT INTO items VALUES (207,1,2,288,2,29.90);
INSERT INTO items VALUES (207,1,3,83,1,15.54);
INSERT INTO items VALUES (207,1,4,964,1,13.33);
INSERT INTO items VALUES (207,2,1,426,12,95.37);
INSERT INTO items VALUES (207,2,2,301,3,88.74);
INSERT INTO items VALUES (207,2,3,49,1,10.18);
INSERT INTO items VALUES (207,2,4,889,2,27.84);
INSERT INTO items VALUES (207,3,1,17,12,277.53);
INSERT INTO items VALUES (207,3,2,374,2,18.56);
INSERT INTO items VALUES (207,3,3,117,2,49.86);
INSERT INTO items VALUES (207,3,4,498,1,16.48);
INSERT INTO items VALUES (207,3,5,648,3,49.02);
INSERT INTO items VALUES (207,4,1,385,12,228.91);
INSERT INTO items VALUES (207,4,2,252,2,51.30);
INSERT INTO items VALUES (207,4,3,983,1,26.11);
INSERT INTO items VALUES (207,4,4,705,12,109.67);
INSERT INTO items VALUES (207,5,1,874,2,38.80);
INSERT INTO items VALUES (207,5,2,575,12,282.37);
INSERT INTO items VALUES (208,1,1,741,1,12.89);
INSERT INTO items VALUES (208,1,2,151,2,44.74);
INSERT INTO items VALUES (208,1,3,469,12,295.68);
INSERT INTO items VALUES (208,1,4,623,12,243.10);
INSERT INTO items VALUES (208,2,1,783,1,27.87);
INSERT INTO items VALUES (208,2,2,976,1,10.41);
INSERT INTO items VALUES (208,2,3,12,2,54.84);
INSERT INTO items VALUES (208,2,4,580,12,269.39);
INSERT INTO items VALUES (208,2,5,129,3,17.25);
INSERT INTO items VALUES (208,2,6,975,3,27.60);
INSERT INTO items VALUES (208,3,1,478,12,196.13);
INSERT INTO items VALUES (208,4,1,248,2,52.36);
INSERT INTO items VALUES (208,4,2,552,12,58.30);
INSERT INTO items VALUES (208,4,3,490,2,16.62);
INSERT INTO items VALUES (208,4,4,1036,2,23.48);
INSERT INTO items VALUES (208,5,1,409,12,245.74);
INSERT INTO items VALUES (208,5,2,737,2,52.38);
INSERT INTO items VALUES (208,5,3,900,1,16.94);
INSERT INTO items VALUES (209,1,1,695,12,264.33);
INSERT INTO items VALUES (209,2,1,942,3,84.69);
INSERT INTO items VALUES (209,2,2,884,2,33.78);
INSERT INTO items VALUES (210,1,1,326,3,39.48);
INSERT INTO items VALUES (210,1,2,911,3,17.13);
INSERT INTO items VALUES (210,1,3,458,1,8.01);
INSERT INTO items VALUES (210,1,4,1035,12,229.79);
INSERT INTO items VALUES (210,2,1,763,12,84.48);
INSERT INTO items VALUES (210,2,2,144,1,26.21);
INSERT INTO items VALUES (210,2,3,895,3,75.18);
INSERT INTO items VALUES (210,3,1,350,2,27.98);
INSERT INTO items VALUES (210,3,2,825,3,88.89);
INSERT INTO items VALUES (211,1,1,355,1,20.33);
INSERT INTO items VALUES (212,1,1,395,2,33.98);
INSERT INTO items VALUES (212,1,2,403,3,74.94);
INSERT INTO items VALUES (212,1,3,407,1,18.98);
INSERT INTO items VALUES (212,1,4,465,2,16.00);
INSERT INTO items VALUES (213,1,1,472,3,25.08);
INSERT INTO items VALUES (213,1,2,993,12,268.07);
INSERT INTO items VALUES (213,1,3,716,2,27.70);
INSERT INTO items VALUES (213,1,4,981,12,273.90);
INSERT INTO items VALUES (213,1,5,39,3,22.14);
INSERT INTO items VALUES (213,2,1,431,12,196.46);
INSERT INTO items VALUES (213,2,2,687,3,50.67);
INSERT INTO items VALUES (213,3,1,749,1,5.57);
INSERT INTO items VALUES (213,3,2,312,1,11.93);
INSERT INTO items VALUES (213,3,3,706,1,26.02);
INSERT INTO items VALUES (213,3,4,70,2,32.10);
INSERT INTO items VALUES (214,1,1,470,1,9.44);
INSERT INTO items VALUES (214,1,2,977,3,43.53);
INSERT INTO items VALUES (214,1,3,546,12,328.68);
INSERT INTO items VALUES (214,1,4,389,1,17.52);
INSERT INTO items VALUES (214,2,1,904,2,37.26);
INSERT INTO items VALUES (214,3,1,101,3,26.19);
INSERT INTO items VALUES (214,4,1,66,2,20.58);
INSERT INTO items VALUES (214,4,2,465,12,88.00);
INSERT INTO items VALUES (214,4,3,696,3,19.86);
INSERT INTO items VALUES (214,4,4,275,1,21.69);
INSERT INTO items VALUES (214,4,5,805,12,314.16);
INSERT INTO items VALUES (214,4,6,170,1,9.75);
INSERT INTO items VALUES (215,1,1,197,1,11.73);
INSERT INTO items VALUES (215,2,1,559,3,20.01);
INSERT INTO items VALUES (215,2,2,35,12,194.04);
INSERT INTO items VALUES (215,2,3,992,12,115.61);
INSERT INTO items VALUES (215,2,4,512,3,82.47);
INSERT INTO items VALUES (215,2,5,266,3,55.98);
INSERT INTO items VALUES (215,2,6,321,1,11.69);
INSERT INTO items VALUES (215,3,1,816,12,127.27);
INSERT INTO items VALUES (215,3,2,926,12,270.60);
INSERT INTO items VALUES (215,3,3,1041,1,17.18);
INSERT INTO items VALUES (215,3,4,832,12,97.68);
INSERT INTO items VALUES (215,3,5,1010,3,57.54);
INSERT INTO items VALUES (215,4,1,1004,3,72.54);
INSERT INTO items VALUES (215,4,2,344,1,15.06);
INSERT INTO items VALUES (215,4,3,103,3,37.11);
INSERT INTO items VALUES (215,4,4,225,12,186.56);
INSERT INTO items VALUES (215,4,5,100,1,23.46);
INSERT INTO items VALUES (215,5,1,943,1,16.13);
INSERT INTO items VALUES (215,6,1,760,1,6.12);
INSERT INTO items VALUES (216,1,1,825,2,59.26);
INSERT INTO items VALUES (216,1,2,300,12,290.18);
INSERT INTO items VALUES (216,1,3,524,3,45.78);
INSERT INTO items VALUES (216,1,4,41,3,50.97);
INSERT INTO items VALUES (217,1,1,734,2,36.62);
INSERT INTO items VALUES (217,1,2,9,12,269.17);
INSERT INTO items VALUES (217,1,3,447,3,40.74);
INSERT INTO items VALUES (217,1,4,977,2,29.02);
INSERT INTO items VALUES (217,2,1,735,1,22.11);
INSERT INTO items VALUES (217,2,2,840,3,43.89);
INSERT INTO items VALUES (217,2,3,687,3,50.67);
INSERT INTO items VALUES (217,2,4,652,2,20.56);
INSERT INTO items VALUES (217,3,1,34,3,42.84);
INSERT INTO items VALUES (217,3,2,1009,1,22.13);
INSERT INTO items VALUES (217,3,3,517,2,14.84);
INSERT INTO items VALUES (217,3,4,810,2,55.42);
INSERT INTO items VALUES (217,4,1,884,12,185.79);
INSERT INTO items VALUES (217,5,1,664,3,78.24);
INSERT INTO items VALUES (217,5,2,259,1,10.52);
INSERT INTO items VALUES (217,6,1,247,1,25.40);
INSERT INTO items VALUES (218,1,1,386,2,56.90);
INSERT INTO items VALUES (218,1,2,776,3,70.89);
INSERT INTO items VALUES (218,1,3,62,1,16.85);
INSERT INTO items VALUES (218,1,4,522,1,7.30);
INSERT INTO items VALUES (218,1,5,129,3,17.25);
INSERT INTO items VALUES (218,1,6,913,3,65.04);
INSERT INTO items VALUES (218,2,1,333,1,16.64);
INSERT INTO items VALUES (218,2,2,65,2,19.96);
INSERT INTO items VALUES (218,2,3,963,3,75.96);
INSERT INTO items VALUES (218,2,4,309,1,19.40);
INSERT INTO items VALUES (218,2,5,594,3,18.24);
INSERT INTO items VALUES (218,3,1,386,1,28.45);
INSERT INTO items VALUES (218,3,2,468,2,57.20);
INSERT INTO items VALUES (218,4,1,962,12,172.92);
INSERT INTO items VALUES (218,4,2,623,1,22.10);
INSERT INTO items VALUES (218,4,3,919,3,40.05);
INSERT INTO items VALUES (218,4,4,635,12,235.29);
INSERT INTO items VALUES (218,4,5,396,12,131.45);
INSERT INTO items VALUES (218,5,1,733,12,106.81);
INSERT INTO items VALUES (218,5,2,53,1,26.62);
INSERT INTO items VALUES (218,5,3,41,2,33.98);
INSERT INTO items VALUES (218,5,4,585,12,295.35);
INSERT INTO items VALUES (218,5,5,852,12,286.99);
INSERT INTO items VALUES (218,5,6,491,1,7.33);
INSERT INTO items VALUES (218,6,1,510,12,121.33);
INSERT INTO items VALUES (218,6,2,308,12,143.66);
INSERT INTO items VALUES (218,6,3,772,2,26.58);
INSERT INTO items VALUES (219,1,1,876,1,12.73);
INSERT INTO items VALUES (219,1,2,706,2,52.04);
INSERT INTO items VALUES (219,1,3,611,2,42.64);
INSERT INTO items VALUES (219,1,4,151,2,44.74);
INSERT INTO items VALUES (219,2,1,469,1,26.88);
INSERT INTO items VALUES (219,2,2,501,2,44.78);
INSERT INTO items VALUES (219,2,3,542,2,39.04);
INSERT INTO items VALUES (219,2,4,21,12,210.54);
INSERT INTO items VALUES (219,2,5,156,1,7.49);
INSERT INTO items VALUES (219,2,6,746,2,22.24);
INSERT INTO items VALUES (219,3,1,695,12,264.33);
INSERT INTO items VALUES (219,3,2,684,12,248.05);
INSERT INTO items VALUES (219,4,1,765,3,89.64);
INSERT INTO items VALUES (219,5,1,731,1,25.68);
INSERT INTO items VALUES (219,5,2,386,1,28.45);
INSERT INTO items VALUES (219,5,3,125,12,97.02);
INSERT INTO items VALUES (219,5,4,493,3,67.17);
INSERT INTO items VALUES (220,1,1,67,3,83.40);
INSERT INTO items VALUES (220,2,1,773,3,76.20);
INSERT INTO items VALUES (221,1,1,1003,12,107.47);
INSERT INTO items VALUES (221,2,1,963,3,75.96);
INSERT INTO items VALUES (221,2,2,420,12,314.05);
INSERT INTO items VALUES (221,3,1,839,1,19.50);
INSERT INTO items VALUES (221,3,2,494,12,311.85);
INSERT INTO items VALUES (221,3,3,354,1,6.19);
INSERT INTO items VALUES (221,3,4,453,2,29.54);
INSERT INTO items VALUES (221,3,5,957,2,11.40);
INSERT INTO items VALUES (221,3,6,426,12,95.37);
INSERT INTO items VALUES (221,4,1,657,12,191.73);
INSERT INTO items VALUES (221,4,2,965,1,25.85);
INSERT INTO items VALUES (221,5,1,319,3,44.10);
INSERT INTO items VALUES (221,5,2,995,12,154.88);
INSERT INTO items VALUES (221,5,3,308,2,26.12);
INSERT INTO items VALUES (221,5,4,891,3,70.80);
INSERT INTO items VALUES (221,5,5,635,12,235.29);
INSERT INTO items VALUES (221,5,6,176,1,20.74);
INSERT INTO items VALUES (221,6,1,211,12,193.38);
INSERT INTO items VALUES (221,6,2,847,1,18.79);
INSERT INTO items VALUES (221,6,3,7,3,36.60);
INSERT INTO items VALUES (221,6,4,348,1,18.36);
INSERT INTO items VALUES (221,6,5,198,12,151.91);
INSERT INTO items VALUES (221,6,6,749,1,5.57);
INSERT INTO items VALUES (222,1,1,970,2,57.14);
INSERT INTO items VALUES (222,1,2,424,12,94.38);
INSERT INTO items VALUES (223,1,1,256,12,308.11);
INSERT INTO items VALUES (223,1,2,95,2,58.38);
INSERT INTO items VALUES (223,1,3,626,2,16.56);
INSERT INTO items VALUES (223,1,4,273,12,65.23);
INSERT INTO items VALUES (223,1,5,204,12,267.08);
INSERT INTO items VALUES (223,1,6,913,2,43.36);
INSERT INTO items VALUES (224,1,1,298,2,49.28);
INSERT INTO items VALUES (224,2,1,785,12,309.21);
INSERT INTO items VALUES (224,2,2,528,3,29.52);
INSERT INTO items VALUES (225,1,1,1039,12,291.06);
INSERT INTO items VALUES (225,1,2,192,12,246.07);
INSERT INTO items VALUES (225,1,3,77,12,97.24);
INSERT INTO items VALUES (225,1,4,125,12,97.02);
INSERT INTO items VALUES (225,1,5,874,2,38.80);
INSERT INTO items VALUES (225,1,6,188,1,7.71);
INSERT INTO items VALUES (226,1,1,426,1,8.67);
INSERT INTO items VALUES (226,1,2,641,2,38.94);
INSERT INTO items VALUES (226,1,3,906,12,113.63);
INSERT INTO items VALUES (226,1,4,1008,12,315.15);
INSERT INTO items VALUES (226,1,5,71,3,22.50);
INSERT INTO items VALUES (226,1,6,908,1,11.74);
INSERT INTO items VALUES (226,2,1,809,2,18.38);
INSERT INTO items VALUES (226,2,2,779,12,218.57);
INSERT INTO items VALUES (226,2,3,725,2,48.36);
INSERT INTO items VALUES (226,2,4,393,1,27.70);
INSERT INTO items VALUES (226,3,1,715,3,56.94);
INSERT INTO items VALUES (226,3,2,893,3,73.32);
INSERT INTO items VALUES (226,3,3,520,12,110.11);
INSERT INTO items VALUES (226,3,4,303,2,24.70);
INSERT INTO items VALUES (226,3,5,1024,12,218.35);
INSERT INTO items VALUES (226,3,6,431,12,196.46);
INSERT INTO items VALUES (227,1,1,33,1,18.75);
INSERT INTO items VALUES (227,2,1,493,12,246.29);
INSERT INTO items VALUES (227,2,2,152,1,5.81);
INSERT INTO items VALUES (227,2,3,665,12,73.92);
INSERT INTO items VALUES (227,3,1,481,3,17.46);
INSERT INTO items VALUES (227,3,2,741,2,25.78);
INSERT INTO items VALUES (227,3,3,666,12,171.05);
INSERT INTO items VALUES (227,4,1,253,3,84.72);
INSERT INTO items VALUES (227,4,2,647,1,29.32);
INSERT INTO items VALUES (227,4,3,69,1,16.61);
INSERT INTO items VALUES (227,4,4,944,1,19.94);
INSERT INTO items VALUES (227,4,5,184,3,81.33);
INSERT INTO items VALUES (227,4,6,1046,12,121.00);
INSERT INTO items VALUES (228,1,1,807,3,29.61);
INSERT INTO items VALUES (228,1,2,196,3,61.95);
INSERT INTO items VALUES (228,1,3,351,3,76.41);
INSERT INTO items VALUES (228,1,4,523,1,26.78);
INSERT INTO items VALUES (229,1,1,808,3,77.58);
INSERT INTO items VALUES (229,1,2,764,12,126.72);
INSERT INTO items VALUES (229,1,3,144,3,78.63);
INSERT INTO items VALUES (229,1,4,739,1,25.28);
INSERT INTO items VALUES (229,2,1,256,2,56.02);
INSERT INTO items VALUES (229,2,2,602,12,128.92);
INSERT INTO items VALUES (229,2,3,820,2,59.32);
INSERT INTO items VALUES (229,3,1,732,12,297.99);
INSERT INTO items VALUES (229,3,2,167,2,42.10);
INSERT INTO items VALUES (229,3,3,514,12,177.98);
INSERT INTO items VALUES (229,3,4,434,3,76.32);
INSERT INTO items VALUES (230,1,1,635,3,64.17);
INSERT INTO items VALUES (230,2,1,823,1,23.20);
INSERT INTO items VALUES (230,2,2,643,12,213.07);
INSERT INTO items VALUES (230,2,3,269,2,30.72);
INSERT INTO items VALUES (230,3,1,274,12,68.42);
INSERT INTO items VALUES (230,3,2,522,1,7.30);
INSERT INTO items VALUES (230,3,3,345,1,8.23);
INSERT INTO items VALUES (230,4,1,447,2,27.16);
INSERT INTO items VALUES (230,4,2,316,12,316.58);
INSERT INTO items VALUES (230,4,3,829,1,10.60);
INSERT INTO items VALUES (231,1,1,365,12,92.40);
INSERT INTO items VALUES (231,2,1,264,1,12.84);
INSERT INTO items VALUES (231,2,2,200,2,23.76);
INSERT INTO items VALUES (231,2,3,618,2,58.14);
INSERT INTO items VALUES (231,2,4,586,1,17.70);
INSERT INTO items VALUES (231,3,1,123,2,15.40);
INSERT INTO items VALUES (231,3,2,961,12,110.88);
INSERT INTO items VALUES (231,3,3,742,2,45.58);
INSERT INTO items VALUES (231,3,4,884,1,16.89);
INSERT INTO items VALUES (231,3,5,297,1,25.27);
INSERT INTO items VALUES (231,4,1,102,2,13.42);
INSERT INTO items VALUES (231,4,2,565,3,72.06);
INSERT INTO items VALUES (231,5,1,771,3,46.05);
INSERT INTO items VALUES (231,5,2,1003,12,107.47);
INSERT INTO items VALUES (231,6,1,461,3,31.98);
INSERT INTO items VALUES (231,6,2,423,12,295.68);
INSERT INTO items VALUES (231,6,3,184,2,54.22);
INSERT INTO items VALUES (231,6,4,945,2,31.78);
INSERT INTO items VALUES (232,1,1,854,2,49.50);
INSERT INTO items VALUES (232,1,2,543,1,28.06);
INSERT INTO items VALUES (232,1,3,60,1,16.21);
INSERT INTO items VALUES (232,2,1,3,1,9.94);
INSERT INTO items VALUES (232,3,1,146,3,63.90);
INSERT INTO items VALUES (232,3,2,404,3,81.03);
INSERT INTO items VALUES (232,3,3,821,1,5.69);
INSERT INTO items VALUES (232,4,1,486,1,15.87);
INSERT INTO items VALUES (232,4,2,965,2,51.70);
INSERT INTO items VALUES (232,4,3,1021,12,239.47);
INSERT INTO items VALUES (232,4,4,951,2,49.06);
INSERT INTO items VALUES (232,4,5,933,12,302.17);
INSERT INTO items VALUES (232,4,6,579,2,15.36);
INSERT INTO items VALUES (233,1,1,681,2,56.24);
INSERT INTO items VALUES (233,1,2,346,3,21.42);
INSERT INTO items VALUES (233,1,3,316,2,57.56);
INSERT INTO items VALUES (233,1,4,223,1,13.04);
INSERT INTO items VALUES (233,2,1,273,3,17.79);
INSERT INTO items VALUES (233,2,2,591,3,38.10);
INSERT INTO items VALUES (233,2,3,670,2,33.82);
INSERT INTO items VALUES (233,2,4,277,1,26.37);
INSERT INTO items VALUES (233,3,1,873,12,227.15);
INSERT INTO items VALUES (233,4,1,415,12,124.41);
INSERT INTO items VALUES (233,4,2,861,3,41.55);
INSERT INTO items VALUES (233,4,3,272,3,28.80);
INSERT INTO items VALUES (233,4,4,353,3,74.37);
INSERT INTO items VALUES (233,4,5,516,12,119.57);
INSERT INTO items VALUES (234,1,1,997,1,9.03);
INSERT INTO items VALUES (234,2,1,175,3,76.80);
INSERT INTO items VALUES (234,2,2,362,12,252.12);
INSERT INTO items VALUES (234,2,3,69,2,33.22);
INSERT INTO items VALUES (234,2,4,847,3,56.37);
INSERT INTO items VALUES (235,1,1,371,12,170.39);
INSERT INTO items VALUES (235,1,2,350,12,153.89);
INSERT INTO items VALUES (235,2,1,729,2,13.42);
INSERT INTO items VALUES (235,2,2,798,2,58.96);
INSERT INTO items VALUES (235,2,3,441,2,11.74);
INSERT INTO items VALUES (235,2,4,665,2,13.44);
INSERT INTO items VALUES (235,3,1,655,12,234.52);
INSERT INTO items VALUES (235,3,2,320,12,230.12);
INSERT INTO items VALUES (235,4,1,202,1,10.08);
INSERT INTO items VALUES (235,4,2,373,12,281.27);
INSERT INTO items VALUES (235,4,3,845,1,16.18);
INSERT INTO items VALUES (235,4,4,254,3,67.65);
INSERT INTO items VALUES (235,4,5,357,3,70.92);
INSERT INTO items VALUES (236,1,1,52,1,26.73);
INSERT INTO items VALUES (236,1,2,84,12,295.24);
INSERT INTO items VALUES (236,1,3,384,1,21.07);
INSERT INTO items VALUES (236,2,1,699,2,39.42);
INSERT INTO items VALUES (236,2,2,239,3,72.57);
INSERT INTO items VALUES (236,2,3,160,2,59.84);
INSERT INTO items VALUES (236,2,4,940,3,36.54);
INSERT INTO items VALUES (236,2,5,648,3,49.02);
INSERT INTO items VALUES (236,2,6,752,3,25.77);
INSERT INTO items VALUES (236,3,1,10,1,17.82);
INSERT INTO items VALUES (236,3,2,858,2,10.66);
INSERT INTO items VALUES (236,3,3,90,3,20.31);
INSERT INTO items VALUES (236,3,4,419,12,121.44);
INSERT INTO items VALUES (236,3,5,854,12,272.25);
INSERT INTO items VALUES (236,3,6,100,3,70.38);
INSERT INTO items VALUES (236,4,1,328,12,215.49);
INSERT INTO items VALUES (236,5,1,199,12,223.08);
INSERT INTO items VALUES (236,5,2,158,1,13.39);
INSERT INTO items VALUES (236,6,1,464,12,165.77);
INSERT INTO items VALUES (236,6,2,23,1,26.56);
INSERT INTO items VALUES (236,6,3,403,2,49.96);
INSERT INTO items VALUES (236,6,4,47,3,72.12);
INSERT INTO items VALUES (236,6,5,61,1,16.98);
INSERT INTO items VALUES (236,6,6,703,2,53.54);
INSERT INTO items VALUES (237,1,1,870,2,45.78);
INSERT INTO items VALUES (237,1,2,984,1,6.17);
INSERT INTO items VALUES (237,1,3,237,12,280.28);
INSERT INTO items VALUES (237,1,4,629,2,48.38);
INSERT INTO items VALUES (237,1,5,560,3,68.73);
INSERT INTO items VALUES (238,1,1,397,3,34.14);
INSERT INTO items VALUES (238,2,1,1016,1,19.99);
INSERT INTO items VALUES (238,2,2,277,12,290.07);
INSERT INTO items VALUES (238,2,3,1023,3,46.47);
INSERT INTO items VALUES (238,2,4,730,1,24.66);
INSERT INTO items VALUES (238,2,5,800,3,54.48);
INSERT INTO items VALUES (238,2,6,632,1,16.48);
INSERT INTO items VALUES (239,1,1,114,2,44.64);
INSERT INTO items VALUES (239,1,2,805,12,314.16);
INSERT INTO items VALUES (239,1,3,790,12,136.73);
INSERT INTO items VALUES (240,1,1,959,3,30.21);
INSERT INTO items VALUES (240,1,2,919,3,40.05);
INSERT INTO items VALUES (240,1,3,603,3,17.34);
INSERT INTO items VALUES (240,2,1,986,2,13.12);
INSERT INTO items VALUES (240,2,2,711,2,56.14);
INSERT INTO items VALUES (240,2,3,446,1,21.44);
INSERT INTO items VALUES (240,3,1,698,1,15.50);
INSERT INTO items VALUES (240,4,1,429,12,181.72);
INSERT INTO items VALUES (240,4,2,1043,3,50.19);
INSERT INTO items VALUES (240,4,3,612,2,59.16);
INSERT INTO items VALUES (240,4,4,984,2,12.34);
INSERT INTO items VALUES (240,4,5,844,12,207.02);
INSERT INTO items VALUES (240,5,1,339,1,10.67);
INSERT INTO items VALUES (240,5,2,726,2,57.02);
INSERT INTO items VALUES (240,5,3,336,2,55.82);
INSERT INTO items VALUES (240,6,1,558,12,314.49);
INSERT INTO items VALUES (241,1,1,279,12,175.67);
INSERT INTO items VALUES (241,1,2,166,2,16.52);
INSERT INTO items VALUES (241,1,3,18,3,25.35);
INSERT INTO items VALUES (241,1,4,817,2,37.50);
INSERT INTO items VALUES (241,1,5,8,12,110.66);
INSERT INTO items VALUES (241,2,1,478,3,53.49);
INSERT INTO items VALUES (241,3,1,24,3,55.80);
INSERT INTO items VALUES (241,3,2,332,1,25.29);
INSERT INTO items VALUES (241,3,3,261,3,46.11);
INSERT INTO items VALUES (241,3,4,888,2,11.56);
INSERT INTO items VALUES (241,3,5,60,12,178.31);
INSERT INTO items VALUES (241,3,6,96,12,248.82);
INSERT INTO items VALUES (241,4,1,102,1,6.71);
INSERT INTO items VALUES (241,5,1,555,3,26.37);
INSERT INTO items VALUES (241,5,2,302,3,68.10);
INSERT INTO items VALUES (241,5,3,151,3,67.11);
INSERT INTO items VALUES (241,6,1,934,1,25.09);
INSERT INTO items VALUES (241,6,2,694,12,173.36);
INSERT INTO items VALUES (242,1,1,55,12,235.51);
INSERT INTO items VALUES (242,1,2,455,1,28.99);
INSERT INTO items VALUES (242,1,3,702,12,97.02);
INSERT INTO items VALUES (242,1,4,669,1,13.62);
INSERT INTO items VALUES (242,2,1,232,3,42.99);
INSERT INTO items VALUES (242,2,2,119,3,53.46);
INSERT INTO items VALUES (242,2,3,488,1,5.10);
INSERT INTO items VALUES (242,2,4,194,2,30.20);
INSERT INTO items VALUES (242,2,5,110,2,25.48);
INSERT INTO items VALUES (242,2,6,899,1,7.35);
INSERT INTO items VALUES (242,3,1,544,12,71.83);
INSERT INTO items VALUES (242,3,2,497,1,21.46);
INSERT INTO items VALUES (242,3,3,1039,3,79.38);
INSERT INTO items VALUES (242,3,4,363,2,29.44);
INSERT INTO items VALUES (242,3,5,247,1,25.40);
INSERT INTO items VALUES (242,4,1,431,1,17.86);
INSERT INTO items VALUES (242,4,2,675,3,65.79);
INSERT INTO items VALUES (242,5,1,279,1,15.97);
INSERT INTO items VALUES (242,5,2,77,12,97.24);
INSERT INTO items VALUES (242,5,3,834,3,67.68);
INSERT INTO items VALUES (242,6,1,324,2,40.74);
INSERT INTO items VALUES (242,6,2,801,1,5.17);
INSERT INTO items VALUES (242,6,3,691,3,87.00);
INSERT INTO items VALUES (243,1,1,300,1,26.38);
INSERT INTO items VALUES (243,1,2,242,3,84.96);
INSERT INTO items VALUES (243,2,1,899,2,14.70);
INSERT INTO items VALUES (243,2,2,527,1,27.40);
INSERT INTO items VALUES (244,1,1,606,12,278.41);
INSERT INTO items VALUES (244,1,2,13,2,35.20);
INSERT INTO items VALUES (244,2,1,125,3,26.46);
INSERT INTO items VALUES (244,2,2,265,12,184.03);
INSERT INTO items VALUES (244,2,3,826,2,41.80);
INSERT INTO items VALUES (244,2,4,171,1,27.30);
INSERT INTO items VALUES (244,2,5,190,3,60.84);
INSERT INTO items VALUES (244,2,6,528,1,9.84);
INSERT INTO items VALUES (244,3,1,442,2,27.34);
INSERT INTO items VALUES (244,3,2,181,2,10.94);
INSERT INTO items VALUES (244,4,1,395,1,16.99);
INSERT INTO items VALUES (244,4,2,260,3,22.02);
INSERT INTO items VALUES (244,4,3,19,1,29.22);
INSERT INTO items VALUES (244,4,4,999,1,17.61);
INSERT INTO items VALUES (244,4,5,39,1,7.38);
INSERT INTO items VALUES (244,5,1,67,3,83.40);
INSERT INTO items VALUES (244,5,2,786,2,41.68);
INSERT INTO items VALUES (244,5,3,202,12,110.88);
INSERT INTO items VALUES (245,1,1,366,3,72.36);
INSERT INTO items VALUES (245,1,2,815,12,70.84);
INSERT INTO items VALUES (245,1,3,743,12,87.78);
INSERT INTO items VALUES (245,1,4,976,12,114.51);
INSERT INTO items VALUES (245,2,1,261,1,15.37);
INSERT INTO items VALUES (245,2,2,435,12,130.35);
INSERT INTO items VALUES (245,2,3,910,12,311.19);
INSERT INTO items VALUES (245,3,1,353,12,272.69);
INSERT INTO items VALUES (245,4,1,622,1,17.45);
INSERT INTO items VALUES (245,4,2,33,3,56.25);
INSERT INTO items VALUES (245,5,1,195,2,45.06);
INSERT INTO items VALUES (245,5,2,431,1,17.86);
INSERT INTO items VALUES (245,5,3,481,1,5.82);
INSERT INTO items VALUES (245,5,4,945,3,47.67);
INSERT INTO items VALUES (245,6,1,676,3,37.05);
INSERT INTO items VALUES (245,6,2,261,12,169.07);
INSERT INTO items VALUES (245,6,3,976,12,114.51);
INSERT INTO items VALUES (245,6,4,61,12,186.78);
INSERT INTO items VALUES (246,1,1,355,1,20.33);
INSERT INTO items VALUES (246,1,2,222,2,48.40);
INSERT INTO items VALUES (246,1,3,624,2,44.50);
INSERT INTO items VALUES (246,1,4,340,2,28.58);
INSERT INTO items VALUES (246,1,5,1025,3,86.34);
INSERT INTO items VALUES (246,2,1,747,1,26.98);
INSERT INTO items VALUES (246,2,2,175,3,76.80);
INSERT INTO items VALUES (246,3,1,694,2,31.52);
INSERT INTO items VALUES (246,3,2,150,12,95.26);
INSERT INTO items VALUES (246,3,3,620,2,51.60);
INSERT INTO items VALUES (247,1,1,652,12,113.08);
INSERT INTO items VALUES (247,1,2,107,1,6.41);
INSERT INTO items VALUES (247,1,3,232,2,28.66);
INSERT INTO items VALUES (247,1,4,836,2,32.38);
INSERT INTO items VALUES (247,2,1,7,1,12.20);
INSERT INTO items VALUES (247,3,1,251,2,11.42);
INSERT INTO items VALUES (247,3,2,1017,3,42.90);
INSERT INTO items VALUES (248,1,1,838,3,57.90);
INSERT INTO items VALUES (248,1,2,877,2,38.30);
INSERT INTO items VALUES (248,1,3,995,2,28.16);
INSERT INTO items VALUES (249,1,1,587,3,31.14);
INSERT INTO items VALUES (249,1,2,914,1,5.23);
INSERT INTO items VALUES (249,1,3,946,1,9.51);
INSERT INTO items VALUES (249,1,4,518,12,168.85);
INSERT INTO items VALUES (249,1,5,899,3,22.05);
INSERT INTO items VALUES (249,2,1,504,3,83.16);
INSERT INTO items VALUES (249,2,2,632,12,181.28);
INSERT INTO items VALUES (249,2,3,681,1,28.12);
INSERT INTO items VALUES (249,2,4,752,1,8.59);
INSERT INTO items VALUES (249,2,5,361,12,140.36);
INSERT INTO items VALUES (249,3,1,397,1,11.38);
INSERT INTO items VALUES (249,4,1,798,3,88.44);
INSERT INTO items VALUES (249,4,2,960,12,234.41);
INSERT INTO items VALUES (249,5,1,940,1,12.18);
INSERT INTO items VALUES (249,6,1,735,12,243.21);
INSERT INTO items VALUES (249,6,2,735,12,243.21);
INSERT INTO items VALUES (250,1,1,969,1,13.93);
INSERT INTO items VALUES (250,1,2,690,2,40.14);
INSERT INTO items VALUES (250,1,3,551,1,23.73);
INSERT INTO items VALUES (250,1,4,269,3,46.08);
INSERT INTO items VALUES (250,1,5,459,2,23.92);
INSERT INTO items VALUES (250,2,1,1026,1,26.36);
INSERT INTO items VALUES (250,2,2,363,12,161.92);
INSERT INTO items VALUES (250,2,3,889,2,27.84);
INSERT INTO items VALUES (250,2,4,775,2,21.32);
INSERT INTO items VALUES (250,3,1,63,12,260.92);
INSERT INTO items VALUES (250,3,2,943,3,48.39);
INSERT INTO items VALUES (250,3,3,136,1,25.35);
INSERT INTO items VALUES (250,3,4,304,3,67.38);
INSERT INTO items VALUES (250,4,1,865,2,59.16);
INSERT INTO items VALUES (250,5,1,865,3,88.74);
INSERT INTO items VALUES (250,5,2,950,3,33.18);
INSERT INTO items VALUES (250,5,3,620,1,25.80);
INSERT INTO items VALUES (250,6,1,550,12,123.42);
INSERT INTO items VALUES (250,6,2,686,2,39.04);
INSERT INTO items VALUES (251,1,1,617,1,12.09);
INSERT INTO items VALUES (251,2,1,409,2,44.68);
INSERT INTO items VALUES (251,2,2,667,3,69.21);
INSERT INTO items VALUES (251,2,3,947,3,58.59);
INSERT INTO items VALUES (251,3,1,81,3,76.56);
INSERT INTO items VALUES (251,3,2,244,3,36.63);
INSERT INTO items VALUES (251,3,3,47,1,24.04);
INSERT INTO items VALUES (251,4,1,998,12,135.30);
INSERT INTO items VALUES (251,4,2,638,3,17.19);
INSERT INTO items VALUES (251,4,3,434,12,279.84);
INSERT INTO items VALUES (251,4,4,909,1,21.84);
INSERT INTO items VALUES (251,4,5,535,12,218.13);
INSERT INTO items VALUES (251,5,1,119,3,53.46);
INSERT INTO items VALUES (251,5,2,937,2,11.50);
INSERT INTO items VALUES (251,6,1,823,1,23.20);
INSERT INTO items VALUES (252,1,1,490,12,91.41);
INSERT INTO items VALUES (252,1,2,1035,1,20.89);
INSERT INTO items VALUES (252,2,1,117,1,24.93);
INSERT INTO items VALUES (252,2,2,191,2,34.58);
INSERT INTO items VALUES (252,2,3,999,3,52.83);
INSERT INTO items VALUES (252,2,4,874,12,213.40);
INSERT INTO items VALUES (252,2,5,402,12,209.88);
INSERT INTO items VALUES (252,2,6,599,2,11.14);
INSERT INTO items VALUES (252,3,1,920,2,40.56);
INSERT INTO items VALUES (252,3,2,529,12,320.10);
INSERT INTO items VALUES (252,3,3,582,2,41.76);
INSERT INTO items VALUES (252,3,4,797,2,36.50);
INSERT INTO items VALUES (252,4,1,800,2,36.32);
INSERT INTO items VALUES (252,4,2,926,3,73.80);
INSERT INTO items VALUES (252,5,1,188,2,15.42);
INSERT INTO items VALUES (253,1,1,996,2,38.24);
INSERT INTO items VALUES (253,1,2,366,1,24.12);
INSERT INTO items VALUES (253,1,3,564,12,207.79);
INSERT INTO items VALUES (253,1,4,194,12,166.10);
INSERT INTO items VALUES (253,1,5,424,2,17.16);
INSERT INTO items VALUES (253,1,6,667,12,253.77);
INSERT INTO items VALUES (253,2,1,1035,1,20.89);
INSERT INTO items VALUES (253,2,2,473,2,14.56);
INSERT INTO items VALUES (253,3,1,886,12,192.83);
INSERT INTO items VALUES (253,3,2,554,1,6.30);
INSERT INTO items VALUES (253,4,1,602,2,23.44);
INSERT INTO items VALUES (253,4,2,836,12,178.09);
INSERT INTO items VALUES (253,4,3,549,2,12.72);
INSERT INTO items VALUES (253,4,4,575,3,77.01);
INSERT INTO items VALUES (253,5,1,285,2,17.08);
INSERT INTO items VALUES (253,5,2,494,1,28.35);
INSERT INTO items VALUES (253,5,3,568,2,22.64);
INSERT INTO items VALUES (253,5,4,917,1,18.43);
INSERT INTO items VALUES (254,1,1,677,2,28.16);
INSERT INTO items VALUES (254,1,2,232,2,28.66);
INSERT INTO items VALUES (254,1,3,968,3,56.07);
INSERT INTO items VALUES (254,2,1,852,12,286.99);
INSERT INTO items VALUES (254,2,2,759,1,21.07);
INSERT INTO items VALUES (254,2,3,321,12,128.59);
INSERT INTO items VALUES (254,3,1,741,2,25.78);
INSERT INTO items VALUES (254,3,2,1001,3,86.28);
INSERT INTO items VALUES (254,3,3,875,3,40.08);
INSERT INTO items VALUES (254,3,4,156,1,7.49);
INSERT INTO items VALUES (254,3,5,53,1,26.62);
INSERT INTO items VALUES (254,3,6,655,1,21.32);
INSERT INTO items VALUES (254,4,1,953,12,219.23);
INSERT INTO items VALUES (254,4,2,656,1,25.43);
INSERT INTO items VALUES (254,4,3,611,2,42.64);
INSERT INTO items VALUES (255,1,1,934,2,50.18);
INSERT INTO items VALUES (255,1,2,24,2,37.20);
INSERT INTO items VALUES (255,2,1,543,1,28.06);
INSERT INTO items VALUES (255,2,2,887,3,45.30);
INSERT INTO items VALUES (255,3,1,275,3,65.07);
INSERT INTO items VALUES (255,3,2,875,2,26.72);
INSERT INTO items VALUES (255,3,3,545,3,51.30);
INSERT INTO items VALUES (255,3,4,264,1,12.84);
INSERT INTO items VALUES (255,4,1,182,12,81.73);
INSERT INTO items VALUES (255,4,2,632,12,181.28);
INSERT INTO items VALUES (255,4,3,7,1,12.20);
INSERT INTO items VALUES (255,4,4,984,12,67.87);
INSERT INTO items VALUES (255,4,5,746,1,11.12);
INSERT INTO items VALUES (255,4,6,193,1,24.18);
INSERT INTO items VALUES (255,5,1,754,12,275.44);
INSERT INTO items VALUES (255,5,2,130,12,173.36);
INSERT INTO items VALUES (255,5,3,201,12,191.18);
INSERT INTO items VALUES (255,5,4,119,12,196.02);
INSERT INTO items VALUES (255,6,1,716,12,152.35);
INSERT INTO items VALUES (255,6,2,384,3,63.21);
INSERT INTO items VALUES (256,1,1,599,2,11.14);
INSERT INTO items VALUES (256,1,2,727,1,8.25);
INSERT INTO items VALUES (256,2,1,724,12,226.93);
INSERT INTO items VALUES (256,2,2,1017,3,42.90);
INSERT INTO items VALUES (256,3,1,202,1,10.08);
INSERT INTO items VALUES (256,4,1,449,2,56.76);
INSERT INTO items VALUES (256,4,2,426,3,26.01);
INSERT INTO items VALUES (256,4,3,544,1,6.53);
INSERT INTO items VALUES (256,4,4,753,3,65.10);
INSERT INTO items VALUES (256,4,5,1024,12,218.35);
INSERT INTO items VALUES (256,5,1,927,1,15.13);
INSERT INTO items VALUES (256,5,2,299,2,26.46);
INSERT INTO items VALUES (256,5,3,141,2,44.94);
INSERT INTO items VALUES (256,5,4,327,2,50.40);
INSERT INTO items VALUES (256,5,5,462,1,23.78);
INSERT INTO items VALUES (257,1,1,107,1,6.41);
INSERT INTO items VALUES (257,1,2,1001,3,86.28);
INSERT INTO items VALUES (257,2,1,800,1,18.16);
INSERT INTO items VALUES (257,3,1,254,2,45.10);
INSERT INTO items VALUES (257,3,2,787,1,9.59);
INSERT INTO items VALUES (257,3,3,656,12,279.73);
INSERT INTO items VALUES (257,3,4,664,2,52.16);
INSERT INTO items VALUES (257,4,1,707,2,13.42);
INSERT INTO items VALUES (257,4,2,1008,2,57.30);
INSERT INTO items VALUES (257,4,3,911,2,11.42);
INSERT INTO items VALUES (257,5,1,314,12,274.12);
INSERT INTO items VALUES (257,5,2,58,3,79.80);
INSERT INTO items VALUES (257,5,3,139,12,170.94);
INSERT INTO items VALUES (257,5,4,653,12,317.57);
INSERT INTO items VALUES (257,6,1,514,1,16.18);
INSERT INTO items VALUES (257,6,2,329,1,14.98);
INSERT INTO items VALUES (257,6,3,613,2,43.24);
INSERT INTO items VALUES (257,6,4,562,2,23.30);
INSERT INTO items VALUES (257,6,5,681,12,309.32);
INSERT INTO items VALUES (257,6,6,91,1,11.58);
INSERT INTO items VALUES (258,1,1,1,3,63.54);
INSERT INTO items VALUES (258,1,2,993,12,268.07);
INSERT INTO items VALUES (258,2,1,565,12,264.22);
INSERT INTO items VALUES (258,2,2,58,3,79.80);
INSERT INTO items VALUES (258,2,3,407,2,37.96);
INSERT INTO items VALUES (258,2,4,252,12,282.15);
INSERT INTO items VALUES (258,2,5,1027,1,28.73);
INSERT INTO items VALUES (259,1,1,357,3,70.92);
INSERT INTO items VALUES (259,2,1,400,3,29.28);
INSERT INTO items VALUES (259,2,2,266,1,18.66);
INSERT INTO items VALUES (259,2,3,272,1,9.60);
INSERT INTO items VALUES (259,2,4,186,12,93.83);
INSERT INTO items VALUES (259,2,5,466,3,35.43);
INSERT INTO items VALUES (259,3,1,656,12,279.73);
INSERT INTO items VALUES (259,3,2,354,12,68.09);
INSERT INTO items VALUES (259,3,3,920,3,60.84);
INSERT INTO items VALUES (259,3,4,360,12,131.34);
INSERT INTO items VALUES (259,3,5,795,12,236.06);
INSERT INTO items VALUES (259,3,6,804,2,51.80);
INSERT INTO items VALUES (259,4,1,804,1,25.90);
INSERT INTO items VALUES (259,4,2,446,1,21.44);
INSERT INTO items VALUES (259,4,3,550,3,33.66);
INSERT INTO items VALUES (259,5,1,460,2,38.70);
INSERT INTO items VALUES (259,5,2,165,2,54.34);
INSERT INTO items VALUES (259,5,3,1026,2,52.72);
INSERT INTO items VALUES (259,6,1,832,12,97.68);
INSERT INTO items VALUES (259,6,2,204,3,72.84);
INSERT INTO items VALUES (259,6,3,483,12,132.66);
INSERT INTO items VALUES (260,1,1,397,12,125.18);
INSERT INTO items VALUES (260,1,2,532,3,83.64);
INSERT INTO items VALUES (260,1,3,266,12,205.26);
INSERT INTO items VALUES (260,1,4,912,3,68.82);
INSERT INTO items VALUES (260,2,1,499,2,14.24);
INSERT INTO items VALUES (260,2,2,410,2,35.08);
INSERT INTO items VALUES (260,2,3,560,1,22.91);
INSERT INTO items VALUES (260,2,4,979,2,56.78);
INSERT INTO items VALUES (260,3,1,919,3,40.05);
INSERT INTO items VALUES (260,4,1,1027,3,86.19);
INSERT INTO items VALUES (260,4,2,539,3,31.44);
INSERT INTO items VALUES (260,4,3,362,2,45.84);
INSERT INTO items VALUES (260,4,4,104,12,70.62);
INSERT INTO items VALUES (260,4,5,744,2,27.08);
INSERT INTO items VALUES (261,1,1,56,2,25.66);
INSERT INTO items VALUES (261,1,2,774,1,5.68);
INSERT INTO items VALUES (261,1,3,268,2,18.30);
INSERT INTO items VALUES (261,2,1,850,12,322.52);
INSERT INTO items VALUES (261,2,2,285,2,17.08);
INSERT INTO items VALUES (261,2,3,188,3,23.13);
INSERT INTO items VALUES (261,2,4,432,12,279.95);
INSERT INTO items VALUES (261,2,5,367,12,218.57);
INSERT INTO items VALUES (262,1,1,698,12,170.50);
INSERT INTO items VALUES (262,1,2,494,12,311.85);
INSERT INTO items VALUES (262,1,3,209,12,162.80);
INSERT INTO items VALUES (262,1,4,759,12,231.77);
INSERT INTO items VALUES (262,1,5,836,12,178.09);
INSERT INTO items VALUES (262,2,1,1029,2,30.38);
INSERT INTO items VALUES (262,2,2,216,12,253.55);
INSERT INTO items VALUES (262,2,3,856,1,5.29);
INSERT INTO items VALUES (262,2,4,287,2,24.30);
INSERT INTO items VALUES (262,2,5,550,12,123.42);
INSERT INTO items VALUES (263,1,1,527,12,301.40);
INSERT INTO items VALUES (263,1,2,306,2,52.94);
INSERT INTO items VALUES (263,1,3,692,1,17.90);
INSERT INTO items VALUES (263,1,4,12,3,82.26);
INSERT INTO items VALUES (263,2,1,515,2,50.18);
INSERT INTO items VALUES (263,2,2,789,3,42.93);
INSERT INTO items VALUES (263,2,3,699,1,19.71);
INSERT INTO items VALUES (263,2,4,129,2,11.50);
INSERT INTO items VALUES (263,2,5,943,2,32.26);
INSERT INTO items VALUES (263,2,6,858,2,10.66);
INSERT INTO items VALUES (263,3,1,1011,12,122.32);
INSERT INTO items VALUES (263,3,2,11,12,181.28);
INSERT INTO items VALUES (263,3,3,484,3,86.76);
INSERT INTO items VALUES (263,3,4,490,12,91.41);
INSERT INTO items VALUES (263,3,5,129,12,63.25);
INSERT INTO items VALUES (263,3,6,318,1,14.12);
INSERT INTO items VALUES (263,4,1,860,12,321.64);
INSERT INTO items VALUES (263,4,2,237,3,76.44);
INSERT INTO items VALUES (263,4,3,253,2,56.48);
INSERT INTO items VALUES (263,4,4,798,3,88.44);
INSERT INTO items VALUES (263,4,5,964,2,26.66);
INSERT INTO items VALUES (263,4,6,763,12,84.48);
INSERT INTO items VALUES (263,5,1,958,3,32.49);
INSERT INTO items VALUES (263,5,2,570,1,25.09);
INSERT INTO items VALUES (263,5,3,719,12,111.76);
INSERT INTO items VALUES (263,5,4,956,2,40.22);
INSERT INTO items VALUES (263,5,5,659,2,48.76);
INSERT INTO items VALUES (264,1,1,518,1,15.35);
INSERT INTO items VALUES (264,2,1,579,2,15.36);
INSERT INTO items VALUES (264,2,2,237,2,50.96);
INSERT INTO items VALUES (264,2,3,375,12,257.40);
INSERT INTO items VALUES (264,2,4,928,3,22.68);
INSERT INTO items VALUES (264,2,5,565,3,72.06);
INSERT INTO items VALUES (264,3,1,879,3,26.79);
INSERT INTO items VALUES (264,3,2,613,2,43.24);
INSERT INTO items VALUES (264,3,3,860,1,29.24);
INSERT INTO items VALUES (264,3,4,576,12,294.36);
INSERT INTO items VALUES (264,3,5,1002,2,47.94);
INSERT INTO items VALUES (264,3,6,752,1,8.59);
INSERT INTO items VALUES (265,1,1,1009,1,22.13);
INSERT INTO items VALUES (265,1,2,58,3,79.80);
INSERT INTO items VALUES (265,1,3,721,1,5.07);
INSERT INTO items VALUES (265,1,4,981,2,49.80);
INSERT INTO items VALUES (265,2,1,380,12,301.95);
INSERT INTO items VALUES (265,2,2,412,1,6.56);
INSERT INTO items VALUES (265,2,3,959,12,110.77);
INSERT INTO items VALUES (265,2,4,973,1,16.02);
INSERT INTO items VALUES (265,2,5,660,2,24.22);
INSERT INTO items VALUES (265,2,6,874,12,213.40);
INSERT INTO items VALUES (265,3,1,533,2,37.48);
INSERT INTO items VALUES (265,3,2,724,2,41.26);
INSERT INTO items VALUES (265,3,3,907,2,44.10);
INSERT INTO items VALUES (265,3,4,286,1,27.29);
INSERT INTO items VALUES (265,4,1,406,12,73.92);
INSERT INTO items VALUES (265,4,2,782,2,24.12);
INSERT INTO items VALUES (265,4,3,16,2,17.90);
INSERT INTO items VALUES (265,4,4,714,12,283.69);
INSERT INTO items VALUES (265,4,5,289,3,58.08);
INSERT INTO items VALUES (265,4,6,795,12,236.06);
INSERT INTO items VALUES (265,5,1,611,12,234.52);
INSERT INTO items VALUES (265,5,2,870,12,251.79);
INSERT INTO items VALUES (265,5,3,1030,3,63.63);
INSERT INTO items VALUES (265,5,4,701,1,24.32);
INSERT INTO items VALUES (266,1,1,1005,1,18.57);
INSERT INTO items VALUES (266,1,2,240,12,125.84);
INSERT INTO items VALUES (266,1,3,449,12,312.18);
INSERT INTO items VALUES (266,1,4,593,1,6.84);
INSERT INTO items VALUES (267,1,1,571,2,34.50);
INSERT INTO items VALUES (267,1,2,809,3,27.57);
INSERT INTO items VALUES (267,1,3,1018,2,18.44);
INSERT INTO items VALUES (267,1,4,578,1,7.32);
INSERT INTO items VALUES (267,1,5,300,3,79.14);
INSERT INTO items VALUES (267,1,6,97,3,36.33);
INSERT INTO items VALUES (267,2,1,473,1,7.28);
INSERT INTO items VALUES (267,2,2,895,3,75.18);
INSERT INTO items VALUES (268,1,1,756,3,88.56);
INSERT INTO items VALUES (268,1,2,78,1,15.50);
INSERT INTO items VALUES (268,2,1,334,12,156.75);
INSERT INTO items VALUES (268,2,2,541,2,35.24);
INSERT INTO items VALUES (268,2,3,400,3,29.28);
INSERT INTO items VALUES (268,2,4,713,3,75.18);
INSERT INTO items VALUES (268,3,1,871,12,112.42);
INSERT INTO items VALUES (269,1,1,889,1,13.92);
INSERT INTO items VALUES (269,1,2,520,3,30.03);
INSERT INTO items VALUES (269,1,3,465,1,8.00);
INSERT INTO items VALUES (269,1,4,1014,2,27.64);
INSERT INTO items VALUES (269,1,5,690,2,40.14);
INSERT INTO items VALUES (269,1,6,760,1,6.12);
INSERT INTO items VALUES (269,2,1,515,12,275.99);
INSERT INTO items VALUES (269,2,2,129,2,11.50);
INSERT INTO items VALUES (270,1,1,934,3,75.27);
INSERT INTO items VALUES (270,1,2,973,3,48.06);
INSERT INTO items VALUES (270,1,3,83,1,15.54);
INSERT INTO items VALUES (270,2,1,567,1,12.37);
INSERT INTO items VALUES (270,2,2,877,2,38.30);
INSERT INTO items VALUES (270,2,3,1013,1,10.04);
INSERT INTO items VALUES (270,2,4,995,12,154.88);
INSERT INTO items VALUES (270,2,5,263,2,26.24);
INSERT INTO items VALUES (270,2,6,240,2,22.88);
INSERT INTO items VALUES (271,1,1,153,3,69.33);
INSERT INTO items VALUES (271,1,2,856,1,5.29);
INSERT INTO items VALUES (271,1,3,92,1,29.26);
INSERT INTO items VALUES (271,1,4,989,12,132.99);
INSERT INTO items VALUES (271,1,5,403,12,274.78);
INSERT INTO items VALUES (272,1,1,933,1,27.47);
INSERT INTO items VALUES (272,1,2,766,1,29.86);
INSERT INTO items VALUES (272,2,1,31,2,33.48);
INSERT INTO items VALUES (272,2,2,517,3,22.26);
INSERT INTO items VALUES (272,2,3,321,3,35.07);
INSERT INTO items VALUES (272,3,1,895,2,50.12);
INSERT INTO items VALUES (272,3,2,155,1,24.83);
INSERT INTO items VALUES (272,3,3,460,12,212.85);
INSERT INTO items VALUES (272,4,1,103,2,24.74);
INSERT INTO items VALUES (272,5,1,677,1,14.08);
INSERT INTO items VALUES (272,5,2,484,1,28.92);
INSERT INTO items VALUES (272,5,3,701,1,24.32);
INSERT INTO items VALUES (272,5,4,125,1,8.82);
INSERT INTO items VALUES (272,5,5,609,12,247.61);
INSERT INTO items VALUES (272,6,1,701,1,24.32);
INSERT INTO items VALUES (272,6,2,941,1,16.57);
INSERT INTO items VALUES (272,6,3,224,12,263.12);
INSERT INTO items VALUES (273,1,1,869,3,53.79);
INSERT INTO items VALUES (273,1,2,753,1,21.70);
INSERT INTO items VALUES (273,2,1,137,2,25.70);
INSERT INTO items VALUES (273,3,1,504,2,55.44);
INSERT INTO items VALUES (273,3,2,652,12,113.08);
INSERT INTO items VALUES (273,3,3,763,2,15.36);
INSERT INTO items VALUES (273,3,4,263,1,13.12);
INSERT INTO items VALUES (274,1,1,17,3,75.69);
INSERT INTO items VALUES (274,1,2,242,2,56.64);
INSERT INTO items VALUES (274,1,3,784,2,17.74);
INSERT INTO items VALUES (274,1,4,575,1,25.67);
INSERT INTO items VALUES (274,1,5,699,2,39.42);
INSERT INTO items VALUES (274,2,1,676,2,24.70);
INSERT INTO items VALUES (274,2,2,480,1,28.89);
INSERT INTO items VALUES (274,2,3,537,3,78.90);
INSERT INTO items VALUES (274,2,4,799,2,27.74);
INSERT INTO items VALUES (274,2,5,160,1,29.92);
INSERT INTO items VALUES (274,3,1,818,1,6.57);
INSERT INTO items VALUES (274,3,2,220,2,23.48);
INSERT INTO items VALUES (274,3,3,201,12,191.18);
INSERT INTO items VALUES (274,3,4,713,2,50.12);
INSERT INTO items VALUES (274,3,5,286,3,81.87);
INSERT INTO items VALUES (274,4,1,55,3,64.23);
INSERT INTO items VALUES (274,4,2,590,12,168.63);
INSERT INTO items VALUES (274,4,3,991,3,79.68);
INSERT INTO items VALUES (274,4,4,59,12,316.91);
INSERT INTO items VALUES (274,4,5,64,12,289.63);
INSERT INTO items VALUES (274,4,6,390,2,16.86);
INSERT INTO items VALUES (275,1,1,222,12,266.20);
INSERT INTO items VALUES (275,1,2,577,3,63.18);
INSERT INTO items VALUES (275,2,1,878,1,22.43);
INSERT INTO items VALUES (275,2,2,440,3,16.05);
INSERT INTO items VALUES (275,2,3,122,1,22.13);
INSERT INTO items VALUES (275,2,4,741,12,141.79);
INSERT INTO items VALUES (275,2,5,204,3,72.84);
INSERT INTO items VALUES (275,2,6,281,3,16.89);
INSERT INTO items VALUES (276,1,1,591,2,25.40);
INSERT INTO items VALUES (276,2,1,409,3,67.02);
INSERT INTO items VALUES (276,2,2,167,3,63.15);
INSERT INTO items VALUES (276,3,1,21,12,210.54);
INSERT INTO items VALUES (276,3,2,45,3,23.13);
INSERT INTO items VALUES (276,3,3,317,12,63.69);
INSERT INTO items VALUES (276,4,1,1046,1,11.00);
INSERT INTO items VALUES (276,4,2,297,3,75.81);
INSERT INTO items VALUES (276,4,3,899,1,7.35);
INSERT INTO items VALUES (276,5,1,508,1,28.48);
INSERT INTO items VALUES (276,5,2,360,1,11.94);
INSERT INTO items VALUES (276,5,3,561,2,17.28);
INSERT INTO items VALUES (276,5,4,943,3,48.39);
INSERT INTO items VALUES (276,5,5,61,1,16.98);
INSERT INTO items VALUES (277,1,1,701,2,48.64);
INSERT INTO items VALUES (277,1,2,598,1,12.93);
INSERT INTO items VALUES (277,2,1,351,12,280.17);
INSERT INTO items VALUES (277,2,2,933,2,54.94);
INSERT INTO items VALUES (277,2,3,258,12,194.48);
INSERT INTO items VALUES (277,3,1,411,2,47.98);
INSERT INTO items VALUES (277,3,2,686,1,19.52);
INSERT INTO items VALUES (277,3,3,89,1,27.85);
INSERT INTO items VALUES (277,3,4,557,12,149.38);
INSERT INTO items VALUES (277,3,5,614,1,8.93);
INSERT INTO items VALUES (277,3,6,1003,12,107.47);
INSERT INTO items VALUES (278,1,1,871,1,10.22);
INSERT INTO items VALUES (278,1,2,253,12,310.64);
INSERT INTO items VALUES (278,1,3,1035,12,229.79);
INSERT INTO items VALUES (278,1,4,656,3,76.29);
INSERT INTO items VALUES (278,1,5,541,3,52.86);
INSERT INTO items VALUES (278,1,6,566,12,77.44);
INSERT INTO items VALUES (278,2,1,912,12,252.34);
INSERT INTO items VALUES (278,2,2,924,12,227.37);
INSERT INTO items VALUES (278,2,3,587,12,114.18);
INSERT INTO items VALUES (278,2,4,359,12,204.71);
INSERT INTO items VALUES (278,2,5,1039,2,52.92);
INSERT INTO items VALUES (278,2,6,373,12,281.27);
INSERT INTO items VALUES (278,3,1,936,3,61.02);
INSERT INTO items VALUES (278,3,2,200,2,23.76);
INSERT INTO items VALUES (278,3,3,523,2,53.56);
INSERT INTO items VALUES (278,3,4,657,3,52.29);
INSERT INTO items VALUES (278,4,1,616,3,37.17);
INSERT INTO items VALUES (278,4,2,159,12,162.36);
INSERT INTO items VALUES (278,5,1,372,1,10.21);
INSERT INTO items VALUES (278,5,2,563,2,53.64);
INSERT INTO items VALUES (279,1,1,181,3,16.41);
INSERT INTO items VALUES (279,1,2,418,3,30.99);
INSERT INTO items VALUES (279,1,3,22,1,8.05);
INSERT INTO items VALUES (279,2,1,596,12,203.17);
INSERT INTO items VALUES (279,2,2,622,3,52.35);
INSERT INTO items VALUES (279,2,3,243,12,212.85);
INSERT INTO items VALUES (279,2,4,53,2,53.24);
INSERT INTO items VALUES (279,2,5,332,2,50.58);
INSERT INTO items VALUES (279,3,1,101,1,8.73);
INSERT INTO items VALUES (279,3,2,994,2,30.88);
INSERT INTO items VALUES (279,4,1,701,1,24.32);
INSERT INTO items VALUES (279,4,2,417,1,13.92);
INSERT INTO items VALUES (279,4,3,47,12,264.44);
INSERT INTO items VALUES (279,4,4,977,2,29.02);
INSERT INTO items VALUES (279,5,1,1013,1,10.04);
INSERT INTO items VALUES (279,5,2,463,12,298.54);
INSERT INTO items VALUES (279,5,3,317,3,17.37);
INSERT INTO items VALUES (279,5,4,197,2,23.46);
INSERT INTO items VALUES (279,5,5,33,12,206.25);
INSERT INTO items VALUES (279,5,6,229,3,20.97);
INSERT INTO items VALUES (280,1,1,342,1,11.22);
INSERT INTO items VALUES (280,1,2,313,3,60.66);
INSERT INTO items VALUES (280,1,3,2,2,56.30);
INSERT INTO items VALUES (280,2,1,382,3,21.27);
INSERT INTO items VALUES (280,2,2,556,12,63.58);
INSERT INTO items VALUES (281,1,1,819,12,85.47);
INSERT INTO items VALUES (281,1,2,618,1,29.07);
INSERT INTO items VALUES (281,1,3,78,12,170.50);
INSERT INTO items VALUES (281,2,1,414,2,44.46);
INSERT INTO items VALUES (281,2,2,569,2,26.80);
INSERT INTO items VALUES (281,3,1,85,3,64.62);
INSERT INTO items VALUES (281,3,2,369,1,22.92);
INSERT INTO items VALUES (281,3,3,156,2,14.98);
INSERT INTO items VALUES (281,3,4,566,12,77.44);
INSERT INTO items VALUES (281,4,1,353,2,49.58);
INSERT INTO items VALUES (281,4,2,903,12,258.94);
INSERT INTO items VALUES (281,4,3,722,2,30.00);
INSERT INTO items VALUES (281,4,4,154,1,5.97);
INSERT INTO items VALUES (281,5,1,414,2,44.46);
INSERT INTO items VALUES (281,5,2,363,3,44.16);
INSERT INTO items VALUES (281,5,3,484,2,57.84);
INSERT INTO items VALUES (281,5,4,94,1,6.53);
INSERT INTO items VALUES (281,5,5,444,2,36.32);
INSERT INTO items VALUES (281,5,6,137,2,25.70);
INSERT INTO items VALUES (281,6,1,441,12,64.57);
INSERT INTO items VALUES (281,6,2,198,3,41.43);
INSERT INTO items VALUES (281,6,3,93,12,238.37);
INSERT INTO items VALUES (281,6,4,733,1,9.71);
INSERT INTO items VALUES (281,6,5,15,3,36.99);
INSERT INTO items VALUES (281,6,6,409,12,245.74);
INSERT INTO items VALUES (282,1,1,117,1,24.93);
INSERT INTO items VALUES (282,1,2,382,3,21.27);
INSERT INTO items VALUES (282,2,1,576,2,53.52);
INSERT INTO items VALUES (282,2,2,759,1,21.07);
INSERT INTO items VALUES (282,2,3,459,2,23.92);
INSERT INTO items VALUES (282,2,4,854,3,74.25);
INSERT INTO items VALUES (282,3,1,946,12,104.61);
INSERT INTO items VALUES (282,3,2,240,3,34.32);
INSERT INTO items VALUES (282,3,3,162,2,39.28);
INSERT INTO items VALUES (282,3,4,695,3,72.09);
INSERT INTO items VALUES (282,4,1,347,12,116.49);
INSERT INTO items VALUES (282,4,2,35,1,17.64);
INSERT INTO items VALUES (282,4,3,933,2,54.94);
INSERT INTO items VALUES (282,4,4,566,3,21.12);
INSERT INTO items VALUES (282,4,5,1045,1,18.76);
INSERT INTO items VALUES (282,5,1,545,1,17.10);
INSERT INTO items VALUES (282,5,2,873,3,61.95);
INSERT INTO items VALUES (282,6,1,507,3,54.06);
INSERT INTO items VALUES (282,6,2,247,12,279.40);
INSERT INTO items VALUES (282,6,3,299,2,26.46);
INSERT INTO items VALUES (282,6,4,910,1,28.29);
INSERT INTO items VALUES (283,1,1,205,1,12.99);
INSERT INTO items VALUES (283,1,2,795,2,42.92);
INSERT INTO items VALUES (283,1,3,802,12,134.64);
INSERT INTO items VALUES (283,1,4,221,2,24.46);
INSERT INTO items VALUES (283,1,5,428,3,18.72);
INSERT INTO items VALUES (283,2,1,586,3,53.10);
INSERT INTO items VALUES (283,2,2,747,12,296.78);
INSERT INTO items VALUES (283,2,3,586,12,194.70);
INSERT INTO items VALUES (283,3,1,258,12,194.48);
INSERT INTO items VALUES (283,3,2,202,1,10.08);
INSERT INTO items VALUES (283,3,3,266,12,205.26);
INSERT INTO items VALUES (283,3,4,962,2,31.44);
INSERT INTO items VALUES (283,3,5,414,2,44.46);
INSERT INTO items VALUES (283,3,6,179,1,5.38);
INSERT INTO items VALUES (283,4,1,140,1,5.95);
INSERT INTO items VALUES (283,4,2,842,3,85.59);
INSERT INTO items VALUES (283,4,3,1014,2,27.64);
INSERT INTO items VALUES (283,4,4,691,3,87.00);
INSERT INTO items VALUES (283,4,5,700,1,19.35);
INSERT INTO items VALUES (283,4,6,432,3,76.35);
INSERT INTO items VALUES (283,5,1,4,1,21.16);
INSERT INTO items VALUES (283,5,2,591,1,12.70);
INSERT INTO items VALUES (284,1,1,328,3,58.77);
INSERT INTO items VALUES (284,2,1,771,3,46.05);
INSERT INTO items VALUES (284,2,2,530,1,14.32);
INSERT INTO items VALUES (284,2,3,1011,2,22.24);
INSERT INTO items VALUES (284,2,4,392,3,39.51);
INSERT INTO items VALUES (284,2,5,77,3,26.52);
INSERT INTO items VALUES (284,2,6,532,1,27.88);
INSERT INTO items VALUES (285,1,1,21,12,210.54);
INSERT INTO items VALUES (285,1,2,953,3,59.79);
INSERT INTO items VALUES (285,1,3,860,12,321.64);
INSERT INTO items VALUES (285,1,4,127,1,17.86);
INSERT INTO items VALUES (285,2,1,32,12,141.68);
INSERT INTO items VALUES (285,2,2,772,3,39.87);
INSERT INTO items VALUES (285,2,3,864,2,46.96);
INSERT INTO items VALUES (286,1,1,279,3,47.91);
INSERT INTO items VALUES (286,1,2,19,1,29.22);
INSERT INTO items VALUES (286,1,3,674,3,44.61);
INSERT INTO items VALUES (286,1,4,52,3,80.19);
INSERT INTO items VALUES (286,1,5,761,1,18.88);
INSERT INTO items VALUES (286,1,6,138,1,21.51);
INSERT INTO items VALUES (287,1,1,778,1,8.86);
INSERT INTO items VALUES (287,1,2,932,12,231.77);
INSERT INTO items VALUES (287,1,3,104,2,12.84);
INSERT INTO items VALUES (287,1,4,527,3,82.20);
INSERT INTO items VALUES (288,1,1,194,2,30.20);
INSERT INTO items VALUES (288,2,1,211,12,193.38);
INSERT INTO items VALUES (288,3,1,978,2,20.10);
INSERT INTO items VALUES (288,3,2,831,2,47.22);
INSERT INTO items VALUES (288,3,3,871,3,30.66);
INSERT INTO items VALUES (288,4,1,167,1,21.05);
INSERT INTO items VALUES (288,4,2,42,1,21.28);
INSERT INTO items VALUES (288,4,3,599,3,16.71);
INSERT INTO items VALUES (288,5,1,31,2,33.48);
INSERT INTO items VALUES (288,5,2,893,1,24.44);
INSERT INTO items VALUES (288,5,3,750,12,72.27);
INSERT INTO items VALUES (288,5,4,484,3,86.76);
INSERT INTO items VALUES (288,5,5,230,2,22.48);
INSERT INTO items VALUES (289,1,1,859,3,30.78);
INSERT INTO items VALUES (289,1,2,264,12,141.24);
INSERT INTO items VALUES (290,1,1,1020,1,5.51);
INSERT INTO items VALUES (290,1,2,62,12,185.35);
INSERT INTO items VALUES (290,1,3,405,12,71.06);
INSERT INTO items VALUES (290,1,4,637,12,160.16);
INSERT INTO items VALUES (290,1,5,295,12,275.55);
INSERT INTO items VALUES (290,2,1,547,1,24.75);
INSERT INTO items VALUES (290,2,2,321,1,11.69);
INSERT INTO items VALUES (290,2,3,344,1,15.06);
INSERT INTO items VALUES (291,1,1,437,1,8.61);
INSERT INTO items VALUES (291,1,2,1040,1,28.12);
INSERT INTO items VALUES (291,1,3,468,12,314.60);
INSERT INTO items VALUES (291,1,4,889,2,27.84);
INSERT INTO items VALUES (291,1,5,49,3,30.54);
INSERT INTO items VALUES (291,1,6,455,2,57.98);
INSERT INTO items VALUES (291,2,1,54,1,20.31);
INSERT INTO items VALUES (291,2,2,65,1,9.98);
INSERT INTO items VALUES (291,2,3,608,2,58.96);
INSERT INTO items VALUES (291,2,4,438,2,21.34);
INSERT INTO items VALUES (291,2,5,621,12,324.06);
INSERT INTO items VALUES (291,3,1,296,2,19.90);
INSERT INTO items VALUES (291,3,2,1001,2,57.52);
INSERT INTO items VALUES (291,3,3,43,2,55.64);
INSERT INTO items VALUES (291,3,4,758,12,198.66);
INSERT INTO items VALUES (292,1,1,303,3,37.05);
INSERT INTO items VALUES (292,1,2,795,3,64.38);
INSERT INTO items VALUES (292,2,1,437,2,17.22);
INSERT INTO items VALUES (292,2,2,804,1,25.90);
INSERT INTO items VALUES (292,3,1,8,1,10.06);
INSERT INTO items VALUES (292,3,2,803,2,41.38);
INSERT INTO items VALUES (292,3,3,487,12,325.82);
INSERT INTO items VALUES (292,3,4,761,12,207.68);
INSERT INTO items VALUES (292,4,1,998,3,36.90);
INSERT INTO items VALUES (292,4,2,1047,3,41.55);
INSERT INTO items VALUES (292,4,3,968,2,37.38);
INSERT INTO items VALUES (292,4,4,51,3,72.27);
INSERT INTO items VALUES (292,4,5,518,3,46.05);
INSERT INTO items VALUES (293,1,1,1004,3,72.54);
INSERT INTO items VALUES (293,2,1,548,12,56.32);
INSERT INTO items VALUES (293,2,2,731,2,51.36);
INSERT INTO items VALUES (293,2,3,925,2,33.94);
INSERT INTO items VALUES (293,2,4,335,3,28.74);
INSERT INTO items VALUES (293,2,5,310,3,30.78);
INSERT INTO items VALUES (293,2,6,704,12,255.09);
INSERT INTO items VALUES (293,3,1,54,12,223.41);
INSERT INTO items VALUES (293,3,2,761,1,18.88);
INSERT INTO items VALUES (293,3,3,325,1,13.21);
INSERT INTO items VALUES (293,3,4,821,3,17.07);
INSERT INTO items VALUES (293,3,5,632,3,49.44);
INSERT INTO items VALUES (293,4,1,696,3,19.86);
INSERT INTO items VALUES (293,4,2,226,12,95.48);
INSERT INTO items VALUES (293,4,3,471,12,315.04);
INSERT INTO items VALUES (293,4,4,989,3,36.27);
INSERT INTO items VALUES (293,5,1,378,12,326.48);
INSERT INTO items VALUES (294,1,1,284,3,26.67);
INSERT INTO items VALUES (294,1,2,732,3,81.27);
INSERT INTO items VALUES (294,1,3,962,2,31.44);
INSERT INTO items VALUES (294,1,4,236,3,66.03);
INSERT INTO items VALUES (294,1,5,530,1,14.32);
INSERT INTO items VALUES (294,1,6,86,2,30.08);
INSERT INTO items VALUES (295,1,1,780,12,80.41);
INSERT INTO items VALUES (295,1,2,208,12,112.09);
INSERT INTO items VALUES (296,1,1,756,2,59.04);
INSERT INTO items VALUES (296,1,2,822,3,33.09);
INSERT INTO items VALUES (296,2,1,335,1,9.58);
INSERT INTO items VALUES (296,2,2,135,1,11.58);
INSERT INTO items VALUES (296,2,3,319,12,161.70);
INSERT INTO items VALUES (296,2,4,658,3,74.64);
INSERT INTO items VALUES (296,3,1,576,1,26.76);
INSERT INTO items VALUES (297,1,1,76,12,197.34);
INSERT INTO items VALUES (297,1,2,371,2,30.98);
INSERT INTO items VALUES (297,2,1,829,2,21.20);
INSERT INTO items VALUES (297,2,2,370,2,12.40);
INSERT INTO items VALUES (297,2,3,866,1,14.59);
INSERT INTO items VALUES (297,2,4,704,3,69.57);
INSERT INTO items VALUES (297,2,5,308,12,143.66);
INSERT INTO items VALUES (298,1,1,871,1,10.22);
INSERT INTO items VALUES (298,1,2,805,12,314.16);
INSERT INTO items VALUES (298,1,3,605,1,20.78);
INSERT INTO items VALUES (298,1,4,86,2,30.08);
INSERT INTO items VALUES (298,1,5,645,2,36.26);
INSERT INTO items VALUES (298,2,1,658,3,74.64);
INSERT INTO items VALUES (298,2,2,273,2,11.86);
INSERT INTO items VALUES (298,2,3,46,1,15.67);
INSERT INTO items VALUES (298,2,4,617,2,24.18);
INSERT INTO items VALUES (299,1,1,515,12,275.99);
INSERT INTO items VALUES (299,1,2,911,3,17.13);
INSERT INTO items VALUES (300,1,1,349,2,31.18);
INSERT INTO items VALUES (301,1,1,488,1,5.10);
INSERT INTO items VALUES (301,1,2,976,2,20.82);
INSERT INTO items VALUES (301,1,3,525,12,242.99);
INSERT INTO items VALUES (301,1,4,227,3,50.28);
INSERT INTO items VALUES (301,1,5,306,3,79.41);
INSERT INTO items VALUES (301,1,6,597,1,27.67);
INSERT INTO items VALUES (301,2,1,826,2,41.80);
INSERT INTO items VALUES (301,2,2,245,1,28.86);
INSERT INTO items VALUES (301,2,3,180,1,18.57);
INSERT INTO items VALUES (301,2,4,94,1,6.53);
INSERT INTO items VALUES (301,2,5,510,1,11.03);
INSERT INTO items VALUES (301,2,6,173,2,53.04);
INSERT INTO items VALUES (301,3,1,519,3,35.28);
INSERT INTO items VALUES (301,3,2,42,1,21.28);
INSERT INTO items VALUES (301,4,1,564,3,56.67);
INSERT INTO items VALUES (301,4,2,52,12,294.03);
INSERT INTO items VALUES (301,4,3,593,1,6.84);
INSERT INTO items VALUES (301,4,4,1011,3,33.36);
INSERT INTO items VALUES (301,5,1,124,3,82.26);
INSERT INTO items VALUES (301,5,2,763,2,15.36);
INSERT INTO items VALUES (301,5,3,926,1,24.60);
INSERT INTO items VALUES (301,5,4,6,12,222.75);
INSERT INTO items VALUES (301,5,5,301,12,325.38);
INSERT INTO items VALUES (301,5,6,203,12,163.57);
INSERT INTO items VALUES (302,1,1,741,12,141.79);
INSERT INTO items VALUES (303,1,1,662,2,46.58);
INSERT INTO items VALUES (303,1,2,168,2,48.74);
INSERT INTO items VALUES (303,1,3,951,1,24.53);
INSERT INTO items VALUES (303,1,4,610,12,65.56);
INSERT INTO items VALUES (304,1,1,281,2,11.26);
INSERT INTO items VALUES (304,1,2,603,12,63.58);
INSERT INTO items VALUES (304,1,3,525,2,44.18);
INSERT INTO items VALUES (304,2,1,558,2,57.18);
INSERT INTO items VALUES (304,2,2,406,1,6.72);
INSERT INTO items VALUES (304,2,3,612,3,88.74);
INSERT INTO items VALUES (304,2,4,975,3,27.60);
INSERT INTO items VALUES (304,2,5,345,12,90.53);
INSERT INTO items VALUES (304,3,1,445,2,42.86);
INSERT INTO items VALUES (304,3,2,109,12,176.00);
INSERT INTO items VALUES (304,3,3,379,3,25.17);
INSERT INTO items VALUES (304,3,4,294,1,7.91);
INSERT INTO items VALUES (304,3,5,218,12,99.66);
INSERT INTO items VALUES (304,4,1,966,3,31.35);
INSERT INTO items VALUES (304,4,2,32,12,141.68);
INSERT INTO items VALUES (304,5,1,572,2,54.98);
INSERT INTO items VALUES (304,5,2,485,12,251.46);
INSERT INTO items VALUES (304,5,3,877,3,57.45);
INSERT INTO items VALUES (304,5,4,1015,1,28.35);
INSERT INTO items VALUES (304,5,5,177,1,27.41);
INSERT INTO items VALUES (304,6,1,672,1,10.92);
INSERT INTO items VALUES (304,6,2,687,3,50.67);
INSERT INTO items VALUES (304,6,3,859,3,30.78);
INSERT INTO items VALUES (305,1,1,151,3,67.11);
INSERT INTO items VALUES (305,1,2,357,1,23.64);
INSERT INTO items VALUES (305,1,3,562,12,128.15);
INSERT INTO items VALUES (305,1,4,86,3,45.12);
INSERT INTO items VALUES (305,1,5,78,2,31.00);
INSERT INTO items VALUES (305,1,6,72,2,49.92);
INSERT INTO items VALUES (305,2,1,598,2,25.86);
INSERT INTO items VALUES (305,2,2,318,2,28.24);
INSERT INTO items VALUES (305,2,3,851,2,40.26);
INSERT INTO items VALUES (305,3,1,977,12,159.61);
INSERT INTO items VALUES (306,1,1,316,1,28.78);
INSERT INTO items VALUES (306,1,2,852,2,52.18);
INSERT INTO items VALUES (307,1,1,563,12,295.02);
INSERT INTO items VALUES (307,1,2,893,2,48.88);
INSERT INTO items VALUES (307,1,3,430,3,31.41);
INSERT INTO items VALUES (307,1,4,723,12,229.13);
INSERT INTO items VALUES (307,2,1,303,2,24.70);
INSERT INTO items VALUES (307,2,2,768,3,24.24);
INSERT INTO items VALUES (307,3,1,242,2,56.64);
INSERT INTO items VALUES (307,3,2,302,2,45.40);
INSERT INTO items VALUES (307,3,3,998,12,135.30);
INSERT INTO items VALUES (307,3,4,260,12,80.74);
INSERT INTO items VALUES (308,1,1,288,3,44.85);
INSERT INTO items VALUES (308,1,2,1045,2,37.52);
INSERT INTO items VALUES (308,1,3,1014,2,27.64);
INSERT INTO items VALUES (308,2,1,1043,12,184.03);
INSERT INTO items VALUES (308,2,2,499,2,14.24);
INSERT INTO items VALUES (309,1,1,735,2,44.22);
INSERT INTO items VALUES (309,1,2,491,1,7.33);
INSERT INTO items VALUES (309,1,3,966,12,114.95);
INSERT INTO items VALUES (309,1,4,329,3,44.94);
INSERT INTO items VALUES (309,1,5,916,12,228.03);
INSERT INTO items VALUES (309,1,6,595,2,57.90);
INSERT INTO items VALUES (309,2,1,1030,12,233.31);
INSERT INTO items VALUES (310,1,1,590,3,45.99);
INSERT INTO items VALUES (310,1,2,597,12,304.37);
INSERT INTO items VALUES (310,1,3,156,3,22.47);
INSERT INTO items VALUES (310,1,4,855,1,7.23);
INSERT INTO items VALUES (310,1,5,965,2,51.70);
INSERT INTO items VALUES (310,1,6,942,3,84.69);
INSERT INTO items VALUES (310,2,1,609,3,67.53);
INSERT INTO items VALUES (310,3,1,799,3,41.61);
INSERT INTO items VALUES (310,4,1,35,3,52.92);
INSERT INTO items VALUES (310,4,2,110,2,25.48);
INSERT INTO items VALUES (311,1,1,597,12,304.37);
INSERT INTO items VALUES (311,1,2,621,3,88.38);
INSERT INTO items VALUES (311,1,3,402,12,209.88);
INSERT INTO items VALUES (311,1,4,36,12,324.61);
INSERT INTO items VALUES (311,1,5,836,1,16.19);
INSERT INTO items VALUES (311,1,6,740,3,15.24);
INSERT INTO items VALUES (311,2,1,294,12,87.01);
INSERT INTO items VALUES (311,2,2,49,3,30.54);
INSERT INTO items VALUES (311,2,3,484,12,318.12);
INSERT INTO items VALUES (311,2,4,168,1,24.37);
INSERT INTO items VALUES (311,2,5,235,3,65.55);
INSERT INTO items VALUES (311,2,6,515,1,25.09);
INSERT INTO items VALUES (311,3,1,795,2,42.92);
INSERT INTO items VALUES (311,3,2,61,2,33.96);
INSERT INTO items VALUES (311,3,3,980,1,22.32);
INSERT INTO items VALUES (311,3,4,517,12,81.62);
INSERT INTO items VALUES (311,3,5,1044,3,57.36);
INSERT INTO items VALUES (311,3,6,281,12,61.93);
INSERT INTO items VALUES (312,1,1,38,3,17.25);
INSERT INTO items VALUES (312,1,2,367,1,19.87);
INSERT INTO items VALUES (312,1,3,851,12,221.43);
INSERT INTO items VALUES (312,1,4,954,3,16.53);
INSERT INTO items VALUES (312,1,5,624,3,66.75);
INSERT INTO items VALUES (312,1,6,572,2,54.98);
INSERT INTO items VALUES (313,1,1,51,1,24.09);
INSERT INTO items VALUES (313,1,2,813,1,9.68);
INSERT INTO items VALUES (313,1,3,282,12,306.13);
INSERT INTO items VALUES (313,1,4,857,12,86.24);
INSERT INTO items VALUES (313,1,5,598,3,38.79);
INSERT INTO items VALUES (313,1,6,897,3,68.97);
INSERT INTO items VALUES (313,2,1,610,1,5.96);
INSERT INTO items VALUES (313,2,2,335,12,105.38);
INSERT INTO items VALUES (313,2,3,208,12,112.09);
INSERT INTO items VALUES (313,2,4,787,1,9.59);
INSERT INTO items VALUES (313,2,5,801,1,5.17);
INSERT INTO items VALUES (313,3,1,141,12,247.17);
INSERT INTO items VALUES (313,4,1,96,1,22.62);
INSERT INTO items VALUES (313,5,1,222,1,24.20);
INSERT INTO items VALUES (313,5,2,436,2,11.98);
INSERT INTO items VALUES (313,5,3,956,2,40.22);
INSERT INTO items VALUES (313,5,4,153,3,69.33);
INSERT INTO items VALUES (313,6,1,194,3,45.30);
INSERT INTO items VALUES (313,6,2,495,1,27.04);
INSERT INTO items VALUES (313,6,3,39,2,14.76);
INSERT INTO items VALUES (313,6,4,317,1,5.79);
INSERT INTO items VALUES (313,6,5,657,2,34.86);
INSERT INTO items VALUES (314,1,1,271,2,13.78);
INSERT INTO items VALUES (314,1,2,861,3,41.55);
INSERT INTO items VALUES (314,1,3,621,2,58.92);
INSERT INTO items VALUES (314,1,4,332,3,75.87);
INSERT INTO items VALUES (314,1,5,234,1,26.40);
INSERT INTO items VALUES (314,1,6,690,1,20.07);
INSERT INTO items VALUES (314,2,1,299,1,13.23);
INSERT INTO items VALUES (314,2,2,440,3,16.05);
INSERT INTO items VALUES (314,2,3,52,12,294.03);
INSERT INTO items VALUES (314,2,4,958,12,119.13);
INSERT INTO items VALUES (314,2,5,748,12,250.36);
INSERT INTO items VALUES (314,3,1,814,1,13.52);
INSERT INTO items VALUES (314,4,1,228,2,43.86);
INSERT INTO items VALUES (314,4,2,217,1,6.83);
INSERT INTO items VALUES (314,5,1,147,2,39.16);
INSERT INTO items VALUES (314,5,2,157,12,264.66);
INSERT INTO items VALUES (314,5,3,523,12,294.58);
INSERT INTO items VALUES (314,6,1,971,12,217.91);
INSERT INTO items VALUES (314,6,2,910,2,56.58);
INSERT INTO items VALUES (314,6,3,244,12,134.31);
INSERT INTO items VALUES (314,6,4,555,2,17.58);
INSERT INTO items VALUES (314,6,5,112,3,23.85);
INSERT INTO items VALUES (315,1,1,621,12,324.06);
INSERT INTO items VALUES (315,2,1,68,3,64.98);
INSERT INTO items VALUES (315,2,2,223,12,143.44);
INSERT INTO items VALUES (315,3,1,925,3,50.91);
INSERT INTO items VALUES (315,3,2,104,3,19.26);
INSERT INTO items VALUES (315,3,3,810,2,55.42);
INSERT INTO items VALUES (315,4,1,789,12,157.41);
INSERT INTO items VALUES (315,4,2,268,12,100.65);
INSERT INTO items VALUES (315,4,3,275,3,65.07);
INSERT INTO items VALUES (315,4,4,1032,2,39.86);
INSERT INTO items VALUES (315,4,5,272,1,9.60);
INSERT INTO items VALUES (315,4,6,125,12,97.02);
INSERT INTO items VALUES (315,5,1,920,1,20.28);
INSERT INTO items VALUES (315,5,2,284,3,26.67);
INSERT INTO items VALUES (315,5,3,433,12,234.41);
INSERT INTO items VALUES (315,5,4,80,1,28.44);
INSERT INTO items VALUES (315,5,5,979,3,85.17);
INSERT INTO items VALUES (316,1,1,95,1,29.19);
INSERT INTO items VALUES (316,1,2,14,2,10.54);
INSERT INTO items VALUES (316,1,3,131,12,206.14);
INSERT INTO items VALUES (316,1,4,717,12,263.12);
INSERT INTO items VALUES (316,1,5,447,3,40.74);
INSERT INTO items VALUES (316,2,1,958,2,21.66);
INSERT INTO items VALUES (316,2,2,819,1,7.77);
INSERT INTO items VALUES (316,2,3,317,2,11.58);
INSERT INTO items VALUES (316,2,4,695,1,24.03);
INSERT INTO items VALUES (316,2,5,749,1,5.57);
INSERT INTO items VALUES (316,3,1,206,12,270.60);
INSERT INTO items VALUES (316,4,1,646,1,7.95);
INSERT INTO items VALUES (316,4,2,158,1,13.39);
INSERT INTO items VALUES (316,4,3,768,1,8.08);
INSERT INTO items VALUES (316,4,4,502,3,72.33);
INSERT INTO items VALUES (317,1,1,440,3,16.05);
INSERT INTO items VALUES (317,1,2,171,2,54.60);
INSERT INTO items VALUES (317,2,1,225,12,186.56);
INSERT INTO items VALUES (318,1,1,2,2,56.30);
INSERT INTO items VALUES (319,1,1,285,3,25.62);
INSERT INTO items VALUES (319,1,2,38,3,17.25);
INSERT INTO items VALUES (319,1,3,103,1,12.37);
INSERT INTO items VALUES (319,1,4,132,2,36.86);
INSERT INTO items VALUES (319,1,5,195,3,67.59);
INSERT INTO items VALUES (319,1,6,580,2,48.98);
INSERT INTO items VALUES (319,2,1,659,2,48.76);
INSERT INTO items VALUES (319,2,2,275,12,238.59);
INSERT INTO items VALUES (320,1,1,392,2,26.34);
INSERT INTO items VALUES (320,1,2,692,12,196.90);
INSERT INTO items VALUES (320,1,3,448,12,63.58);
INSERT INTO items VALUES (320,1,4,104,12,70.62);
INSERT INTO items VALUES (320,2,1,726,12,313.61);
INSERT INTO items VALUES (320,2,2,1043,12,184.03);
INSERT INTO items VALUES (320,2,3,481,2,11.64);
INSERT INTO items VALUES (320,2,4,226,2,17.36);
INSERT INTO items VALUES (320,2,5,1002,2,47.94);
INSERT INTO items VALUES (320,3,1,666,2,31.10);
INSERT INTO items VALUES (320,3,2,160,1,29.92);
INSERT INTO items VALUES (320,4,1,874,2,38.80);
INSERT INTO items VALUES (320,4,2,397,3,34.14);
INSERT INTO items VALUES (320,4,3,225,2,33.92);
INSERT INTO items VALUES (320,4,4,503,3,74.37);
INSERT INTO items VALUES (321,1,1,668,3,44.55);
INSERT INTO items VALUES (321,1,2,625,12,197.89);
INSERT INTO items VALUES (321,1,3,272,12,105.60);
INSERT INTO items VALUES (321,1,4,1015,2,56.70);
INSERT INTO items VALUES (321,1,5,50,1,15.62);
INSERT INTO items VALUES (321,1,6,251,2,11.42);
INSERT INTO items VALUES (321,2,1,170,3,29.25);
INSERT INTO items VALUES (321,2,2,982,12,315.37);
INSERT INTO items VALUES (321,2,3,415,3,33.93);
INSERT INTO items VALUES (321,3,1,19,1,29.22);
INSERT INTO items VALUES (321,3,2,258,2,35.36);
INSERT INTO items VALUES (321,3,3,35,1,17.64);
INSERT INTO items VALUES (321,4,1,268,2,18.30);
INSERT INTO items VALUES (321,4,2,367,3,59.61);
INSERT INTO items VALUES (321,4,3,962,3,47.16);
INSERT INTO items VALUES (321,5,1,74,1,12.56);
INSERT INTO items VALUES (321,5,2,93,3,65.01);
INSERT INTO items VALUES (321,5,3,559,1,6.67);
INSERT INTO items VALUES (321,5,4,800,12,199.76);
INSERT INTO items VALUES (321,5,5,403,12,274.78);
INSERT INTO items VALUES (322,1,1,492,2,44.20);
INSERT INTO items VALUES (322,1,2,598,1,12.93);
INSERT INTO items VALUES (322,2,1,773,3,76.20);
INSERT INTO items VALUES (322,2,2,778,12,97.46);
INSERT INTO items VALUES (322,2,3,678,2,52.90);
INSERT INTO items VALUES (322,2,4,390,12,92.73);
INSERT INTO items VALUES (322,2,5,130,1,15.76);
INSERT INTO items VALUES (322,3,1,9,3,73.41);
INSERT INTO items VALUES (322,3,2,168,2,48.74);
INSERT INTO items VALUES (322,3,3,983,3,78.33);
INSERT INTO items VALUES (322,3,4,523,2,53.56);
INSERT INTO items VALUES (322,3,5,852,3,78.27);
INSERT INTO items VALUES (322,3,6,480,1,28.89);
INSERT INTO items VALUES (322,4,1,243,1,19.35);
INSERT INTO items VALUES (322,4,2,593,2,13.68);
INSERT INTO items VALUES (322,4,3,356,3,67.29);
INSERT INTO items VALUES (322,4,4,288,2,29.90);
INSERT INTO items VALUES (322,4,5,862,1,6.71);
INSERT INTO items VALUES (322,5,1,683,1,9.19);
INSERT INTO items VALUES (322,5,2,818,2,13.14);
INSERT INTO items VALUES (322,5,3,837,1,8.82);
INSERT INTO items VALUES (322,5,4,738,2,48.44);
INSERT INTO items VALUES (322,6,1,719,12,111.76);
INSERT INTO items VALUES (322,6,2,865,1,29.58);
INSERT INTO items VALUES (322,6,3,682,1,27.34);
INSERT INTO items VALUES (323,1,1,841,3,76.14);
INSERT INTO items VALUES (323,2,1,63,1,23.72);
INSERT INTO items VALUES (323,2,2,686,3,58.56);
INSERT INTO items VALUES (323,2,3,278,1,24.56);
INSERT INTO items VALUES (323,2,4,14,3,15.81);
INSERT INTO items VALUES (323,2,5,877,12,210.65);
INSERT INTO items VALUES (323,2,6,587,12,114.18);
INSERT INTO items VALUES (323,3,1,79,1,11.97);
INSERT INTO items VALUES (323,3,2,495,12,297.44);
INSERT INTO items VALUES (323,4,1,546,2,59.76);
INSERT INTO items VALUES (323,4,2,838,1,19.30);
INSERT INTO items VALUES (323,4,3,81,1,25.52);
INSERT INTO items VALUES (323,4,4,342,1,11.22);
INSERT INTO items VALUES (323,4,5,838,1,19.30);
INSERT INTO items VALUES (324,1,1,333,1,16.64);
INSERT INTO items VALUES (324,1,2,966,2,20.90);
INSERT INTO items VALUES (324,1,3,559,12,73.37);
INSERT INTO items VALUES (324,1,4,72,12,274.56);
INSERT INTO items VALUES (324,1,5,558,1,28.59);
INSERT INTO items VALUES (324,1,6,375,12,257.40);
INSERT INTO items VALUES (325,1,1,558,3,85.77);
INSERT INTO items VALUES (325,1,2,566,3,21.12);
INSERT INTO items VALUES (325,1,3,1027,3,86.19);
INSERT INTO items VALUES (325,2,1,802,3,36.72);
INSERT INTO items VALUES (325,3,1,16,12,98.45);
INSERT INTO items VALUES (325,3,2,658,2,49.76);
INSERT INTO items VALUES (325,3,3,643,3,58.11);
INSERT INTO items VALUES (325,3,4,864,2,46.96);
INSERT INTO items VALUES (325,3,5,60,2,32.42);
INSERT INTO items VALUES (325,4,1,121,1,29.02);
INSERT INTO items VALUES (325,5,1,783,1,27.87);
INSERT INTO items VALUES (325,5,2,313,3,60.66);
INSERT INTO items VALUES (325,6,1,543,3,84.18);
INSERT INTO items VALUES (325,6,2,312,12,131.23);
INSERT INTO items VALUES (326,1,1,165,3,81.51);
INSERT INTO items VALUES (326,1,2,585,2,53.70);
INSERT INTO items VALUES (326,2,1,1029,2,30.38);
INSERT INTO items VALUES (326,2,2,2,2,56.30);
INSERT INTO items VALUES (326,2,3,885,3,27.66);
INSERT INTO items VALUES (326,2,4,624,1,22.25);
INSERT INTO items VALUES (326,2,5,224,1,23.92);
INSERT INTO items VALUES (326,3,1,933,1,27.47);
INSERT INTO items VALUES (326,3,2,525,1,22.09);
INSERT INTO items VALUES (326,4,1,1034,12,164.56);
INSERT INTO items VALUES (326,4,2,908,12,129.14);
INSERT INTO items VALUES (327,1,1,196,3,61.95);
INSERT INTO items VALUES (327,1,2,906,12,113.63);
INSERT INTO items VALUES (327,1,3,836,12,178.09);
INSERT INTO items VALUES (327,1,4,332,1,25.29);
INSERT INTO items VALUES (327,1,5,684,2,45.10);
INSERT INTO items VALUES (327,2,1,728,12,60.28);
INSERT INTO items VALUES (327,2,2,338,3,72.84);
INSERT INTO items VALUES (327,2,3,840,2,29.26);
INSERT INTO items VALUES (328,1,1,1016,3,59.97);
INSERT INTO items VALUES (328,2,1,616,1,12.39);
INSERT INTO items VALUES (328,2,2,1034,3,44.88);
INSERT INTO items VALUES (328,3,1,438,1,10.67);
INSERT INTO items VALUES (328,3,2,776,2,47.26);
INSERT INTO items VALUES (328,3,3,757,2,42.74);
INSERT INTO items VALUES (328,4,1,877,1,19.15);
INSERT INTO items VALUES (328,4,2,82,2,44.60);
INSERT INTO items VALUES (328,4,3,365,3,25.20);
INSERT INTO items VALUES (328,4,4,798,12,324.28);
INSERT INTO items VALUES (328,4,5,695,3,72.09);
INSERT INTO items VALUES (328,5,1,39,1,7.38);
INSERT INTO items VALUES (328,6,1,542,3,58.56);
INSERT INTO items VALUES (328,6,2,788,3,32.19);
INSERT INTO items VALUES (328,6,3,373,3,76.71);
INSERT INTO items VALUES (328,6,4,920,2,40.56);
INSERT INTO items VALUES (328,6,5,64,1,26.33);
INSERT INTO items VALUES (329,1,1,488,3,15.30);
INSERT INTO items VALUES (329,1,2,60,3,48.63);
INSERT INTO items VALUES (329,1,3,764,1,11.52);
INSERT INTO items VALUES (329,2,1,292,3,23.52);
INSERT INTO items VALUES (329,2,2,14,1,5.27);
INSERT INTO items VALUES (329,3,1,506,2,48.74);
INSERT INTO items VALUES (329,3,2,980,1,22.32);
INSERT INTO items VALUES (329,4,1,485,3,68.58);
INSERT INTO items VALUES (329,4,2,603,12,63.58);
INSERT INTO items VALUES (329,4,3,68,1,21.66);
INSERT INTO items VALUES (329,4,4,764,12,126.72);
INSERT INTO items VALUES (329,4,5,325,1,13.21);
INSERT INTO items VALUES (329,4,6,474,2,53.44);
INSERT INTO items VALUES (329,5,1,940,1,12.18);
INSERT INTO items VALUES (329,6,1,635,1,21.39);
INSERT INTO items VALUES (329,6,2,674,1,14.87);
INSERT INTO items VALUES (329,6,3,784,1,8.87);
INSERT INTO items VALUES (329,6,4,38,12,63.25);
INSERT INTO items VALUES (329,6,5,279,12,175.67);
INSERT INTO items VALUES (330,1,1,772,1,13.29);
INSERT INTO items VALUES (330,1,2,427,12,220.11);
INSERT INTO items VALUES (330,1,3,34,2,28.56);
INSERT INTO items VALUES (330,1,4,158,12,147.29);
INSERT INTO items VALUES (330,1,5,623,2,44.20);
INSERT INTO items VALUES (330,2,1,39,1,7.38);
INSERT INTO items VALUES (330,2,2,466,12,129.91);
INSERT INTO items VALUES (330,2,3,293,1,21.79);
INSERT INTO items VALUES (330,3,1,601,3,42.87);
INSERT INTO items VALUES (330,3,2,496,12,258.17);
INSERT INTO items VALUES (330,3,3,332,3,75.87);
INSERT INTO items VALUES (330,4,1,70,2,32.10);
INSERT INTO items VALUES (330,4,2,544,12,71.83);
INSERT INTO items VALUES (330,5,1,9,1,24.47);
INSERT INTO items VALUES (330,5,2,509,12,171.38);
INSERT INTO items VALUES (330,5,3,797,2,36.50);
INSERT INTO items VALUES (330,5,4,167,2,42.10);
INSERT INTO items VALUES (331,1,1,858,2,10.66);
INSERT INTO items VALUES (331,1,2,638,1,5.73);
INSERT INTO items VALUES (331,1,3,572,1,27.49);
INSERT INTO items VALUES (331,1,4,593,2,13.68);
INSERT INTO items VALUES (331,2,1,559,2,13.34);
INSERT INTO items VALUES (331,2,2,205,2,25.98);
INSERT INTO items VALUES (331,2,3,218,2,18.12);
INSERT INTO items VALUES (331,2,4,539,3,31.44);
INSERT INTO items VALUES (331,2,5,259,1,10.52);
INSERT INTO items VALUES (331,3,1,413,2,36.68);
INSERT INTO items VALUES (331,3,2,514,12,177.98);
INSERT INTO items VALUES (331,3,3,471,1,28.64);
INSERT INTO items VALUES (331,4,1,280,1,18.58);
INSERT INTO items VALUES (331,5,1,180,1,18.57);
INSERT INTO items VALUES (331,5,2,126,3,72.27);
INSERT INTO items VALUES (332,1,1,803,1,20.69);
INSERT INTO items VALUES (332,1,2,767,1,6.53);
INSERT INTO items VALUES (332,1,3,543,12,308.66);
INSERT INTO items VALUES (332,1,4,779,1,19.87);
INSERT INTO items VALUES (332,1,5,639,12,258.83);
INSERT INTO items VALUES (332,2,1,558,2,57.18);
INSERT INTO items VALUES (332,2,2,942,12,310.53);
INSERT INTO items VALUES (332,2,3,457,2,42.00);
INSERT INTO items VALUES (332,2,4,325,1,13.21);
INSERT INTO items VALUES (332,2,5,891,3,70.80);
INSERT INTO items VALUES (332,3,1,581,1,14.98);
INSERT INTO items VALUES (332,3,2,715,2,37.96);
INSERT INTO items VALUES (332,3,3,107,2,12.82);
INSERT INTO items VALUES (332,3,4,114,2,44.64);
INSERT INTO items VALUES (332,3,5,139,2,31.08);
INSERT INTO items VALUES (332,4,1,915,1,12.51);
INSERT INTO items VALUES (332,4,2,306,1,26.47);
INSERT INTO items VALUES (332,4,3,440,1,5.35);
INSERT INTO items VALUES (332,4,4,852,12,286.99);
INSERT INTO items VALUES (332,4,5,859,1,10.26);
INSERT INTO items VALUES (332,4,6,866,2,29.18);
INSERT INTO items VALUES (333,1,1,232,1,14.33);
INSERT INTO items VALUES (333,1,2,737,3,78.57);
INSERT INTO items VALUES (333,1,3,511,2,29.44);
INSERT INTO items VALUES (333,1,4,152,2,11.62);
INSERT INTO items VALUES (333,2,1,638,12,63.03);
INSERT INTO items VALUES (333,2,2,239,2,48.38);
INSERT INTO items VALUES (333,2,3,619,2,41.58);
INSERT INTO items VALUES (333,3,1,816,3,34.71);
INSERT INTO items VALUES (333,4,1,839,3,58.50);
INSERT INTO items VALUES (333,4,2,1044,3,57.36);
INSERT INTO items VALUES (333,4,3,65,1,9.98);
INSERT INTO items VALUES (333,4,4,983,3,78.33);
INSERT INTO items VALUES (334,1,1,947,2,39.06);
INSERT INTO items VALUES (334,2,1,362,2,45.84);
INSERT INTO items VALUES (334,2,2,117,12,274.23);
INSERT INTO items VALUES (334,2,3,651,3,89.76);
INSERT INTO items VALUES (334,2,4,839,2,39.00);
INSERT INTO items VALUES (334,2,5,780,3,21.93);
INSERT INTO items VALUES (334,3,1,510,12,121.33);
INSERT INTO items VALUES (334,3,2,642,3,41.73);
INSERT INTO items VALUES (334,3,3,134,3,67.35);
INSERT INTO items VALUES (334,3,4,51,1,24.09);
INSERT INTO items VALUES (334,4,1,42,1,21.28);
INSERT INTO items VALUES (334,4,2,814,3,40.56);
INSERT INTO items VALUES (334,4,3,807,3,29.61);
INSERT INTO items VALUES (334,4,4,5,3,20.01);
INSERT INTO items VALUES (334,4,5,132,2,36.86);
INSERT INTO items VALUES (335,1,1,715,2,37.96);
INSERT INTO items VALUES (335,1,2,779,1,19.87);
INSERT INTO items VALUES (335,1,3,396,12,131.45);
INSERT INTO items VALUES (335,1,4,296,2,19.90);
INSERT INTO items VALUES (335,2,1,279,12,175.67);
INSERT INTO items VALUES (335,2,2,754,12,275.44);
INSERT INTO items VALUES (335,2,3,899,1,7.35);
INSERT INTO items VALUES (335,2,4,1014,2,27.64);
INSERT INTO items VALUES (335,2,5,751,3,74.67);
INSERT INTO items VALUES (335,2,6,815,12,70.84);
INSERT INTO items VALUES (335,3,1,761,1,18.88);
INSERT INTO items VALUES (335,3,2,446,1,21.44);
INSERT INTO items VALUES (335,3,3,612,2,59.16);
INSERT INTO items VALUES (335,3,4,756,3,88.56);
INSERT INTO items VALUES (336,1,1,670,2,33.82);
INSERT INTO items VALUES (336,1,2,301,12,325.38);
INSERT INTO items VALUES (336,2,1,973,1,16.02);
INSERT INTO items VALUES (336,2,2,982,3,86.01);
INSERT INTO items VALUES (336,3,1,385,3,62.43);
INSERT INTO items VALUES (336,3,2,762,2,56.08);
INSERT INTO items VALUES (336,3,3,63,1,23.72);
INSERT INTO items VALUES (336,3,4,83,1,15.54);
INSERT INTO items VALUES (337,1,1,153,12,254.21);
INSERT INTO items VALUES (337,1,2,884,2,33.78);
INSERT INTO items VALUES (337,2,1,508,12,313.28);
INSERT INTO items VALUES (337,3,1,975,3,27.60);
INSERT INTO items VALUES (337,3,2,430,2,20.94);
INSERT INTO items VALUES (337,4,1,276,3,69.66);
INSERT INTO items VALUES (337,4,2,213,3,75.51);
INSERT INTO items VALUES (337,4,3,408,1,15.95);
INSERT INTO items VALUES (338,1,1,295,3,75.15);
INSERT INTO items VALUES (338,1,2,516,1,10.87);
INSERT INTO items VALUES (338,2,1,1036,3,35.22);
INSERT INTO items VALUES (338,2,2,336,1,27.91);
INSERT INTO items VALUES (338,3,1,1037,12,293.37);
INSERT INTO items VALUES (338,3,2,273,12,65.23);
INSERT INTO items VALUES (338,3,3,111,12,306.68);
INSERT INTO items VALUES (338,3,4,71,2,15.00);
INSERT INTO items VALUES (338,3,5,234,2,52.80);
INSERT INTO items VALUES (338,4,1,773,3,76.20);
INSERT INTO items VALUES (338,4,2,87,3,51.57);
INSERT INTO items VALUES (338,4,3,343,2,11.40);
INSERT INTO items VALUES (338,4,4,870,12,251.79);
INSERT INTO items VALUES (338,4,5,87,1,17.19);
INSERT INTO items VALUES (338,5,1,777,1,23.70);
INSERT INTO items VALUES (338,6,1,535,1,19.83);
INSERT INTO items VALUES (339,1,1,555,12,96.69);
INSERT INTO items VALUES (339,1,2,751,3,74.67);
INSERT INTO items VALUES (339,1,3,59,12,316.91);
INSERT INTO items VALUES (339,1,4,606,1,25.31);
INSERT INTO items VALUES (339,1,5,805,3,85.68);
INSERT INTO items VALUES (339,2,1,341,1,17.40);
INSERT INTO items VALUES (339,2,2,175,2,51.20);
INSERT INTO items VALUES (339,2,3,783,2,55.74);
INSERT INTO items VALUES (339,2,4,982,3,86.01);
INSERT INTO items VALUES (339,2,5,462,1,23.78);
INSERT INTO items VALUES (339,2,6,28,3,59.97);
INSERT INTO items VALUES (339,3,1,478,2,35.66);
INSERT INTO items VALUES (339,3,2,434,1,25.44);
INSERT INTO items VALUES (339,4,1,38,2,11.50);
INSERT INTO items VALUES (339,4,2,426,1,8.67);
INSERT INTO items VALUES (340,1,1,635,1,21.39);
INSERT INTO items VALUES (340,1,2,587,3,31.14);
INSERT INTO items VALUES (340,1,3,392,1,13.17);
INSERT INTO items VALUES (340,1,4,426,3,26.01);
INSERT INTO items VALUES (340,1,5,591,3,38.10);
INSERT INTO items VALUES (340,2,1,4,12,232.76);
INSERT INTO items VALUES (340,2,2,883,2,18.60);
INSERT INTO items VALUES (340,2,3,180,1,18.57);
INSERT INTO items VALUES (340,2,4,248,2,52.36);
INSERT INTO items VALUES (340,2,5,675,12,241.23);
INSERT INTO items VALUES (340,3,1,1037,3,80.01);
INSERT INTO items VALUES (340,3,2,440,2,10.70);
INSERT INTO items VALUES (340,4,1,698,1,15.50);
INSERT INTO items VALUES (340,4,2,599,3,16.71);
INSERT INTO items VALUES (340,4,3,998,2,24.60);
INSERT INTO items VALUES (340,4,4,110,1,12.74);
INSERT INTO items VALUES (340,4,5,480,2,57.78);
INSERT INTO items VALUES (340,5,1,78,2,31.00);
INSERT INTO items VALUES (340,5,2,561,1,8.64);
INSERT INTO items VALUES (341,1,1,143,1,12.49);
INSERT INTO items VALUES (341,1,2,389,2,35.04);
INSERT INTO items VALUES (341,1,3,627,1,6.58);
INSERT INTO items VALUES (341,1,4,289,1,19.36);
INSERT INTO items VALUES (341,1,5,153,2,46.22);
INSERT INTO items VALUES (342,1,1,569,2,26.80);
INSERT INTO items VALUES (342,2,1,1015,2,56.70);
INSERT INTO items VALUES (342,2,2,10,3,53.46);
INSERT INTO items VALUES (342,2,3,661,1,11.08);
INSERT INTO items VALUES (342,2,4,46,12,172.37);
INSERT INTO items VALUES (342,2,5,665,1,6.72);
INSERT INTO items VALUES (342,3,1,717,3,71.76);
INSERT INTO items VALUES (342,3,2,829,1,10.60);
INSERT INTO items VALUES (342,3,3,621,2,58.92);
INSERT INTO items VALUES (343,1,1,430,2,20.94);
INSERT INTO items VALUES (343,1,2,485,1,22.86);
INSERT INTO items VALUES (343,1,3,34,2,28.56);
INSERT INTO items VALUES (343,2,1,882,12,238.59);
INSERT INTO items VALUES (343,2,2,166,2,16.52);
INSERT INTO items VALUES (343,2,3,605,3,62.34);
INSERT INTO items VALUES (343,3,1,42,1,21.28);
INSERT INTO items VALUES (343,3,2,304,12,247.06);
INSERT INTO items VALUES (343,3,3,590,3,45.99);
INSERT INTO items VALUES (343,3,4,365,1,8.40);
INSERT INTO items VALUES (343,3,5,819,2,15.54);
INSERT INTO items VALUES (343,3,6,549,12,69.96);
INSERT INTO items VALUES (344,1,1,752,3,25.77);
INSERT INTO items VALUES (344,1,2,948,2,16.76);
INSERT INTO items VALUES (344,2,1,671,1,26.19);
INSERT INTO items VALUES (344,3,1,329,2,29.96);
INSERT INTO items VALUES (344,3,2,839,3,58.50);
INSERT INTO items VALUES (344,3,3,987,12,307.34);
INSERT INTO items VALUES (344,3,4,270,2,40.92);
INSERT INTO items VALUES (344,3,5,500,3,48.84);
INSERT INTO items VALUES (344,3,6,736,1,26.06);
INSERT INTO items VALUES (345,1,1,334,3,42.75);
INSERT INTO items VALUES (345,1,2,384,2,42.14);
INSERT INTO items VALUES (345,1,3,71,12,82.50);
INSERT INTO items VALUES (345,1,4,242,1,28.32);
INSERT INTO items VALUES (345,1,5,930,12,280.61);
INSERT INTO items VALUES (345,2,1,143,3,37.47);
INSERT INTO items VALUES (345,2,2,281,12,61.93);
INSERT INTO items VALUES (345,2,3,311,2,48.44);
INSERT INTO items VALUES (345,2,4,238,12,265.65);
INSERT INTO items VALUES (345,2,5,52,2,53.46);
INSERT INTO items VALUES (345,3,1,120,3,15.33);
INSERT INTO items VALUES (346,1,1,893,1,24.44);
INSERT INTO items VALUES (346,1,2,872,3,78.87);
INSERT INTO items VALUES (346,1,3,182,2,14.86);
INSERT INTO items VALUES (346,1,4,954,12,60.61);
INSERT INTO items VALUES (347,1,1,731,2,51.36);
INSERT INTO items VALUES (347,1,2,360,2,23.88);
INSERT INTO items VALUES (347,1,3,548,2,10.24);
INSERT INTO items VALUES (347,1,4,87,3,51.57);
INSERT INTO items VALUES (347,1,5,839,12,214.50);
INSERT INTO items VALUES (347,2,1,611,2,42.64);
INSERT INTO items VALUES (347,2,2,966,1,10.45);
INSERT INTO items VALUES (347,2,3,389,12,192.72);
INSERT INTO items VALUES (347,2,4,765,3,89.64);
INSERT INTO items VALUES (347,2,5,127,2,35.72);
INSERT INTO items VALUES (347,3,1,907,12,242.55);
INSERT INTO items VALUES (347,3,2,716,12,152.35);
INSERT INTO items VALUES (347,4,1,389,3,52.56);
INSERT INTO items VALUES (347,4,2,562,12,128.15);
INSERT INTO items VALUES (347,4,3,189,2,33.46);
INSERT INTO items VALUES (347,4,4,1008,3,85.95);
INSERT INTO items VALUES (347,4,5,383,3,56.67);
INSERT INTO items VALUES (347,5,1,845,2,32.36);
INSERT INTO items VALUES (347,5,2,592,3,45.96);
INSERT INTO items VALUES (347,5,3,402,1,19.08);
INSERT INTO items VALUES (348,1,1,757,1,21.37);
INSERT INTO items VALUES (348,1,2,320,3,62.76);
INSERT INTO items VALUES (348,1,3,372,12,112.31);
INSERT INTO items VALUES (348,1,4,667,12,253.77);
INSERT INTO items VALUES (348,1,5,133,2,35.08);
INSERT INTO items VALUES (348,2,1,750,12,72.27);
INSERT INTO items VALUES (348,2,2,582,2,41.76);
INSERT INTO items VALUES (348,2,3,266,12,205.26);
INSERT INTO items VALUES (348,2,4,5,1,6.67);
INSERT INTO items VALUES (348,2,5,560,3,68.73);
INSERT INTO items VALUES (348,2,6,148,12,145.64);
INSERT INTO items VALUES (348,3,1,1023,12,170.39);
INSERT INTO items VALUES (348,3,2,469,1,26.88);
INSERT INTO items VALUES (348,3,3,258,3,53.04);
INSERT INTO items VALUES (348,3,4,749,3,16.71);
INSERT INTO items VALUES (348,4,1,760,1,6.12);
INSERT INTO items VALUES (348,4,2,677,3,42.24);
INSERT INTO items VALUES (348,4,3,331,1,7.84);
INSERT INTO items VALUES (348,4,4,301,2,59.16);
INSERT INTO items VALUES (348,4,5,69,2,33.22);
INSERT INTO items VALUES (348,4,6,385,3,62.43);
INSERT INTO items VALUES (349,1,1,125,1,8.82);
INSERT INTO items VALUES (349,1,2,392,3,39.51);
INSERT INTO items VALUES (349,1,3,439,12,210.43);
INSERT INTO items VALUES (349,1,4,804,3,77.70);
INSERT INTO items VALUES (349,2,1,148,2,26.48);
INSERT INTO items VALUES (349,2,2,81,3,76.56);
INSERT INTO items VALUES (349,2,3,462,2,47.56);
INSERT INTO items VALUES (349,2,4,1011,1,11.12);
INSERT INTO items VALUES (349,2,5,904,3,55.89);
INSERT INTO items VALUES (349,3,1,510,1,11.03);
INSERT INTO items VALUES (350,1,1,558,1,28.59);
INSERT INTO items VALUES (350,2,1,814,12,148.72);
INSERT INTO items VALUES (350,2,2,299,3,39.69);
INSERT INTO items VALUES (350,3,1,369,2,45.84);
INSERT INTO items VALUES (350,3,2,323,1,13.60);
INSERT INTO items VALUES (350,4,1,466,12,129.91);
INSERT INTO items VALUES (350,5,1,988,3,33.51);
INSERT INTO items VALUES (350,5,2,630,3,84.00);
INSERT INTO items VALUES (351,1,1,404,12,297.11);
INSERT INTO items VALUES (351,1,2,777,3,71.10);
INSERT INTO items VALUES (351,1,3,384,2,42.14);
INSERT INTO items VALUES (351,1,4,594,2,12.16);
INSERT INTO items VALUES (352,1,1,689,3,30.09);
INSERT INTO items VALUES (352,1,2,520,3,30.03);
INSERT INTO items VALUES (352,2,1,307,2,10.56);
INSERT INTO items VALUES (352,2,2,383,12,207.79);
INSERT INTO items VALUES (352,2,3,713,2,50.12);
INSERT INTO items VALUES (352,2,4,660,2,24.22);
INSERT INTO items VALUES (352,2,5,686,1,19.52);
INSERT INTO items VALUES (352,3,1,153,2,46.22);
INSERT INTO items VALUES (352,3,2,791,12,57.09);
INSERT INTO items VALUES (352,3,3,946,1,9.51);
INSERT INTO items VALUES (352,3,4,421,1,14.30);
INSERT INTO items VALUES (353,1,1,611,3,63.96);
INSERT INTO items VALUES (353,1,2,888,12,63.58);
INSERT INTO items VALUES (353,2,1,686,1,19.52);
INSERT INTO items VALUES (353,2,2,582,1,20.88);
INSERT INTO items VALUES (353,2,3,270,12,225.06);
INSERT INTO items VALUES (353,2,4,1031,1,6.87);
INSERT INTO items VALUES (353,2,5,870,1,22.89);
INSERT INTO items VALUES (353,3,1,716,3,41.55);
INSERT INTO items VALUES (353,3,2,85,2,43.08);
INSERT INTO items VALUES (353,3,3,248,12,287.98);
INSERT INTO items VALUES (353,3,4,143,2,24.98);
INSERT INTO items VALUES (353,3,5,132,3,55.29);
INSERT INTO items VALUES (353,3,6,756,1,29.52);
INSERT INTO items VALUES (354,1,1,111,3,83.64);
INSERT INTO items VALUES (354,1,2,803,2,41.38);
INSERT INTO items VALUES (354,1,3,5,12,73.37);
INSERT INTO items VALUES (354,1,4,961,1,10.08);
INSERT INTO items VALUES (354,1,5,238,12,265.65);
INSERT INTO items VALUES (354,1,6,1006,12,221.76);
INSERT INTO items VALUES (355,1,1,1018,12,101.42);
INSERT INTO items VALUES (355,2,1,840,2,29.26);
INSERT INTO items VALUES (355,2,2,477,2,47.78);
INSERT INTO items VALUES (355,2,3,118,12,158.18);
INSERT INTO items VALUES (355,3,1,10,1,17.82);
INSERT INTO items VALUES (355,3,2,415,1,11.31);
INSERT INTO items VALUES (355,3,3,978,2,20.10);
INSERT INTO items VALUES (355,4,1,533,1,18.74);
INSERT INTO items VALUES (355,4,2,912,12,252.34);
INSERT INTO items VALUES (355,4,3,385,3,62.43);
INSERT INTO items VALUES (355,4,4,279,12,175.67);
INSERT INTO items VALUES (356,1,1,967,1,7.48);
INSERT INTO items VALUES (356,1,2,377,1,29.73);
INSERT INTO items VALUES (356,1,3,537,3,78.90);
INSERT INTO items VALUES (357,1,1,60,12,178.31);
INSERT INTO items VALUES (358,1,1,355,12,223.63);
INSERT INTO items VALUES (358,1,2,1025,3,86.34);
INSERT INTO items VALUES (358,1,3,280,3,55.74);
INSERT INTO items VALUES (358,1,4,985,1,20.34);
INSERT INTO items VALUES (359,1,1,447,3,40.74);
INSERT INTO items VALUES (359,1,2,401,3,50.25);
INSERT INTO items VALUES (359,1,3,730,2,49.32);
INSERT INTO items VALUES (359,1,4,494,12,311.85);
INSERT INTO items VALUES (359,1,5,382,1,7.09);
INSERT INTO items VALUES (359,1,6,359,12,204.71);
INSERT INTO items VALUES (359,2,1,923,2,29.28);
INSERT INTO items VALUES (359,3,1,622,12,191.95);
INSERT INTO items VALUES (359,4,1,194,12,166.10);
INSERT INTO items VALUES (359,4,2,210,2,24.14);
INSERT INTO items VALUES (359,4,3,212,1,29.80);
INSERT INTO items VALUES (359,4,4,500,12,179.08);
INSERT INTO items VALUES (359,4,5,769,12,63.14);
INSERT INTO items VALUES (359,4,6,509,2,31.16);
INSERT INTO items VALUES (359,5,1,803,1,20.69);
INSERT INTO items VALUES (359,5,2,435,2,23.70);
INSERT INTO items VALUES (359,6,1,692,2,35.80);
INSERT INTO items VALUES (359,6,2,207,12,273.57);
INSERT INTO items VALUES (359,6,3,656,2,50.86);
INSERT INTO items VALUES (360,1,1,129,3,17.25);
INSERT INTO items VALUES (361,1,1,575,1,25.67);
INSERT INTO items VALUES (361,1,2,63,12,260.92);
INSERT INTO items VALUES (361,1,3,1025,1,28.78);
INSERT INTO items VALUES (361,1,4,210,3,36.21);
INSERT INTO items VALUES (361,1,5,446,2,42.88);
INSERT INTO items VALUES (362,1,1,864,2,46.96);
INSERT INTO items VALUES (362,1,2,248,12,287.98);
INSERT INTO items VALUES (362,2,1,312,3,35.79);
INSERT INTO items VALUES (362,2,2,375,2,46.80);
INSERT INTO items VALUES (362,2,3,599,1,5.57);
INSERT INTO items VALUES (362,2,4,448,3,17.34);
INSERT INTO items VALUES (362,2,5,439,1,19.13);
INSERT INTO items VALUES (362,3,1,711,2,56.14);
INSERT INTO items VALUES (362,3,2,573,3,61.08);
INSERT INTO items VALUES (362,3,3,681,12,309.32);
INSERT INTO items VALUES (363,1,1,962,2,31.44);
INSERT INTO items VALUES (363,1,2,1027,2,57.46);
INSERT INTO items VALUES (363,1,3,905,1,11.44);
INSERT INTO items VALUES (363,1,4,833,3,58.89);
INSERT INTO items VALUES (363,2,1,519,2,23.52);
INSERT INTO items VALUES (363,3,1,57,3,52.80);
INSERT INTO items VALUES (363,3,2,655,12,234.52);
INSERT INTO items VALUES (363,3,3,290,2,17.82);
INSERT INTO items VALUES (363,3,4,514,1,16.18);
INSERT INTO items VALUES (363,3,5,732,2,54.18);
INSERT INTO items VALUES (364,1,1,751,3,74.67);
INSERT INTO items VALUES (364,1,2,848,12,191.07);
INSERT INTO items VALUES (364,1,3,134,1,22.45);
INSERT INTO items VALUES (364,1,4,504,12,304.92);
INSERT INTO items VALUES (364,1,5,958,3,32.49);
INSERT INTO items VALUES (364,1,6,477,3,71.67);
INSERT INTO items VALUES (364,2,1,907,3,66.15);
INSERT INTO items VALUES (364,2,2,110,2,25.48);
INSERT INTO items VALUES (364,2,3,219,3,19.35);
INSERT INTO items VALUES (364,3,1,432,3,76.35);
INSERT INTO items VALUES (364,4,1,1007,1,12.34);
INSERT INTO items VALUES (364,4,2,339,2,21.34);
INSERT INTO items VALUES (364,4,3,212,2,59.60);
INSERT INTO items VALUES (364,4,4,885,3,27.66);
INSERT INTO items VALUES (364,4,5,766,3,89.58);
INSERT INTO items VALUES (364,4,6,318,12,155.32);
INSERT INTO items VALUES (365,1,1,7,2,24.40);
INSERT INTO items VALUES (365,1,2,279,3,47.91);
INSERT INTO items VALUES (365,1,3,99,12,268.40);
INSERT INTO items VALUES (365,1,4,100,2,46.92);
INSERT INTO items VALUES (365,1,5,326,3,39.48);
INSERT INTO items VALUES (365,1,6,298,2,49.28);
INSERT INTO items VALUES (366,1,1,306,12,291.17);
INSERT INTO items VALUES (366,1,2,519,2,23.52);
INSERT INTO items VALUES (366,1,3,305,12,57.97);
INSERT INTO items VALUES (366,1,4,396,2,23.90);
INSERT INTO items VALUES (366,2,1,141,2,44.94);
INSERT INTO items VALUES (366,2,2,964,2,26.66);
INSERT INTO items VALUES (366,2,3,630,3,84.00);
INSERT INTO items VALUES (366,2,4,792,12,71.39);
INSERT INTO items VALUES (366,2,5,144,2,52.42);
INSERT INTO items VALUES (366,3,1,226,2,17.36);
INSERT INTO items VALUES (366,3,2,857,3,23.52);
INSERT INTO items VALUES (366,3,3,464,1,15.07);
INSERT INTO items VALUES (366,4,1,939,1,14.37);
INSERT INTO items VALUES (366,4,2,908,12,129.14);
INSERT INTO items VALUES (366,4,3,575,2,51.34);
INSERT INTO items VALUES (366,4,4,347,2,21.18);
INSERT INTO items VALUES (367,1,1,952,3,64.44);
INSERT INTO items VALUES (367,1,2,80,2,56.88);
INSERT INTO items VALUES (367,1,3,461,3,31.98);
INSERT INTO items VALUES (367,1,4,836,3,48.57);
INSERT INTO items VALUES (367,1,5,475,3,86.52);
INSERT INTO items VALUES (367,1,6,563,3,80.46);
INSERT INTO items VALUES (367,2,1,111,2,55.76);
INSERT INTO items VALUES (367,2,2,693,2,56.16);
INSERT INTO items VALUES (367,3,1,435,12,130.35);
INSERT INTO items VALUES (367,3,2,522,2,14.60);
INSERT INTO items VALUES (367,3,3,307,12,58.08);
INSERT INTO items VALUES (367,3,4,75,1,22.73);
INSERT INTO items VALUES (367,3,5,600,3,50.97);
INSERT INTO items VALUES (367,3,6,671,1,26.19);
INSERT INTO items VALUES (368,1,1,264,3,38.52);
INSERT INTO items VALUES (369,1,1,27,12,229.57);
INSERT INTO items VALUES (369,1,2,738,3,72.66);
INSERT INTO items VALUES (369,1,3,371,12,170.39);
INSERT INTO items VALUES (369,1,4,483,2,24.12);
INSERT INTO items VALUES (369,1,5,89,1,27.85);
INSERT INTO items VALUES (369,2,1,798,12,324.28);
INSERT INTO items VALUES (369,2,2,402,12,209.88);
INSERT INTO items VALUES (369,3,1,606,12,278.41);
INSERT INTO items VALUES (369,3,2,302,3,68.10);
INSERT INTO items VALUES (369,3,3,885,12,101.42);
INSERT INTO items VALUES (369,3,4,133,1,17.54);
INSERT INTO items VALUES (369,4,1,795,3,64.38);
INSERT INTO items VALUES (369,4,2,818,2,13.14);
INSERT INTO items VALUES (369,4,3,838,3,57.90);
INSERT INTO items VALUES (369,4,4,379,1,8.39);
INSERT INTO items VALUES (369,4,5,429,2,33.04);
INSERT INTO items VALUES (369,5,1,583,1,18.49);
INSERT INTO items VALUES (369,5,2,838,2,38.60);
INSERT INTO items VALUES (370,1,1,830,12,94.38);
INSERT INTO items VALUES (371,1,1,690,1,20.07);
INSERT INTO items VALUES (371,1,2,583,3,55.47);
INSERT INTO items VALUES (371,1,3,520,1,10.01);
INSERT INTO items VALUES (371,2,1,471,1,28.64);
INSERT INTO items VALUES (371,2,2,870,3,68.67);
INSERT INTO items VALUES (371,3,1,235,2,43.70);
INSERT INTO items VALUES (371,3,2,1046,2,22.00);
INSERT INTO items VALUES (371,3,3,552,3,15.90);
INSERT INTO items VALUES (371,3,4,806,1,8.34);
INSERT INTO items VALUES (371,4,1,911,12,62.81);
INSERT INTO items VALUES (371,4,2,121,1,29.02);
INSERT INTO items VALUES (371,4,3,237,3,76.44);
INSERT INTO items VALUES (371,4,4,141,1,22.47);
INSERT INTO items VALUES (371,4,5,77,3,26.52);
INSERT INTO items VALUES (371,5,1,589,1,21.56);
INSERT INTO items VALUES (371,5,2,602,1,11.72);
INSERT INTO items VALUES (371,6,1,174,2,51.36);
INSERT INTO items VALUES (371,6,2,1020,1,5.51);
INSERT INTO items VALUES (372,1,1,996,3,57.36);
INSERT INTO items VALUES (372,1,2,460,2,38.70);
INSERT INTO items VALUES (372,1,3,675,3,65.79);
INSERT INTO items VALUES (372,1,4,556,12,63.58);
INSERT INTO items VALUES (372,1,5,298,3,73.92);
INSERT INTO items VALUES (372,2,1,838,2,38.60);
INSERT INTO items VALUES (372,2,2,590,1,15.33);
INSERT INTO items VALUES (372,2,3,472,3,25.08);
INSERT INTO items VALUES (373,1,1,869,2,35.86);
INSERT INTO items VALUES (373,1,2,368,2,56.74);
INSERT INTO items VALUES (373,1,3,948,1,8.38);
INSERT INTO items VALUES (373,1,4,825,3,88.89);
INSERT INTO items VALUES (373,1,5,373,2,51.14);
INSERT INTO items VALUES (373,1,6,110,3,38.22);
INSERT INTO items VALUES (373,2,1,833,2,39.26);
INSERT INTO items VALUES (373,2,2,50,2,31.24);
INSERT INTO items VALUES (373,2,3,752,3,25.77);
INSERT INTO items VALUES (373,2,4,65,3,29.94);
INSERT INTO items VALUES (373,3,1,26,2,52.06);
INSERT INTO items VALUES (374,1,1,74,3,37.68);
INSERT INTO items VALUES (375,1,1,771,2,30.70);
INSERT INTO items VALUES (375,1,2,576,2,53.52);
INSERT INTO items VALUES (375,1,3,235,2,43.70);
INSERT INTO items VALUES (375,2,1,57,1,17.60);
INSERT INTO items VALUES (375,2,2,762,3,84.12);
INSERT INTO items VALUES (375,2,3,335,12,105.38);
INSERT INTO items VALUES (375,2,4,745,2,20.52);
INSERT INTO items VALUES (376,1,1,343,12,62.70);
INSERT INTO items VALUES (377,1,1,224,1,23.92);
INSERT INTO items VALUES (377,1,2,897,2,45.98);
INSERT INTO items VALUES (377,1,3,650,12,256.74);
INSERT INTO items VALUES (377,1,4,617,2,24.18);
INSERT INTO items VALUES (377,1,5,449,12,312.18);
INSERT INTO items VALUES (377,1,6,324,1,20.37);
INSERT INTO items VALUES (377,2,1,114,2,44.64);
INSERT INTO items VALUES (377,2,2,797,1,18.25);
INSERT INTO items VALUES (377,2,3,194,3,45.30);
INSERT INTO items VALUES (377,3,1,242,2,56.64);
INSERT INTO items VALUES (377,3,2,167,12,231.55);
INSERT INTO items VALUES (377,3,3,223,3,39.12);
INSERT INTO items VALUES (377,3,4,206,3,73.80);
INSERT INTO items VALUES (377,4,1,550,3,33.66);
INSERT INTO items VALUES (377,4,2,410,3,52.62);
INSERT INTO items VALUES (377,4,3,33,1,18.75);
INSERT INTO items VALUES (377,4,4,691,1,29.00);
INSERT INTO items VALUES (377,4,5,720,1,28.12);
INSERT INTO items VALUES (377,4,6,603,1,5.78);
INSERT INTO items VALUES (377,5,1,902,1,10.77);
INSERT INTO items VALUES (377,5,2,180,1,18.57);
INSERT INTO items VALUES (377,5,3,866,12,160.49);
INSERT INTO items VALUES (378,1,1,167,3,63.15);
INSERT INTO items VALUES (378,1,2,445,2,42.86);
INSERT INTO items VALUES (378,1,3,236,3,66.03);
INSERT INTO items VALUES (378,2,1,257,1,29.82);
INSERT INTO items VALUES (378,2,2,906,3,30.99);
INSERT INTO items VALUES (378,2,3,906,1,10.33);
INSERT INTO items VALUES (378,2,4,881,12,284.13);
INSERT INTO items VALUES (378,2,5,918,3,47.10);
INSERT INTO items VALUES (378,2,6,506,2,48.74);
INSERT INTO items VALUES (378,3,1,411,1,23.99);
INSERT INTO items VALUES (378,3,2,750,3,19.71);
INSERT INTO items VALUES (378,3,3,765,3,89.64);
INSERT INTO items VALUES (378,4,1,987,3,83.82);
INSERT INTO items VALUES (378,4,2,930,12,280.61);
INSERT INTO items VALUES (379,1,1,105,2,44.82);
INSERT INTO items VALUES (379,1,2,124,12,301.62);
INSERT INTO items VALUES (379,1,3,36,3,88.53);
INSERT INTO items VALUES (379,1,4,332,1,25.29);
INSERT INTO items VALUES (379,1,5,251,12,62.81);
INSERT INTO items VALUES (379,1,6,896,12,303.16);
INSERT INTO items VALUES (379,2,1,710,2,58.54);
INSERT INTO items VALUES (379,3,1,435,12,130.35);
INSERT INTO items VALUES (379,4,1,792,2,12.98);
INSERT INTO items VALUES (379,4,2,920,3,60.84);
INSERT INTO items VALUES (379,4,3,231,12,193.16);
INSERT INTO items VALUES (379,4,4,644,1,28.46);
INSERT INTO items VALUES (379,5,1,666,12,171.05);
INSERT INTO items VALUES (379,5,2,987,2,55.88);
INSERT INTO items VALUES (379,5,3,126,3,72.27);
INSERT INTO items VALUES (379,5,4,515,3,75.27);
INSERT INTO items VALUES (379,5,5,549,2,12.72);
INSERT INTO items VALUES (380,1,1,123,12,84.70);
INSERT INTO items VALUES (380,1,2,579,12,84.48);
INSERT INTO items VALUES (381,1,1,928,2,15.12);
INSERT INTO items VALUES (381,1,2,701,12,267.52);
INSERT INTO items VALUES (381,1,3,722,12,165.00);
INSERT INTO items VALUES (381,1,4,537,1,26.30);
INSERT INTO items VALUES (381,1,5,338,1,24.28);
INSERT INTO items VALUES (381,2,1,107,1,6.41);
INSERT INTO items VALUES (381,2,2,655,1,21.32);
INSERT INTO items VALUES (381,2,3,646,3,23.85);
INSERT INTO items VALUES (381,2,4,605,1,20.78);
INSERT INTO items VALUES (381,3,1,676,12,135.85);
INSERT INTO items VALUES (381,3,2,14,2,10.54);
INSERT INTO items VALUES (381,4,1,338,2,48.56);
INSERT INTO items VALUES (381,4,2,288,1,14.95);
INSERT INTO items VALUES (381,4,3,1000,2,13.82);
INSERT INTO items VALUES (382,1,1,652,2,20.56);
INSERT INTO items VALUES (382,1,2,709,12,73.81);
INSERT INTO items VALUES (382,1,3,730,12,271.26);
INSERT INTO items VALUES (383,1,1,1006,3,60.48);
INSERT INTO items VALUES (383,1,2,853,2,58.46);
INSERT INTO items VALUES (383,1,3,63,1,23.72);
INSERT INTO items VALUES (383,2,1,774,12,62.48);
INSERT INTO items VALUES (383,2,2,109,1,16.00);
INSERT INTO items VALUES (383,3,1,901,3,47.01);
INSERT INTO items VALUES (383,4,1,444,1,18.16);
INSERT INTO items VALUES (383,4,2,47,3,72.12);
INSERT INTO items VALUES (383,4,3,526,1,19.31);
INSERT INTO items VALUES (383,4,4,1024,12,218.35);
INSERT INTO items VALUES (383,4,5,679,12,129.91);
INSERT INTO items VALUES (383,4,6,146,2,42.60);
INSERT INTO items VALUES (384,1,1,982,3,86.01);
INSERT INTO items VALUES (384,2,1,287,12,133.65);
INSERT INTO items VALUES (384,2,2,116,2,23.74);
INSERT INTO items VALUES (384,2,3,1024,3,59.55);
INSERT INTO items VALUES (384,2,4,987,1,27.94);
INSERT INTO items VALUES (384,2,5,627,12,72.38);
INSERT INTO items VALUES (384,3,1,376,1,21.17);
INSERT INTO items VALUES (384,3,2,891,12,259.60);
INSERT INTO items VALUES (384,3,3,60,12,178.31);
INSERT INTO items VALUES (384,3,4,650,12,256.74);
INSERT INTO items VALUES (384,4,1,79,12,131.67);
INSERT INTO items VALUES (384,4,2,368,1,28.37);
INSERT INTO items VALUES (384,4,3,439,2,38.26);
INSERT INTO items VALUES (384,4,4,90,1,6.77);
INSERT INTO items VALUES (384,4,5,196,12,227.15);
INSERT INTO items VALUES (384,4,6,488,1,5.10);
INSERT INTO items VALUES (384,5,1,1014,3,41.46);
INSERT INTO items VALUES (384,5,2,37,3,42.45);
INSERT INTO items VALUES (385,1,1,2,1,28.15);
INSERT INTO items VALUES (385,1,2,190,1,20.28);
INSERT INTO items VALUES (385,1,3,448,2,11.56);
INSERT INTO items VALUES (385,1,4,146,2,42.60);
INSERT INTO items VALUES (385,1,5,691,12,319.00);
INSERT INTO items VALUES (385,2,1,967,2,14.96);
INSERT INTO items VALUES (385,2,2,512,3,82.47);
INSERT INTO items VALUES (385,2,3,442,1,13.67);
INSERT INTO items VALUES (385,2,4,57,3,52.80);
INSERT INTO items VALUES (385,3,1,840,3,43.89);
INSERT INTO items VALUES (385,3,2,880,1,26.62);
INSERT INTO items VALUES (385,3,3,116,12,130.57);
INSERT INTO items VALUES (385,3,4,704,12,255.09);
INSERT INTO items VALUES (385,3,5,926,3,73.80);
INSERT INTO items VALUES (385,4,1,155,1,24.83);
INSERT INTO items VALUES (385,4,2,496,3,70.41);
INSERT INTO items VALUES (385,4,3,210,3,36.21);
INSERT INTO items VALUES (385,4,4,287,1,12.15);
INSERT INTO items VALUES (385,4,5,112,12,87.45);
INSERT INTO items VALUES (385,4,6,884,12,185.79);
INSERT INTO items VALUES (386,1,1,629,12,266.09);
INSERT INTO items VALUES (386,1,2,344,1,15.06);
INSERT INTO items VALUES (386,1,3,546,12,328.68);
INSERT INTO items VALUES (386,2,1,1010,2,38.36);
INSERT INTO items VALUES (386,3,1,520,12,110.11);
INSERT INTO items VALUES (387,1,1,966,1,10.45);
INSERT INTO items VALUES (387,1,2,946,2,19.02);
INSERT INTO items VALUES (387,1,3,1025,1,28.78);
INSERT INTO items VALUES (387,1,4,1034,3,44.88);
INSERT INTO items VALUES (387,1,5,133,2,35.08);
INSERT INTO items VALUES (387,2,1,785,3,84.33);
INSERT INTO items VALUES (387,2,2,293,12,239.69);
INSERT INTO items VALUES (387,2,3,24,1,18.60);
INSERT INTO items VALUES (387,2,4,725,1,24.18);
INSERT INTO items VALUES (387,2,5,191,12,190.19);
INSERT INTO items VALUES (387,3,1,625,3,53.97);
INSERT INTO items VALUES (387,3,2,175,3,76.80);
INSERT INTO items VALUES (387,3,3,353,2,49.58);
INSERT INTO items VALUES (387,3,4,61,12,186.78);
INSERT INTO items VALUES (387,3,5,497,2,42.92);
INSERT INTO items VALUES (387,3,6,904,12,204.93);
INSERT INTO items VALUES (387,4,1,57,2,35.20);
INSERT INTO items VALUES (387,4,2,205,1,12.99);
INSERT INTO items VALUES (387,4,3,210,3,36.21);
INSERT INTO items VALUES (387,4,4,490,12,91.41);
INSERT INTO items VALUES (387,4,5,636,3,76.53);
INSERT INTO items VALUES (387,4,6,537,3,78.90);
INSERT INTO items VALUES (387,5,1,399,3,43.89);
INSERT INTO items VALUES (387,5,2,371,1,15.49);
INSERT INTO items VALUES (387,5,3,439,12,210.43);
INSERT INTO items VALUES (387,5,4,821,1,5.69);
INSERT INTO items VALUES (387,5,5,770,3,47.43);
INSERT INTO items VALUES (387,5,6,672,3,32.76);
INSERT INTO items VALUES (388,1,1,53,12,292.82);
INSERT INTO items VALUES (388,1,2,474,3,80.16);
INSERT INTO items VALUES (388,1,3,206,3,73.80);
INSERT INTO items VALUES (388,1,4,386,12,312.95);
INSERT INTO items VALUES (388,1,5,112,2,15.90);
INSERT INTO items VALUES (388,1,6,893,2,48.88);
INSERT INTO items VALUES (388,2,1,755,1,13.25);
INSERT INTO items VALUES (388,2,2,52,2,53.46);
INSERT INTO items VALUES (388,2,3,806,12,91.74);
INSERT INTO items VALUES (388,3,1,1047,2,27.70);
INSERT INTO items VALUES (388,3,2,478,1,17.83);
INSERT INTO items VALUES (388,3,3,46,12,172.37);
INSERT INTO items VALUES (388,3,4,199,1,20.28);
INSERT INTO items VALUES (388,3,5,238,1,24.15);
INSERT INTO items VALUES (388,4,1,922,12,253.00);
INSERT INTO items VALUES (388,4,2,1038,12,253.22);
INSERT INTO items VALUES (388,4,3,402,12,209.88);
INSERT INTO items VALUES (388,4,4,916,3,62.19);
INSERT INTO items VALUES (388,4,5,439,12,210.43);
INSERT INTO items VALUES (388,4,6,523,2,53.56);
INSERT INTO items VALUES (389,1,1,861,3,41.55);
INSERT INTO items VALUES (389,1,2,874,12,213.40);
INSERT INTO items VALUES (389,1,3,168,12,268.07);
INSERT INTO items VALUES (389,1,4,114,3,66.96);
INSERT INTO items VALUES (389,2,1,710,1,29.27);
INSERT INTO items VALUES (389,2,2,132,2,36.86);
INSERT INTO items VALUES (389,3,1,280,1,18.58);
INSERT INTO items VALUES (389,3,2,76,3,53.82);
INSERT INTO items VALUES (389,3,3,643,12,213.07);
INSERT INTO items VALUES (389,4,1,907,1,22.05);
INSERT INTO items VALUES (389,4,2,263,1,13.12);
INSERT INTO items VALUES (389,4,3,522,3,21.90);
INSERT INTO items VALUES (389,4,4,461,1,10.66);
INSERT INTO items VALUES (389,4,5,831,3,70.83);
INSERT INTO items VALUES (389,4,6,598,2,25.86);
INSERT INTO items VALUES (389,5,1,728,12,60.28);
INSERT INTO items VALUES (389,5,2,472,2,16.72);
INSERT INTO items VALUES (389,5,3,809,3,27.57);
INSERT INTO items VALUES (389,5,4,791,3,15.57);
INSERT INTO items VALUES (389,5,5,982,1,28.67);
INSERT INTO items VALUES (389,6,1,711,3,84.21);
INSERT INTO items VALUES (390,1,1,395,12,186.89);
INSERT INTO items VALUES (390,1,2,4,1,21.16);
INSERT INTO items VALUES (390,2,1,190,1,20.28);
INSERT INTO items VALUES (390,2,2,961,3,30.24);
INSERT INTO items VALUES (390,2,3,1017,12,157.30);
INSERT INTO items VALUES (390,2,4,173,1,26.52);
INSERT INTO items VALUES (390,2,5,191,2,34.58);
INSERT INTO items VALUES (391,1,1,688,1,15.77);
INSERT INTO items VALUES (391,1,2,303,3,37.05);
INSERT INTO items VALUES (391,1,3,194,2,30.20);
INSERT INTO items VALUES (391,1,4,341,1,17.40);
INSERT INTO items VALUES (391,1,5,116,2,23.74);
INSERT INTO items VALUES (391,1,6,757,2,42.74);
INSERT INTO items VALUES (391,2,1,670,3,50.73);
INSERT INTO items VALUES (391,2,2,114,12,245.52);
INSERT INTO items VALUES (391,2,3,214,12,307.45);
INSERT INTO items VALUES (391,2,4,435,2,23.70);
INSERT INTO items VALUES (391,2,5,35,12,194.04);
INSERT INTO items VALUES (391,2,6,360,12,131.34);
INSERT INTO items VALUES (391,3,1,816,12,127.27);
INSERT INTO items VALUES (391,3,2,742,2,45.58);
INSERT INTO items VALUES (391,3,3,184,12,298.21);
INSERT INTO items VALUES (391,4,1,787,12,105.49);
INSERT INTO items VALUES (391,4,2,429,12,181.72);
INSERT INTO items VALUES (391,4,3,762,12,308.44);
INSERT INTO items VALUES (391,4,4,328,12,215.49);
INSERT INTO items VALUES (391,5,1,934,3,75.27);
INSERT INTO items VALUES (392,1,1,368,3,85.11);
INSERT INTO items VALUES (392,1,2,470,3,28.32);
INSERT INTO items VALUES (392,1,3,368,12,312.07);
INSERT INTO items VALUES (392,1,4,349,1,15.59);
INSERT INTO items VALUES (392,2,1,268,2,18.30);
INSERT INTO items VALUES (392,2,2,849,2,57.92);
INSERT INTO items VALUES (392,2,3,257,12,328.02);
INSERT INTO items VALUES (392,2,4,343,12,62.70);
INSERT INTO items VALUES (392,2,5,401,12,184.25);
INSERT INTO items VALUES (392,3,1,226,1,8.68);
INSERT INTO items VALUES (392,3,2,954,3,16.53);
INSERT INTO items VALUES (393,1,1,150,3,25.98);
INSERT INTO items VALUES (394,1,1,625,1,17.99);
INSERT INTO items VALUES (394,1,2,973,1,16.02);
INSERT INTO items VALUES (394,1,3,321,12,128.59);
INSERT INTO items VALUES (394,1,4,729,1,6.71);
INSERT INTO items VALUES (394,2,1,174,12,282.48);
INSERT INTO items VALUES (394,2,2,959,3,30.21);
INSERT INTO items VALUES (394,2,3,638,1,5.73);
INSERT INTO items VALUES (394,3,1,674,2,29.74);
INSERT INTO items VALUES (394,3,2,607,1,22.19);
INSERT INTO items VALUES (394,3,3,560,3,68.73);
INSERT INTO items VALUES (394,3,4,427,12,220.11);
INSERT INTO items VALUES (394,3,5,432,1,25.45);
INSERT INTO items VALUES (394,3,6,925,3,50.91);
INSERT INTO items VALUES (395,1,1,92,2,58.52);
INSERT INTO items VALUES (395,1,2,1031,1,6.87);
INSERT INTO items VALUES (395,1,3,212,1,29.80);
INSERT INTO items VALUES (396,1,1,427,3,60.03);
INSERT INTO items VALUES (396,2,1,975,3,27.60);
INSERT INTO items VALUES (396,2,2,443,2,58.64);
INSERT INTO items VALUES (396,2,3,46,3,47.01);
INSERT INTO items VALUES (396,2,4,81,2,51.04);
INSERT INTO items VALUES (396,3,1,143,1,12.49);
INSERT INTO items VALUES (396,3,2,185,3,47.76);
INSERT INTO items VALUES (396,3,3,202,2,20.16);
INSERT INTO items VALUES (396,4,1,345,1,8.23);
INSERT INTO items VALUES (396,4,2,949,2,21.54);
INSERT INTO items VALUES (397,1,1,199,3,60.84);
INSERT INTO items VALUES (397,1,2,438,12,117.37);
INSERT INTO items VALUES (397,1,3,55,12,235.51);
INSERT INTO items VALUES (397,1,4,1009,1,22.13);
INSERT INTO items VALUES (397,2,1,603,2,11.56);
INSERT INTO items VALUES (397,2,2,127,12,196.46);
INSERT INTO items VALUES (397,2,3,637,2,29.12);
INSERT INTO items VALUES (397,3,1,313,12,222.42);
INSERT INTO items VALUES (397,3,2,631,2,10.00);
INSERT INTO items VALUES (397,3,3,410,1,17.54);
INSERT INTO items VALUES (397,3,4,330,2,41.20);
INSERT INTO items VALUES (397,3,5,847,2,37.58);
INSERT INTO items VALUES (397,3,6,545,12,188.10);
INSERT INTO items VALUES (397,4,1,978,3,30.15);
INSERT INTO items VALUES (397,4,2,611,3,63.96);
INSERT INTO items VALUES (397,4,3,976,2,20.82);
INSERT INTO items VALUES (397,4,4,425,12,174.35);
INSERT INTO items VALUES (397,4,5,429,12,181.72);
INSERT INTO items VALUES (397,5,1,29,1,20.97);
INSERT INTO items VALUES (397,5,2,240,12,125.84);
INSERT INTO items VALUES (397,5,3,342,3,33.66);
INSERT INTO items VALUES (397,5,4,639,1,23.53);
INSERT INTO items VALUES (397,5,5,561,3,25.92);
INSERT INTO items VALUES (398,1,1,932,1,21.07);
INSERT INTO items VALUES (398,1,2,70,12,176.55);
INSERT INTO items VALUES (398,1,3,442,1,13.67);
INSERT INTO items VALUES (398,1,4,337,12,183.92);
INSERT INTO items VALUES (398,2,1,763,3,23.04);
INSERT INTO items VALUES (398,3,1,209,2,29.60);
INSERT INTO items VALUES (398,3,2,25,2,29.82);
INSERT INTO items VALUES (398,3,3,283,3,86.49);
INSERT INTO items VALUES (398,3,4,1030,1,21.21);
INSERT INTO items VALUES (398,3,5,750,1,6.57);
INSERT INTO items VALUES (398,3,6,967,1,7.48);
INSERT INTO items VALUES (399,1,1,698,2,31.00);
INSERT INTO items VALUES (399,1,2,194,2,30.20);
INSERT INTO items VALUES (399,1,3,776,3,70.89);
INSERT INTO items VALUES (400,1,1,200,2,23.76);
INSERT INTO items VALUES (400,1,2,1006,1,20.16);
INSERT INTO items VALUES (400,2,1,815,3,19.32);
INSERT INTO items VALUES (400,2,2,593,3,20.52);
INSERT INTO items VALUES (400,2,3,980,1,22.32);
INSERT INTO items VALUES (400,2,4,256,2,56.02);
INSERT INTO items VALUES (400,3,1,1033,3,88.11);
INSERT INTO items VALUES (400,3,2,428,12,68.64);
INSERT INTO items VALUES (400,3,3,882,3,65.07);
INSERT INTO items VALUES (400,3,4,298,12,271.04);
INSERT INTO items VALUES (400,4,1,730,1,24.66);
INSERT INTO items VALUES (400,4,2,937,2,11.50);
INSERT INTO items VALUES (400,5,1,184,2,54.22);
INSERT INTO items VALUES (400,5,2,813,3,29.04);
INSERT INTO items VALUES (400,5,3,941,12,182.27);
INSERT INTO items VALUES (401,1,1,808,1,25.86);
INSERT INTO items VALUES (401,1,2,703,12,294.47);
INSERT INTO items VALUES (401,1,3,542,12,214.72);
INSERT INTO items VALUES (401,1,4,582,3,62.64);
INSERT INTO items VALUES (401,1,5,886,12,192.83);
INSERT INTO items VALUES (402,1,1,995,2,28.16);
INSERT INTO items VALUES (402,1,2,530,12,157.52);
INSERT INTO items VALUES (402,1,3,150,3,25.98);
INSERT INTO items VALUES (402,1,4,159,12,162.36);
INSERT INTO items VALUES (402,1,5,595,1,28.95);
INSERT INTO items VALUES (402,1,6,993,2,48.74);
INSERT INTO items VALUES (402,2,1,139,3,46.62);
INSERT INTO items VALUES (402,2,2,209,12,162.80);
INSERT INTO items VALUES (402,2,3,913,12,238.48);
INSERT INTO items VALUES (403,1,1,170,2,19.50);
INSERT INTO items VALUES (403,1,2,117,12,274.23);
INSERT INTO items VALUES (403,1,3,614,1,8.93);
INSERT INTO items VALUES (403,1,4,362,3,68.76);
INSERT INTO items VALUES (403,1,5,1008,3,85.95);
INSERT INTO items VALUES (403,1,6,392,3,39.51);
INSERT INTO items VALUES (404,1,1,353,12,272.69);
INSERT INTO items VALUES (404,1,2,214,2,55.90);
INSERT INTO items VALUES (404,2,1,732,1,27.09);
INSERT INTO items VALUES (404,2,2,464,2,30.14);
INSERT INTO items VALUES (405,1,1,733,2,19.42);
INSERT INTO items VALUES (405,2,1,729,1,6.71);
INSERT INTO items VALUES (405,3,1,173,1,26.52);
INSERT INTO items VALUES (405,4,1,503,12,272.69);
INSERT INTO items VALUES (406,1,1,588,3,34.38);
INSERT INTO items VALUES (406,1,2,775,2,21.32);
INSERT INTO items VALUES (406,1,3,655,1,21.32);
INSERT INTO items VALUES (406,1,4,761,3,56.64);
INSERT INTO items VALUES (406,2,1,347,12,116.49);
INSERT INTO items VALUES (406,2,2,703,2,53.54);
INSERT INTO items VALUES (406,2,3,498,3,49.44);
INSERT INTO items VALUES (406,2,4,914,2,10.46);
INSERT INTO items VALUES (406,2,5,402,2,38.16);
INSERT INTO items VALUES (406,2,6,150,2,17.32);
INSERT INTO items VALUES (406,3,1,649,2,34.18);
INSERT INTO items VALUES (406,3,2,1019,2,25.86);
INSERT INTO items VALUES (406,3,3,930,3,76.53);
INSERT INTO items VALUES (406,3,4,949,12,118.47);
INSERT INTO items VALUES (406,3,5,443,3,87.96);
INSERT INTO items VALUES (406,4,1,738,1,24.22);
INSERT INTO items VALUES (406,4,2,198,1,13.81);
INSERT INTO items VALUES (406,4,3,703,2,53.54);
INSERT INTO items VALUES (406,4,4,597,1,27.67);
INSERT INTO items VALUES (406,4,5,141,3,67.41);
INSERT INTO items VALUES (406,5,1,485,3,68.58);
INSERT INTO items VALUES (406,5,2,498,2,32.96);
INSERT INTO items VALUES (406,5,3,568,12,124.52);
INSERT INTO items VALUES (406,5,4,1044,12,210.32);
INSERT INTO items VALUES (406,5,5,237,12,280.28);
INSERT INTO items VALUES (407,1,1,211,2,35.16);
INSERT INTO items VALUES (408,1,1,79,2,23.94);
INSERT INTO items VALUES (408,1,2,1044,3,57.36);
INSERT INTO items VALUES (408,2,1,621,12,324.06);
INSERT INTO items VALUES (408,2,2,350,12,153.89);
INSERT INTO items VALUES (408,3,1,484,2,57.84);
INSERT INTO items VALUES (408,3,2,142,12,165.00);
INSERT INTO items VALUES (408,3,3,663,2,14.46);
INSERT INTO items VALUES (408,3,4,923,2,29.28);
INSERT INTO items VALUES (408,3,5,658,12,273.68);
INSERT INTO items VALUES (408,3,6,664,3,78.24);
INSERT INTO items VALUES (408,4,1,232,1,14.33);
INSERT INTO items VALUES (408,4,2,160,3,89.76);
INSERT INTO items VALUES (409,1,1,304,3,67.38);
INSERT INTO items VALUES (409,1,2,34,1,14.28);
INSERT INTO items VALUES (409,1,3,364,2,45.58);
INSERT INTO items VALUES (409,1,4,96,3,67.86);
INSERT INTO items VALUES (409,1,5,120,1,5.11);
INSERT INTO items VALUES (409,1,6,292,3,23.52);
INSERT INTO items VALUES (409,2,1,1039,2,52.92);
INSERT INTO items VALUES (409,2,2,406,3,20.16);
INSERT INTO items VALUES (409,3,1,633,2,32.36);
INSERT INTO items VALUES (409,3,2,947,3,58.59);
INSERT INTO items VALUES (409,4,1,182,12,81.73);
INSERT INTO items VALUES (409,4,2,258,12,194.48);
INSERT INTO items VALUES (409,4,3,842,1,28.53);
INSERT INTO items VALUES (409,4,4,785,1,28.11);
INSERT INTO items VALUES (409,4,5,438,3,32.01);
INSERT INTO items VALUES (409,5,1,222,3,72.60);
INSERT INTO items VALUES (409,5,2,672,12,120.12);
INSERT INTO items VALUES (409,5,3,996,3,57.36);
INSERT INTO items VALUES (409,6,1,929,12,207.90);
INSERT INTO items VALUES (409,6,2,823,1,23.20);
INSERT INTO items VALUES (409,6,3,881,3,77.49);
INSERT INTO items VALUES (409,6,4,330,3,61.80);
INSERT INTO items VALUES (409,6,5,711,3,84.21);
INSERT INTO items VALUES (410,1,1,266,3,55.98);
INSERT INTO items VALUES (410,1,2,875,1,13.36);
INSERT INTO items VALUES (410,2,1,904,12,204.93);
INSERT INTO items VALUES (410,2,2,279,3,47.91);
INSERT INTO items VALUES (410,2,3,721,2,10.14);
INSERT INTO items VALUES (411,1,1,1026,1,26.36);
INSERT INTO items VALUES (411,2,1,358,3,51.51);
INSERT INTO items VALUES (411,2,2,219,12,70.95);
INSERT INTO items VALUES (411,2,3,890,2,39.56);
INSERT INTO items VALUES (411,2,4,999,1,17.61);
INSERT INTO items VALUES (411,2,5,255,12,302.28);
INSERT INTO items VALUES (411,3,1,718,12,111.10);
INSERT INTO items VALUES (411,3,2,47,1,24.04);
INSERT INTO items VALUES (411,3,3,870,1,22.89);
INSERT INTO items VALUES (411,3,4,278,3,73.68);
INSERT INTO items VALUES (411,4,1,121,3,87.06);
INSERT INTO items VALUES (411,4,2,541,12,193.82);
INSERT INTO items VALUES (411,4,3,47,2,48.08);
INSERT INTO items VALUES (411,4,4,202,2,20.16);
INSERT INTO items VALUES (412,1,1,491,2,14.66);
INSERT INTO items VALUES (412,1,2,236,3,66.03);
INSERT INTO items VALUES (412,2,1,635,12,235.29);
INSERT INTO items VALUES (412,2,2,1043,2,33.46);
INSERT INTO items VALUES (412,2,3,1030,3,63.63);
INSERT INTO items VALUES (412,2,4,815,12,70.84);
INSERT INTO items VALUES (413,1,1,422,1,19.36);
INSERT INTO items VALUES (413,1,2,128,3,63.75);
INSERT INTO items VALUES (413,1,3,519,3,35.28);
INSERT INTO items VALUES (413,2,1,452,2,15.56);
INSERT INTO items VALUES (413,2,2,996,2,38.24);
INSERT INTO items VALUES (413,2,3,329,1,14.98);
INSERT INTO items VALUES (413,3,1,694,12,173.36);
INSERT INTO items VALUES (413,3,2,201,12,191.18);
INSERT INTO items VALUES (413,3,3,252,3,76.95);
INSERT INTO items VALUES (413,4,1,841,1,25.38);
INSERT INTO items VALUES (413,4,2,615,3,70.71);
INSERT INTO items VALUES (413,4,3,401,1,16.75);
INSERT INTO items VALUES (413,4,4,942,2,56.46);
INSERT INTO items VALUES (413,5,1,897,12,252.89);
INSERT INTO items VALUES (413,5,2,201,3,52.14);
INSERT INTO items VALUES (413,5,3,599,2,11.14);
INSERT INTO items VALUES (413,5,4,442,12,150.37);
INSERT INTO items VALUES (413,5,5,1024,2,39.70);
INSERT INTO items VALUES (414,1,1,965,2,51.70);
INSERT INTO items VALUES (414,1,2,583,12,203.39);
INSERT INTO items VALUES (414,2,1,1012,3,53.55);
INSERT INTO items VALUES (414,2,2,671,3,78.57);
INSERT INTO items VALUES (414,2,3,908,1,11.74);
INSERT INTO items VALUES (414,2,4,318,1,14.12);
INSERT INTO items VALUES (414,2,5,607,1,22.19);
INSERT INTO items VALUES (415,1,1,326,3,39.48);
INSERT INTO items VALUES (415,2,1,835,3,43.68);
INSERT INTO items VALUES (416,1,1,594,12,66.88);
INSERT INTO items VALUES (416,1,2,1004,3,72.54);
INSERT INTO items VALUES (416,1,3,22,12,88.55);
INSERT INTO items VALUES (417,1,1,632,2,32.96);
INSERT INTO items VALUES (417,1,2,891,3,70.80);
INSERT INTO items VALUES (417,1,3,704,12,255.09);
INSERT INTO items VALUES (417,1,4,691,2,58.00);
INSERT INTO items VALUES (417,2,1,933,3,82.41);
INSERT INTO items VALUES (417,2,2,953,3,59.79);
INSERT INTO items VALUES (417,2,3,634,3,23.61);
INSERT INTO items VALUES (417,3,1,766,3,89.58);
INSERT INTO items VALUES (417,4,1,519,1,11.76);
INSERT INTO items VALUES (417,4,2,9,1,24.47);
INSERT INTO items VALUES (417,4,3,273,1,5.93);
INSERT INTO items VALUES (417,5,1,819,12,85.47);
INSERT INTO items VALUES (417,6,1,100,12,258.06);
INSERT INTO items VALUES (417,6,2,562,2,23.30);
INSERT INTO items VALUES (417,6,3,75,1,22.73);
INSERT INTO items VALUES (417,6,4,278,12,270.16);
INSERT INTO items VALUES (417,6,5,492,12,243.10);
INSERT INTO items VALUES (417,6,6,29,2,41.94);
INSERT INTO items VALUES (418,1,1,351,12,280.17);
INSERT INTO items VALUES (418,1,2,811,2,11.50);
INSERT INTO items VALUES (418,1,3,709,1,6.71);
INSERT INTO items VALUES (418,1,4,782,3,36.18);
INSERT INTO items VALUES (418,1,5,434,1,25.44);
INSERT INTO items VALUES (418,1,6,499,3,21.36);
INSERT INTO items VALUES (418,2,1,515,12,275.99);
INSERT INTO items VALUES (418,3,1,554,1,6.30);
INSERT INTO items VALUES (418,4,1,912,1,22.94);
INSERT INTO items VALUES (418,4,2,412,1,6.56);
INSERT INTO items VALUES (418,4,3,759,12,231.77);
INSERT INTO items VALUES (418,4,4,176,3,62.22);
INSERT INTO items VALUES (418,4,5,879,2,17.86);
INSERT INTO items VALUES (418,4,6,793,1,16.37);
INSERT INTO items VALUES (418,5,1,785,1,28.11);
INSERT INTO items VALUES (418,5,2,1045,2,37.52);
INSERT INTO items VALUES (418,5,3,312,1,11.93);
INSERT INTO items VALUES (418,5,4,146,2,42.60);
INSERT INTO items VALUES (418,5,5,89,2,55.70);
INSERT INTO items VALUES (418,6,1,376,2,42.34);
INSERT INTO items VALUES (418,6,2,728,1,5.48);
INSERT INTO items VALUES (418,6,3,742,2,45.58);
INSERT INTO items VALUES (418,6,4,249,1,25.97);
INSERT INTO items VALUES (418,6,5,733,1,9.71);
INSERT INTO items VALUES (418,6,6,643,12,213.07);
INSERT INTO items VALUES (419,1,1,82,12,245.30);
INSERT INTO items VALUES (419,1,2,714,2,51.58);
INSERT INTO items VALUES (419,1,3,936,3,61.02);
INSERT INTO items VALUES (419,1,4,496,1,23.47);
INSERT INTO items VALUES (420,1,1,246,12,204.27);
INSERT INTO items VALUES (420,1,2,820,12,326.26);
INSERT INTO items VALUES (420,1,3,242,2,56.64);
INSERT INTO items VALUES (420,1,4,888,2,11.56);
INSERT INTO items VALUES (420,2,1,552,1,5.30);
INSERT INTO items VALUES (420,2,2,588,12,126.06);
INSERT INTO items VALUES (420,2,3,53,2,53.24);
INSERT INTO items VALUES (420,2,4,357,1,23.64);
INSERT INTO items VALUES (420,2,5,530,12,157.52);
INSERT INTO items VALUES (420,2,6,280,1,18.58);
INSERT INTO items VALUES (421,1,1,45,3,23.13);
INSERT INTO items VALUES (421,1,2,66,2,20.58);
INSERT INTO items VALUES (421,2,1,574,2,37.82);
INSERT INTO items VALUES (421,2,2,320,2,41.84);
INSERT INTO items VALUES (421,2,3,529,3,87.30);
INSERT INTO items VALUES (421,2,4,791,3,15.57);
INSERT INTO items VALUES (421,2,5,121,3,87.06);
INSERT INTO items VALUES (421,3,1,851,3,60.39);
INSERT INTO items VALUES (421,3,2,522,12,80.30);
INSERT INTO items VALUES (421,4,1,162,3,58.92);
INSERT INTO items VALUES (421,4,2,500,3,48.84);
INSERT INTO items VALUES (421,4,3,44,12,244.20);
INSERT INTO items VALUES (421,4,4,122,3,66.39);
INSERT INTO items VALUES (421,4,5,411,12,263.89);
INSERT INTO items VALUES (421,5,1,719,2,20.32);
INSERT INTO items VALUES (421,5,2,478,2,35.66);
INSERT INTO items VALUES (421,6,1,677,12,154.88);
INSERT INTO items VALUES (422,1,1,66,2,20.58);
INSERT INTO items VALUES (422,1,2,512,2,54.98);
INSERT INTO items VALUES (422,1,3,6,1,20.25);
INSERT INTO items VALUES (422,1,4,490,3,24.93);
INSERT INTO items VALUES (422,2,1,51,1,24.09);
INSERT INTO items VALUES (422,2,2,981,3,74.70);
INSERT INTO items VALUES (422,2,3,863,1,13.71);
INSERT INTO items VALUES (422,2,4,217,3,20.49);
INSERT INTO items VALUES (422,2,5,945,1,15.89);
INSERT INTO items VALUES (422,3,1,874,3,58.20);
INSERT INTO items VALUES (422,3,2,59,12,316.91);
INSERT INTO items VALUES (422,3,3,727,3,24.75);
INSERT INTO items VALUES (422,3,4,557,12,149.38);
INSERT INTO items VALUES (422,3,5,172,12,328.79);
INSERT INTO items VALUES (422,4,1,911,12,62.81);
INSERT INTO items VALUES (422,4,2,414,1,22.23);
INSERT INTO items VALUES (422,4,3,571,2,34.50);
INSERT INTO items VALUES (422,5,1,209,3,44.40);
INSERT INTO items VALUES (422,5,2,342,2,22.44);
INSERT INTO items VALUES (422,5,3,554,1,6.30);
INSERT INTO items VALUES (422,5,4,816,1,11.57);
INSERT INTO items VALUES (422,5,5,16,12,98.45);
INSERT INTO items VALUES (422,6,1,508,2,56.96);
INSERT INTO items VALUES (422,6,2,625,12,197.89);
INSERT INTO items VALUES (422,6,3,476,1,5.09);
INSERT INTO items VALUES (422,6,4,183,3,75.81);
INSERT INTO items VALUES (422,6,5,914,3,15.69);
INSERT INTO items VALUES (423,1,1,808,1,25.86);
INSERT INTO items VALUES (423,1,2,565,12,264.22);
INSERT INTO items VALUES (423,1,3,206,2,49.20);
INSERT INTO items VALUES (423,1,4,836,12,178.09);
INSERT INTO items VALUES (423,1,5,714,3,77.37);
INSERT INTO items VALUES (424,1,1,52,3,80.19);
INSERT INTO items VALUES (425,1,1,104,3,19.26);
INSERT INTO items VALUES (425,1,2,515,12,275.99);
INSERT INTO items VALUES (425,1,3,903,1,23.54);
INSERT INTO items VALUES (425,1,4,733,1,9.71);
INSERT INTO items VALUES (425,1,5,534,2,32.30);
INSERT INTO items VALUES (425,2,1,996,2,38.24);
INSERT INTO items VALUES (425,2,2,57,12,193.60);
INSERT INTO items VALUES (425,2,3,330,3,61.80);
INSERT INTO items VALUES (425,2,4,555,1,8.79);
INSERT INTO items VALUES (425,3,1,428,3,18.72);
INSERT INTO items VALUES (425,3,2,831,2,47.22);
INSERT INTO items VALUES (425,3,3,749,2,11.14);
INSERT INTO items VALUES (425,3,4,343,1,5.70);
INSERT INTO items VALUES (425,3,5,1036,2,23.48);
INSERT INTO items VALUES (425,3,6,435,1,11.85);
INSERT INTO items VALUES (425,4,1,752,12,94.49);
INSERT INTO items VALUES (426,1,1,904,2,37.26);
INSERT INTO items VALUES (426,1,2,622,3,52.35);
INSERT INTO items VALUES (426,2,1,528,12,108.24);
INSERT INTO items VALUES (426,2,2,769,12,63.14);
INSERT INTO items VALUES (426,2,3,728,1,5.48);
INSERT INTO items VALUES (426,2,4,917,2,36.86);
INSERT INTO items VALUES (426,2,5,818,12,72.27);
INSERT INTO items VALUES (426,3,1,657,12,191.73);
INSERT INTO items VALUES (426,3,2,48,2,58.12);
INSERT INTO items VALUES (426,3,3,257,3,89.46);
INSERT INTO items VALUES (426,3,4,36,2,59.02);
INSERT INTO items VALUES (426,3,5,525,2,44.18);
INSERT INTO items VALUES (426,3,6,186,3,25.59);
INSERT INTO items VALUES (426,4,1,770,12,173.91);
INSERT INTO items VALUES (426,4,2,849,3,86.88);
INSERT INTO items VALUES (426,4,3,912,12,252.34);
INSERT INTO items VALUES (426,5,1,665,2,13.44);
INSERT INTO items VALUES (426,5,2,353,12,272.69);
INSERT INTO items VALUES (426,5,3,958,2,21.66);
INSERT INTO items VALUES (426,5,4,361,2,25.52);
INSERT INTO items VALUES (426,5,5,697,3,66.27);
INSERT INTO items VALUES (426,5,6,108,2,32.42);
INSERT INTO items VALUES (427,1,1,314,2,49.84);
INSERT INTO items VALUES (427,1,2,192,2,44.74);
INSERT INTO items VALUES (427,2,1,145,1,26.47);
INSERT INTO items VALUES (427,2,2,974,1,6.37);
INSERT INTO items VALUES (427,2,3,54,2,40.62);
INSERT INTO items VALUES (427,2,4,379,2,16.78);
INSERT INTO items VALUES (427,3,1,302,1,22.70);
INSERT INTO items VALUES (427,3,2,18,1,8.45);
INSERT INTO items VALUES (427,3,3,568,2,22.64);
INSERT INTO items VALUES (427,3,4,299,3,39.69);
INSERT INTO items VALUES (428,1,1,57,1,17.60);
INSERT INTO items VALUES (428,2,1,330,2,41.20);
INSERT INTO items VALUES (428,2,2,776,3,70.89);
INSERT INTO items VALUES (428,3,1,629,1,24.19);
INSERT INTO items VALUES (428,3,2,684,1,22.55);
INSERT INTO items VALUES (428,3,3,2,1,28.15);
INSERT INTO items VALUES (428,3,4,413,3,55.02);
INSERT INTO items VALUES (428,3,5,1027,2,57.46);
INSERT INTO items VALUES (428,3,6,726,1,28.51);
INSERT INTO items VALUES (428,4,1,486,12,174.57);
INSERT INTO items VALUES (428,4,2,1019,1,12.93);
INSERT INTO items VALUES (428,4,3,469,1,26.88);
INSERT INTO items VALUES (428,4,4,494,2,56.70);
INSERT INTO items VALUES (428,4,5,540,12,295.35);
INSERT INTO items VALUES (429,1,1,972,12,266.31);
INSERT INTO items VALUES (429,2,1,30,3,24.48);
INSERT INTO items VALUES (429,2,2,856,3,15.87);
INSERT INTO items VALUES (430,1,1,337,2,33.44);
INSERT INTO items VALUES (430,1,2,717,12,263.12);
INSERT INTO items VALUES (430,1,3,858,1,5.33);
INSERT INTO items VALUES (431,1,1,238,2,48.30);
INSERT INTO items VALUES (431,1,2,792,3,19.47);
INSERT INTO items VALUES (431,1,3,634,12,86.57);
INSERT INTO items VALUES (431,1,4,253,2,56.48);
INSERT INTO items VALUES (431,1,5,511,2,29.44);
INSERT INTO items VALUES (431,2,1,306,3,79.41);
INSERT INTO items VALUES (431,2,2,348,1,18.36);
INSERT INTO items VALUES (431,2,3,534,2,32.30);
INSERT INTO items VALUES (431,2,4,958,12,119.13);
INSERT INTO items VALUES (431,3,1,430,3,31.41);
INSERT INTO items VALUES (431,3,2,473,1,7.28);
INSERT INTO items VALUES (431,3,3,371,3,46.47);
INSERT INTO items VALUES (431,3,4,455,12,318.89);
INSERT INTO items VALUES (431,3,5,1015,3,85.05);
INSERT INTO items VALUES (431,4,1,421,3,42.90);
INSERT INTO items VALUES (431,4,2,338,12,267.08);
INSERT INTO items VALUES (431,5,1,261,3,46.11);
INSERT INTO items VALUES (431,5,2,531,3,74.34);
INSERT INTO items VALUES (431,5,3,311,12,266.42);
INSERT INTO items VALUES (431,5,4,705,3,29.91);
INSERT INTO items VALUES (431,5,5,681,1,28.12);
INSERT INTO items VALUES (431,6,1,851,3,60.39);
INSERT INTO items VALUES (431,6,2,775,1,10.66);
INSERT INTO items VALUES (431,6,3,458,1,8.01);
INSERT INTO items VALUES (432,1,1,744,3,40.62);
INSERT INTO items VALUES (432,1,2,1040,2,56.24);
INSERT INTO items VALUES (432,1,3,868,12,128.70);
INSERT INTO items VALUES (433,1,1,333,1,16.64);
INSERT INTO items VALUES (433,1,2,983,1,26.11);
INSERT INTO items VALUES (433,1,3,904,3,55.89);
INSERT INTO items VALUES (434,1,1,520,1,10.01);
INSERT INTO items VALUES (434,1,2,148,1,13.24);
INSERT INTO items VALUES (434,1,3,729,1,6.71);
INSERT INTO items VALUES (434,1,4,602,3,35.16);
INSERT INTO items VALUES (434,2,1,564,2,37.78);
INSERT INTO items VALUES (434,2,2,223,3,39.12);
INSERT INTO items VALUES (434,2,3,391,2,58.10);
INSERT INTO items VALUES (434,2,4,558,1,28.59);
INSERT INTO items VALUES (434,2,5,716,12,152.35);
INSERT INTO items VALUES (434,2,6,826,1,20.90);
INSERT INTO items VALUES (434,3,1,548,2,10.24);
INSERT INTO items VALUES (434,3,2,683,1,9.19);
INSERT INTO items VALUES (434,3,3,930,3,76.53);
INSERT INTO items VALUES (434,3,4,745,12,112.86);
INSERT INTO items VALUES (435,1,1,696,12,72.82);
INSERT INTO items VALUES (435,1,2,223,3,39.12);
INSERT INTO items VALUES (435,1,3,573,1,20.36);
INSERT INTO items VALUES (435,1,4,525,3,66.27);
INSERT INTO items VALUES (435,1,5,803,2,41.38);
INSERT INTO items VALUES (435,2,1,328,2,39.18);
INSERT INTO items VALUES (435,2,2,131,1,18.74);
INSERT INTO items VALUES (435,3,1,166,2,16.52);
INSERT INTO items VALUES (435,3,2,137,12,141.35);
INSERT INTO items VALUES (435,3,3,161,2,37.26);
INSERT INTO items VALUES (436,1,1,310,12,112.86);
INSERT INTO items VALUES (436,1,2,488,12,56.10);
INSERT INTO items VALUES (436,1,3,169,3,29.25);
INSERT INTO items VALUES (436,1,4,284,2,17.78);
INSERT INTO items VALUES (436,2,1,569,2,26.80);
INSERT INTO items VALUES (436,2,2,905,12,125.84);
INSERT INTO items VALUES (436,2,3,427,3,60.03);
INSERT INTO items VALUES (436,2,4,1033,12,323.07);
INSERT INTO items VALUES (436,2,5,231,3,52.68);
INSERT INTO items VALUES (436,3,1,643,1,19.37);
INSERT INTO items VALUES (436,3,2,566,12,77.44);
INSERT INTO items VALUES (436,3,3,880,12,292.82);
INSERT INTO items VALUES (436,3,4,202,3,30.24);
INSERT INTO items VALUES (436,4,1,716,1,13.85);
INSERT INTO items VALUES (436,4,2,290,1,8.91);
INSERT INTO items VALUES (436,4,3,794,2,21.04);
INSERT INTO items VALUES (437,1,1,727,12,90.75);
INSERT INTO items VALUES (437,1,2,484,12,318.12);
INSERT INTO items VALUES (437,1,3,405,1,6.46);
INSERT INTO items VALUES (437,1,4,703,1,26.77);
INSERT INTO items VALUES (437,1,5,448,2,11.56);
INSERT INTO items VALUES (437,1,6,338,1,24.28);
INSERT INTO items VALUES (437,2,1,989,1,12.09);
INSERT INTO items VALUES (437,3,1,180,2,37.14);
INSERT INTO items VALUES (437,4,1,383,3,56.67);
INSERT INTO items VALUES (437,4,2,64,3,78.99);
INSERT INTO items VALUES (437,4,3,17,1,25.23);
INSERT INTO items VALUES (437,4,4,567,1,12.37);
INSERT INTO items VALUES (437,5,1,615,1,23.57);
INSERT INTO items VALUES (437,5,2,824,2,57.12);
INSERT INTO items VALUES (437,5,3,211,12,193.38);
INSERT INTO items VALUES (437,5,4,556,2,11.56);
INSERT INTO items VALUES (437,5,5,58,2,53.20);
INSERT INTO items VALUES (437,6,1,377,3,89.19);
INSERT INTO items VALUES (437,6,2,1046,2,22.00);
INSERT INTO items VALUES (438,1,1,387,2,30.86);
INSERT INTO items VALUES (438,1,2,444,2,36.32);
INSERT INTO items VALUES (438,1,3,235,12,240.35);
INSERT INTO items VALUES (438,1,4,653,1,28.87);
INSERT INTO items VALUES (438,1,5,414,12,244.53);
INSERT INTO items VALUES (438,1,6,70,12,176.55);
INSERT INTO items VALUES (438,2,1,270,12,225.06);
INSERT INTO items VALUES (438,2,2,479,3,35.10);
INSERT INTO items VALUES (438,2,3,430,12,115.17);
INSERT INTO items VALUES (438,3,1,661,2,22.16);
INSERT INTO items VALUES (438,4,1,976,3,31.23);
INSERT INTO items VALUES (438,4,2,426,1,8.67);
INSERT INTO items VALUES (439,1,1,996,3,57.36);
INSERT INTO items VALUES (439,1,2,503,1,24.79);
INSERT INTO items VALUES (439,1,3,172,3,89.67);
INSERT INTO items VALUES (439,2,1,880,1,26.62);
INSERT INTO items VALUES (439,2,2,879,3,26.79);
INSERT INTO items VALUES (439,2,3,878,1,22.43);
INSERT INTO items VALUES (439,2,4,665,2,13.44);
INSERT INTO items VALUES (440,1,1,283,3,86.49);
INSERT INTO items VALUES (440,1,2,134,12,246.95);
INSERT INTO items VALUES (440,2,1,407,2,37.96);
INSERT INTO items VALUES (440,3,1,941,3,49.71);
INSERT INTO items VALUES (441,1,1,457,2,42.00);
INSERT INTO items VALUES (441,1,2,862,3,20.13);
INSERT INTO items VALUES (441,2,1,557,3,40.74);
INSERT INTO items VALUES (441,2,2,212,3,89.40);
INSERT INTO items VALUES (441,2,3,637,2,29.12);
INSERT INTO items VALUES (441,2,4,951,2,49.06);
INSERT INTO items VALUES (441,2,5,454,1,28.31);
INSERT INTO items VALUES (441,3,1,726,3,85.53);
INSERT INTO items VALUES (442,1,1,556,2,11.56);
INSERT INTO items VALUES (442,1,2,788,2,21.46);
INSERT INTO items VALUES (442,1,3,914,2,10.46);
INSERT INTO items VALUES (442,1,4,535,2,39.66);
INSERT INTO items VALUES (442,2,1,464,12,165.77);
INSERT INTO items VALUES (442,2,2,528,12,108.24);
INSERT INTO items VALUES (442,2,3,477,3,71.67);
INSERT INTO items VALUES (442,2,4,596,1,18.47);
INSERT INTO items VALUES (442,2,5,886,3,52.59);
INSERT INTO items VALUES (443,1,1,750,1,6.57);
INSERT INTO items VALUES (443,1,2,176,1,20.74);
INSERT INTO items VALUES (443,2,1,514,1,16.18);
INSERT INTO items VALUES (443,2,2,368,2,56.74);
INSERT INTO items VALUES (443,2,3,695,1,24.03);
INSERT INTO items VALUES (443,2,4,910,1,28.29);
INSERT INTO items VALUES (443,2,5,834,12,248.16);
INSERT INTO items VALUES (443,2,6,22,2,16.10);
INSERT INTO items VALUES (443,3,1,282,3,83.49);
INSERT INTO items VALUES (443,3,2,851,2,40.26);
INSERT INTO items VALUES (443,3,3,614,2,17.86);
INSERT INTO items VALUES (443,3,4,101,3,26.19);
INSERT INTO items VALUES (443,3,5,879,1,8.93);
INSERT INTO items VALUES (443,4,1,341,12,191.40);
INSERT INTO items VALUES (443,4,2,935,1,28.56);
INSERT INTO items VALUES (443,4,3,891,12,259.60);
INSERT INTO items VALUES (443,4,4,641,12,214.17);
INSERT INTO items VALUES (443,4,5,976,2,20.82);
INSERT INTO items VALUES (443,5,1,639,2,47.06);
INSERT INTO items VALUES (443,5,2,829,3,31.80);
INSERT INTO items VALUES (443,5,3,9,3,73.41);
INSERT INTO items VALUES (443,6,1,704,12,255.09);
INSERT INTO items VALUES (443,6,2,525,3,66.27);
INSERT INTO items VALUES (443,6,3,964,2,26.66);
INSERT INTO items VALUES (443,6,4,498,3,49.44);
INSERT INTO items VALUES (444,1,1,249,1,25.97);
INSERT INTO items VALUES (444,1,2,99,3,73.20);
INSERT INTO items VALUES (444,1,3,878,12,246.73);
INSERT INTO items VALUES (445,1,1,780,1,7.31);
INSERT INTO items VALUES (445,1,2,124,1,27.42);
INSERT INTO items VALUES (445,2,1,615,3,70.71);
INSERT INTO items VALUES (445,2,2,4,12,232.76);
INSERT INTO items VALUES (445,2,3,259,2,21.04);
INSERT INTO items VALUES (445,2,4,182,2,14.86);
INSERT INTO items VALUES (445,2,5,610,12,65.56);
INSERT INTO items VALUES (445,3,1,226,12,95.48);
INSERT INTO items VALUES (445,3,2,793,12,180.07);
INSERT INTO items VALUES (445,3,3,50,12,171.82);
INSERT INTO items VALUES (445,4,1,879,1,8.93);
INSERT INTO items VALUES (445,4,2,158,12,147.29);
INSERT INTO items VALUES (445,4,3,2,2,56.30);
INSERT INTO items VALUES (445,5,1,692,2,35.80);
INSERT INTO items VALUES (445,5,2,352,12,107.25);
INSERT INTO items VALUES (446,1,1,617,2,24.18);
INSERT INTO items VALUES (446,1,2,532,3,83.64);
INSERT INTO items VALUES (446,1,3,919,1,13.35);
INSERT INTO items VALUES (446,1,4,599,12,61.27);
INSERT INTO items VALUES (446,1,5,162,2,39.28);
INSERT INTO items VALUES (446,2,1,65,12,109.78);
INSERT INTO items VALUES (446,2,2,877,2,38.30);
INSERT INTO items VALUES (446,3,1,136,2,50.70);
INSERT INTO items VALUES (446,3,2,55,3,64.23);
INSERT INTO items VALUES (446,3,3,871,3,30.66);
INSERT INTO items VALUES (446,4,1,621,2,58.92);
INSERT INTO items VALUES (446,4,2,185,3,47.76);
INSERT INTO items VALUES (446,4,3,534,12,177.65);
INSERT INTO items VALUES (446,5,1,403,12,274.78);
INSERT INTO items VALUES (446,5,2,881,2,51.66);
INSERT INTO items VALUES (446,5,3,236,12,242.11);
INSERT INTO items VALUES (446,6,1,420,1,28.55);
INSERT INTO items VALUES (446,6,2,998,1,12.30);
INSERT INTO items VALUES (447,1,1,490,2,16.62);
INSERT INTO items VALUES (447,2,1,243,3,58.05);
INSERT INTO items VALUES (447,3,1,937,1,5.75);
INSERT INTO items VALUES (447,3,2,102,12,73.81);
INSERT INTO items VALUES (447,3,3,175,3,76.80);
INSERT INTO items VALUES (447,3,4,408,3,47.85);
INSERT INTO items VALUES (447,3,5,484,3,86.76);
INSERT INTO items VALUES (447,3,6,471,1,28.64);
INSERT INTO items VALUES (447,4,1,348,1,18.36);
INSERT INTO items VALUES (447,4,2,95,3,87.57);
INSERT INTO items VALUES (447,4,3,741,1,12.89);
INSERT INTO items VALUES (447,4,4,586,3,53.10);
INSERT INTO items VALUES (447,4,5,4,1,21.16);
INSERT INTO items VALUES (447,4,6,176,12,228.14);
INSERT INTO items VALUES (448,1,1,200,12,130.68);
INSERT INTO items VALUES (448,1,2,405,2,12.92);
INSERT INTO items VALUES (448,1,3,734,2,36.62);
INSERT INTO items VALUES (448,1,4,718,2,20.20);
INSERT INTO items VALUES (448,1,5,769,3,17.22);
INSERT INTO items VALUES (448,1,6,306,1,26.47);
INSERT INTO items VALUES (449,1,1,352,1,9.75);
INSERT INTO items VALUES (449,1,2,557,2,27.16);
INSERT INTO items VALUES (449,1,3,341,3,52.20);
INSERT INTO items VALUES (449,1,4,279,3,47.91);
INSERT INTO items VALUES (449,2,1,168,2,48.74);
INSERT INTO items VALUES (449,2,2,446,3,64.32);
INSERT INTO items VALUES (449,2,3,69,12,182.71);
INSERT INTO items VALUES (449,2,4,835,1,14.56);
INSERT INTO items VALUES (449,2,5,717,1,23.92);
INSERT INTO items VALUES (449,3,1,161,12,204.93);
INSERT INTO items VALUES (449,3,2,690,2,40.14);
INSERT INTO items VALUES (449,4,1,969,12,153.23);
INSERT INTO items VALUES (449,4,2,1033,1,29.37);
INSERT INTO items VALUES (449,5,1,67,3,83.40);
INSERT INTO items VALUES (449,5,2,155,1,24.83);
INSERT INTO items VALUES (449,5,3,345,1,8.23);
INSERT INTO items VALUES (450,1,1,999,1,17.61);
INSERT INTO items VALUES (450,2,1,446,12,235.84);
INSERT INTO items VALUES (451,1,1,748,1,22.76);
INSERT INTO items VALUES (451,1,2,305,12,57.97);
INSERT INTO items VALUES (451,1,3,254,12,248.05);
INSERT INTO items VALUES (451,1,4,186,3,25.59);
INSERT INTO items VALUES (451,1,5,570,1,25.09);
INSERT INTO items VALUES (451,1,6,476,3,15.27);
INSERT INTO items VALUES (451,2,1,74,2,25.12);
INSERT INTO items VALUES (451,2,2,359,12,204.71);
INSERT INTO items VALUES (451,2,3,834,2,45.12);
INSERT INTO items VALUES (451,2,4,172,3,89.67);
INSERT INTO items VALUES (451,2,5,791,3,15.57);
INSERT INTO items VALUES (451,2,6,475,3,86.52);
INSERT INTO items VALUES (451,3,1,348,3,55.08);
INSERT INTO items VALUES (451,3,2,663,12,79.53);
INSERT INTO items VALUES (451,3,3,97,12,133.21);
INSERT INTO items VALUES (452,1,1,655,3,63.96);
INSERT INTO items VALUES (452,1,2,1028,12,152.90);
INSERT INTO items VALUES (452,2,1,530,2,28.64);
INSERT INTO items VALUES (453,1,1,56,1,12.83);
INSERT INTO items VALUES (453,1,2,645,2,36.26);
INSERT INTO items VALUES (453,1,3,500,1,16.28);
INSERT INTO items VALUES (453,2,1,382,2,14.18);
INSERT INTO items VALUES (453,2,2,39,1,7.38);
INSERT INTO items VALUES (453,2,3,1044,1,19.12);
INSERT INTO items VALUES (454,1,1,373,2,51.14);
INSERT INTO items VALUES (454,1,2,288,3,44.85);
INSERT INTO items VALUES (454,1,3,479,2,23.40);
INSERT INTO items VALUES (454,1,4,332,12,278.19);
INSERT INTO items VALUES (454,1,5,902,3,32.31);
INSERT INTO items VALUES (454,1,6,260,3,22.02);
INSERT INTO items VALUES (454,2,1,244,2,24.42);
INSERT INTO items VALUES (454,2,2,503,2,49.58);
INSERT INTO items VALUES (454,2,3,15,2,24.66);
INSERT INTO items VALUES (454,3,1,905,12,125.84);
INSERT INTO items VALUES (454,4,1,541,12,193.82);
INSERT INTO items VALUES (454,4,2,45,1,7.71);
INSERT INTO items VALUES (454,4,3,891,1,23.60);
INSERT INTO items VALUES (454,4,4,465,1,8.00);
INSERT INTO items VALUES (455,1,1,750,2,13.14);
INSERT INTO items VALUES (455,1,2,512,1,27.49);
INSERT INTO items VALUES (455,1,3,13,3,52.80);
INSERT INTO items VALUES (455,1,4,41,12,186.89);
INSERT INTO items VALUES (455,1,5,224,2,47.84);
INSERT INTO items VALUES (455,2,1,905,2,22.88);
INSERT INTO items VALUES (455,2,2,300,12,290.18);
INSERT INTO items VALUES (455,2,3,873,3,61.95);
INSERT INTO items VALUES (455,3,1,325,3,39.63);
INSERT INTO items VALUES (455,4,1,537,1,26.30);
INSERT INTO items VALUES (455,4,2,868,12,128.70);
INSERT INTO items VALUES (455,4,3,836,2,32.38);
INSERT INTO items VALUES (456,1,1,675,12,241.23);
INSERT INTO items VALUES (456,2,1,326,1,13.16);
INSERT INTO items VALUES (456,2,2,268,1,9.15);
INSERT INTO items VALUES (456,2,3,661,3,33.24);
INSERT INTO items VALUES (456,3,1,357,2,47.28);
INSERT INTO items VALUES (456,3,2,841,1,25.38);
INSERT INTO items VALUES (456,3,3,873,1,20.65);
INSERT INTO items VALUES (456,3,4,350,1,13.99);
INSERT INTO items VALUES (456,3,5,308,12,143.66);
INSERT INTO items VALUES (456,3,6,183,12,277.97);
INSERT INTO items VALUES (456,4,1,614,12,98.23);
INSERT INTO items VALUES (456,4,2,958,1,10.83);
INSERT INTO items VALUES (456,4,3,397,12,125.18);
INSERT INTO items VALUES (456,4,4,326,2,26.32);
INSERT INTO items VALUES (456,4,5,917,1,18.43);
INSERT INTO items VALUES (457,1,1,105,3,67.23);
INSERT INTO items VALUES (457,1,2,1011,1,11.12);
INSERT INTO items VALUES (457,1,3,939,12,158.07);
INSERT INTO items VALUES (457,1,4,925,3,50.91);
INSERT INTO items VALUES (457,1,5,42,2,42.56);
INSERT INTO items VALUES (457,2,1,852,12,286.99);
INSERT INTO items VALUES (457,2,2,164,2,18.80);
INSERT INTO items VALUES (457,2,3,870,2,45.78);
INSERT INTO items VALUES (457,2,4,545,3,51.30);
INSERT INTO items VALUES (457,2,5,1008,1,28.65);
INSERT INTO items VALUES (457,2,6,113,3,57.75);
INSERT INTO items VALUES (458,1,1,824,12,314.16);
INSERT INTO items VALUES (458,1,2,745,1,10.26);
INSERT INTO items VALUES (458,1,3,992,2,21.02);
INSERT INTO items VALUES (458,1,4,439,3,57.39);
INSERT INTO items VALUES (458,1,5,790,3,37.29);
INSERT INTO items VALUES (458,2,1,360,12,131.34);
INSERT INTO items VALUES (458,2,2,971,3,59.43);
INSERT INTO items VALUES (458,2,3,25,3,44.73);
INSERT INTO items VALUES (458,2,4,198,12,151.91);
INSERT INTO items VALUES (458,2,5,505,3,82.89);
INSERT INTO items VALUES (458,2,6,571,2,34.50);
INSERT INTO items VALUES (458,3,1,257,12,328.02);
INSERT INTO items VALUES (458,3,2,299,12,145.53);
INSERT INTO items VALUES (458,3,3,356,3,67.29);
INSERT INTO items VALUES (458,3,4,593,12,75.24);
INSERT INTO items VALUES (458,3,5,296,2,19.90);
INSERT INTO items VALUES (458,4,1,867,2,31.36);
INSERT INTO items VALUES (458,5,1,906,3,30.99);
INSERT INTO items VALUES (458,5,2,663,1,7.23);
INSERT INTO items VALUES (458,5,3,370,12,68.20);
INSERT INTO items VALUES (458,5,4,1045,3,56.28);
INSERT INTO items VALUES (458,5,5,918,2,31.40);
INSERT INTO items VALUES (459,1,1,548,1,5.12);
INSERT INTO items VALUES (459,1,2,854,3,74.25);
INSERT INTO items VALUES (459,1,3,913,2,43.36);
INSERT INTO items VALUES (459,1,4,644,1,28.46);
INSERT INTO items VALUES (459,2,1,465,12,88.00);
INSERT INTO items VALUES (459,2,2,157,2,48.12);
INSERT INTO items VALUES (459,2,3,1000,12,76.01);
INSERT INTO items VALUES (459,2,4,206,2,49.20);
INSERT INTO items VALUES (459,2,5,137,3,38.55);
INSERT INTO items VALUES (459,3,1,703,12,294.47);
INSERT INTO items VALUES (459,3,2,79,3,35.91);
INSERT INTO items VALUES (459,3,3,105,3,67.23);
INSERT INTO items VALUES (460,1,1,53,2,53.24);
INSERT INTO items VALUES (460,1,2,496,2,46.94);
INSERT INTO items VALUES (460,2,1,151,3,67.11);
INSERT INTO items VALUES (460,3,1,1029,3,45.57);
INSERT INTO items VALUES (460,3,2,72,3,74.88);
INSERT INTO items VALUES (460,3,3,21,12,210.54);
INSERT INTO items VALUES (460,4,1,359,12,204.71);
INSERT INTO items VALUES (460,4,2,154,3,17.91);
INSERT INTO items VALUES (460,4,3,480,3,86.67);
INSERT INTO items VALUES (460,4,4,1039,3,79.38);
INSERT INTO items VALUES (460,4,5,721,1,5.07);
INSERT INTO items VALUES (460,4,6,352,3,29.25);
INSERT INTO items VALUES (460,5,1,241,2,33.90);
INSERT INTO items VALUES (460,5,2,29,1,20.97);
INSERT INTO items VALUES (461,1,1,9,1,24.47);
INSERT INTO items VALUES (461,1,2,1046,3,33.00);
INSERT INTO items VALUES (461,1,3,564,3,56.67);
INSERT INTO items VALUES (461,1,4,630,1,28.00);
INSERT INTO items VALUES (461,1,5,378,3,89.04);
INSERT INTO items VALUES (461,1,6,562,12,128.15);
INSERT INTO items VALUES (461,2,1,407,2,37.96);
INSERT INTO items VALUES (461,2,2,356,3,67.29);
INSERT INTO items VALUES (462,1,1,112,3,23.85);
INSERT INTO items VALUES (462,1,2,475,3,86.52);
INSERT INTO items VALUES (462,1,3,120,1,5.11);
INSERT INTO items VALUES (462,2,1,446,2,42.88);
INSERT INTO items VALUES (462,2,2,711,3,84.21);
INSERT INTO items VALUES (462,2,3,382,12,77.99);
INSERT INTO items VALUES (462,2,4,1018,12,101.42);
INSERT INTO items VALUES (462,2,5,346,3,21.42);
INSERT INTO items VALUES (462,3,1,53,1,26.62);
INSERT INTO items VALUES (462,3,2,855,3,21.69);
INSERT INTO items VALUES (462,4,1,101,3,26.19);
INSERT INTO items VALUES (462,4,2,22,3,24.15);
INSERT INTO items VALUES (463,1,1,714,2,51.58);
INSERT INTO items VALUES (463,2,1,110,1,12.74);
INSERT INTO items VALUES (463,2,2,163,1,20.38);
INSERT INTO items VALUES (463,2,3,142,12,165.00);
INSERT INTO items VALUES (463,2,4,358,2,34.34);
INSERT INTO items VALUES (463,3,1,409,1,22.34);
INSERT INTO items VALUES (463,3,2,428,1,6.24);
INSERT INTO items VALUES (463,4,1,979,3,85.17);
INSERT INTO items VALUES (463,4,2,457,2,42.00);
INSERT INTO items VALUES (463,4,3,381,3,62.58);
INSERT INTO items VALUES (463,4,4,555,3,26.37);
INSERT INTO items VALUES (463,5,1,545,3,51.30);
INSERT INTO items VALUES (463,5,2,323,3,40.80);
INSERT INTO items VALUES (463,5,3,915,3,37.53);
INSERT INTO items VALUES (463,5,4,645,2,36.26);
INSERT INTO items VALUES (464,1,1,392,3,39.51);
INSERT INTO items VALUES (464,1,2,686,3,58.56);
INSERT INTO items VALUES (464,2,1,782,12,132.66);
INSERT INTO items VALUES (464,2,2,72,2,49.92);
INSERT INTO items VALUES (464,2,3,479,3,35.10);
INSERT INTO items VALUES (464,2,4,702,12,97.02);
INSERT INTO items VALUES (464,2,5,600,2,33.98);
INSERT INTO items VALUES (464,2,6,616,12,136.29);
INSERT INTO items VALUES (464,3,1,249,2,51.94);
INSERT INTO items VALUES (464,3,2,721,12,55.77);
INSERT INTO items VALUES (464,3,3,24,3,55.80);
INSERT INTO items VALUES (464,3,4,90,1,6.77);
INSERT INTO items VALUES (464,3,5,326,12,144.76);
INSERT INTO items VALUES (464,3,6,149,1,14.66);
INSERT INTO items VALUES (464,4,1,532,3,83.64);
INSERT INTO items VALUES (464,4,2,31,1,16.74);
INSERT INTO items VALUES (464,4,3,395,1,16.99);
INSERT INTO items VALUES (464,4,4,494,12,311.85);
INSERT INTO items VALUES (464,5,1,648,1,16.34);
INSERT INTO items VALUES (464,5,2,644,3,85.38);
INSERT INTO items VALUES (464,5,3,454,12,311.41);
INSERT INTO items VALUES (464,5,4,618,3,87.21);
INSERT INTO items VALUES (464,5,5,114,1,22.32);
INSERT INTO items VALUES (464,5,6,683,2,18.38);
INSERT INTO items VALUES (465,1,1,220,1,11.74);
INSERT INTO items VALUES (465,1,2,270,1,20.46);
INSERT INTO items VALUES (465,1,3,279,3,47.91);
INSERT INTO items VALUES (465,1,4,977,2,29.02);
INSERT INTO items VALUES (465,1,5,497,1,21.46);
INSERT INTO items VALUES (465,2,1,404,2,54.02);
INSERT INTO items VALUES (465,2,2,1022,3,18.75);
INSERT INTO items VALUES (465,2,3,978,2,20.10);
INSERT INTO items VALUES (465,2,4,855,1,7.23);
INSERT INTO items VALUES (465,2,5,675,3,65.79);
INSERT INTO items VALUES (465,2,6,851,2,40.26);
INSERT INTO items VALUES (466,1,1,749,2,11.14);
INSERT INTO items VALUES (466,1,2,80,12,312.84);
INSERT INTO items VALUES (466,1,3,749,1,5.57);
INSERT INTO items VALUES (466,1,4,87,3,51.57);
INSERT INTO items VALUES (466,2,1,6,12,222.75);
INSERT INTO items VALUES (466,2,2,805,1,28.56);
INSERT INTO items VALUES (466,2,3,496,2,46.94);
INSERT INTO items VALUES (466,2,4,981,12,273.90);
INSERT INTO items VALUES (466,2,5,53,3,79.86);
INSERT INTO items VALUES (466,2,6,668,3,44.55);
INSERT INTO items VALUES (466,3,1,986,12,72.16);
INSERT INTO items VALUES (466,4,1,929,2,37.80);
INSERT INTO items VALUES (466,4,2,522,12,80.30);
INSERT INTO items VALUES (466,4,3,266,2,37.32);
INSERT INTO items VALUES (466,4,4,16,3,26.85);
INSERT INTO items VALUES (467,1,1,769,1,5.74);
INSERT INTO items VALUES (467,1,2,905,12,125.84);
INSERT INTO items VALUES (467,1,3,193,12,265.98);
INSERT INTO items VALUES (467,1,4,847,12,206.69);
INSERT INTO items VALUES (467,1,5,172,12,328.79);
INSERT INTO items VALUES (467,1,6,362,2,45.84);
INSERT INTO items VALUES (467,2,1,997,3,27.09);
INSERT INTO items VALUES (467,2,2,457,3,63.00);
INSERT INTO items VALUES (467,2,3,412,2,13.12);
INSERT INTO items VALUES (467,3,1,839,3,58.50);
INSERT INTO items VALUES (467,3,2,282,12,306.13);
INSERT INTO items VALUES (467,3,3,558,1,28.59);
INSERT INTO items VALUES (467,4,1,1009,1,22.13);
INSERT INTO items VALUES (467,4,2,248,2,52.36);
INSERT INTO items VALUES (467,4,3,526,1,19.31);
INSERT INTO items VALUES (467,4,4,39,12,81.18);
INSERT INTO items VALUES (467,5,1,263,12,144.32);
INSERT INTO items VALUES (467,5,2,303,1,12.35);
INSERT INTO items VALUES (467,5,3,559,3,20.01);
INSERT INTO items VALUES (467,5,4,37,1,14.15);
INSERT INTO items VALUES (467,5,5,663,12,79.53);
INSERT INTO items VALUES (467,5,6,798,3,88.44);
INSERT INTO items VALUES (468,1,1,705,1,9.97);
INSERT INTO items VALUES (468,2,1,127,1,17.86);
INSERT INTO items VALUES (468,2,2,478,1,17.83);
INSERT INTO items VALUES (469,1,1,430,1,10.47);
INSERT INTO items VALUES (469,1,2,750,1,6.57);
INSERT INTO items VALUES (469,1,3,271,2,13.78);
INSERT INTO items VALUES (469,2,1,744,3,40.62);
INSERT INTO items VALUES (469,2,2,993,3,73.11);
INSERT INTO items VALUES (469,2,3,1007,1,12.34);
INSERT INTO items VALUES (469,3,1,580,3,73.47);
INSERT INTO items VALUES (469,3,2,48,1,29.06);
INSERT INTO items VALUES (469,3,3,159,2,29.52);
INSERT INTO items VALUES (470,1,1,882,1,21.69);
INSERT INTO items VALUES (470,1,2,476,1,5.09);
INSERT INTO items VALUES (470,1,3,890,1,19.78);
INSERT INTO items VALUES (470,1,4,130,2,31.52);
INSERT INTO items VALUES (470,1,5,114,2,44.64);
INSERT INTO items VALUES (470,2,1,346,3,21.42);
INSERT INTO items VALUES (470,2,2,528,3,29.52);
INSERT INTO items VALUES (470,2,3,845,12,177.98);
INSERT INTO items VALUES (470,3,1,857,1,7.84);
INSERT INTO items VALUES (470,3,2,682,2,54.68);
INSERT INTO items VALUES (470,3,3,365,2,16.80);
INSERT INTO items VALUES (470,3,4,440,2,10.70);
INSERT INTO items VALUES (471,1,1,660,12,133.21);
INSERT INTO items VALUES (471,1,2,898,2,44.04);
INSERT INTO items VALUES (471,1,3,271,2,13.78);
INSERT INTO items VALUES (471,1,4,95,1,29.19);
INSERT INTO items VALUES (471,2,1,620,2,51.60);
INSERT INTO items VALUES (471,2,2,906,12,113.63);
INSERT INTO items VALUES (471,3,1,616,3,37.17);
INSERT INTO items VALUES (471,3,2,582,12,229.68);
INSERT INTO items VALUES (471,3,3,90,1,6.77);
INSERT INTO items VALUES (471,3,4,672,12,120.12);
INSERT INTO items VALUES (471,3,5,490,12,91.41);
INSERT INTO items VALUES (471,3,6,325,3,39.63);
INSERT INTO items VALUES (471,4,1,480,3,86.67);
INSERT INTO items VALUES (471,5,1,38,3,17.25);
INSERT INTO items VALUES (471,5,2,351,3,76.41);
INSERT INTO items VALUES (471,5,3,207,12,273.57);
INSERT INTO items VALUES (471,6,1,559,1,6.67);
INSERT INTO items VALUES (472,1,1,206,12,270.60);
INSERT INTO items VALUES (472,1,2,101,3,26.19);
INSERT INTO items VALUES (472,1,3,62,12,185.35);
INSERT INTO items VALUES (472,1,4,600,2,33.98);
INSERT INTO items VALUES (472,1,5,856,1,5.29);
INSERT INTO items VALUES (473,1,1,959,2,20.14);
INSERT INTO items VALUES (473,2,1,878,2,44.86);
INSERT INTO items VALUES (473,2,2,786,3,62.52);
INSERT INTO items VALUES (473,2,3,552,3,15.90);
INSERT INTO items VALUES (473,3,1,55,12,235.51);
INSERT INTO items VALUES (473,3,2,779,2,39.74);
INSERT INTO items VALUES (473,4,1,975,3,27.60);
INSERT INTO items VALUES (473,4,2,75,1,22.73);
INSERT INTO items VALUES (473,4,3,37,12,155.65);
INSERT INTO items VALUES (473,4,4,718,12,111.10);
INSERT INTO items VALUES (473,4,5,232,2,28.66);
INSERT INTO items VALUES (473,5,1,900,3,50.82);
INSERT INTO items VALUES (473,5,2,1029,12,167.09);
INSERT INTO items VALUES (473,5,3,686,3,58.56);
INSERT INTO items VALUES (473,5,4,389,2,35.04);
INSERT INTO items VALUES (473,5,5,435,3,35.55);
INSERT INTO items VALUES (474,1,1,142,1,15.00);
INSERT INTO items VALUES (474,1,2,57,1,17.60);
INSERT INTO items VALUES (474,1,3,492,2,44.20);
INSERT INTO items VALUES (474,2,1,96,12,248.82);
INSERT INTO items VALUES (474,2,2,358,1,17.17);
INSERT INTO items VALUES (474,2,3,572,1,27.49);
INSERT INTO items VALUES (474,3,1,734,12,201.41);
INSERT INTO items VALUES (474,3,2,612,1,29.58);
INSERT INTO items VALUES (474,3,3,192,3,67.11);
INSERT INTO items VALUES (474,4,1,232,12,157.63);
INSERT INTO items VALUES (474,4,2,233,2,11.30);
INSERT INTO items VALUES (474,4,3,272,2,19.20);
INSERT INTO items VALUES (474,4,4,267,3,25.89);
INSERT INTO items VALUES (474,4,5,332,12,278.19);
INSERT INTO items VALUES (474,4,6,697,3,66.27);
INSERT INTO items VALUES (475,1,1,683,12,101.09);
INSERT INTO items VALUES (475,1,2,863,2,27.42);
INSERT INTO items VALUES (475,1,3,75,1,22.73);
INSERT INTO items VALUES (475,1,4,101,12,96.03);
INSERT INTO items VALUES (475,2,1,496,2,46.94);
INSERT INTO items VALUES (475,2,2,653,1,28.87);
INSERT INTO items VALUES (475,2,3,718,2,20.20);
INSERT INTO items VALUES (475,3,1,29,3,62.91);
INSERT INTO items VALUES (475,3,2,366,3,72.36);
INSERT INTO items VALUES (475,3,3,533,1,18.74);
INSERT INTO items VALUES (475,3,4,50,3,46.86);
INSERT INTO items VALUES (475,3,5,243,1,19.35);
INSERT INTO items VALUES (475,4,1,406,1,6.72);
INSERT INTO items VALUES (475,4,2,710,1,29.27);
INSERT INTO items VALUES (476,1,1,504,3,83.16);
INSERT INTO items VALUES (476,1,2,756,1,29.52);
INSERT INTO items VALUES (476,1,3,936,2,40.68);
INSERT INTO items VALUES (476,1,4,765,1,29.88);
INSERT INTO items VALUES (476,1,5,469,2,53.76);
INSERT INTO items VALUES (476,2,1,755,2,26.50);
INSERT INTO items VALUES (476,2,2,751,12,273.79);
INSERT INTO items VALUES (477,1,1,912,12,252.34);
INSERT INTO items VALUES (477,1,2,91,2,23.16);
INSERT INTO items VALUES (477,1,3,509,2,31.16);
INSERT INTO items VALUES (477,1,4,320,12,230.12);
INSERT INTO items VALUES (477,2,1,1021,12,239.47);
INSERT INTO items VALUES (477,3,1,780,3,21.93);
INSERT INTO items VALUES (477,3,2,698,12,170.50);
INSERT INTO items VALUES (477,4,1,1032,12,219.23);
INSERT INTO items VALUES (477,4,2,271,12,75.79);
INSERT INTO items VALUES (477,4,3,983,3,78.33);
INSERT INTO items VALUES (477,4,4,210,2,24.14);
INSERT INTO items VALUES (477,4,5,306,1,26.47);
INSERT INTO items VALUES (477,4,6,379,2,16.78);
INSERT INTO items VALUES (477,5,1,121,2,58.04);
INSERT INTO items VALUES (477,5,2,1019,12,142.23);
INSERT INTO items VALUES (477,5,3,243,3,58.05);
INSERT INTO items VALUES (477,6,1,242,2,56.64);
INSERT INTO items VALUES (478,1,1,602,2,23.44);
INSERT INTO items VALUES (478,1,2,248,1,26.18);
INSERT INTO items VALUES (478,1,3,66,1,10.29);
INSERT INTO items VALUES (478,1,4,763,2,15.36);
INSERT INTO items VALUES (478,1,5,142,1,15.00);
INSERT INTO items VALUES (478,2,1,471,2,57.28);
INSERT INTO items VALUES (478,2,2,341,2,34.80);
INSERT INTO items VALUES (478,3,1,44,3,66.60);
INSERT INTO items VALUES (478,3,2,19,3,87.66);
INSERT INTO items VALUES (478,4,1,429,3,49.56);
INSERT INTO items VALUES (478,4,2,722,2,30.00);
INSERT INTO items VALUES (478,5,1,227,3,50.28);
INSERT INTO items VALUES (478,5,2,844,12,207.02);
INSERT INTO items VALUES (478,6,1,820,2,59.32);
INSERT INTO items VALUES (478,6,2,841,1,25.38);
INSERT INTO items VALUES (478,6,3,84,3,80.52);
INSERT INTO items VALUES (478,6,4,325,3,39.63);
INSERT INTO items VALUES (478,6,5,44,3,66.60);
INSERT INTO items VALUES (478,6,6,115,3,42.06);
INSERT INTO items VALUES (479,1,1,564,3,56.67);
INSERT INTO items VALUES (480,1,1,998,12,135.30);
INSERT INTO items VALUES (480,1,2,170,12,107.25);
INSERT INTO items VALUES (480,1,3,1014,1,13.82);
INSERT INTO items VALUES (480,1,4,500,2,32.56);
INSERT INTO items VALUES (480,1,5,846,3,19.95);
INSERT INTO items VALUES (480,1,6,1045,12,206.36);
INSERT INTO items VALUES (480,2,1,898,3,66.06);
INSERT INTO items VALUES (480,3,1,189,1,16.73);
INSERT INTO items VALUES (480,4,1,379,1,8.39);
INSERT INTO items VALUES (480,4,2,199,12,223.08);
INSERT INTO items VALUES (480,4,3,216,1,23.05);
INSERT INTO items VALUES (480,5,1,994,2,30.88);
INSERT INTO items VALUES (480,5,2,364,2,45.58);
INSERT INTO items VALUES (480,5,3,843,2,16.22);
INSERT INTO items VALUES (480,5,4,675,3,65.79);
INSERT INTO items VALUES (480,5,5,518,12,168.85);
INSERT INTO items VALUES (481,1,1,211,12,193.38);
INSERT INTO items VALUES (481,1,2,196,1,20.65);
INSERT INTO items VALUES (481,1,3,43,2,55.64);
INSERT INTO items VALUES (481,1,4,221,2,24.46);
INSERT INTO items VALUES (481,1,5,265,1,16.73);
INSERT INTO items VALUES (481,1,6,398,12,320.54);
INSERT INTO items VALUES (481,2,1,466,3,35.43);
INSERT INTO items VALUES (481,2,2,22,2,16.10);
INSERT INTO items VALUES (481,2,3,414,2,44.46);
INSERT INTO items VALUES (481,2,4,232,1,14.33);
INSERT INTO items VALUES (481,3,1,360,3,35.82);
INSERT INTO items VALUES (481,3,2,611,3,63.96);
INSERT INTO items VALUES (481,4,1,926,3,73.80);
INSERT INTO items VALUES (481,4,2,398,12,320.54);
INSERT INTO items VALUES (481,4,3,106,12,287.10);
INSERT INTO items VALUES (481,4,4,557,1,13.58);
INSERT INTO items VALUES (481,5,1,758,12,198.66);
INSERT INTO items VALUES (481,5,2,665,2,13.44);
INSERT INTO items VALUES (481,5,3,128,12,233.75);
INSERT INTO items VALUES (482,1,1,529,3,87.30);
INSERT INTO items VALUES (482,1,2,139,1,15.54);
INSERT INTO items VALUES (482,2,1,473,12,80.08);
INSERT INTO items VALUES (482,2,2,165,2,54.34);
INSERT INTO items VALUES (482,2,3,671,3,78.57);
INSERT INTO items VALUES (482,2,4,196,2,41.30);
INSERT INTO items VALUES (482,2,5,172,2,59.78);
INSERT INTO items VALUES (482,2,6,620,1,25.80);
INSERT INTO items VALUES (482,3,1,88,2,29.18);
INSERT INTO items VALUES (482,4,1,771,12,168.85);
INSERT INTO items VALUES (482,4,2,101,1,8.73);
INSERT INTO items VALUES (482,5,1,992,2,21.02);
INSERT INTO items VALUES (482,5,2,478,1,17.83);
INSERT INTO items VALUES (482,5,3,626,12,91.08);
INSERT INTO items VALUES (482,5,4,798,3,88.44);
INSERT INTO items VALUES (482,5,5,615,3,70.71);
INSERT INTO items VALUES (482,5,6,665,3,20.16);
INSERT INTO items VALUES (482,6,1,983,12,287.21);
INSERT INTO items VALUES (482,6,2,582,1,20.88);
INSERT INTO items VALUES (482,6,3,19,2,58.44);
INSERT INTO items VALUES (482,6,4,300,3,79.14);
INSERT INTO items VALUES (482,6,5,739,1,25.28);
INSERT INTO items VALUES (483,1,1,906,1,10.33);
INSERT INTO items VALUES (483,1,2,380,2,54.90);
INSERT INTO items VALUES (483,1,3,686,1,19.52);
INSERT INTO items VALUES (483,1,4,234,12,290.40);
INSERT INTO items VALUES (483,1,5,963,2,50.64);
INSERT INTO items VALUES (483,2,1,906,12,113.63);
INSERT INTO items VALUES (483,2,2,830,3,25.74);
INSERT INTO items VALUES (483,2,3,721,12,55.77);
INSERT INTO items VALUES (483,2,4,38,2,11.50);
INSERT INTO items VALUES (483,3,1,256,2,56.02);
INSERT INTO items VALUES (483,3,2,258,12,194.48);
INSERT INTO items VALUES (483,3,3,472,2,16.72);
INSERT INTO items VALUES (483,3,4,783,2,55.74);
INSERT INTO items VALUES (483,3,5,912,2,45.88);
INSERT INTO items VALUES (483,3,6,403,12,274.78);
INSERT INTO items VALUES (483,4,1,657,2,34.86);
INSERT INTO items VALUES (484,1,1,967,3,22.44);
INSERT INTO items VALUES (484,1,2,1008,2,57.30);
INSERT INTO items VALUES (484,1,3,898,12,242.22);
INSERT INTO items VALUES (484,1,4,828,2,33.02);
INSERT INTO items VALUES (484,1,5,636,1,25.51);
INSERT INTO items VALUES (484,2,1,950,12,121.66);
INSERT INTO items VALUES (484,2,2,508,12,313.28);
INSERT INTO items VALUES (484,2,3,518,12,168.85);
INSERT INTO items VALUES (484,2,4,914,1,5.23);
INSERT INTO items VALUES (484,2,5,421,3,42.90);
INSERT INTO items VALUES (484,2,6,682,2,54.68);
INSERT INTO items VALUES (484,3,1,199,2,40.56);
INSERT INTO items VALUES (484,3,2,231,12,193.16);
INSERT INTO items VALUES (484,3,3,500,2,32.56);
INSERT INTO items VALUES (484,3,4,719,1,10.16);
INSERT INTO items VALUES (484,3,5,624,2,44.50);
INSERT INTO items VALUES (484,3,6,831,2,47.22);
INSERT INTO items VALUES (484,4,1,325,1,13.21);
INSERT INTO items VALUES (484,5,1,689,1,10.03);
INSERT INTO items VALUES (484,5,2,96,12,248.82);
INSERT INTO items VALUES (484,6,1,336,3,83.73);
INSERT INTO items VALUES (484,6,2,762,12,308.44);
INSERT INTO items VALUES (484,6,3,937,2,11.50);
INSERT INTO items VALUES (484,6,4,710,1,29.27);
INSERT INTO items VALUES (484,6,5,565,2,48.04);
INSERT INTO items VALUES (484,6,6,163,12,224.18);
INSERT INTO items VALUES (485,1,1,830,3,25.74);
INSERT INTO items VALUES (485,1,2,342,3,33.66);
INSERT INTO items VALUES (485,2,1,715,2,37.96);
INSERT INTO items VALUES (485,2,2,714,2,51.58);
INSERT INTO items VALUES (485,2,3,167,1,21.05);
INSERT INTO items VALUES (485,2,4,121,1,29.02);
INSERT INTO items VALUES (485,2,5,636,3,76.53);
INSERT INTO items VALUES (485,2,6,422,2,38.72);
INSERT INTO items VALUES (485,3,1,587,1,10.38);
INSERT INTO items VALUES (485,3,2,257,12,328.02);
INSERT INTO items VALUES (485,3,3,867,2,31.36);
INSERT INTO items VALUES (485,3,4,548,1,5.12);
INSERT INTO items VALUES (485,4,1,4,1,21.16);
INSERT INTO items VALUES (486,1,1,76,2,35.88);
INSERT INTO items VALUES (486,1,2,794,2,21.04);
INSERT INTO items VALUES (486,1,3,833,2,39.26);
INSERT INTO items VALUES (486,1,4,1003,12,107.47);
INSERT INTO items VALUES (486,1,5,609,12,247.61);
INSERT INTO items VALUES (487,1,1,855,3,21.69);
INSERT INTO items VALUES (487,1,2,666,12,171.05);
INSERT INTO items VALUES (487,1,3,784,3,26.61);
INSERT INTO items VALUES (487,1,4,984,1,6.17);
INSERT INTO items VALUES (487,2,1,72,2,49.92);
INSERT INTO items VALUES (487,2,2,752,2,17.18);
INSERT INTO items VALUES (487,2,3,363,3,44.16);
INSERT INTO items VALUES (487,2,4,1033,1,29.37);
INSERT INTO items VALUES (487,2,5,536,12,268.62);
INSERT INTO items VALUES (487,2,6,580,2,48.98);
INSERT INTO items VALUES (487,3,1,460,2,38.70);
INSERT INTO items VALUES (487,3,2,199,2,40.56);
INSERT INTO items VALUES (487,3,3,575,3,77.01);
INSERT INTO items VALUES (487,4,1,891,3,70.80);
INSERT INTO items VALUES (487,4,2,781,1,24.74);
INSERT INTO items VALUES (487,4,3,463,3,81.42);
INSERT INTO items VALUES (487,5,1,459,3,35.88);
INSERT INTO items VALUES (487,5,2,377,1,29.73);
INSERT INTO items VALUES (487,5,3,199,12,223.08);
INSERT INTO items VALUES (487,5,4,547,2,49.50);
INSERT INTO items VALUES (487,5,5,182,1,7.43);
INSERT INTO items VALUES (488,1,1,890,12,217.58);
INSERT INTO items VALUES (488,1,2,518,1,15.35);
INSERT INTO items VALUES (488,1,3,280,1,18.58);
INSERT INTO items VALUES (488,1,4,449,1,28.38);
INSERT INTO items VALUES (488,1,5,912,2,45.88);
INSERT INTO items VALUES (488,2,1,662,2,46.58);
INSERT INTO items VALUES (488,3,1,28,12,219.89);
INSERT INTO items VALUES (488,3,2,281,1,5.63);
INSERT INTO items VALUES (488,4,1,617,2,24.18);
INSERT INTO items VALUES (488,4,2,328,12,215.49);
INSERT INTO items VALUES (488,4,3,18,1,8.45);
INSERT INTO items VALUES (488,5,1,894,1,7.88);
INSERT INTO items VALUES (488,5,2,228,3,65.79);
INSERT INTO items VALUES (488,5,3,101,12,96.03);
INSERT INTO items VALUES (488,5,4,895,1,25.06);
INSERT INTO items VALUES (488,5,5,802,1,12.24);
INSERT INTO items VALUES (488,6,1,161,12,204.93);
INSERT INTO items VALUES (488,6,2,825,2,59.26);
INSERT INTO items VALUES (488,6,3,986,12,72.16);
INSERT INTO items VALUES (489,1,1,943,1,16.13);
INSERT INTO items VALUES (489,1,2,545,2,34.20);
INSERT INTO items VALUES (489,2,1,590,3,45.99);
INSERT INTO items VALUES (489,2,2,906,2,20.66);
INSERT INTO items VALUES (489,2,3,101,1,8.73);
INSERT INTO items VALUES (489,2,4,448,1,5.78);
INSERT INTO items VALUES (489,2,5,19,12,321.42);
INSERT INTO items VALUES (489,3,1,758,3,54.18);
INSERT INTO items VALUES (489,3,2,885,3,27.66);
INSERT INTO items VALUES (489,3,3,805,2,57.12);
INSERT INTO items VALUES (489,3,4,111,1,27.88);
INSERT INTO items VALUES (489,4,1,627,1,6.58);
INSERT INTO items VALUES (489,4,2,608,3,88.44);
INSERT INTO items VALUES (490,1,1,861,12,152.35);
INSERT INTO items VALUES (490,1,2,739,2,50.56);
INSERT INTO items VALUES (490,2,1,110,1,12.74);
INSERT INTO items VALUES (490,2,2,815,3,19.32);
INSERT INTO items VALUES (490,2,3,1033,3,88.11);
INSERT INTO items VALUES (490,3,1,919,3,40.05);
INSERT INTO items VALUES (490,3,2,887,12,166.10);
INSERT INTO items VALUES (490,3,3,571,1,17.25);
INSERT INTO items VALUES (491,1,1,810,1,27.71);
INSERT INTO items VALUES (491,1,2,529,1,29.10);
INSERT INTO items VALUES (491,1,3,110,3,38.22);
INSERT INTO items VALUES (491,1,4,926,12,270.60);
INSERT INTO items VALUES (491,1,5,768,3,24.24);
INSERT INTO items VALUES (491,1,6,775,1,10.66);
INSERT INTO items VALUES (492,1,1,573,1,20.36);
INSERT INTO items VALUES (492,2,1,434,1,25.44);
INSERT INTO items VALUES (492,2,2,464,2,30.14);
INSERT INTO items VALUES (492,2,3,654,3,80.40);
INSERT INTO items VALUES (492,2,4,545,2,34.20);
INSERT INTO items VALUES (492,2,5,453,2,29.54);
INSERT INTO items VALUES (492,3,1,665,1,6.72);
INSERT INTO items VALUES (492,4,1,773,3,76.20);
INSERT INTO items VALUES (492,4,2,387,12,169.73);
INSERT INTO items VALUES (492,4,3,300,12,290.18);
INSERT INTO items VALUES (492,4,4,45,3,23.13);
INSERT INTO items VALUES (492,4,5,207,3,74.61);
INSERT INTO items VALUES (492,4,6,290,3,26.73);
INSERT INTO items VALUES (492,5,1,555,12,96.69);
INSERT INTO items VALUES (492,5,2,301,1,29.58);
INSERT INTO items VALUES (492,6,1,398,2,58.28);
INSERT INTO items VALUES (492,6,2,527,3,82.20);
INSERT INTO items VALUES (492,6,3,300,12,290.18);
INSERT INTO items VALUES (492,6,4,556,2,11.56);
INSERT INTO items VALUES (492,6,5,541,3,52.86);
INSERT INTO items VALUES (492,6,6,1043,12,184.03);
INSERT INTO items VALUES (493,1,1,765,2,59.76);
INSERT INTO items VALUES (493,1,2,758,12,198.66);
INSERT INTO items VALUES (493,1,3,593,12,75.24);
INSERT INTO items VALUES (493,2,1,371,2,30.98);
INSERT INTO items VALUES (493,2,2,540,1,26.85);
INSERT INTO items VALUES (493,3,1,911,12,62.81);
INSERT INTO items VALUES (494,1,1,811,1,5.75);
INSERT INTO items VALUES (494,1,2,1,1,21.18);
INSERT INTO items VALUES (494,2,1,169,3,29.25);
INSERT INTO items VALUES (494,2,2,394,1,5.38);
INSERT INTO items VALUES (494,3,1,456,1,25.66);
INSERT INTO items VALUES (494,3,2,222,3,72.60);
INSERT INTO items VALUES (494,4,1,930,2,51.02);
INSERT INTO items VALUES (494,4,2,856,1,5.29);
INSERT INTO items VALUES (494,4,3,139,3,46.62);
INSERT INTO items VALUES (494,4,4,967,1,7.48);
INSERT INTO items VALUES (494,4,5,976,1,10.41);
INSERT INTO items VALUES (495,1,1,457,12,231.00);
INSERT INTO items VALUES (495,1,2,270,3,61.38);
INSERT INTO items VALUES (495,1,3,19,12,321.42);
INSERT INTO items VALUES (495,1,4,889,3,41.76);
INSERT INTO items VALUES (495,1,5,324,3,61.11);
INSERT INTO items VALUES (495,2,1,978,12,110.55);
INSERT INTO items VALUES (495,2,2,530,1,14.32);
INSERT INTO items VALUES (495,2,3,843,3,24.33);
INSERT INTO items VALUES (495,2,4,38,1,5.75);
INSERT INTO items VALUES (495,3,1,843,3,24.33);
INSERT INTO items VALUES (495,3,2,548,12,56.32);
INSERT INTO items VALUES (495,3,3,389,2,35.04);
INSERT INTO items VALUES (495,3,4,551,3,71.19);
INSERT INTO items VALUES (495,3,5,988,1,11.17);
INSERT INTO items VALUES (495,3,6,238,2,48.30);
INSERT INTO items VALUES (495,4,1,139,1,15.54);
INSERT INTO items VALUES (495,4,2,285,1,8.54);
INSERT INTO items VALUES (495,4,3,277,12,290.07);
INSERT INTO items VALUES (495,4,4,559,3,20.01);
INSERT INTO items VALUES (495,4,5,461,3,31.98);
INSERT INTO items VALUES (495,5,1,242,3,84.96);
INSERT INTO items VALUES (495,5,2,589,1,21.56);
INSERT INTO items VALUES (495,5,3,837,12,97.02);
INSERT INTO items VALUES (495,5,4,496,2,46.94);
INSERT INTO items VALUES (495,5,5,855,12,79.53);
INSERT INTO items VALUES (495,5,6,598,12,142.23);
INSERT INTO items VALUES (495,6,1,528,3,29.52);
INSERT INTO items VALUES (495,6,2,454,12,311.41);
INSERT INTO items VALUES (495,6,3,145,2,52.94);
INSERT INTO items VALUES (495,6,4,294,2,15.82);
INSERT INTO items VALUES (495,6,5,974,1,6.37);
INSERT INTO items VALUES (496,1,1,16,2,17.90);
INSERT INTO items VALUES (496,2,1,758,12,198.66);
INSERT INTO items VALUES (496,2,2,769,2,11.48);
INSERT INTO items VALUES (496,2,3,368,2,56.74);
INSERT INTO items VALUES (496,2,4,918,2,31.40);
INSERT INTO items VALUES (496,3,1,35,1,17.64);
INSERT INTO items VALUES (496,3,2,930,2,51.02);
INSERT INTO items VALUES (496,3,3,653,12,317.57);
INSERT INTO items VALUES (496,3,4,596,3,55.41);
INSERT INTO items VALUES (496,4,1,1003,3,29.31);
INSERT INTO items VALUES (496,4,2,766,3,89.58);
INSERT INTO items VALUES (496,4,3,38,1,5.75);
INSERT INTO items VALUES (496,4,4,33,12,206.25);
INSERT INTO items VALUES (496,4,5,392,3,39.51);
INSERT INTO items VALUES (496,4,6,214,12,307.45);
INSERT INTO items VALUES (497,1,1,380,12,301.95);
INSERT INTO items VALUES (497,1,2,453,12,162.47);
INSERT INTO items VALUES (497,1,3,430,12,115.17);
INSERT INTO items VALUES (497,1,4,631,12,55.00);
INSERT INTO items VALUES (497,1,5,289,2,38.72);
INSERT INTO items VALUES (497,1,6,896,1,27.56);
INSERT INTO items VALUES (497,2,1,43,2,55.64);
INSERT INTO items VALUES (497,3,1,403,12,274.78);
INSERT INTO items VALUES (498,1,1,193,3,72.54);
INSERT INTO items VALUES (498,1,2,858,1,5.33);
INSERT INTO items VALUES (498,1,3,921,12,278.30);
INSERT INTO items VALUES (498,2,1,229,1,6.99);
INSERT INTO items VALUES (498,2,2,332,1,25.29);
INSERT INTO items VALUES (498,3,1,97,12,133.21);
INSERT INTO items VALUES (498,3,2,313,12,222.42);
INSERT INTO items VALUES (498,3,3,1046,3,33.00);
INSERT INTO items VALUES (498,3,4,194,1,15.10);
INSERT INTO items VALUES (498,3,5,330,1,20.60);
INSERT INTO items VALUES (498,3,6,231,1,17.56);
INSERT INTO items VALUES (498,4,1,486,12,174.57);
INSERT INTO items VALUES (498,4,2,74,12,138.16);
INSERT INTO items VALUES (498,4,3,113,12,211.75);
INSERT INTO items VALUES (498,4,4,778,1,8.86);
INSERT INTO items VALUES (498,4,5,905,1,11.44);
INSERT INTO items VALUES (498,4,6,200,12,130.68);
INSERT INTO items VALUES (498,5,1,164,1,9.40);
INSERT INTO items VALUES (498,5,2,216,2,46.10);
INSERT INTO items VALUES (498,6,1,861,12,152.35);
INSERT INTO items VALUES (498,6,2,1001,12,316.36);
INSERT INTO items VALUES (498,6,3,624,1,22.25);
INSERT INTO items VALUES (498,6,4,849,2,57.92);
INSERT INTO items VALUES (498,6,5,282,3,83.49);
INSERT INTO items VALUES (498,6,6,445,2,42.86);
INSERT INTO items VALUES (499,1,1,594,2,12.16);
INSERT INTO items VALUES (499,1,2,30,12,89.76);
INSERT INTO items VALUES (499,1,3,561,1,8.64);
INSERT INTO items VALUES (499,1,4,169,12,107.25);
INSERT INTO items VALUES (499,1,5,83,3,46.62);
INSERT INTO items VALUES (499,2,1,632,2,32.96);
INSERT INTO items VALUES (499,2,2,47,2,48.08);
INSERT INTO items VALUES (499,2,3,716,3,41.55);
INSERT INTO items VALUES (499,2,4,751,2,49.78);
INSERT INTO items VALUES (499,2,5,985,1,20.34);
INSERT INTO items VALUES (499,3,1,900,2,33.88);
INSERT INTO items VALUES (499,3,2,918,1,15.70);
INSERT INTO items VALUES (499,3,3,70,12,176.55);
INSERT INTO items VALUES (499,3,4,556,12,63.58);
INSERT INTO items VALUES (499,3,5,897,12,252.89);
INSERT INTO items VALUES (500,1,1,757,12,235.07);
INSERT INTO items VALUES (500,1,2,254,1,22.55);
INSERT INTO items VALUES (500,1,3,840,2,29.26);
INSERT INTO items VALUES (500,1,4,959,1,10.07);
INSERT INTO items VALUES (500,2,1,289,12,212.96);
INSERT INTO items VALUES (500,2,2,54,1,20.31);
INSERT INTO items VALUES (500,2,3,496,12,258.17);
INSERT INTO items VALUES (500,2,4,91,2,23.16);
INSERT INTO items VALUES (500,2,5,436,3,17.97);
INSERT INTO items VALUES (500,2,6,116,3,35.61);
INSERT INTO items VALUES (500,3,1,922,3,69.00);
INSERT INTO items VALUES (500,3,2,228,12,241.23);
INSERT INTO items VALUES (500,3,3,943,1,16.13);
INSERT INTO items VALUES (500,3,4,458,12,88.11);
INSERT INTO items VALUES (500,3,5,880,12,292.82);
INSERT INTO items VALUES (500,4,1,790,2,24.86);
INSERT INTO items VALUES (500,4,2,667,1,23.07);
INSERT INTO items VALUES (501,1,1,977,2,29.02);
INSERT INTO items VALUES (501,1,2,679,3,35.43);
INSERT INTO items VALUES (501,1,3,656,2,50.86);
INSERT INTO items VALUES (501,1,4,608,12,324.28);
INSERT INTO items VALUES (501,1,5,920,3,60.84);
INSERT INTO items VALUES (502,1,1,600,1,16.99);
INSERT INTO items VALUES (502,2,1,892,1,7.25);
INSERT INTO items VALUES (502,2,2,587,3,31.14);
INSERT INTO items VALUES (502,2,3,54,12,223.41);
INSERT INTO items VALUES (502,2,4,279,3,47.91);
INSERT INTO items VALUES (502,2,5,623,3,66.30);
INSERT INTO items VALUES (502,2,6,327,2,50.40);
INSERT INTO items VALUES (502,3,1,586,3,53.10);
INSERT INTO items VALUES (502,4,1,308,1,13.06);
INSERT INTO items VALUES (502,4,2,566,1,7.04);
INSERT INTO items VALUES (502,4,3,309,1,19.40);
INSERT INTO items VALUES (502,4,4,799,2,27.74);
INSERT INTO items VALUES (503,1,1,256,1,28.01);
INSERT INTO items VALUES (503,1,2,645,3,54.39);
INSERT INTO items VALUES (504,1,1,591,1,12.70);
INSERT INTO items VALUES (504,1,2,572,12,302.39);
INSERT INTO items VALUES (504,1,3,200,1,11.88);
INSERT INTO items VALUES (504,1,4,1,2,42.36);
INSERT INTO items VALUES (504,1,5,193,12,265.98);
INSERT INTO items VALUES (504,1,6,871,2,20.44);
INSERT INTO items VALUES (504,2,1,565,12,264.22);
INSERT INTO items VALUES (504,2,2,479,1,11.70);
INSERT INTO items VALUES (504,2,3,401,1,16.75);
INSERT INTO items VALUES (504,2,4,176,3,62.22);
INSERT INTO items VALUES (504,2,5,231,2,35.12);
INSERT INTO items VALUES (504,2,6,550,1,11.22);
INSERT INTO items VALUES (504,3,1,226,12,95.48);
INSERT INTO items VALUES (504,3,2,602,1,11.72);
INSERT INTO items VALUES (504,3,3,201,2,34.76);
INSERT INTO items VALUES (504,3,4,999,1,17.61);
INSERT INTO items VALUES (504,3,5,930,1,25.51);
INSERT INTO items VALUES (505,1,1,30,12,89.76);
INSERT INTO items VALUES (505,1,2,627,2,13.16);
INSERT INTO items VALUES (505,1,3,472,3,25.08);
INSERT INTO items VALUES (506,1,1,102,3,20.13);
INSERT INTO items VALUES (506,1,2,1028,2,27.80);
INSERT INTO items VALUES (506,1,3,979,12,312.29);
INSERT INTO items VALUES (506,1,4,409,12,245.74);
INSERT INTO items VALUES (506,1,5,190,2,40.56);
INSERT INTO items VALUES (506,1,6,575,12,282.37);
INSERT INTO items VALUES (506,2,1,743,2,15.96);
INSERT INTO items VALUES (506,2,2,183,2,50.54);
INSERT INTO items VALUES (506,2,3,680,1,5.25);
INSERT INTO items VALUES (506,2,4,873,12,227.15);
INSERT INTO items VALUES (506,2,5,927,12,166.43);
INSERT INTO items VALUES (506,3,1,769,12,63.14);
INSERT INTO items VALUES (506,3,2,162,12,216.04);
INSERT INTO items VALUES (506,3,3,205,3,38.97);
INSERT INTO items VALUES (507,1,1,266,12,205.26);
INSERT INTO items VALUES (507,2,1,535,1,19.83);
INSERT INTO items VALUES (507,2,2,193,3,72.54);
INSERT INTO items VALUES (507,2,3,574,12,208.01);
INSERT INTO items VALUES (507,3,1,772,3,39.87);
INSERT INTO items VALUES (507,3,2,573,1,20.36);
INSERT INTO items VALUES (507,3,3,231,12,193.16);
INSERT INTO items VALUES (507,3,4,750,12,72.27);
INSERT INTO items VALUES (507,3,5,110,12,140.14);
INSERT INTO items VALUES (507,3,6,648,2,32.68);
INSERT INTO items VALUES (507,4,1,594,2,12.16);
INSERT INTO items VALUES (507,4,2,296,1,9.95);
INSERT INTO items VALUES (507,4,3,451,2,24.90);
INSERT INTO items VALUES (507,4,4,1042,1,26.76);
INSERT INTO items VALUES (507,4,5,1030,1,21.21);
INSERT INTO items VALUES (507,5,1,440,3,16.05);
INSERT INTO items VALUES (507,5,2,308,3,39.18);
INSERT INTO items VALUES (507,5,3,650,12,256.74);
INSERT INTO items VALUES (507,5,4,989,2,24.18);
INSERT INTO items VALUES (507,6,1,577,2,42.12);
INSERT INTO items VALUES (507,6,2,118,12,158.18);
INSERT INTO items VALUES (507,6,3,707,1,6.71);
INSERT INTO items VALUES (507,6,4,134,3,67.35);
INSERT INTO items VALUES (507,6,5,141,12,247.17);
INSERT INTO items VALUES (507,6,6,594,12,66.88);
INSERT INTO items VALUES (508,1,1,111,12,306.68);
INSERT INTO items VALUES (508,1,2,951,2,49.06);
INSERT INTO items VALUES (508,1,3,973,3,48.06);
INSERT INTO items VALUES (508,1,4,877,2,38.30);
INSERT INTO items VALUES (508,1,5,895,12,275.66);
INSERT INTO items VALUES (508,1,6,377,2,59.46);
INSERT INTO items VALUES (508,2,1,746,2,22.24);
INSERT INTO items VALUES (508,2,2,314,3,74.76);
INSERT INTO items VALUES (508,2,3,644,2,56.92);
INSERT INTO items VALUES (508,2,4,467,2,50.94);
INSERT INTO items VALUES (508,2,5,800,12,199.76);
INSERT INTO items VALUES (509,1,1,268,3,27.45);
INSERT INTO items VALUES (509,1,2,249,1,25.97);
INSERT INTO items VALUES (509,1,3,931,3,43.02);
INSERT INTO items VALUES (509,2,1,678,12,290.95);
INSERT INTO items VALUES (509,2,2,779,2,39.74);
INSERT INTO items VALUES (509,2,3,594,1,6.08);
INSERT INTO items VALUES (510,1,1,198,1,13.81);
INSERT INTO items VALUES (510,1,2,651,3,89.76);
INSERT INTO items VALUES (510,1,3,363,1,14.72);
INSERT INTO items VALUES (510,2,1,969,2,27.86);
INSERT INTO items VALUES (510,2,2,11,2,32.96);
INSERT INTO items VALUES (510,2,3,1025,12,316.58);
INSERT INTO items VALUES (510,3,1,599,3,16.71);
INSERT INTO items VALUES (510,4,1,712,12,310.31);
INSERT INTO items VALUES (510,4,2,132,2,36.86);
INSERT INTO items VALUES (510,5,1,65,12,109.78);
INSERT INTO items VALUES (510,5,2,624,1,22.25);
INSERT INTO items VALUES (510,5,3,913,12,238.48);
INSERT INTO items VALUES (510,5,4,580,1,24.49);
INSERT INTO items VALUES (511,1,1,362,12,252.12);
INSERT INTO items VALUES (511,1,2,417,3,41.76);
INSERT INTO items VALUES (511,1,3,620,2,51.60);
INSERT INTO items VALUES (511,1,4,825,12,325.93);
INSERT INTO items VALUES (511,1,5,151,2,44.74);
INSERT INTO items VALUES (511,2,1,673,2,52.04);
INSERT INTO items VALUES (511,2,2,365,2,16.80);
INSERT INTO items VALUES (511,2,3,55,2,42.82);
INSERT INTO items VALUES (511,3,1,335,2,19.16);
INSERT INTO items VALUES (511,4,1,118,1,14.38);
INSERT INTO items VALUES (511,4,2,870,3,68.67);
INSERT INTO items VALUES (511,4,3,639,3,70.59);
INSERT INTO items VALUES (511,4,4,617,1,12.09);
INSERT INTO items VALUES (511,5,1,985,3,61.02);
INSERT INTO items VALUES (511,5,2,210,3,36.21);
INSERT INTO items VALUES (511,5,3,302,1,22.70);
INSERT INTO items VALUES (511,5,4,705,3,29.91);
INSERT INTO items VALUES (511,5,5,654,3,80.40);
INSERT INTO items VALUES (512,1,1,776,12,259.93);
INSERT INTO items VALUES (512,1,2,320,2,41.84);
INSERT INTO items VALUES (512,1,3,561,2,17.28);
INSERT INTO items VALUES (512,1,4,320,12,230.12);
INSERT INTO items VALUES (512,1,5,1019,3,38.79);
INSERT INTO items VALUES (512,2,1,581,12,164.78);
INSERT INTO items VALUES (512,2,2,622,1,17.45);
INSERT INTO items VALUES (512,2,3,523,2,53.56);
INSERT INTO items VALUES (512,2,4,509,1,15.58);
INSERT INTO items VALUES (512,2,5,772,12,146.19);
INSERT INTO items VALUES (512,2,6,701,3,72.96);
INSERT INTO items VALUES (513,1,1,1023,2,30.98);
INSERT INTO items VALUES (513,2,1,756,1,29.52);
INSERT INTO items VALUES (513,2,2,479,3,35.10);
INSERT INTO items VALUES (513,2,3,854,3,74.25);
INSERT INTO items VALUES (513,2,4,100,1,23.46);
INSERT INTO items VALUES (513,2,5,109,2,32.00);
INSERT INTO items VALUES (513,2,6,927,12,166.43);
INSERT INTO items VALUES (514,1,1,899,1,7.35);
INSERT INTO items VALUES (514,1,2,591,2,25.40);
INSERT INTO items VALUES (514,1,3,58,1,26.60);
INSERT INTO items VALUES (514,1,4,190,3,60.84);
INSERT INTO items VALUES (514,2,1,541,3,52.86);
INSERT INTO items VALUES (514,2,2,746,3,33.36);
INSERT INTO items VALUES (514,2,3,810,12,304.81);
INSERT INTO items VALUES (514,2,4,575,3,77.01);
INSERT INTO items VALUES (514,3,1,614,12,98.23);
INSERT INTO items VALUES (514,4,1,694,3,47.28);
INSERT INTO items VALUES (514,4,2,560,3,68.73);
INSERT INTO items VALUES (514,4,3,441,3,17.61);
INSERT INTO items VALUES (514,4,4,313,12,222.42);
INSERT INTO items VALUES (514,4,5,268,1,9.15);
INSERT INTO items VALUES (514,4,6,629,1,24.19);
INSERT INTO items VALUES (514,5,1,237,2,50.96);
INSERT INTO items VALUES (514,6,1,339,2,21.34);
INSERT INTO items VALUES (514,6,2,661,12,121.88);
INSERT INTO items VALUES (514,6,3,96,1,22.62);
INSERT INTO items VALUES (514,6,4,698,3,46.50);
INSERT INTO items VALUES (514,6,5,786,12,229.24);
INSERT INTO items VALUES (515,1,1,888,2,11.56);
INSERT INTO items VALUES (515,1,2,119,12,196.02);
INSERT INTO items VALUES (515,1,3,682,2,54.68);
INSERT INTO items VALUES (515,1,4,200,2,23.76);
INSERT INTO items VALUES (515,1,5,529,3,87.30);
INSERT INTO items VALUES (515,2,1,111,1,27.88);
INSERT INTO items VALUES (515,2,2,413,3,55.02);
INSERT INTO items VALUES (515,2,3,914,2,10.46);
INSERT INTO items VALUES (515,2,4,67,12,305.80);
INSERT INTO items VALUES (515,2,5,349,1,15.59);
INSERT INTO items VALUES (515,3,1,76,2,35.88);
INSERT INTO items VALUES (515,3,2,167,2,42.10);
INSERT INTO items VALUES (515,3,3,883,3,27.90);
INSERT INTO items VALUES (515,3,4,943,2,32.26);
INSERT INTO items VALUES (515,3,5,319,1,14.70);
INSERT INTO items VALUES (516,1,1,189,2,33.46);
INSERT INTO items VALUES (517,1,1,256,2,56.02);
INSERT INTO items VALUES (517,1,2,335,2,19.16);
INSERT INTO items VALUES (517,1,3,665,2,13.44);
INSERT INTO items VALUES (517,1,4,607,2,44.38);
INSERT INTO items VALUES (518,1,1,503,1,24.79);
INSERT INTO items VALUES (518,1,2,210,3,36.21);
INSERT INTO items VALUES (518,1,3,236,2,44.02);
INSERT INTO items VALUES (518,1,4,96,2,45.24);
INSERT INTO items VALUES (518,1,5,457,12,231.00);
INSERT INTO items VALUES (518,1,6,568,2,22.64);
INSERT INTO items VALUES (519,1,1,819,1,7.77);
INSERT INTO items VALUES (519,1,2,446,12,235.84);
INSERT INTO items VALUES (519,1,3,663,1,7.23);
INSERT INTO items VALUES (519,1,4,385,2,41.62);
INSERT INTO items VALUES (519,1,5,955,1,18.91);
INSERT INTO items VALUES (519,1,6,242,2,56.64);
INSERT INTO items VALUES (520,1,1,1044,2,38.24);
INSERT INTO items VALUES (520,1,2,678,1,26.45);
INSERT INTO items VALUES (520,2,1,748,1,22.76);
INSERT INTO items VALUES (520,2,2,168,3,73.11);
INSERT INTO items VALUES (520,2,3,663,2,14.46);
INSERT INTO items VALUES (520,2,4,3,12,109.34);
INSERT INTO items VALUES (520,2,5,247,1,25.40);
INSERT INTO items VALUES (521,1,1,899,3,22.05);
INSERT INTO items VALUES (521,1,2,740,2,10.16);
INSERT INTO items VALUES (521,1,3,351,3,76.41);
INSERT INTO items VALUES (521,1,4,776,12,259.93);
INSERT INTO items VALUES (521,1,5,1036,3,35.22);
INSERT INTO items VALUES (521,2,1,490,3,24.93);
INSERT INTO items VALUES (521,2,2,261,2,30.74);
INSERT INTO items VALUES (522,1,1,746,12,122.32);
INSERT INTO items VALUES (522,1,2,708,2,18.24);
INSERT INTO items VALUES (522,1,3,678,12,290.95);
INSERT INTO items VALUES (522,1,4,770,2,31.62);
INSERT INTO items VALUES (522,1,5,716,3,41.55);
INSERT INTO items VALUES (522,2,1,937,2,11.50);
INSERT INTO items VALUES (522,3,1,243,12,212.85);
INSERT INTO items VALUES (522,3,2,872,2,52.58);
INSERT INTO items VALUES (522,3,3,766,3,89.58);
INSERT INTO items VALUES (522,3,4,421,2,28.60);
INSERT INTO items VALUES (522,4,1,800,1,18.16);
INSERT INTO items VALUES (522,4,2,1019,12,142.23);
INSERT INTO items VALUES (522,4,3,746,1,11.12);
INSERT INTO items VALUES (522,5,1,911,2,11.42);
INSERT INTO items VALUES (522,5,2,988,1,11.17);
INSERT INTO items VALUES (522,5,3,348,12,201.96);
INSERT INTO items VALUES (522,6,1,856,12,58.19);
INSERT INTO items VALUES (523,1,1,486,1,15.87);
INSERT INTO items VALUES (523,1,2,423,1,26.88);
INSERT INTO items VALUES (523,1,3,583,3,55.47);
INSERT INTO items VALUES (523,1,4,453,12,162.47);
INSERT INTO items VALUES (523,1,5,543,12,308.66);
INSERT INTO items VALUES (523,2,1,148,3,39.72);
INSERT INTO items VALUES (523,2,2,239,1,24.19);
INSERT INTO items VALUES (523,2,3,556,1,5.78);
INSERT INTO items VALUES (523,2,4,600,2,33.98);
INSERT INTO items VALUES (523,2,5,500,12,179.08);
INSERT INTO items VALUES (523,2,6,487,12,325.82);
INSERT INTO items VALUES (523,3,1,331,12,86.24);
INSERT INTO items VALUES (523,3,2,502,12,265.21);
INSERT INTO items VALUES (523,3,3,633,2,32.36);
INSERT INTO items VALUES (523,3,4,473,12,80.08);
INSERT INTO items VALUES (524,1,1,290,2,17.82);
INSERT INTO items VALUES (524,1,2,518,3,46.05);
INSERT INTO items VALUES (524,1,3,883,1,9.30);
INSERT INTO items VALUES (524,1,4,124,3,82.26);
INSERT INTO items VALUES (524,1,5,145,2,52.94);
INSERT INTO items VALUES (524,1,6,867,1,15.68);
INSERT INTO items VALUES (525,1,1,529,3,87.30);
INSERT INTO items VALUES (525,1,2,304,3,67.38);
INSERT INTO items VALUES (525,1,3,291,2,19.90);
INSERT INTO items VALUES (525,1,4,507,1,18.02);
INSERT INTO items VALUES (526,1,1,747,1,26.98);
INSERT INTO items VALUES (526,1,2,517,12,81.62);
INSERT INTO items VALUES (526,1,3,523,2,53.56);
INSERT INTO items VALUES (526,1,4,1023,3,46.47);
INSERT INTO items VALUES (526,1,5,489,3,64.05);
INSERT INTO items VALUES (526,1,6,954,2,11.02);
INSERT INTO items VALUES (527,1,1,505,2,55.26);
INSERT INTO items VALUES (527,2,1,937,12,63.25);
INSERT INTO items VALUES (527,2,2,233,1,5.65);
INSERT INTO items VALUES (527,2,3,426,1,8.67);
INSERT INTO items VALUES (527,2,4,533,3,56.22);
INSERT INTO items VALUES (527,3,1,75,2,45.46);
INSERT INTO items VALUES (527,3,2,822,12,121.33);
INSERT INTO items VALUES (527,3,3,615,3,70.71);
INSERT INTO items VALUES (527,4,1,537,12,289.30);
INSERT INTO items VALUES (527,4,2,515,2,50.18);
INSERT INTO items VALUES (527,4,3,831,3,70.83);
INSERT INTO items VALUES (527,4,4,436,1,5.99);
INSERT INTO items VALUES (527,4,5,823,12,255.20);
INSERT INTO items VALUES (527,4,6,970,12,314.27);
INSERT INTO items VALUES (527,5,1,108,12,178.31);
INSERT INTO items VALUES (528,1,1,130,3,47.28);
INSERT INTO items VALUES (528,1,2,927,1,15.13);
INSERT INTO items VALUES (528,1,3,110,2,25.48);
INSERT INTO items VALUES (528,2,1,455,3,86.97);
INSERT INTO items VALUES (528,2,2,38,12,63.25);
INSERT INTO items VALUES (528,2,3,577,3,63.18);
INSERT INTO items VALUES (528,2,4,1014,3,41.46);
INSERT INTO items VALUES (528,2,5,853,12,321.53);
INSERT INTO items VALUES (528,2,6,425,3,47.55);
INSERT INTO items VALUES (528,3,1,363,3,44.16);
INSERT INTO items VALUES (528,3,2,566,2,14.08);
INSERT INTO items VALUES (528,3,3,843,2,16.22);
INSERT INTO items VALUES (528,3,4,281,3,16.89);
INSERT INTO items VALUES (528,4,1,275,2,43.38);
INSERT INTO items VALUES (528,4,2,1043,1,16.73);
INSERT INTO items VALUES (528,5,1,596,3,55.41);
INSERT INTO items VALUES (528,5,2,102,1,6.71);
INSERT INTO items VALUES (528,5,3,93,2,43.34);
INSERT INTO items VALUES (528,6,1,307,1,5.28);
INSERT INTO items VALUES (529,1,1,865,1,29.58);
INSERT INTO items VALUES (529,1,2,659,12,268.18);
INSERT INTO items VALUES (529,1,3,334,12,156.75);
INSERT INTO items VALUES (529,1,4,998,3,36.90);
INSERT INTO items VALUES (529,1,5,531,3,74.34);
INSERT INTO items VALUES (530,1,1,193,2,48.36);
INSERT INTO items VALUES (530,1,2,1001,2,57.52);
INSERT INTO items VALUES (530,1,3,319,1,14.70);
INSERT INTO items VALUES (530,1,4,18,3,25.35);
INSERT INTO items VALUES (530,1,5,20,12,106.70);
INSERT INTO items VALUES (530,1,6,246,1,18.57);
INSERT INTO items VALUES (530,2,1,867,2,31.36);
INSERT INTO items VALUES (530,2,2,769,2,11.48);
INSERT INTO items VALUES (530,3,1,822,2,22.06);
INSERT INTO items VALUES (530,3,2,691,3,87.00);
INSERT INTO items VALUES (530,3,3,839,12,214.50);
INSERT INTO items VALUES (530,4,1,335,12,105.38);
INSERT INTO items VALUES (530,5,1,597,12,304.37);
INSERT INTO items VALUES (530,5,2,288,1,14.95);
INSERT INTO items VALUES (531,1,1,400,1,9.76);
INSERT INTO items VALUES (531,1,2,581,1,14.98);
INSERT INTO items VALUES (531,1,3,973,1,16.02);
INSERT INTO items VALUES (531,1,4,114,3,66.96);
INSERT INTO items VALUES (531,2,1,535,2,39.66);
INSERT INTO items VALUES (531,2,2,270,3,61.38);
INSERT INTO items VALUES (531,2,3,963,1,25.32);
INSERT INTO items VALUES (531,2,4,9,12,269.17);
INSERT INTO items VALUES (531,3,1,82,12,245.30);
INSERT INTO items VALUES (531,3,2,465,3,24.00);
INSERT INTO items VALUES (531,4,1,905,3,34.32);
INSERT INTO items VALUES (531,4,2,951,2,49.06);
INSERT INTO items VALUES (531,4,3,346,2,14.28);
INSERT INTO items VALUES (531,5,1,841,3,76.14);
INSERT INTO items VALUES (531,5,2,370,12,68.20);
INSERT INTO items VALUES (531,5,3,210,12,132.77);
INSERT INTO items VALUES (531,5,4,160,2,59.84);
INSERT INTO items VALUES (531,6,1,968,2,37.38);
INSERT INTO items VALUES (531,6,2,137,12,141.35);
INSERT INTO items VALUES (531,6,3,157,1,24.06);
INSERT INTO items VALUES (531,6,4,172,2,59.78);
INSERT INTO items VALUES (531,6,5,477,12,262.79);
INSERT INTO items VALUES (532,1,1,481,2,11.64);
INSERT INTO items VALUES (532,1,2,710,1,29.27);
INSERT INTO items VALUES (532,1,3,640,12,125.95);
INSERT INTO items VALUES (533,1,1,46,2,31.34);
INSERT INTO items VALUES (533,2,1,772,2,26.58);
INSERT INTO items VALUES (533,2,2,496,3,70.41);
INSERT INTO items VALUES (533,2,3,238,3,72.45);
INSERT INTO items VALUES (533,2,4,219,3,19.35);
INSERT INTO items VALUES (533,2,5,39,3,22.14);
INSERT INTO items VALUES (533,2,6,400,2,19.52);
INSERT INTO items VALUES (533,3,1,803,12,227.59);
INSERT INTO items VALUES (533,3,2,784,12,97.57);
INSERT INTO items VALUES (533,3,3,164,3,28.20);
INSERT INTO items VALUES (533,3,4,2,3,84.45);
INSERT INTO items VALUES (533,4,1,1028,1,13.90);
INSERT INTO items VALUES (533,5,1,138,3,64.53);
INSERT INTO items VALUES (533,5,2,74,3,37.68);
INSERT INTO items VALUES (533,5,3,767,3,19.59);
INSERT INTO items VALUES (533,5,4,279,2,31.94);
INSERT INTO items VALUES (533,5,5,432,1,25.45);
INSERT INTO items VALUES (533,5,6,322,3,50.91);
INSERT INTO items VALUES (534,1,1,449,1,28.38);
INSERT INTO items VALUES (534,1,2,389,3,52.56);
INSERT INTO items VALUES (534,1,3,706,3,78.06);
INSERT INTO items VALUES (534,2,1,433,1,21.31);
INSERT INTO items VALUES (534,3,1,17,1,25.23);
INSERT INTO items VALUES (534,3,2,958,1,10.83);
INSERT INTO items VALUES (534,3,3,415,12,124.41);
INSERT INTO items VALUES (534,3,4,723,2,41.66);
INSERT INTO items VALUES (534,4,1,3,2,19.88);
INSERT INTO items VALUES (534,4,2,659,3,73.14);
INSERT INTO items VALUES (535,1,1,751,3,74.67);
INSERT INTO items VALUES (535,1,2,205,2,25.98);
INSERT INTO items VALUES (535,1,3,664,2,52.16);
INSERT INTO items VALUES (535,1,4,248,12,287.98);
INSERT INTO items VALUES (535,1,5,702,1,8.82);
INSERT INTO items VALUES (535,2,1,351,2,50.94);
INSERT INTO items VALUES (535,2,2,251,3,17.13);
INSERT INTO items VALUES (535,3,1,855,3,21.69);
INSERT INTO items VALUES (535,3,2,190,3,60.84);
INSERT INTO items VALUES (535,3,3,373,2,51.14);
INSERT INTO items VALUES (535,4,1,241,2,33.90);
INSERT INTO items VALUES (535,4,2,668,12,163.35);
INSERT INTO items VALUES (535,5,1,954,1,5.51);
INSERT INTO items VALUES (535,5,2,125,12,97.02);
INSERT INTO items VALUES (535,5,3,494,3,85.05);
INSERT INTO items VALUES (535,5,4,443,2,58.64);
INSERT INTO items VALUES (535,5,5,447,3,40.74);
INSERT INTO items VALUES (536,1,1,992,12,115.61);
INSERT INTO items VALUES (536,1,2,801,2,10.34);
INSERT INTO items VALUES (536,1,3,649,3,51.27);
INSERT INTO items VALUES (536,1,4,938,2,53.70);
INSERT INTO items VALUES (536,2,1,703,1,26.77);
INSERT INTO items VALUES (536,2,2,478,2,35.66);
INSERT INTO items VALUES (536,2,3,685,3,33.66);
INSERT INTO items VALUES (536,2,4,821,2,11.38);
INSERT INTO items VALUES (536,2,5,587,3,31.14);
INSERT INTO items VALUES (536,2,6,245,1,28.86);
INSERT INTO items VALUES (536,3,1,68,3,64.98);
INSERT INTO items VALUES (536,3,2,219,12,70.95);
INSERT INTO items VALUES (536,3,3,964,12,146.63);
INSERT INTO items VALUES (536,3,4,866,1,14.59);
INSERT INTO items VALUES (536,4,1,424,2,17.16);
INSERT INTO items VALUES (536,4,2,976,1,10.41);
INSERT INTO items VALUES (536,5,1,746,12,122.32);
INSERT INTO items VALUES (536,5,2,539,3,31.44);
INSERT INTO items VALUES (536,5,3,614,3,26.79);
INSERT INTO items VALUES (536,5,4,290,12,98.01);
INSERT INTO items VALUES (536,5,5,563,1,26.82);
INSERT INTO items VALUES (537,1,1,646,2,15.90);
INSERT INTO items VALUES (537,1,2,199,12,223.08);
INSERT INTO items VALUES (537,1,3,236,2,44.02);
INSERT INTO items VALUES (537,1,4,615,3,70.71);
INSERT INTO items VALUES (537,1,5,133,2,35.08);
INSERT INTO items VALUES (537,2,1,787,1,9.59);
INSERT INTO items VALUES (537,2,2,114,3,66.96);
INSERT INTO items VALUES (537,2,3,805,2,57.12);
INSERT INTO items VALUES (537,2,4,180,1,18.57);
INSERT INTO items VALUES (537,2,5,778,3,26.58);
INSERT INTO items VALUES (537,3,1,256,1,28.01);
INSERT INTO items VALUES (537,3,2,229,12,76.89);
INSERT INTO items VALUES (537,3,3,927,2,30.26);
INSERT INTO items VALUES (537,3,4,276,2,46.44);
INSERT INTO items VALUES (537,3,5,582,2,41.76);
INSERT INTO items VALUES (537,3,6,488,3,15.30);
INSERT INTO items VALUES (537,4,1,744,1,13.54);
INSERT INTO items VALUES (538,1,1,341,3,52.20);
INSERT INTO items VALUES (538,1,2,650,2,46.68);
INSERT INTO items VALUES (538,1,3,801,2,10.34);
INSERT INTO items VALUES (538,2,1,402,1,19.08);
INSERT INTO items VALUES (539,1,1,730,1,24.66);
INSERT INTO items VALUES (539,2,1,1046,1,11.00);
INSERT INTO items VALUES (539,2,2,1030,12,233.31);
INSERT INTO items VALUES (539,2,3,608,2,58.96);
INSERT INTO items VALUES (539,3,1,611,3,63.96);
INSERT INTO items VALUES (539,3,2,806,1,8.34);
INSERT INTO items VALUES (539,3,3,571,3,51.75);
INSERT INTO items VALUES (539,3,4,580,1,24.49);
INSERT INTO items VALUES (539,3,5,723,1,20.83);
INSERT INTO items VALUES (539,3,6,153,2,46.22);
INSERT INTO items VALUES (540,1,1,110,1,12.74);
INSERT INTO items VALUES (540,1,2,519,2,23.52);
INSERT INTO items VALUES (540,1,3,78,12,170.50);
INSERT INTO items VALUES (540,1,4,547,3,74.25);
INSERT INTO items VALUES (540,1,5,208,3,30.57);
INSERT INTO items VALUES (540,1,6,547,12,272.25);
INSERT INTO items VALUES (540,2,1,647,3,87.96);
INSERT INTO items VALUES (540,3,1,886,3,52.59);
INSERT INTO items VALUES (540,3,2,221,12,134.53);
INSERT INTO items VALUES (540,4,1,724,3,61.89);
INSERT INTO items VALUES (540,4,2,961,2,20.16);
INSERT INTO items VALUES (540,4,3,103,1,12.37);
INSERT INTO items VALUES (540,5,1,400,12,107.36);
INSERT INTO items VALUES (540,5,2,950,12,121.66);
INSERT INTO items VALUES (540,6,1,204,1,24.28);
INSERT INTO items VALUES (540,6,2,808,12,284.46);
INSERT INTO items VALUES (540,6,3,624,3,66.75);
INSERT INTO items VALUES (541,1,1,572,3,82.47);
INSERT INTO items VALUES (541,2,1,1014,12,152.02);
INSERT INTO items VALUES (541,2,2,918,1,15.70);
INSERT INTO items VALUES (541,2,3,202,2,20.16);
INSERT INTO items VALUES (541,2,4,578,3,21.96);
INSERT INTO items VALUES (541,2,5,576,3,80.28);
INSERT INTO items VALUES (541,2,6,336,3,83.73);
INSERT INTO items VALUES (541,3,1,934,3,75.27);
INSERT INTO items VALUES (541,3,2,353,2,49.58);
INSERT INTO items VALUES (542,1,1,185,3,47.76);
INSERT INTO items VALUES (542,1,2,865,2,59.16);
INSERT INTO items VALUES (542,1,3,958,1,10.83);
INSERT INTO items VALUES (542,1,4,923,2,29.28);
INSERT INTO items VALUES (542,1,5,764,3,34.56);
INSERT INTO items VALUES (542,1,6,821,2,11.38);
INSERT INTO items VALUES (542,2,1,116,1,11.87);
INSERT INTO items VALUES (542,2,2,986,3,19.68);
INSERT INTO items VALUES (542,2,3,413,12,201.74);
INSERT INTO items VALUES (542,2,4,712,1,28.21);
INSERT INTO items VALUES (543,1,1,711,12,308.77);
INSERT INTO items VALUES (543,1,2,288,1,14.95);
INSERT INTO items VALUES (543,1,3,751,12,273.79);
INSERT INTO items VALUES (544,1,1,532,1,27.88);
INSERT INTO items VALUES (544,1,2,599,2,11.14);
INSERT INTO items VALUES (544,1,3,639,12,258.83);
INSERT INTO items VALUES (544,1,4,456,2,51.32);
INSERT INTO items VALUES (544,2,1,269,3,46.08);
INSERT INTO items VALUES (544,2,2,586,1,17.70);
INSERT INTO items VALUES (544,2,3,953,3,59.79);
INSERT INTO items VALUES (544,2,4,1006,3,60.48);
INSERT INTO items VALUES (544,2,5,653,12,317.57);
INSERT INTO items VALUES (544,2,6,319,2,29.40);
INSERT INTO items VALUES (544,3,1,169,12,107.25);
INSERT INTO items VALUES (544,4,1,536,3,73.26);
INSERT INTO items VALUES (544,4,2,197,12,129.03);
INSERT INTO items VALUES (544,5,1,72,12,274.56);
INSERT INTO items VALUES (544,5,2,265,2,33.46);
INSERT INTO items VALUES (544,5,3,1032,2,39.86);
INSERT INTO items VALUES (544,5,4,768,3,24.24);
INSERT INTO items VALUES (544,5,5,182,1,7.43);
INSERT INTO items VALUES (544,5,6,761,2,37.76);
INSERT INTO items VALUES (544,6,1,362,3,68.76);
INSERT INTO items VALUES (544,6,2,508,3,85.44);
INSERT INTO items VALUES (544,6,3,285,12,93.94);
INSERT INTO items VALUES (544,6,4,291,2,19.90);
INSERT INTO items VALUES (544,6,5,41,3,50.97);
INSERT INTO items VALUES (545,1,1,992,3,31.53);
INSERT INTO items VALUES (545,1,2,915,1,12.51);
INSERT INTO items VALUES (545,1,3,461,1,10.66);
INSERT INTO items VALUES (545,1,4,138,2,43.02);
INSERT INTO items VALUES (545,1,5,144,2,52.42);
INSERT INTO items VALUES (545,2,1,948,3,25.14);
INSERT INTO items VALUES (545,2,2,501,1,22.39);
INSERT INTO items VALUES (546,1,1,778,3,26.58);
INSERT INTO items VALUES (546,1,2,157,2,48.12);
INSERT INTO items VALUES (546,2,1,851,3,60.39);
INSERT INTO items VALUES (546,2,2,921,1,25.30);
INSERT INTO items VALUES (546,2,3,180,3,55.71);
INSERT INTO items VALUES (546,2,4,898,2,44.04);
INSERT INTO items VALUES (546,2,5,435,2,23.70);
INSERT INTO items VALUES (546,3,1,668,2,29.70);
INSERT INTO items VALUES (546,4,1,764,1,11.52);
INSERT INTO items VALUES (546,4,2,962,12,172.92);
INSERT INTO items VALUES (546,4,3,804,3,77.70);
INSERT INTO items VALUES (546,4,4,431,3,53.58);
INSERT INTO items VALUES (547,1,1,178,1,11.21);
INSERT INTO items VALUES (547,1,2,891,1,23.60);
INSERT INTO items VALUES (547,1,3,809,12,101.09);
INSERT INTO items VALUES (547,1,4,887,1,15.10);
INSERT INTO items VALUES (547,1,5,136,1,25.35);
INSERT INTO items VALUES (547,2,1,28,3,59.97);
INSERT INTO items VALUES (547,2,2,449,12,312.18);
INSERT INTO items VALUES (547,2,3,111,1,27.88);
INSERT INTO items VALUES (547,2,4,605,3,62.34);
INSERT INTO items VALUES (547,3,1,523,2,53.56);
INSERT INTO items VALUES (547,3,2,186,2,17.06);
INSERT INTO items VALUES (547,3,3,189,1,16.73);
INSERT INTO items VALUES (547,3,4,533,2,37.48);
INSERT INTO items VALUES (547,3,5,261,3,46.11);
INSERT INTO items VALUES (547,3,6,870,2,45.78);
INSERT INTO items VALUES (547,4,1,756,12,324.72);
INSERT INTO items VALUES (547,4,2,581,2,29.96);
INSERT INTO items VALUES (547,4,3,612,12,325.38);
INSERT INTO items VALUES (547,5,1,1002,3,71.91);
INSERT INTO items VALUES (547,5,2,711,1,28.07);
INSERT INTO items VALUES (547,5,3,785,1,28.11);
INSERT INTO items VALUES (548,1,1,395,1,16.99);
INSERT INTO items VALUES (548,1,2,201,12,191.18);
INSERT INTO items VALUES (548,1,3,942,1,28.23);
INSERT INTO items VALUES (548,2,1,690,3,60.21);
INSERT INTO items VALUES (548,2,2,338,1,24.28);
INSERT INTO items VALUES (548,2,3,538,1,14.50);
INSERT INTO items VALUES (548,2,4,781,3,74.22);
INSERT INTO items VALUES (548,2,5,835,12,160.16);
INSERT INTO items VALUES (548,3,1,524,3,45.78);
INSERT INTO items VALUES (548,3,2,795,3,64.38);
INSERT INTO items VALUES (548,3,3,444,3,54.48);
INSERT INTO items VALUES (548,3,4,816,12,127.27);
INSERT INTO items VALUES (549,1,1,129,2,11.50);
INSERT INTO items VALUES (549,1,2,435,1,11.85);
INSERT INTO items VALUES (549,1,3,72,1,24.96);
INSERT INTO items VALUES (549,1,4,1014,12,152.02);
INSERT INTO items VALUES (549,1,5,164,12,103.40);
INSERT INTO items VALUES (549,1,6,906,3,30.99);
INSERT INTO items VALUES (549,2,1,45,3,23.13);
INSERT INTO items VALUES (549,3,1,739,1,25.28);
INSERT INTO items VALUES (549,3,2,548,12,56.32);
INSERT INTO items VALUES (549,3,3,577,12,231.66);
INSERT INTO items VALUES (549,3,4,1046,3,33.00);
INSERT INTO items VALUES (549,4,1,614,3,26.79);
INSERT INTO items VALUES (549,4,2,818,12,72.27);
INSERT INTO items VALUES (549,4,3,163,3,61.14);
INSERT INTO items VALUES (549,4,4,1043,1,16.73);
INSERT INTO items VALUES (549,4,5,166,12,90.86);
INSERT INTO items VALUES (549,5,1,757,1,21.37);
INSERT INTO items VALUES (549,5,2,537,2,52.60);
INSERT INTO items VALUES (549,5,3,191,3,51.87);
INSERT INTO items VALUES (549,5,4,933,1,27.47);
INSERT INTO items VALUES (549,5,5,498,3,49.44);
INSERT INTO items VALUES (549,6,1,766,3,89.58);
INSERT INTO items VALUES (549,6,2,455,3,86.97);
INSERT INTO items VALUES (549,6,3,920,3,60.84);
INSERT INTO items VALUES (549,6,4,576,12,294.36);
INSERT INTO items VALUES (549,6,5,125,3,26.46);
INSERT INTO items VALUES (550,1,1,839,3,58.50);
INSERT INTO items VALUES (550,1,2,521,12,180.51);
INSERT INTO items VALUES (550,1,3,117,1,24.93);
INSERT INTO items VALUES (550,1,4,331,2,15.68);
INSERT INTO items VALUES (550,2,1,581,3,44.94);
INSERT INTO items VALUES (550,2,2,79,1,11.97);
INSERT INTO items VALUES (550,3,1,603,1,5.78);
INSERT INTO items VALUES (550,4,1,472,2,16.72);
INSERT INTO items VALUES (550,4,2,881,12,284.13);
INSERT INTO items VALUES (550,4,3,327,1,25.20);
INSERT INTO items VALUES (550,4,4,900,12,186.34);
INSERT INTO items VALUES (550,5,1,354,1,6.19);
INSERT INTO items VALUES (550,5,2,263,1,13.12);
INSERT INTO items VALUES (550,5,3,92,1,29.26);
INSERT INTO items VALUES (550,5,4,224,3,71.76);
INSERT INTO items VALUES (550,5,5,356,12,246.73);
INSERT INTO items VALUES (550,5,6,381,1,20.86);
INSERT INTO items VALUES (550,6,1,957,1,5.70);
INSERT INTO items VALUES (550,6,2,38,12,63.25);
INSERT INTO items VALUES (550,6,3,977,2,29.02);
INSERT INTO items VALUES (550,6,4,478,12,196.13);
INSERT INTO items VALUES (550,6,5,173,3,79.56);
INSERT INTO items VALUES (550,6,6,62,1,16.85);
INSERT INTO items VALUES (551,1,1,911,2,11.42);
INSERT INTO items VALUES (551,1,2,313,1,20.22);
INSERT INTO items VALUES (551,1,3,827,1,20.44);
INSERT INTO items VALUES (551,1,4,524,12,167.86);
INSERT INTO items VALUES (551,1,5,160,2,59.84);
INSERT INTO items VALUES (551,1,6,716,1,13.85);
INSERT INTO items VALUES (552,1,1,1032,2,39.86);
INSERT INTO items VALUES (552,1,2,375,1,23.40);
INSERT INTO items VALUES (552,2,1,165,3,81.51);
INSERT INTO items VALUES (552,2,2,39,1,7.38);
INSERT INTO items VALUES (552,2,3,563,1,26.82);
INSERT INTO items VALUES (552,2,4,716,2,27.70);
INSERT INTO items VALUES (552,2,5,198,12,151.91);
INSERT INTO items VALUES (552,3,1,401,12,184.25);
INSERT INTO items VALUES (552,3,2,1046,2,22.00);
INSERT INTO items VALUES (552,3,3,337,2,33.44);
INSERT INTO items VALUES (552,3,4,399,12,160.93);
INSERT INTO items VALUES (552,3,5,120,3,15.33);
INSERT INTO items VALUES (553,1,1,269,2,30.72);
INSERT INTO items VALUES (553,1,2,446,3,64.32);
INSERT INTO items VALUES (553,1,3,686,2,39.04);
INSERT INTO items VALUES (553,1,4,672,12,120.12);
INSERT INTO items VALUES (553,1,5,805,2,57.12);
INSERT INTO items VALUES (553,2,1,798,3,88.44);
INSERT INTO items VALUES (553,2,2,132,3,55.29);
INSERT INTO items VALUES (553,2,3,684,3,67.65);
INSERT INTO items VALUES (553,2,4,279,1,15.97);
INSERT INTO items VALUES (553,2,5,638,3,17.19);
INSERT INTO items VALUES (553,3,1,201,1,17.38);
INSERT INTO items VALUES (553,3,2,191,12,190.19);
INSERT INTO items VALUES (553,3,3,119,12,196.02);
INSERT INTO items VALUES (553,3,4,235,1,21.85);
INSERT INTO items VALUES (553,3,5,431,2,35.72);
INSERT INTO items VALUES (553,4,1,235,12,240.35);
INSERT INTO items VALUES (553,4,2,1046,2,22.00);
INSERT INTO items VALUES (553,4,3,875,3,40.08);
INSERT INTO items VALUES (554,1,1,742,12,250.69);
INSERT INTO items VALUES (554,1,2,807,3,29.61);
INSERT INTO items VALUES (554,1,3,107,3,19.23);
INSERT INTO items VALUES (554,1,4,800,1,18.16);
INSERT INTO items VALUES (555,1,1,315,12,285.23);
INSERT INTO items VALUES (555,1,2,702,2,17.64);
INSERT INTO items VALUES (555,1,3,321,3,35.07);
INSERT INTO items VALUES (555,1,4,946,2,19.02);
INSERT INTO items VALUES (555,1,5,999,12,193.71);
INSERT INTO items VALUES (555,1,6,719,12,111.76);
INSERT INTO items VALUES (556,1,1,876,2,25.46);
INSERT INTO items VALUES (556,1,2,811,12,63.25);
INSERT INTO items VALUES (556,1,3,559,2,13.34);
INSERT INTO items VALUES (556,1,4,991,2,53.12);
INSERT INTO items VALUES (556,2,1,692,2,35.80);
INSERT INTO items VALUES (556,3,1,282,2,55.66);
INSERT INTO items VALUES (557,1,1,351,3,76.41);
INSERT INTO items VALUES (558,1,1,1035,3,62.67);
INSERT INTO items VALUES (558,1,2,871,2,20.44);
INSERT INTO items VALUES (558,2,1,12,1,27.42);
INSERT INTO items VALUES (558,2,2,626,3,24.84);
INSERT INTO items VALUES (558,2,3,710,2,58.54);
INSERT INTO items VALUES (558,3,1,691,1,29.00);
INSERT INTO items VALUES (558,3,2,602,2,23.44);
INSERT INTO items VALUES (558,3,3,224,1,23.92);
INSERT INTO items VALUES (558,3,4,679,1,11.81);
INSERT INTO items VALUES (558,4,1,172,12,328.79);
INSERT INTO items VALUES (558,4,2,285,1,8.54);
INSERT INTO items VALUES (558,4,3,77,12,97.24);
INSERT INTO items VALUES (558,4,4,957,3,17.10);
INSERT INTO items VALUES (558,4,5,234,12,290.40);
INSERT INTO items VALUES (558,4,6,834,3,67.68);
INSERT INTO items VALUES (559,1,1,128,2,42.50);
INSERT INTO items VALUES (559,1,2,1004,2,48.36);
INSERT INTO items VALUES (560,1,1,2,12,309.65);
INSERT INTO items VALUES (560,2,1,650,12,256.74);
INSERT INTO items VALUES (560,3,1,986,3,19.68);
INSERT INTO items VALUES (560,3,2,423,12,295.68);
INSERT INTO items VALUES (560,3,3,995,12,154.88);
INSERT INTO items VALUES (560,3,4,350,12,153.89);
INSERT INTO items VALUES (560,3,5,678,1,26.45);
INSERT INTO items VALUES (560,3,6,932,2,42.14);
INSERT INTO items VALUES (561,1,1,253,3,84.72);
INSERT INTO items VALUES (561,1,2,428,1,6.24);
INSERT INTO items VALUES (561,1,3,660,1,12.11);
INSERT INTO items VALUES (561,1,4,633,2,32.36);
INSERT INTO items VALUES (561,1,5,873,1,20.65);
INSERT INTO items VALUES (561,2,1,5,3,20.01);
INSERT INTO items VALUES (561,2,2,123,1,7.70);
INSERT INTO items VALUES (561,2,3,410,2,35.08);
INSERT INTO items VALUES (562,1,1,223,12,143.44);
INSERT INTO items VALUES (562,2,1,978,1,10.05);
INSERT INTO items VALUES (562,2,2,264,3,38.52);
INSERT INTO items VALUES (562,2,3,892,12,79.75);
INSERT INTO items VALUES (562,3,1,952,3,64.44);
INSERT INTO items VALUES (562,3,2,552,3,15.90);
INSERT INTO items VALUES (563,1,1,117,1,24.93);
INSERT INTO items VALUES (563,1,2,937,12,63.25);
INSERT INTO items VALUES (563,2,1,572,12,302.39);
INSERT INTO items VALUES (563,2,2,265,2,33.46);
INSERT INTO items VALUES (563,2,3,777,3,71.10);
INSERT INTO items VALUES (563,2,4,623,12,243.10);
INSERT INTO items VALUES (563,2,5,629,1,24.19);
INSERT INTO items VALUES (563,2,6,538,2,29.00);
INSERT INTO items VALUES (563,3,1,355,12,223.63);
INSERT INTO items VALUES (563,3,2,777,1,23.70);
INSERT INTO items VALUES (563,3,3,965,3,77.55);
INSERT INTO items VALUES (563,3,4,633,12,177.98);
INSERT INTO items VALUES (563,3,5,781,1,24.74);
INSERT INTO items VALUES (564,1,1,880,12,292.82);
INSERT INTO items VALUES (564,1,2,229,12,76.89);
INSERT INTO items VALUES (564,1,3,472,3,25.08);
INSERT INTO items VALUES (564,1,4,445,3,64.29);
INSERT INTO items VALUES (564,2,1,1019,2,25.86);
INSERT INTO items VALUES (564,2,2,302,3,68.10);
INSERT INTO items VALUES (564,2,3,1047,1,13.85);
INSERT INTO items VALUES (565,1,1,585,3,80.55);
INSERT INTO items VALUES (565,1,2,87,2,34.38);
INSERT INTO items VALUES (565,2,1,24,3,55.80);
INSERT INTO items VALUES (565,2,2,245,2,57.72);
INSERT INTO items VALUES (565,2,3,700,3,58.05);
INSERT INTO items VALUES (565,2,4,238,1,24.15);
INSERT INTO items VALUES (565,2,5,931,12,157.74);
INSERT INTO items VALUES (565,2,6,64,12,289.63);
INSERT INTO items VALUES (565,3,1,555,3,26.37);
INSERT INTO items VALUES (565,3,2,932,3,63.21);
INSERT INTO items VALUES (566,1,1,154,1,5.97);
INSERT INTO items VALUES (566,1,2,144,2,52.42);
INSERT INTO items VALUES (566,1,3,855,3,21.69);
INSERT INTO items VALUES (566,1,4,657,12,191.73);
INSERT INTO items VALUES (566,1,5,656,2,50.86);
INSERT INTO items VALUES (566,1,6,983,3,78.33);
INSERT INTO items VALUES (567,1,1,463,1,27.14);
INSERT INTO items VALUES (567,2,1,72,12,274.56);
INSERT INTO items VALUES (567,2,2,605,1,20.78);
INSERT INTO items VALUES (567,2,3,17,12,277.53);
INSERT INTO items VALUES (567,3,1,1013,12,110.44);
INSERT INTO items VALUES (567,3,2,73,12,117.70);
INSERT INTO items VALUES (567,3,3,908,3,35.22);
INSERT INTO items VALUES (567,3,4,873,1,20.65);
INSERT INTO items VALUES (567,3,5,648,2,32.68);
INSERT INTO items VALUES (567,3,6,424,2,17.16);
INSERT INTO items VALUES (567,4,1,190,3,60.84);
INSERT INTO items VALUES (567,4,2,463,1,27.14);
INSERT INTO items VALUES (567,5,1,235,2,43.70);
INSERT INTO items VALUES (567,5,2,86,2,30.08);
INSERT INTO items VALUES (568,1,1,796,1,24.09);
INSERT INTO items VALUES (568,1,2,912,2,45.88);
INSERT INTO items VALUES (568,1,3,215,1,5.27);
INSERT INTO items VALUES (568,1,4,355,2,40.66);
INSERT INTO items VALUES (568,2,1,667,3,69.21);
INSERT INTO items VALUES (568,2,2,863,12,150.81);
INSERT INTO items VALUES (568,2,3,991,1,26.56);
INSERT INTO items VALUES (569,1,1,712,3,84.63);
INSERT INTO items VALUES (569,1,2,379,3,25.17);
INSERT INTO items VALUES (569,1,3,496,3,70.41);
INSERT INTO items VALUES (569,1,4,976,3,31.23);
INSERT INTO items VALUES (569,2,1,604,1,12.83);
INSERT INTO items VALUES (569,2,2,66,2,20.58);
INSERT INTO items VALUES (569,2,3,907,12,242.55);
INSERT INTO items VALUES (569,3,1,704,12,255.09);
INSERT INTO items VALUES (569,3,2,202,2,20.16);
INSERT INTO items VALUES (569,3,3,530,3,42.96);
INSERT INTO items VALUES (569,3,4,80,12,312.84);
INSERT INTO items VALUES (569,4,1,631,1,5.00);
INSERT INTO items VALUES (569,4,2,690,1,20.07);
INSERT INTO items VALUES (569,5,1,626,1,8.28);
INSERT INTO items VALUES (569,6,1,889,3,41.76);
INSERT INTO items VALUES (569,6,2,478,12,196.13);
INSERT INTO items VALUES (569,6,3,816,2,23.14);
INSERT INTO items VALUES (570,1,1,639,2,47.06);
INSERT INTO items VALUES (570,1,2,702,1,8.82);
INSERT INTO items VALUES (570,1,3,531,2,49.56);
INSERT INTO items VALUES (570,1,4,836,3,48.57);
INSERT INTO items VALUES (570,1,5,985,12,223.74);
INSERT INTO items VALUES (570,1,6,962,2,31.44);
INSERT INTO items VALUES (570,2,1,819,2,15.54);
INSERT INTO items VALUES (570,2,2,67,1,27.80);
INSERT INTO items VALUES (570,3,1,378,1,29.68);
INSERT INTO items VALUES (571,1,1,1034,3,44.88);
INSERT INTO items VALUES (571,1,2,725,12,265.98);
INSERT INTO items VALUES (571,2,1,404,12,297.11);
INSERT INTO items VALUES (571,2,2,892,1,7.25);
INSERT INTO items VALUES (571,2,3,1035,12,229.79);
INSERT INTO items VALUES (571,2,4,146,2,42.60);
INSERT INTO items VALUES (571,3,1,975,1,9.20);
INSERT INTO items VALUES (571,3,2,773,3,76.20);
INSERT INTO items VALUES (571,3,3,494,3,85.05);
INSERT INTO items VALUES (571,3,4,129,1,5.75);
INSERT INTO items VALUES (571,3,5,510,3,33.09);
INSERT INTO items VALUES (571,4,1,704,12,255.09);
INSERT INTO items VALUES (571,4,2,189,3,50.19);
INSERT INTO items VALUES (571,4,3,874,2,38.80);
INSERT INTO items VALUES (571,4,4,62,2,33.70);
INSERT INTO items VALUES (571,4,5,626,12,91.08);
INSERT INTO items VALUES (571,4,6,849,2,57.92);
INSERT INTO items VALUES (572,1,1,72,2,49.92);
INSERT INTO items VALUES (572,2,1,211,2,35.16);
INSERT INTO items VALUES (572,2,2,1028,1,13.90);
INSERT INTO items VALUES (572,3,1,542,1,19.52);
INSERT INTO items VALUES (572,3,2,42,1,21.28);
INSERT INTO items VALUES (572,3,3,597,2,55.34);
INSERT INTO items VALUES (572,3,4,936,12,223.74);
INSERT INTO items VALUES (572,4,1,539,12,115.28);
INSERT INTO items VALUES (573,1,1,843,3,24.33);
INSERT INTO items VALUES (573,1,2,239,3,72.57);
INSERT INTO items VALUES (573,2,1,291,1,9.95);
INSERT INTO items VALUES (573,2,2,183,3,75.81);
INSERT INTO items VALUES (574,1,1,482,2,49.90);
INSERT INTO items VALUES (574,1,2,498,12,181.28);
INSERT INTO items VALUES (574,2,1,991,12,292.16);
INSERT INTO items VALUES (574,2,2,116,12,130.57);
INSERT INTO items VALUES (575,1,1,329,1,14.98);
INSERT INTO items VALUES (575,1,2,1005,1,18.57);
INSERT INTO items VALUES (575,1,3,471,1,28.64);
INSERT INTO items VALUES (575,1,4,243,3,58.05);
INSERT INTO items VALUES (575,1,5,641,3,58.41);
INSERT INTO items VALUES (575,1,6,227,3,50.28);
INSERT INTO items VALUES (575,2,1,256,12,308.11);
INSERT INTO items VALUES (575,2,2,842,1,28.53);
INSERT INTO items VALUES (575,2,3,330,12,226.60);
INSERT INTO items VALUES (575,2,4,333,1,16.64);
INSERT INTO items VALUES (575,2,5,23,2,53.12);
INSERT INTO items VALUES (575,3,1,20,1,9.70);
INSERT INTO items VALUES (575,3,2,351,3,76.41);
INSERT INTO items VALUES (575,3,3,557,3,40.74);
INSERT INTO items VALUES (575,3,4,177,12,301.51);
INSERT INTO items VALUES (576,1,1,804,1,25.90);
INSERT INTO items VALUES (576,2,1,493,3,67.17);
INSERT INTO items VALUES (576,2,2,831,2,47.22);
INSERT INTO items VALUES (576,2,3,531,2,49.56);
INSERT INTO items VALUES (576,2,4,373,3,76.71);
INSERT INTO items VALUES (576,3,1,381,1,20.86);
INSERT INTO items VALUES (576,3,2,400,3,29.28);
INSERT INTO items VALUES (576,3,3,173,2,53.04);
INSERT INTO items VALUES (576,3,4,768,12,88.88);
INSERT INTO items VALUES (576,3,5,510,1,11.03);
INSERT INTO items VALUES (577,1,1,122,12,243.43);
INSERT INTO items VALUES (577,1,2,126,3,72.27);
INSERT INTO items VALUES (577,1,3,206,3,73.80);
INSERT INTO items VALUES (577,1,4,234,1,26.40);
INSERT INTO items VALUES (577,2,1,580,2,48.98);
INSERT INTO items VALUES (577,2,2,7,12,134.20);
INSERT INTO items VALUES (577,2,3,73,12,117.70);
INSERT INTO items VALUES (577,2,4,387,1,15.43);
INSERT INTO items VALUES (577,2,5,431,2,35.72);
INSERT INTO items VALUES (577,2,6,928,2,15.12);
INSERT INTO items VALUES (577,3,1,867,12,172.48);
INSERT INTO items VALUES (577,3,2,641,1,19.47);
INSERT INTO items VALUES (577,3,3,175,2,51.20);
INSERT INTO items VALUES (577,3,4,571,3,51.75);
INSERT INTO items VALUES (577,3,5,1008,3,85.95);
INSERT INTO items VALUES (577,3,6,209,12,162.80);
INSERT INTO items VALUES (578,1,1,167,12,231.55);
INSERT INTO items VALUES (578,1,2,735,3,66.33);
INSERT INTO items VALUES (578,1,3,82,12,245.30);
INSERT INTO items VALUES (578,1,4,579,12,84.48);
INSERT INTO items VALUES (578,1,5,245,2,57.72);
INSERT INTO items VALUES (578,2,1,686,12,214.72);
INSERT INTO items VALUES (578,2,2,814,2,27.04);
INSERT INTO items VALUES (578,2,3,202,3,30.24);
INSERT INTO items VALUES (578,2,4,669,3,40.86);
INSERT INTO items VALUES (578,2,5,409,12,245.74);
INSERT INTO items VALUES (579,1,1,245,12,317.46);
INSERT INTO items VALUES (579,1,2,475,1,28.84);
INSERT INTO items VALUES (579,1,3,1042,12,294.36);
INSERT INTO items VALUES (579,1,4,37,1,14.15);
INSERT INTO items VALUES (579,1,5,127,3,53.58);
INSERT INTO items VALUES (579,1,6,171,3,81.90);
INSERT INTO items VALUES (579,2,1,864,3,70.44);
INSERT INTO items VALUES (579,2,2,92,3,87.78);
INSERT INTO items VALUES (579,2,3,905,1,11.44);
INSERT INTO items VALUES (579,2,4,963,1,25.32);
INSERT INTO items VALUES (579,2,5,547,1,24.75);
INSERT INTO items VALUES (579,3,1,701,2,48.64);
INSERT INTO items VALUES (579,3,2,703,12,294.47);
INSERT INTO items VALUES (579,3,3,24,12,204.60);
INSERT INTO items VALUES (579,3,4,424,2,17.16);
INSERT INTO items VALUES (580,1,1,282,2,55.66);
INSERT INTO items VALUES (580,1,2,214,2,55.90);
INSERT INTO items VALUES (580,1,3,200,1,11.88);
INSERT INTO items VALUES (580,2,1,34,2,28.56);
INSERT INTO items VALUES (580,2,2,1029,3,45.57);
INSERT INTO items VALUES (580,3,1,197,2,23.46);
INSERT INTO items VALUES (580,3,2,323,1,13.60);
INSERT INTO items VALUES (580,3,3,605,12,228.58);
INSERT INTO items VALUES (580,4,1,373,3,76.71);
INSERT INTO items VALUES (580,4,2,882,12,238.59);
INSERT INTO items VALUES (580,4,3,279,3,47.91);
INSERT INTO items VALUES (580,4,4,111,2,55.76);
INSERT INTO items VALUES (580,4,5,904,1,18.63);
INSERT INTO items VALUES (581,1,1,234,3,79.20);
INSERT INTO items VALUES (581,2,1,115,2,28.04);
INSERT INTO items VALUES (581,2,2,91,12,127.38);
INSERT INTO items VALUES (581,2,3,834,12,248.16);
INSERT INTO items VALUES (581,2,4,747,3,80.94);
INSERT INTO items VALUES (581,3,1,1017,3,42.90);
INSERT INTO items VALUES (581,4,1,251,1,5.71);
INSERT INTO items VALUES (581,4,2,796,3,72.27);
INSERT INTO items VALUES (581,4,3,718,12,111.10);
INSERT INTO items VALUES (581,4,4,331,12,86.24);
INSERT INTO items VALUES (581,5,1,239,3,72.57);
INSERT INTO items VALUES (581,5,2,397,3,34.14);
INSERT INTO items VALUES (581,5,3,790,1,12.43);
INSERT INTO items VALUES (581,5,4,772,3,39.87);
INSERT INTO items VALUES (581,5,5,839,2,39.00);
INSERT INTO items VALUES (582,1,1,375,1,23.40);
INSERT INTO items VALUES (582,1,2,186,1,8.53);
INSERT INTO items VALUES (582,1,3,383,12,207.79);
INSERT INTO items VALUES (582,2,1,185,3,47.76);
INSERT INTO items VALUES (582,2,2,708,3,27.36);
INSERT INTO items VALUES (582,3,1,116,12,130.57);
INSERT INTO items VALUES (582,3,2,678,2,52.90);
INSERT INTO items VALUES (582,3,3,474,1,26.72);
INSERT INTO items VALUES (583,1,1,233,12,62.15);
INSERT INTO items VALUES (583,1,2,164,1,9.40);
INSERT INTO items VALUES (583,1,3,815,2,12.88);
INSERT INTO items VALUES (583,1,4,364,2,45.58);
INSERT INTO items VALUES (583,2,1,349,2,31.18);
INSERT INTO items VALUES (583,2,2,744,1,13.54);
INSERT INTO items VALUES (583,2,3,106,1,26.10);
INSERT INTO items VALUES (583,2,4,668,1,14.85);
INSERT INTO items VALUES (583,3,1,16,12,98.45);
INSERT INTO items VALUES (583,3,2,217,1,6.83);
INSERT INTO items VALUES (583,3,3,80,12,312.84);
INSERT INTO items VALUES (583,4,1,97,1,12.11);
INSERT INTO items VALUES (583,4,2,334,2,28.50);
INSERT INTO items VALUES (583,4,3,690,1,20.07);
INSERT INTO items VALUES (583,4,4,640,12,125.95);
INSERT INTO items VALUES (583,4,5,232,1,14.33);
INSERT INTO items VALUES (583,5,1,162,1,19.64);
INSERT INTO items VALUES (583,5,2,749,2,11.14);
INSERT INTO items VALUES (583,5,3,367,12,218.57);
INSERT INTO items VALUES (583,5,4,361,12,140.36);
INSERT INTO items VALUES (583,5,5,223,12,143.44);
INSERT INTO items VALUES (583,6,1,257,12,328.02);
INSERT INTO items VALUES (583,6,2,831,12,259.71);
INSERT INTO items VALUES (583,6,3,650,1,23.34);
INSERT INTO items VALUES (583,6,4,107,3,19.23);
INSERT INTO items VALUES (583,6,5,421,12,157.30);
INSERT INTO items VALUES (584,1,1,508,12,313.28);
INSERT INTO items VALUES (584,1,2,1015,2,56.70);
INSERT INTO items VALUES (584,1,3,176,3,62.22);
INSERT INTO items VALUES (584,1,4,196,12,227.15);
INSERT INTO items VALUES (584,2,1,200,12,130.68);
INSERT INTO items VALUES (584,2,2,427,1,20.01);
INSERT INTO items VALUES (584,2,3,962,12,172.92);
INSERT INTO items VALUES (584,2,4,635,3,64.17);
INSERT INTO items VALUES (584,2,5,595,3,86.85);
INSERT INTO items VALUES (584,3,1,150,3,25.98);
INSERT INTO items VALUES (584,3,2,783,2,55.74);
INSERT INTO items VALUES (584,4,1,1010,12,210.98);
INSERT INTO items VALUES (584,4,2,770,1,15.81);
INSERT INTO items VALUES (584,4,3,733,1,9.71);
INSERT INTO items VALUES (584,4,4,375,3,70.20);
INSERT INTO items VALUES (584,4,5,70,12,176.55);
INSERT INTO items VALUES (584,4,6,343,3,17.10);
INSERT INTO items VALUES (585,1,1,1030,12,233.31);
INSERT INTO items VALUES (585,2,1,443,1,29.32);
INSERT INTO items VALUES (585,2,2,310,2,20.52);
INSERT INTO items VALUES (585,3,1,806,12,91.74);
INSERT INTO items VALUES (585,4,1,389,12,192.72);
INSERT INTO items VALUES (585,4,2,163,1,20.38);
INSERT INTO items VALUES (585,5,1,388,3,73.17);
INSERT INTO items VALUES (585,5,2,53,3,79.86);
INSERT INTO items VALUES (585,5,3,458,2,16.02);
INSERT INTO items VALUES (585,5,4,712,2,56.42);
INSERT INTO items VALUES (585,5,5,321,2,23.38);
INSERT INTO items VALUES (586,1,1,974,3,19.11);
INSERT INTO items VALUES (586,1,2,1047,12,152.35);
INSERT INTO items VALUES (586,1,3,837,1,8.82);
INSERT INTO items VALUES (586,1,4,434,1,25.44);
INSERT INTO items VALUES (586,2,1,673,1,26.02);
INSERT INTO items VALUES (586,2,2,89,1,27.85);
INSERT INTO items VALUES (586,2,3,962,2,31.44);
INSERT INTO items VALUES (586,2,4,468,1,28.60);
INSERT INTO items VALUES (586,3,1,703,3,80.31);
INSERT INTO items VALUES (586,3,2,222,3,72.60);
INSERT INTO items VALUES (586,3,3,355,1,20.33);
INSERT INTO items VALUES (586,3,4,918,12,172.70);
INSERT INTO items VALUES (587,1,1,862,2,13.42);
INSERT INTO items VALUES (587,2,1,974,12,70.07);
INSERT INTO items VALUES (587,2,2,801,12,56.87);
INSERT INTO items VALUES (587,2,3,529,2,58.20);
INSERT INTO items VALUES (587,2,4,672,1,10.92);
INSERT INTO items VALUES (588,1,1,801,2,10.34);
INSERT INTO items VALUES (588,1,2,89,12,306.35);
INSERT INTO items VALUES (588,1,3,283,1,28.83);
INSERT INTO items VALUES (588,1,4,803,3,62.07);
INSERT INTO items VALUES (588,2,1,69,12,182.71);
INSERT INTO items VALUES (588,2,2,575,1,25.67);
INSERT INTO items VALUES (588,2,3,452,12,85.58);
INSERT INTO items VALUES (588,2,4,710,3,87.81);
INSERT INTO items VALUES (588,2,5,445,12,235.73);
INSERT INTO items VALUES (588,3,1,43,12,306.02);
INSERT INTO items VALUES (588,3,2,866,2,29.18);
INSERT INTO items VALUES (588,3,3,75,3,68.19);
INSERT INTO items VALUES (588,3,4,871,2,20.44);
INSERT INTO items VALUES (588,3,5,336,3,83.73);
INSERT INTO items VALUES (588,3,6,630,2,56.00);
INSERT INTO items VALUES (588,4,1,853,1,29.23);
INSERT INTO items VALUES (588,4,2,497,1,21.46);
INSERT INTO items VALUES (588,4,3,232,2,28.66);
INSERT INTO items VALUES (588,4,4,224,2,47.84);
INSERT INTO items VALUES (588,4,5,560,12,252.01);
INSERT INTO items VALUES (588,4,6,183,2,50.54);
INSERT INTO items VALUES (589,1,1,162,3,58.92);
INSERT INTO items VALUES (589,1,2,205,3,38.97);
INSERT INTO items VALUES (589,1,3,310,3,30.78);
INSERT INTO items VALUES (589,1,4,140,12,65.45);
INSERT INTO items VALUES (590,1,1,698,12,170.50);
INSERT INTO items VALUES (590,2,1,899,1,7.35);
INSERT INTO items VALUES (590,2,2,906,3,30.99);
INSERT INTO items VALUES (590,2,3,352,2,19.50);
INSERT INTO items VALUES (590,2,4,887,1,15.10);
INSERT INTO items VALUES (590,2,5,685,2,22.44);
INSERT INTO items VALUES (590,3,1,77,1,8.84);
INSERT INTO items VALUES (590,3,2,184,3,81.33);
INSERT INTO items VALUES (590,3,3,374,12,102.08);
INSERT INTO items VALUES (590,3,4,434,12,279.84);
INSERT INTO items VALUES (590,3,5,42,1,21.28);
INSERT INTO items VALUES (590,3,6,639,3,70.59);
INSERT INTO items VALUES (590,4,1,718,1,10.10);
INSERT INTO items VALUES (590,4,2,553,2,18.46);
INSERT INTO items VALUES (590,4,3,532,12,306.68);
INSERT INTO items VALUES (591,1,1,113,1,19.25);
INSERT INTO items VALUES (591,1,2,990,12,140.58);
INSERT INTO items VALUES (591,1,3,462,12,261.58);
INSERT INTO items VALUES (591,1,4,1036,3,35.22);
INSERT INTO items VALUES (591,2,1,378,2,59.36);
INSERT INTO items VALUES (591,3,1,15,3,36.99);
INSERT INTO items VALUES (591,3,2,994,2,30.88);
INSERT INTO items VALUES (591,3,3,632,2,32.96);
INSERT INTO items VALUES (591,3,4,1029,3,45.57);
INSERT INTO items VALUES (591,4,1,226,2,17.36);
INSERT INTO items VALUES (591,4,2,62,1,16.85);
INSERT INTO items VALUES (591,4,3,466,12,129.91);
INSERT INTO items VALUES (592,1,1,620,2,51.60);
INSERT INTO items VALUES (593,1,1,140,2,11.90);
INSERT INTO items VALUES (593,1,2,242,12,311.52);
INSERT INTO items VALUES (593,1,3,220,12,129.14);
INSERT INTO items VALUES (593,1,4,387,2,30.86);
INSERT INTO items VALUES (594,1,1,326,3,39.48);
INSERT INTO items VALUES (594,1,2,337,1,16.72);
INSERT INTO items VALUES (594,1,3,792,12,71.39);
INSERT INTO items VALUES (595,1,1,638,12,63.03);
INSERT INTO items VALUES (595,1,2,419,12,121.44);
INSERT INTO items VALUES (595,1,3,966,3,31.35);
INSERT INTO items VALUES (595,1,4,749,2,11.14);
INSERT INTO items VALUES (595,1,5,36,12,324.61);
INSERT INTO items VALUES (595,1,6,752,2,17.18);
INSERT INTO items VALUES (595,2,1,737,2,52.38);
INSERT INTO items VALUES (595,2,2,290,3,26.73);
INSERT INTO items VALUES (595,2,3,135,1,11.58);
INSERT INTO items VALUES (595,2,4,825,1,29.63);
INSERT INTO items VALUES (595,3,1,282,12,306.13);
INSERT INTO items VALUES (595,3,2,606,12,278.41);
INSERT INTO items VALUES (595,3,3,269,3,46.08);
INSERT INTO items VALUES (595,3,4,902,12,118.47);
INSERT INTO items VALUES (595,3,5,102,2,13.42);
INSERT INTO items VALUES (595,3,6,1008,1,28.65);
INSERT INTO items VALUES (595,4,1,691,1,29.00);
INSERT INTO items VALUES (596,1,1,360,2,23.88);
INSERT INTO items VALUES (596,1,2,1013,2,20.08);
INSERT INTO items VALUES (596,1,3,988,12,122.87);
INSERT INTO items VALUES (596,1,4,594,3,18.24);
INSERT INTO items VALUES (596,1,5,848,3,52.11);
INSERT INTO items VALUES (596,2,1,168,12,268.07);
INSERT INTO items VALUES (596,2,2,74,1,12.56);
INSERT INTO items VALUES (597,1,1,671,12,288.09);
INSERT INTO items VALUES (597,1,2,1024,1,19.85);
INSERT INTO items VALUES (597,1,3,968,2,37.38);
INSERT INTO items VALUES (597,1,4,994,12,169.84);
INSERT INTO items VALUES (597,2,1,948,1,8.38);
INSERT INTO items VALUES (597,2,2,769,1,5.74);
INSERT INTO items VALUES (597,2,3,408,3,47.85);
INSERT INTO items VALUES (597,2,4,153,3,69.33);
INSERT INTO items VALUES (597,2,5,175,1,25.60);
INSERT INTO items VALUES (597,2,6,4,1,21.16);
INSERT INTO items VALUES (597,3,1,935,2,57.12);
INSERT INTO items VALUES (597,3,2,498,12,181.28);
INSERT INTO items VALUES (597,4,1,638,2,11.46);
INSERT INTO items VALUES (597,4,2,957,2,11.40);
INSERT INTO items VALUES (597,4,3,494,2,56.70);
INSERT INTO items VALUES (597,4,4,1009,3,66.39);
INSERT INTO items VALUES (597,4,5,933,1,27.47);
INSERT INTO items VALUES (598,1,1,83,12,170.94);
INSERT INTO items VALUES (598,2,1,414,2,44.46);
INSERT INTO items VALUES (598,3,1,307,2,10.56);
INSERT INTO items VALUES (598,3,2,76,1,17.94);
INSERT INTO items VALUES (598,3,3,416,12,279.29);
INSERT INTO items VALUES (598,4,1,489,12,234.85);
INSERT INTO items VALUES (598,4,2,168,12,268.07);
INSERT INTO items VALUES (598,5,1,634,12,86.57);
INSERT INTO items VALUES (598,5,2,139,3,46.62);
INSERT INTO items VALUES (598,6,1,109,1,16.00);
INSERT INTO items VALUES (598,6,2,421,12,157.30);
INSERT INTO items VALUES (599,1,1,507,2,36.04);
INSERT INTO items VALUES (599,2,1,541,3,52.86);
INSERT INTO items VALUES (599,2,2,151,2,44.74);
INSERT INTO items VALUES (599,2,3,21,1,19.14);
INSERT INTO items VALUES (599,2,4,537,3,78.90);
INSERT INTO items VALUES (599,3,1,898,12,242.22);
INSERT INTO items VALUES (599,3,2,226,3,26.04);
INSERT INTO items VALUES (599,3,3,452,3,23.34);
INSERT INTO items VALUES (599,3,4,768,12,88.88);
INSERT INTO items VALUES (599,3,5,1033,3,88.11);
INSERT INTO items VALUES (600,1,1,330,2,41.20);
INSERT INTO items VALUES (600,1,2,331,3,23.52);
INSERT INTO items VALUES (600,2,1,510,12,121.33);
INSERT INTO items VALUES (600,2,2,807,2,19.74);
INSERT INTO items VALUES (600,2,3,164,2,18.80);
INSERT INTO items VALUES (600,2,4,741,3,38.67);
INSERT INTO items VALUES (600,2,5,228,3,65.79);
INSERT INTO items VALUES (600,2,6,688,12,173.47);
INSERT INTO items VALUES (600,3,1,979,12,312.29);
INSERT INTO items VALUES (600,3,2,132,1,18.43);
INSERT INTO items VALUES (600,3,3,515,12,275.99);
INSERT INTO items VALUES (600,3,4,305,2,10.54);
INSERT INTO items VALUES (600,3,5,666,1,15.55);
INSERT INTO items VALUES (600,4,1,842,3,85.59);
INSERT INTO items VALUES (600,4,2,246,1,18.57);
INSERT INTO items VALUES (600,4,3,265,12,184.03);
INSERT INTO items VALUES (600,4,4,948,3,25.14);
INSERT INTO items VALUES (600,5,1,69,2,33.22);
INSERT INTO items VALUES (600,5,2,664,3,78.24);
INSERT INTO items VALUES (600,5,3,410,12,192.94);
INSERT INTO items VALUES (601,1,1,690,2,40.14);
INSERT INTO items VALUES (601,1,2,728,2,10.96);
INSERT INTO items VALUES (601,1,3,552,3,15.90);
INSERT INTO items VALUES (601,1,4,568,2,22.64);
INSERT INTO items VALUES (601,1,5,649,1,17.09);
INSERT INTO items VALUES (601,1,6,240,1,11.44);
INSERT INTO items VALUES (601,2,1,730,3,73.98);
INSERT INTO items VALUES (601,2,2,867,3,47.04);
INSERT INTO items VALUES (601,2,3,608,12,324.28);
INSERT INTO items VALUES (601,3,1,968,1,18.69);
INSERT INTO items VALUES (601,4,1,98,2,48.98);
INSERT INTO items VALUES (601,5,1,556,2,11.56);
INSERT INTO items VALUES (601,5,2,106,1,26.10);
INSERT INTO items VALUES (601,6,1,728,2,10.96);
INSERT INTO items VALUES (601,6,2,419,3,33.12);
INSERT INTO items VALUES (601,6,3,818,12,72.27);
INSERT INTO items VALUES (602,1,1,606,3,75.93);
INSERT INTO items VALUES (602,1,2,531,2,49.56);
INSERT INTO items VALUES (602,1,3,269,12,168.96);
INSERT INTO items VALUES (602,1,4,987,3,83.82);
INSERT INTO items VALUES (602,1,5,924,1,20.67);
INSERT INTO items VALUES (602,2,1,951,3,73.59);
INSERT INTO items VALUES (602,2,2,297,3,75.81);
INSERT INTO items VALUES (602,2,3,437,1,8.61);
INSERT INTO items VALUES (602,2,4,46,1,15.67);
INSERT INTO items VALUES (602,2,5,885,12,101.42);
INSERT INTO items VALUES (602,2,6,1010,3,57.54);
INSERT INTO items VALUES (602,3,1,964,3,39.99);
INSERT INTO items VALUES (602,3,2,478,12,196.13);
INSERT INTO items VALUES (602,3,3,705,1,9.97);
INSERT INTO items VALUES (602,3,4,666,3,46.65);
INSERT INTO items VALUES (602,3,5,447,12,149.38);
INSERT INTO items VALUES (602,3,6,905,2,22.88);
INSERT INTO items VALUES (603,1,1,596,1,18.47);
INSERT INTO items VALUES (603,2,1,90,3,20.31);
INSERT INTO items VALUES (603,2,2,728,3,16.44);
INSERT INTO items VALUES (603,2,3,66,2,20.58);
INSERT INTO items VALUES (603,2,4,356,1,22.43);
INSERT INTO items VALUES (603,2,5,137,12,141.35);
INSERT INTO items VALUES (603,3,1,101,1,8.73);
INSERT INTO items VALUES (603,3,2,142,3,45.00);
INSERT INTO items VALUES (603,3,3,288,3,44.85);
INSERT INTO items VALUES (603,4,1,723,2,41.66);
INSERT INTO items VALUES (603,4,2,319,2,29.40);
INSERT INTO items VALUES (603,4,3,127,2,35.72);
INSERT INTO items VALUES (603,4,4,921,2,50.60);
INSERT INTO items VALUES (603,4,5,470,1,9.44);
INSERT INTO items VALUES (603,5,1,192,12,246.07);
INSERT INTO items VALUES (603,5,2,834,2,45.12);
INSERT INTO items VALUES (603,5,3,332,1,25.29);
INSERT INTO items VALUES (603,5,4,23,1,26.56);
INSERT INTO items VALUES (604,1,1,1021,2,43.54);
INSERT INTO items VALUES (604,1,2,931,2,28.68);
INSERT INTO items VALUES (604,1,3,224,2,47.84);
INSERT INTO items VALUES (604,1,4,827,1,20.44);
INSERT INTO items VALUES (604,1,5,804,3,77.70);
INSERT INTO items VALUES (604,2,1,383,1,18.89);
INSERT INTO items VALUES (604,2,2,53,2,53.24);
INSERT INTO items VALUES (604,2,3,38,1,5.75);
INSERT INTO items VALUES (604,2,4,821,12,62.59);
INSERT INTO items VALUES (604,2,5,77,1,8.84);
INSERT INTO items VALUES (604,3,1,61,3,50.94);
INSERT INTO items VALUES (604,3,2,309,12,213.40);
INSERT INTO items VALUES (604,3,3,804,1,25.90);
INSERT INTO items VALUES (604,3,4,619,12,228.69);
INSERT INTO items VALUES (604,3,5,73,1,10.70);
INSERT INTO items VALUES (604,3,6,940,3,36.54);
INSERT INTO items VALUES (605,1,1,232,12,157.63);
INSERT INTO items VALUES (605,1,2,893,2,48.88);
INSERT INTO items VALUES (605,1,3,132,3,55.29);
INSERT INTO items VALUES (605,1,4,277,1,26.37);
INSERT INTO items VALUES (605,1,5,326,3,39.48);
INSERT INTO items VALUES (605,2,1,844,12,207.02);
INSERT INTO items VALUES (605,2,2,582,12,229.68);
INSERT INTO items VALUES (605,2,3,817,1,18.75);
INSERT INTO items VALUES (605,3,1,909,12,240.24);
INSERT INTO items VALUES (605,3,2,229,3,20.97);
INSERT INTO items VALUES (605,3,3,126,2,48.18);
INSERT INTO items VALUES (605,4,1,127,1,17.86);
INSERT INTO items VALUES (605,4,2,217,1,6.83);
INSERT INTO items VALUES (605,4,3,598,1,12.93);
INSERT INTO items VALUES (605,4,4,956,1,20.11);
INSERT INTO items VALUES (605,4,5,966,3,31.35);
INSERT INTO items VALUES (605,4,6,333,3,49.92);
INSERT INTO items VALUES (605,5,1,1047,12,152.35);
INSERT INTO items VALUES (606,1,1,313,3,60.66);
INSERT INTO items VALUES (606,1,2,630,2,56.00);
INSERT INTO items VALUES (606,1,3,950,3,33.18);
INSERT INTO items VALUES (606,2,1,498,2,32.96);
INSERT INTO items VALUES (606,2,2,952,3,64.44);
INSERT INTO items VALUES (606,2,3,545,1,17.10);
INSERT INTO items VALUES (606,3,1,452,3,23.34);
INSERT INTO items VALUES (606,4,1,780,2,14.62);
INSERT INTO items VALUES (606,4,2,352,3,29.25);
INSERT INTO items VALUES (606,4,3,967,2,14.96);
INSERT INTO items VALUES (606,5,1,6,12,222.75);
INSERT INTO items VALUES (606,5,2,843,3,24.33);
INSERT INTO items VALUES (606,5,3,859,12,112.86);
INSERT INTO items VALUES (606,5,4,969,12,153.23);
INSERT INTO items VALUES (607,1,1,589,12,237.16);
INSERT INTO items VALUES (607,1,2,79,12,131.67);
INSERT INTO items VALUES (607,2,1,228,3,65.79);
INSERT INTO items VALUES (607,2,2,191,12,190.19);
INSERT INTO items VALUES (607,2,3,534,12,177.65);
INSERT INTO items VALUES (607,3,1,385,2,41.62);
INSERT INTO items VALUES (607,3,2,781,12,272.14);
INSERT INTO items VALUES (607,4,1,456,1,25.66);
INSERT INTO items VALUES (607,4,2,625,1,17.99);
INSERT INTO items VALUES (607,4,3,256,3,84.03);
INSERT INTO items VALUES (607,4,4,590,2,30.66);
INSERT INTO items VALUES (607,4,5,123,3,23.10);
INSERT INTO items VALUES (607,5,1,760,1,6.12);
INSERT INTO items VALUES (607,5,2,568,1,11.32);
INSERT INTO items VALUES (608,1,1,428,2,12.48);
INSERT INTO items VALUES (608,1,2,190,2,40.56);
INSERT INTO items VALUES (608,1,3,1035,2,41.78);
INSERT INTO items VALUES (608,1,4,688,3,47.31);
INSERT INTO items VALUES (608,1,5,880,1,26.62);
INSERT INTO items VALUES (608,2,1,779,3,59.61);
INSERT INTO items VALUES (608,3,1,498,1,16.48);
INSERT INTO items VALUES (608,3,2,1012,1,17.85);
INSERT INTO items VALUES (608,3,3,838,2,38.60);
INSERT INTO items VALUES (608,3,4,552,12,58.30);
INSERT INTO items VALUES (608,3,5,823,3,69.60);
INSERT INTO items VALUES (608,4,1,1014,1,13.82);
INSERT INTO items VALUES (608,4,2,1006,2,40.32);
INSERT INTO items VALUES (608,4,3,243,3,58.05);
INSERT INTO items VALUES (608,4,4,1018,1,9.22);
INSERT INTO items VALUES (608,4,5,699,1,19.71);
INSERT INTO items VALUES (609,1,1,545,1,17.10);
INSERT INTO items VALUES (609,1,2,426,2,17.34);
INSERT INTO items VALUES (609,1,3,871,12,112.42);
INSERT INTO items VALUES (609,1,4,793,2,32.74);
INSERT INTO items VALUES (609,1,5,36,12,324.61);
INSERT INTO items VALUES (609,1,6,869,12,197.23);
INSERT INTO items VALUES (609,2,1,77,2,17.68);
INSERT INTO items VALUES (609,2,2,902,1,10.77);
INSERT INTO items VALUES (609,3,1,794,1,10.52);
INSERT INTO items VALUES (609,3,2,624,1,22.25);
INSERT INTO items VALUES (609,3,3,689,2,20.06);
INSERT INTO items VALUES (609,3,4,86,2,30.08);
INSERT INTO items VALUES (609,4,1,24,2,37.20);
INSERT INTO items VALUES (609,4,2,446,2,42.88);
INSERT INTO items VALUES (609,5,1,699,3,59.13);
INSERT INTO items VALUES (609,5,2,368,2,56.74);
INSERT INTO items VALUES (609,5,3,185,1,15.92);
INSERT INTO items VALUES (609,6,1,939,2,28.74);
INSERT INTO items VALUES (609,6,2,837,2,17.64);
INSERT INTO items VALUES (609,6,3,470,3,28.32);
INSERT INTO items VALUES (609,6,4,780,2,14.62);
INSERT INTO items VALUES (610,1,1,99,1,24.40);
INSERT INTO items VALUES (610,1,2,85,3,64.62);
INSERT INTO items VALUES (610,1,3,558,2,57.18);
INSERT INTO items VALUES (610,2,1,274,3,18.66);
INSERT INTO items VALUES (610,2,2,799,3,41.61);
INSERT INTO items VALUES (610,2,3,316,1,28.78);
INSERT INTO items VALUES (610,2,4,185,12,175.12);
INSERT INTO items VALUES (610,2,5,972,3,72.63);
INSERT INTO items VALUES (610,2,6,818,1,6.57);
INSERT INTO items VALUES (610,3,1,38,2,11.50);
INSERT INTO items VALUES (610,3,2,598,3,38.79);
INSERT INTO items VALUES (610,3,3,675,2,43.86);
INSERT INTO items VALUES (610,3,4,217,2,13.66);
INSERT INTO items VALUES (610,3,5,143,1,12.49);
INSERT INTO items VALUES (610,3,6,485,1,22.86);
INSERT INTO items VALUES (610,4,1,170,12,107.25);
INSERT INTO items VALUES (610,4,2,970,12,314.27);
INSERT INTO items VALUES (610,5,1,987,12,307.34);
INSERT INTO items VALUES (610,5,2,176,3,62.22);
INSERT INTO items VALUES (610,5,3,573,12,223.96);
INSERT INTO items VALUES (610,5,4,1027,12,316.03);
INSERT INTO items VALUES (610,5,5,319,1,14.70);
INSERT INTO items VALUES (610,5,6,911,12,62.81);
INSERT INTO items VALUES (610,6,1,659,1,24.38);
INSERT INTO items VALUES (610,6,2,738,3,72.66);
INSERT INTO items VALUES (610,6,3,104,3,19.26);
INSERT INTO items VALUES (610,6,4,934,1,25.09);
INSERT INTO items VALUES (610,6,5,425,12,174.35);
INSERT INTO items VALUES (611,1,1,434,2,50.88);
INSERT INTO items VALUES (611,1,2,625,3,53.97);
INSERT INTO items VALUES (612,1,1,375,3,70.20);
INSERT INTO items VALUES (612,2,1,147,12,215.38);
INSERT INTO items VALUES (612,2,2,693,2,56.16);
INSERT INTO items VALUES (612,2,3,891,12,259.60);
INSERT INTO items VALUES (612,2,4,981,2,49.80);
INSERT INTO items VALUES (613,1,1,915,3,37.53);
INSERT INTO items VALUES (613,1,2,292,2,15.68);
INSERT INTO items VALUES (613,2,1,1002,3,71.91);
INSERT INTO items VALUES (613,3,1,962,1,15.72);
INSERT INTO items VALUES (613,3,2,70,2,32.10);
INSERT INTO items VALUES (613,3,3,325,12,145.31);
INSERT INTO items VALUES (613,3,4,184,1,27.11);
INSERT INTO items VALUES (613,3,5,1037,2,53.34);
INSERT INTO items VALUES (614,1,1,452,3,23.34);
INSERT INTO items VALUES (614,2,1,452,1,7.78);
INSERT INTO items VALUES (615,1,1,632,12,181.28);
INSERT INTO items VALUES (615,2,1,246,3,55.71);
INSERT INTO items VALUES (616,1,1,809,2,18.38);
INSERT INTO items VALUES (616,1,2,91,12,127.38);
INSERT INTO items VALUES (616,1,3,747,2,53.96);
INSERT INTO items VALUES (616,1,4,26,1,26.03);
INSERT INTO items VALUES (616,2,1,990,2,25.56);
INSERT INTO items VALUES (616,2,2,572,12,302.39);
INSERT INTO items VALUES (616,2,3,154,3,17.91);
INSERT INTO items VALUES (616,2,4,1035,12,229.79);
INSERT INTO items VALUES (617,1,1,556,12,63.58);
INSERT INTO items VALUES (617,1,2,580,2,48.98);
INSERT INTO items VALUES (617,1,3,511,12,161.92);
INSERT INTO items VALUES (617,2,1,574,3,56.73);
INSERT INTO items VALUES (617,3,1,999,12,193.71);
INSERT INTO items VALUES (617,3,2,355,12,223.63);
INSERT INTO items VALUES (617,3,3,743,1,7.98);
INSERT INTO items VALUES (617,3,4,753,12,238.70);
INSERT INTO items VALUES (617,3,5,645,1,18.13);
INSERT INTO items VALUES (617,4,1,472,1,8.36);
INSERT INTO items VALUES (617,4,2,966,3,31.35);
INSERT INTO items VALUES (617,4,3,169,2,19.50);
INSERT INTO items VALUES (617,4,4,215,1,5.27);
INSERT INTO items VALUES (617,4,5,511,2,29.44);
INSERT INTO items VALUES (617,5,1,593,12,75.24);
INSERT INTO items VALUES (617,5,2,1023,2,30.98);
INSERT INTO items VALUES (617,5,3,974,3,19.11);
INSERT INTO items VALUES (617,5,4,558,3,85.77);
INSERT INTO items VALUES (617,5,5,795,2,42.92);
INSERT INTO items VALUES (617,6,1,765,12,328.68);
INSERT INTO items VALUES (617,6,2,130,12,173.36);
INSERT INTO items VALUES (617,6,3,935,3,85.68);
INSERT INTO items VALUES (617,6,4,404,3,81.03);
INSERT INTO items VALUES (618,1,1,1037,3,80.01);
INSERT INTO items VALUES (618,1,2,909,3,65.52);
INSERT INTO items VALUES (618,1,3,263,3,39.36);
INSERT INTO items VALUES (618,1,4,355,3,60.99);
INSERT INTO items VALUES (618,1,5,559,1,6.67);
INSERT INTO items VALUES (618,1,6,1013,2,20.08);
INSERT INTO items VALUES (618,2,1,282,3,83.49);
INSERT INTO items VALUES (619,1,1,236,1,22.01);
INSERT INTO items VALUES (619,2,1,729,1,6.71);
INSERT INTO items VALUES (619,3,1,659,2,48.76);
INSERT INTO items VALUES (619,3,2,641,12,214.17);
INSERT INTO items VALUES (619,3,3,1029,1,15.19);
INSERT INTO items VALUES (619,3,4,903,12,258.94);
INSERT INTO items VALUES (620,1,1,903,2,47.08);
INSERT INTO items VALUES (620,1,2,65,1,9.98);
INSERT INTO items VALUES (620,2,1,894,3,23.64);
INSERT INTO items VALUES (620,2,2,802,2,24.48);
INSERT INTO items VALUES (620,2,3,306,1,26.47);
INSERT INTO items VALUES (621,1,1,699,3,59.13);
INSERT INTO items VALUES (622,1,1,648,12,179.74);
INSERT INTO items VALUES (622,1,2,263,3,39.36);
INSERT INTO items VALUES (622,1,3,87,3,51.57);
INSERT INTO items VALUES (622,1,4,242,12,311.52);
INSERT INTO items VALUES (622,2,1,163,3,61.14);
INSERT INTO items VALUES (622,2,2,895,1,25.06);
INSERT INTO items VALUES (622,2,3,827,12,224.84);
INSERT INTO items VALUES (622,2,4,833,2,39.26);
INSERT INTO items VALUES (622,2,5,160,2,59.84);
INSERT INTO items VALUES (623,1,1,603,2,11.56);
INSERT INTO items VALUES (623,2,1,188,12,84.81);
INSERT INTO items VALUES (623,2,2,1027,12,316.03);
INSERT INTO items VALUES (623,2,3,966,3,31.35);
INSERT INTO items VALUES (623,2,4,878,1,22.43);
INSERT INTO items VALUES (623,3,1,652,1,10.28);
INSERT INTO items VALUES (623,3,2,332,12,278.19);
INSERT INTO items VALUES (623,4,1,184,2,54.22);
INSERT INTO items VALUES (623,4,2,780,12,80.41);
INSERT INTO items VALUES (624,1,1,623,3,66.30);
INSERT INTO items VALUES (624,1,2,520,2,20.02);
INSERT INTO items VALUES (624,1,3,434,2,50.88);
INSERT INTO items VALUES (624,1,4,691,3,87.00);
INSERT INTO items VALUES (624,1,5,23,3,79.68);
INSERT INTO items VALUES (624,2,1,345,1,8.23);
INSERT INTO items VALUES (624,2,2,674,3,44.61);
INSERT INTO items VALUES (624,2,3,989,2,24.18);
INSERT INTO items VALUES (624,3,1,541,2,35.24);
INSERT INTO items VALUES (624,3,2,645,1,18.13);
INSERT INTO items VALUES (624,3,3,735,1,22.11);
INSERT INTO items VALUES (624,3,4,431,2,35.72);
INSERT INTO items VALUES (624,3,5,696,2,13.24);
INSERT INTO items VALUES (624,3,6,67,3,83.40);
INSERT INTO items VALUES (624,4,1,371,3,46.47);
INSERT INTO items VALUES (624,4,2,559,2,13.34);
INSERT INTO items VALUES (624,4,3,218,1,9.06);
INSERT INTO items VALUES (624,4,4,170,2,19.50);
INSERT INTO items VALUES (624,4,5,700,12,212.85);
INSERT INTO items VALUES (624,5,1,233,12,62.15);
INSERT INTO items VALUES (624,5,2,341,12,191.40);
INSERT INTO items VALUES (624,5,3,321,2,23.38);
INSERT INTO items VALUES (624,5,4,526,3,57.93);
INSERT INTO items VALUES (624,5,5,551,1,23.73);
INSERT INTO items VALUES (624,5,6,226,3,26.04);
INSERT INTO items VALUES (624,6,1,756,2,59.04);
INSERT INTO items VALUES (625,1,1,354,3,18.57);
INSERT INTO items VALUES (625,2,1,257,12,328.02);
INSERT INTO items VALUES (625,2,2,909,2,43.68);
INSERT INTO items VALUES (625,2,3,583,1,18.49);
INSERT INTO items VALUES (625,2,4,514,3,48.54);
INSERT INTO items VALUES (625,2,5,946,1,9.51);
INSERT INTO items VALUES (625,3,1,839,1,19.50);
INSERT INTO items VALUES (625,3,2,741,2,25.78);
INSERT INTO items VALUES (625,3,3,300,1,26.38);
INSERT INTO items VALUES (625,3,4,119,3,53.46);
INSERT INTO items VALUES (625,3,5,268,1,9.15);
INSERT INTO items VALUES (626,1,1,902,3,32.31);
INSERT INTO items VALUES (626,1,2,1013,2,20.08);
INSERT INTO items VALUES (626,1,3,525,1,22.09);
INSERT INTO items VALUES (626,2,1,704,1,23.19);
INSERT INTO items VALUES (626,2,2,322,1,16.97);
INSERT INTO items VALUES (626,2,3,386,2,56.90);
INSERT INTO items VALUES (626,2,4,271,1,6.89);
INSERT INTO items VALUES (626,3,1,72,1,24.96);
INSERT INTO items VALUES (626,3,2,913,12,238.48);
INSERT INTO items VALUES (626,3,3,877,12,210.65);
INSERT INTO items VALUES (626,4,1,723,3,62.49);
INSERT INTO items VALUES (626,4,2,115,2,28.04);
INSERT INTO items VALUES (626,4,3,719,2,20.32);
INSERT INTO items VALUES (626,4,4,531,1,24.78);
INSERT INTO items VALUES (626,5,1,904,3,55.89);
INSERT INTO items VALUES (626,5,2,152,12,63.91);
INSERT INTO items VALUES (626,5,3,1008,1,28.65);
INSERT INTO items VALUES (626,5,4,901,12,172.37);
INSERT INTO items VALUES (626,5,5,893,1,24.44);
INSERT INTO items VALUES (626,6,1,1007,3,37.02);
INSERT INTO items VALUES (626,6,2,4,3,63.48);
INSERT INTO items VALUES (626,6,3,11,3,49.44);
INSERT INTO items VALUES (626,6,4,733,12,106.81);
INSERT INTO items VALUES (627,1,1,46,1,15.67);
INSERT INTO items VALUES (627,1,2,554,1,6.30);
INSERT INTO items VALUES (627,1,3,26,2,52.06);
INSERT INTO items VALUES (627,1,4,954,2,11.02);
INSERT INTO items VALUES (627,2,1,980,2,44.64);
INSERT INTO items VALUES (628,1,1,260,1,7.34);
INSERT INTO items VALUES (629,1,1,669,2,27.24);
INSERT INTO items VALUES (629,1,2,167,12,231.55);
INSERT INTO items VALUES (629,2,1,718,1,10.10);
INSERT INTO items VALUES (629,2,2,334,2,28.50);
INSERT INTO items VALUES (629,3,1,989,3,36.27);
INSERT INTO items VALUES (629,3,2,1028,2,27.80);
INSERT INTO items VALUES (629,3,3,1040,1,28.12);
INSERT INTO items VALUES (629,3,4,7,12,134.20);
INSERT INTO items VALUES (629,3,5,440,3,16.05);
INSERT INTO items VALUES (629,3,6,339,3,32.01);
INSERT INTO items VALUES (629,4,1,603,12,63.58);
INSERT INTO items VALUES (629,4,2,722,12,165.00);
INSERT INTO items VALUES (629,4,3,56,1,12.83);
INSERT INTO items VALUES (629,4,4,818,3,19.71);
INSERT INTO items VALUES (629,5,1,886,3,52.59);
INSERT INTO items VALUES (629,5,2,783,12,306.57);
INSERT INTO items VALUES (629,5,3,743,1,7.98);
INSERT INTO items VALUES (629,5,4,519,1,11.76);
INSERT INTO items VALUES (629,6,1,246,1,18.57);
INSERT INTO items VALUES (629,6,2,1039,12,291.06);
INSERT INTO items VALUES (630,1,1,479,3,35.10);
INSERT INTO items VALUES (630,1,2,596,1,18.47);
INSERT INTO items VALUES (630,1,3,541,2,35.24);
INSERT INTO items VALUES (630,1,4,818,2,13.14);
INSERT INTO items VALUES (630,1,5,1039,12,291.06);
INSERT INTO items VALUES (630,1,6,903,1,23.54);
INSERT INTO items VALUES (630,2,1,882,3,65.07);
INSERT INTO items VALUES (630,2,2,1028,12,152.90);
INSERT INTO items VALUES (630,2,3,621,1,29.46);
INSERT INTO items VALUES (630,2,4,905,2,22.88);
INSERT INTO items VALUES (630,2,5,697,3,66.27);
INSERT INTO items VALUES (630,2,6,545,3,51.30);
INSERT INTO items VALUES (630,3,1,76,2,35.88);
INSERT INTO items VALUES (630,3,2,984,12,67.87);
INSERT INTO items VALUES (630,3,3,394,3,16.14);
INSERT INTO items VALUES (630,3,4,872,3,78.87);
INSERT INTO items VALUES (630,3,5,437,2,17.22);
INSERT INTO items VALUES (630,3,6,180,2,37.14);
INSERT INTO items VALUES (630,4,1,765,1,29.88);
INSERT INTO items VALUES (630,4,2,662,1,23.29);
INSERT INTO items VALUES (630,4,3,614,12,98.23);
INSERT INTO items VALUES (630,4,4,461,3,31.98);
INSERT INTO items VALUES (630,4,5,26,1,26.03);
INSERT INTO items VALUES (630,4,6,26,1,26.03);
INSERT INTO items VALUES (630,5,1,310,1,10.26);
INSERT INTO items VALUES (630,5,2,442,2,27.34);
INSERT INTO items VALUES (630,5,3,427,3,60.03);
INSERT INTO items VALUES (630,5,4,317,12,63.69);
INSERT INTO items VALUES (630,5,5,783,3,83.61);
INSERT INTO items VALUES (630,5,6,215,3,15.81);
INSERT INTO items VALUES (630,6,1,556,1,5.78);
INSERT INTO items VALUES (631,1,1,711,3,84.21);
INSERT INTO items VALUES (631,1,2,1025,3,86.34);
INSERT INTO items VALUES (631,1,3,69,2,33.22);
INSERT INTO items VALUES (631,1,4,91,12,127.38);
INSERT INTO items VALUES (631,1,5,782,12,132.66);
INSERT INTO items VALUES (631,2,1,672,1,10.92);
INSERT INTO items VALUES (631,2,2,575,12,282.37);
INSERT INTO items VALUES (631,2,3,798,3,88.44);
INSERT INTO items VALUES (632,1,1,607,12,244.09);
INSERT INTO items VALUES (632,1,2,952,2,42.96);
INSERT INTO items VALUES (632,1,3,1005,2,37.14);
INSERT INTO items VALUES (632,1,4,361,3,38.28);
INSERT INTO items VALUES (632,1,5,103,1,12.37);
INSERT INTO items VALUES (632,1,6,251,3,17.13);
INSERT INTO items VALUES (633,1,1,980,3,66.96);
INSERT INTO items VALUES (633,1,2,80,1,28.44);
INSERT INTO items VALUES (633,1,3,1028,12,152.90);
INSERT INTO items VALUES (633,2,1,68,3,64.98);
INSERT INTO items VALUES (633,2,2,736,2,52.12);
INSERT INTO items VALUES (633,2,3,1011,2,22.24);
INSERT INTO items VALUES (633,2,4,540,1,26.85);
INSERT INTO items VALUES (633,2,5,699,1,19.71);
INSERT INTO items VALUES (634,1,1,712,3,84.63);
INSERT INTO items VALUES (634,1,2,435,3,35.55);
INSERT INTO items VALUES (634,1,3,753,2,43.40);
INSERT INTO items VALUES (634,2,1,175,1,25.60);
INSERT INTO items VALUES (634,2,2,617,3,36.27);
INSERT INTO items VALUES (634,2,3,29,1,20.97);
INSERT INTO items VALUES (634,2,4,104,1,6.42);
INSERT INTO items VALUES (634,2,5,715,1,18.98);
INSERT INTO items VALUES (634,2,6,745,12,112.86);
INSERT INTO items VALUES (634,3,1,724,2,41.26);
INSERT INTO items VALUES (634,3,2,941,2,33.14);
INSERT INTO items VALUES (635,1,1,652,2,20.56);
INSERT INTO items VALUES (635,1,2,850,1,29.32);
INSERT INTO items VALUES (635,2,1,275,2,43.38);
INSERT INTO items VALUES (635,2,2,162,12,216.04);
INSERT INTO items VALUES (635,3,1,215,1,5.27);
INSERT INTO items VALUES (635,3,2,100,3,70.38);
INSERT INTO items VALUES (635,3,3,1006,2,40.32);
INSERT INTO items VALUES (635,3,4,15,1,12.33);
INSERT INTO items VALUES (635,3,5,684,3,67.65);
INSERT INTO items VALUES (635,3,6,568,2,22.64);
INSERT INTO items VALUES (635,4,1,767,1,6.53);
INSERT INTO items VALUES (635,4,2,955,12,208.01);
INSERT INTO items VALUES (635,4,3,6,3,60.75);
INSERT INTO items VALUES (635,4,4,1041,12,188.98);
INSERT INTO items VALUES (635,5,1,580,2,48.98);
INSERT INTO items VALUES (635,5,2,156,3,22.47);
INSERT INTO items VALUES (635,5,3,739,12,278.08);
INSERT INTO items VALUES (635,5,4,213,1,25.17);
INSERT INTO items VALUES (635,5,5,276,1,23.22);
INSERT INTO items VALUES (636,1,1,773,1,25.40);
INSERT INTO items VALUES (636,1,2,432,2,50.90);
INSERT INTO items VALUES (636,1,3,214,2,55.90);
INSERT INTO items VALUES (637,1,1,819,3,23.31);
INSERT INTO items VALUES (637,1,2,113,2,38.50);
INSERT INTO items VALUES (637,1,3,479,2,23.40);
INSERT INTO items VALUES (637,1,4,767,3,19.59);
INSERT INTO items VALUES (637,2,1,827,1,20.44);
INSERT INTO items VALUES (637,2,2,111,1,27.88);
INSERT INTO items VALUES (637,2,3,459,3,35.88);
INSERT INTO items VALUES (638,1,1,23,3,79.68);
INSERT INTO items VALUES (638,1,2,703,3,80.31);
INSERT INTO items VALUES (638,1,3,875,1,13.36);
INSERT INTO items VALUES (638,1,4,142,1,15.00);
INSERT INTO items VALUES (638,1,5,930,12,280.61);
INSERT INTO items VALUES (638,1,6,522,12,80.30);
INSERT INTO items VALUES (638,2,1,539,1,10.48);
INSERT INTO items VALUES (638,2,2,222,1,24.20);
INSERT INTO items VALUES (638,2,3,225,1,16.96);
INSERT INTO items VALUES (638,2,4,829,2,21.20);
INSERT INTO items VALUES (638,2,5,660,2,24.22);
INSERT INTO items VALUES (639,1,1,147,2,39.16);
INSERT INTO items VALUES (639,1,2,243,12,212.85);
INSERT INTO items VALUES (639,1,3,841,12,279.18);
INSERT INTO items VALUES (639,2,1,801,1,5.17);
INSERT INTO items VALUES (639,2,2,895,12,275.66);
INSERT INTO items VALUES (639,2,3,461,12,117.26);
INSERT INTO items VALUES (639,2,4,652,12,113.08);
INSERT INTO items VALUES (639,3,1,268,12,100.65);
INSERT INTO items VALUES (639,3,2,597,2,55.34);
INSERT INTO items VALUES (639,4,1,1042,2,53.52);
INSERT INTO items VALUES (639,4,2,140,1,5.95);
INSERT INTO items VALUES (639,4,3,22,12,88.55);
INSERT INTO items VALUES (639,4,4,457,12,231.00);
INSERT INTO items VALUES (639,4,5,764,12,126.72);
INSERT INTO items VALUES (639,4,6,800,2,36.32);
INSERT INTO items VALUES (640,1,1,820,12,326.26);
INSERT INTO items VALUES (640,1,2,118,1,14.38);
INSERT INTO items VALUES (640,1,3,136,12,278.85);
INSERT INTO items VALUES (640,1,4,594,1,6.08);
INSERT INTO items VALUES (640,2,1,500,1,16.28);
INSERT INTO items VALUES (640,2,2,356,2,44.86);
INSERT INTO items VALUES (640,2,3,852,1,26.09);
INSERT INTO items VALUES (640,2,4,120,1,5.11);
INSERT INTO items VALUES (640,2,5,986,2,13.12);
INSERT INTO items VALUES (640,2,6,461,1,10.66);
INSERT INTO items VALUES (640,3,1,971,1,19.81);
INSERT INTO items VALUES (640,3,2,294,2,15.82);
INSERT INTO items VALUES (640,3,3,273,12,65.23);
INSERT INTO items VALUES (640,4,1,614,12,98.23);
INSERT INTO items VALUES (640,4,2,893,2,48.88);
INSERT INTO items VALUES (640,4,3,134,12,246.95);
INSERT INTO items VALUES (640,4,4,590,1,15.33);
INSERT INTO items VALUES (640,5,1,753,1,21.70);
INSERT INTO items VALUES (640,5,2,734,3,54.93);
INSERT INTO items VALUES (641,1,1,766,2,59.72);
INSERT INTO items VALUES (641,1,2,217,1,6.83);
INSERT INTO items VALUES (641,1,3,1015,1,28.35);
INSERT INTO items VALUES (641,1,4,87,2,34.38);
INSERT INTO items VALUES (641,2,1,507,12,198.22);
INSERT INTO items VALUES (641,2,2,797,12,200.75);
INSERT INTO items VALUES (641,2,3,647,12,322.52);
INSERT INTO items VALUES (641,2,4,540,2,53.70);
INSERT INTO items VALUES (642,1,1,874,1,19.40);
INSERT INTO items VALUES (642,2,1,205,2,25.98);
INSERT INTO items VALUES (642,2,2,1027,3,86.19);
INSERT INTO items VALUES (642,2,3,326,2,26.32);
INSERT INTO items VALUES (642,2,4,92,1,29.26);
INSERT INTO items VALUES (643,1,1,510,2,22.06);
INSERT INTO items VALUES (643,1,2,384,3,63.21);
INSERT INTO items VALUES (643,1,3,92,2,58.52);
INSERT INTO items VALUES (643,1,4,443,1,29.32);
INSERT INTO items VALUES (643,1,5,780,2,14.62);
INSERT INTO items VALUES (643,1,6,299,1,13.23);
INSERT INTO items VALUES (643,2,1,446,2,42.88);
INSERT INTO items VALUES (643,2,2,543,3,84.18);
INSERT INTO items VALUES (643,2,3,548,2,10.24);
INSERT INTO items VALUES (644,1,1,121,3,87.06);
INSERT INTO items VALUES (644,1,2,723,3,62.49);
INSERT INTO items VALUES (644,1,3,50,12,171.82);
INSERT INTO items VALUES (644,1,4,325,3,39.63);
INSERT INTO items VALUES (644,2,1,87,2,34.38);
INSERT INTO items VALUES (644,3,1,658,1,24.88);
INSERT INTO items VALUES (644,3,2,106,12,287.10);
INSERT INTO items VALUES (644,3,3,994,1,15.44);
INSERT INTO items VALUES (644,3,4,499,1,7.12);
INSERT INTO items VALUES (645,1,1,425,3,47.55);
INSERT INTO items VALUES (645,1,2,151,3,67.11);
INSERT INTO items VALUES (645,2,1,744,1,13.54);
INSERT INTO items VALUES (645,2,2,245,2,57.72);
INSERT INTO items VALUES (645,2,3,680,2,10.50);
INSERT INTO items VALUES (645,2,4,377,3,89.19);
INSERT INTO items VALUES (645,2,5,400,2,19.52);
INSERT INTO items VALUES (645,2,6,1047,2,27.70);
INSERT INTO items VALUES (645,3,1,475,2,57.68);
INSERT INTO items VALUES (645,3,2,966,3,31.35);
INSERT INTO items VALUES (645,3,3,112,2,15.90);
INSERT INTO items VALUES (645,4,1,39,2,14.76);
INSERT INTO items VALUES (645,5,1,218,3,27.18);
INSERT INTO items VALUES (645,5,2,497,2,42.92);
INSERT INTO items VALUES (646,1,1,672,2,21.84);
INSERT INTO items VALUES (646,1,2,314,2,49.84);
INSERT INTO items VALUES (646,1,3,211,3,52.74);
INSERT INTO items VALUES (646,1,4,836,1,16.19);
INSERT INTO items VALUES (646,1,5,915,12,137.61);
INSERT INTO items VALUES (646,1,6,265,2,33.46);
INSERT INTO items VALUES (646,2,1,371,1,15.49);
INSERT INTO items VALUES (646,2,2,693,3,84.24);
INSERT INTO items VALUES (646,3,1,35,1,17.64);
INSERT INTO items VALUES (646,3,2,335,2,19.16);
INSERT INTO items VALUES (646,3,3,429,3,49.56);
INSERT INTO items VALUES (646,3,4,1030,1,21.21);
INSERT INTO items VALUES (646,3,5,773,12,279.40);
INSERT INTO items VALUES (646,3,6,108,12,178.31);
INSERT INTO items VALUES (646,4,1,543,2,56.12);
INSERT INTO items VALUES (646,4,2,85,1,21.54);
INSERT INTO items VALUES (646,4,3,159,1,14.76);
INSERT INTO items VALUES (646,4,4,401,2,33.50);
INSERT INTO items VALUES (646,4,5,890,3,59.34);
INSERT INTO items VALUES (646,4,6,868,12,128.70);
INSERT INTO items VALUES (646,5,1,464,2,30.14);
INSERT INTO items VALUES (646,5,2,777,3,71.10);
INSERT INTO items VALUES (646,5,3,433,12,234.41);
INSERT INTO items VALUES (646,5,4,946,2,19.02);
INSERT INTO items VALUES (646,5,5,338,1,24.28);
INSERT INTO items VALUES (646,5,6,433,1,21.31);
INSERT INTO items VALUES (647,1,1,210,12,132.77);
INSERT INTO items VALUES (647,1,2,299,1,13.23);
INSERT INTO items VALUES (647,1,3,441,1,5.87);
INSERT INTO items VALUES (647,2,1,997,2,18.06);
INSERT INTO items VALUES (647,2,2,772,12,146.19);
INSERT INTO items VALUES (647,3,1,344,3,45.18);
INSERT INTO items VALUES (647,3,2,156,2,14.98);
INSERT INTO items VALUES (647,4,1,764,1,11.52);
INSERT INTO items VALUES (647,4,2,522,1,7.30);
INSERT INTO items VALUES (647,5,1,479,1,11.70);
INSERT INTO items VALUES (647,5,2,934,3,75.27);
INSERT INTO items VALUES (647,5,3,300,2,52.76);
INSERT INTO items VALUES (647,5,4,24,3,55.80);
INSERT INTO items VALUES (648,1,1,683,2,18.38);
INSERT INTO items VALUES (648,1,2,526,12,212.41);
INSERT INTO items VALUES (648,1,3,238,3,72.45);
INSERT INTO items VALUES (648,2,1,792,1,6.49);
INSERT INTO items VALUES (648,2,2,10,12,196.02);
INSERT INTO items VALUES (648,2,3,56,3,38.49);
INSERT INTO items VALUES (648,2,4,136,2,50.70);
INSERT INTO items VALUES (648,3,1,635,12,235.29);
INSERT INTO items VALUES (648,3,2,25,2,29.82);
INSERT INTO items VALUES (648,3,3,440,3,16.05);
INSERT INTO items VALUES (648,3,4,202,3,30.24);
INSERT INTO items VALUES (648,4,1,10,1,17.82);
INSERT INTO items VALUES (648,4,2,71,1,7.50);
INSERT INTO items VALUES (648,4,3,67,1,27.80);
INSERT INTO items VALUES (648,4,4,587,1,10.38);
INSERT INTO items VALUES (648,4,5,563,1,26.82);
INSERT INTO items VALUES (648,4,6,10,3,53.46);
INSERT INTO items VALUES (649,1,1,636,1,25.51);
INSERT INTO items VALUES (650,1,1,699,2,39.42);
INSERT INTO items VALUES (650,1,2,902,3,32.31);
INSERT INTO items VALUES (650,1,3,382,12,77.99);
INSERT INTO items VALUES (650,1,4,897,12,252.89);
INSERT INTO items VALUES (650,2,1,203,3,44.61);
INSERT INTO items VALUES (650,2,2,140,2,11.90);

INSERT INTO orders VALUES (1,1,'000113133121','','8000000000001001','01/05');
INSERT INTO orders VALUES (1,2,'000205101701','','8000000000001001','01/05');
INSERT INTO orders VALUES (1,3,'000326214418','','8000000000001001','01/05');
INSERT INTO orders VALUES (1,4,'000420184456','','8000000000001001','01/05');
INSERT INTO orders VALUES (2,1,'000113200418','','8000000000001001','01/05');
INSERT INTO orders VALUES (2,2,'000225105446','','8000000000001001','01/05');
INSERT INTO orders VALUES (2,3,'000301154527','','8000000000001001','01/05');
INSERT INTO orders VALUES (2,4,'000404082605','','8000000000001001','01/05');
INSERT INTO orders VALUES (2,5,'000520225329','','8000000000001001','01/05');
INSERT INTO orders VALUES (3,1,'000122133053','','8000000000001001','01/05');
INSERT INTO orders VALUES (3,2,'000229194813','','8000000000001001','01/05');
INSERT INTO orders VALUES (3,3,'000311091605','','8000000000001001','01/05');
INSERT INTO orders VALUES (3,4,'000411183516','','8000000000001001','01/05');
INSERT INTO orders VALUES (3,5,'000502113648','','8000000000001001','01/05');
INSERT INTO orders VALUES (4,1,'000118080218','','8000000000001001','01/05');
INSERT INTO orders VALUES (4,2,'000218140724','','8000000000001001','01/05');
INSERT INTO orders VALUES (5,1,'000127214213','','8000000000001001','01/05');
INSERT INTO orders VALUES (5,2,'000229231026','','8000000000001001','01/05');
INSERT INTO orders VALUES (5,3,'000312201822','','8000000000001001','01/05');
INSERT INTO orders VALUES (5,4,'000422103246','','8000000000001001','01/05');
INSERT INTO orders VALUES (5,5,'000516140506','','8000000000001001','01/05');
INSERT INTO orders VALUES (6,1,'000103110930','','8000000000001001','01/05');
INSERT INTO orders VALUES (6,2,'000212062626','','8000000000001001','01/05');
INSERT INTO orders VALUES (7,1,'000101210131','','8000000000001001','01/05');
INSERT INTO orders VALUES (7,2,'000222152411','','8000000000001001','01/05');
INSERT INTO orders VALUES (7,3,'000329065926','','8000000000001001','01/05');
INSERT INTO orders VALUES (7,4,'000425105420','','8000000000001001','01/05');
INSERT INTO orders VALUES (8,1,'000110084046','','8000000000001001','01/05');
INSERT INTO orders VALUES (9,1,'000107134203','','8000000000001001','01/05');
INSERT INTO orders VALUES (9,2,'000218174017','','8000000000001001','01/05');
INSERT INTO orders VALUES (9,3,'000326193232','','8000000000001001','01/05');
INSERT INTO orders VALUES (9,4,'000425183742','','8000000000001001','01/05');
INSERT INTO orders VALUES (10,1,'000123130042','','8000000000001001','01/05');
INSERT INTO orders VALUES (10,2,'000224141230','','8000000000001001','01/05');
INSERT INTO orders VALUES (10,3,'000306112105','','8000000000001001','01/05');
INSERT INTO orders VALUES (10,4,'000406074238','','8000000000001001','01/05');
INSERT INTO orders VALUES (10,5,'000508220456','','8000000000001001','01/05');
INSERT INTO orders VALUES (10,6,'000609103638','','8000000000001001','01/05');
INSERT INTO orders VALUES (11,1,'000113143733','','8000000000001001','01/05');
INSERT INTO orders VALUES (12,1,'000108153518','','8000000000001001','01/05');
INSERT INTO orders VALUES (12,2,'000208170555','','8000000000001001','01/05');
INSERT INTO orders VALUES (12,3,'000301221936','','8000000000001001','01/05');
INSERT INTO orders VALUES (13,1,'000102085443','','8000000000001001','01/05');
INSERT INTO orders VALUES (13,2,'000221180834','','8000000000001001','01/05');
INSERT INTO orders VALUES (13,3,'000324194018','','8000000000001001','01/05');
INSERT INTO orders VALUES (13,4,'000408145711','','8000000000001001','01/05');
INSERT INTO orders VALUES (15,1,'000108231551','','8000000000001001','01/05');
INSERT INTO orders VALUES (15,2,'000209123945','','8000000000001001','01/05');
INSERT INTO orders VALUES (15,3,'000309084511','','8000000000001001','01/05');
INSERT INTO orders VALUES (15,4,'000411115024','','8000000000001001','01/05');
INSERT INTO orders VALUES (15,5,'000515221440','','8000000000001001','01/05');
INSERT INTO orders VALUES (16,1,'000124060507','','8000000000001001','01/05');
INSERT INTO orders VALUES (17,1,'000116225936','','8000000000001001','01/05');
INSERT INTO orders VALUES (17,2,'000224162656','','8000000000001001','01/05');
INSERT INTO orders VALUES (17,3,'000310090346','','8000000000001001','01/05');
INSERT INTO orders VALUES (17,4,'000412170113','','8000000000001001','01/05');
INSERT INTO orders VALUES (18,1,'000128234041','','8000000000001001','01/05');
INSERT INTO orders VALUES (19,1,'000126114517','','8000000000001001','01/05');
INSERT INTO orders VALUES (19,2,'000211184904','','8000000000001001','01/05');
INSERT INTO orders VALUES (20,1,'000107081729','','8000000000001001','01/05');
INSERT INTO orders VALUES (21,1,'000103090728','','8000000000001001','01/05');
INSERT INTO orders VALUES (21,2,'000206130953','','8000000000001001','01/05');
INSERT INTO orders VALUES (21,3,'000305174920','','8000000000001001','01/05');
INSERT INTO orders VALUES (22,1,'000107223244','','8000000000001001','01/05');
INSERT INTO orders VALUES (22,2,'000219084415','','8000000000001001','01/05');
INSERT INTO orders VALUES (22,3,'000304121845','','8000000000001001','01/05');
INSERT INTO orders VALUES (22,4,'000404195615','','8000000000001001','01/05');
INSERT INTO orders VALUES (23,1,'000114060142','','8000000000001001','01/05');
INSERT INTO orders VALUES (23,2,'000220174040','','8000000000001001','01/05');
INSERT INTO orders VALUES (23,3,'000321062710','','8000000000001001','01/05');
INSERT INTO orders VALUES (23,4,'000408161310','','8000000000001001','01/05');
INSERT INTO orders VALUES (23,5,'000526173357','','8000000000001001','01/05');
INSERT INTO orders VALUES (24,1,'000119135332','','8000000000001001','01/05');
INSERT INTO orders VALUES (24,2,'000205170905','','8000000000001001','01/05');
INSERT INTO orders VALUES (25,1,'000120125523','','8000000000001001','01/05');
INSERT INTO orders VALUES (25,2,'000203130911','','8000000000001001','01/05');
INSERT INTO orders VALUES (25,3,'000325225619','','8000000000001001','01/05');
INSERT INTO orders VALUES (25,4,'000427210859','','8000000000001001','01/05');
INSERT INTO orders VALUES (25,5,'000516143610','','8000000000001001','01/05');
INSERT INTO orders VALUES (26,1,'000108070411','','8000000000001001','01/05');
INSERT INTO orders VALUES (26,2,'000220104742','','8000000000001001','01/05');
INSERT INTO orders VALUES (26,3,'000312064226','','8000000000001001','01/05');
INSERT INTO orders VALUES (26,4,'000416075633','','8000000000001001','01/05');
INSERT INTO orders VALUES (26,5,'000520215357','','8000000000001001','01/05');
INSERT INTO orders VALUES (27,1,'000121181548','','8000000000001001','01/05');
INSERT INTO orders VALUES (27,2,'000205193923','','8000000000001001','01/05');
INSERT INTO orders VALUES (27,3,'000303231747','','8000000000001001','01/05');
INSERT INTO orders VALUES (27,4,'000416184049','','8000000000001001','01/05');
INSERT INTO orders VALUES (27,5,'000514233008','','8000000000001001','01/05');
INSERT INTO orders VALUES (28,1,'000126111315','','8000000000001001','01/05');
INSERT INTO orders VALUES (28,2,'000223111243','','8000000000001001','01/05');
INSERT INTO orders VALUES (28,3,'000307121300','','8000000000001001','01/05');
INSERT INTO orders VALUES (28,4,'000425125351','','8000000000001001','01/05');
INSERT INTO orders VALUES (28,5,'000522100528','','8000000000001001','01/05');
INSERT INTO orders VALUES (28,6,'000605185809','','8000000000001001','01/05');
INSERT INTO orders VALUES (29,1,'000104232928','','8000000000001001','01/05');
INSERT INTO orders VALUES (30,1,'000112204509','','8000000000001001','01/05');
INSERT INTO orders VALUES (30,2,'000226075002','','8000000000001001','01/05');
INSERT INTO orders VALUES (30,3,'000306182216','','8000000000001001','01/05');
INSERT INTO orders VALUES (30,4,'000422185040','','8000000000001001','01/05');
INSERT INTO orders VALUES (30,5,'000504163517','','8000000000001001','01/05');
INSERT INTO orders VALUES (31,1,'000110144256','','8000000000001001','01/05');
INSERT INTO orders VALUES (32,1,'000120154849','','8000000000001001','01/05');
INSERT INTO orders VALUES (32,2,'000224123644','','8000000000001001','01/05');
INSERT INTO orders VALUES (32,3,'000302194533','','8000000000001001','01/05');
INSERT INTO orders VALUES (32,4,'000417214923','','8000000000001001','01/05');
INSERT INTO orders VALUES (32,5,'000510211017','','8000000000001001','01/05');
INSERT INTO orders VALUES (32,6,'000621184645','','8000000000001001','01/05');
INSERT INTO orders VALUES (33,1,'000113135903','','8000000000001001','01/05');
INSERT INTO orders VALUES (33,2,'000222060205','','8000000000001001','01/05');
INSERT INTO orders VALUES (33,3,'000318170044','','8000000000001001','01/05');
INSERT INTO orders VALUES (33,4,'000427132238','','8000000000001001','01/05');
INSERT INTO orders VALUES (33,5,'000502202152','','8000000000001001','01/05');
INSERT INTO orders VALUES (34,1,'000108143640','','8000000000001001','01/05');
INSERT INTO orders VALUES (35,1,'000128104300','','8000000000001001','01/05');
INSERT INTO orders VALUES (35,2,'000210063220','','8000000000001001','01/05');
INSERT INTO orders VALUES (35,3,'000322203953','','8000000000001001','01/05');
INSERT INTO orders VALUES (35,4,'000429083218','','8000000000001001','01/05');
INSERT INTO orders VALUES (36,1,'000118073640','','8000000000001001','01/05');
INSERT INTO orders VALUES (36,2,'000209221927','','8000000000001001','01/05');
INSERT INTO orders VALUES (36,3,'000322195854','','8000000000001001','01/05');
INSERT INTO orders VALUES (36,4,'000412144542','','8000000000001001','01/05');
INSERT INTO orders VALUES (37,1,'000118202213','','8000000000001001','01/05');
INSERT INTO orders VALUES (37,2,'000226163934','','8000000000001001','01/05');
INSERT INTO orders VALUES (37,3,'000325061015','','8000000000001001','01/05');
INSERT INTO orders VALUES (37,4,'000420071632','','8000000000001001','01/05');
INSERT INTO orders VALUES (38,1,'000107092544','','8000000000001001','01/05');
INSERT INTO orders VALUES (39,1,'000129214650','','8000000000001001','01/05');
INSERT INTO orders VALUES (39,2,'000229082710','','8000000000001001','01/05');
INSERT INTO orders VALUES (39,3,'000320222709','','8000000000001001','01/05');
INSERT INTO orders VALUES (39,4,'000423085249','','8000000000001001','01/05');
INSERT INTO orders VALUES (39,5,'000514170052','','8000000000001001','01/05');
INSERT INTO orders VALUES (40,1,'000117125524','','8000000000001001','01/05');
INSERT INTO orders VALUES (40,2,'000208194607','','8000000000001001','01/05');
INSERT INTO orders VALUES (42,1,'000106185457','','8000000000001001','01/05');
INSERT INTO orders VALUES (42,2,'000205154504','','8000000000001001','01/05');
INSERT INTO orders VALUES (42,3,'000306231736','','8000000000001001','01/05');
INSERT INTO orders VALUES (43,1,'000118205745','','8000000000001001','01/05');
INSERT INTO orders VALUES (43,2,'000202115356','','8000000000001001','01/05');
INSERT INTO orders VALUES (43,3,'000303062202','','8000000000001001','01/05');
INSERT INTO orders VALUES (43,4,'000412133648','','8000000000001001','01/05');
INSERT INTO orders VALUES (43,5,'000520181528','','8000000000001001','01/05');
INSERT INTO orders VALUES (44,1,'000103061802','','8000000000001001','01/05');
INSERT INTO orders VALUES (44,2,'000210120505','','8000000000001001','01/05');
INSERT INTO orders VALUES (45,1,'000125081557','','8000000000001001','01/05');
INSERT INTO orders VALUES (46,1,'000124122350','','8000000000001001','01/05');
INSERT INTO orders VALUES (46,2,'000203222333','','8000000000001001','01/05');
INSERT INTO orders VALUES (47,1,'000128063724','','8000000000001001','01/05');
INSERT INTO orders VALUES (48,1,'000106124028','','8000000000001001','01/05');
INSERT INTO orders VALUES (48,2,'000201073939','','8000000000001001','01/05');
INSERT INTO orders VALUES (48,3,'000303124204','','8000000000001001','01/05');
INSERT INTO orders VALUES (48,4,'000426124354','','8000000000001001','01/05');
INSERT INTO orders VALUES (48,5,'000511151048','','8000000000001001','01/05');
INSERT INTO orders VALUES (48,6,'000605230602','','8000000000001001','01/05');
INSERT INTO orders VALUES (49,1,'000113143311','','8000000000001001','01/05');
INSERT INTO orders VALUES (49,2,'000203100554','','8000000000001001','01/05');
INSERT INTO orders VALUES (49,3,'000306215136','','8000000000001001','01/05');
INSERT INTO orders VALUES (49,4,'000424084402','','8000000000001001','01/05');
INSERT INTO orders VALUES (49,5,'000524182704','','8000000000001001','01/05');
INSERT INTO orders VALUES (50,1,'000124153551','','8000000000001001','01/05');
INSERT INTO orders VALUES (50,2,'000219101836','','8000000000001001','01/05');
INSERT INTO orders VALUES (50,3,'000316235156','','8000000000001001','01/05');
INSERT INTO orders VALUES (51,1,'000102150818','','8000000000001001','01/05');
INSERT INTO orders VALUES (51,2,'000218100519','','8000000000001001','01/05');
INSERT INTO orders VALUES (51,3,'000314103637','','8000000000001001','01/05');
INSERT INTO orders VALUES (51,4,'000412155753','','8000000000001001','01/05');
INSERT INTO orders VALUES (51,5,'000528200225','','8000000000001001','01/05');
INSERT INTO orders VALUES (51,6,'000610100718','','8000000000001001','01/05');
INSERT INTO orders VALUES (52,1,'000128123357','','8000000000001001','01/05');
INSERT INTO orders VALUES (52,2,'000225095152','','8000000000001001','01/05');
INSERT INTO orders VALUES (52,3,'000322160641','','8000000000001001','01/05');
INSERT INTO orders VALUES (52,4,'000409071808','','8000000000001001','01/05');
INSERT INTO orders VALUES (52,5,'000507171243','','8000000000001001','01/05');
INSERT INTO orders VALUES (52,6,'000626203527','','8000000000001001','01/05');
INSERT INTO orders VALUES (53,1,'000103191517','','8000000000001001','01/05');
INSERT INTO orders VALUES (53,2,'000225153857','','8000000000001001','01/05');
INSERT INTO orders VALUES (53,3,'000305231025','','8000000000001001','01/05');
INSERT INTO orders VALUES (53,4,'000421132533','','8000000000001001','01/05');
INSERT INTO orders VALUES (53,5,'000523091554','','8000000000001001','01/05');
INSERT INTO orders VALUES (53,6,'000616132220','','8000000000001001','01/05');
INSERT INTO orders VALUES (54,1,'000108081848','','8000000000001001','01/05');
INSERT INTO orders VALUES (54,2,'000209143001','','8000000000001001','01/05');
INSERT INTO orders VALUES (54,3,'000306225259','','8000000000001001','01/05');
INSERT INTO orders VALUES (54,4,'000403072535','','8000000000001001','01/05');
INSERT INTO orders VALUES (55,1,'000124063819','','8000000000001001','01/05');
INSERT INTO orders VALUES (56,1,'000113130330','','8000000000001001','01/05');
INSERT INTO orders VALUES (56,2,'000214135919','','8000000000001001','01/05');
INSERT INTO orders VALUES (57,1,'000122062114','','8000000000001001','01/05');
INSERT INTO orders VALUES (57,2,'000212075947','','8000000000001001','01/05');
INSERT INTO orders VALUES (57,3,'000304164820','','8000000000001001','01/05');
INSERT INTO orders VALUES (57,4,'000401122500','','8000000000001001','01/05');
INSERT INTO orders VALUES (58,1,'000124235101','','8000000000001001','01/05');
INSERT INTO orders VALUES (59,1,'000101220718','','8000000000001001','01/05');
INSERT INTO orders VALUES (59,2,'000219140729','','8000000000001001','01/05');
INSERT INTO orders VALUES (59,3,'000329065252','','8000000000001001','01/05');
INSERT INTO orders VALUES (59,4,'000412125105','','8000000000001001','01/05');
INSERT INTO orders VALUES (59,5,'000521091716','','8000000000001001','01/05');
INSERT INTO orders VALUES (60,1,'000127093528','','8000000000001001','01/05');
INSERT INTO orders VALUES (61,1,'000121130035','','8000000000001001','01/05');
INSERT INTO orders VALUES (61,2,'000214153956','','8000000000001001','01/05');
INSERT INTO orders VALUES (61,3,'000324125821','','8000000000001001','01/05');
INSERT INTO orders VALUES (61,4,'000408232334','','8000000000001001','01/05');
INSERT INTO orders VALUES (62,1,'000117075045','','8000000000001001','01/05');
INSERT INTO orders VALUES (62,2,'000227075232','','8000000000001001','01/05');
INSERT INTO orders VALUES (62,3,'000326231643','','8000000000001001','01/05');
INSERT INTO orders VALUES (62,4,'000405140054','','8000000000001001','01/05');
INSERT INTO orders VALUES (62,5,'000529162056','','8000000000001001','01/05');
INSERT INTO orders VALUES (63,1,'000106120755','','8000000000001001','01/05');
INSERT INTO orders VALUES (63,2,'000202172700','','8000000000001001','01/05');
INSERT INTO orders VALUES (63,3,'000329132426','','8000000000001001','01/05');
INSERT INTO orders VALUES (64,1,'000117230512','','8000000000001001','01/05');
INSERT INTO orders VALUES (64,2,'000220160404','','8000000000001001','01/05');
INSERT INTO orders VALUES (64,3,'000308075113','','8000000000001001','01/05');
INSERT INTO orders VALUES (64,4,'000409172717','','8000000000001001','01/05');
INSERT INTO orders VALUES (64,5,'000511134027','','8000000000001001','01/05');
INSERT INTO orders VALUES (64,6,'000606205528','','8000000000001001','01/05');
INSERT INTO orders VALUES (65,1,'000122200239','','8000000000001001','01/05');
INSERT INTO orders VALUES (65,2,'000203213328','','8000000000001001','01/05');
INSERT INTO orders VALUES (66,1,'000126224440','','8000000000001001','01/05');
INSERT INTO orders VALUES (66,2,'000229150109','','8000000000001001','01/05');
INSERT INTO orders VALUES (66,3,'000323233844','','8000000000001001','01/05');
INSERT INTO orders VALUES (66,4,'000405090939','','8000000000001001','01/05');
INSERT INTO orders VALUES (66,5,'000516142617','','8000000000001001','01/05');
INSERT INTO orders VALUES (67,1,'000115221838','','8000000000001001','01/05');
INSERT INTO orders VALUES (67,2,'000202141714','','8000000000001001','01/05');
INSERT INTO orders VALUES (67,3,'000313131343','','8000000000001001','01/05');
INSERT INTO orders VALUES (67,4,'000418100052','','8000000000001001','01/05');
INSERT INTO orders VALUES (68,1,'000119133327','','8000000000001001','01/05');
INSERT INTO orders VALUES (68,2,'000224155203','','8000000000001001','01/05');
INSERT INTO orders VALUES (68,3,'000324130421','','8000000000001001','01/05');
INSERT INTO orders VALUES (68,4,'000426181138','','8000000000001001','01/05');
INSERT INTO orders VALUES (68,5,'000516233351','','8000000000001001','01/05');
INSERT INTO orders VALUES (68,6,'000628101826','','8000000000001001','01/05');
INSERT INTO orders VALUES (69,1,'000123104738','','8000000000001001','01/05');
INSERT INTO orders VALUES (69,2,'000217225247','','8000000000001001','01/05');
INSERT INTO orders VALUES (70,1,'000121091120','','8000000000001001','01/05');
INSERT INTO orders VALUES (70,2,'000201070057','','8000000000001001','01/05');
INSERT INTO orders VALUES (71,1,'000113130525','','8000000000001001','01/05');
INSERT INTO orders VALUES (71,2,'000210194616','','8000000000001001','01/05');
INSERT INTO orders VALUES (71,3,'000309173143','','8000000000001001','01/05');
INSERT INTO orders VALUES (71,4,'000421064606','','8000000000001001','01/05');
INSERT INTO orders VALUES (71,5,'000509184927','','8000000000001001','01/05');
INSERT INTO orders VALUES (71,6,'000603160116','','8000000000001001','01/05');
INSERT INTO orders VALUES (72,1,'000118221003','','8000000000001001','01/05');
INSERT INTO orders VALUES (72,2,'000208114340','','8000000000001001','01/05');
INSERT INTO orders VALUES (74,1,'000103070849','','8000000000001001','01/05');
INSERT INTO orders VALUES (74,2,'000218191816','','8000000000001001','01/05');
INSERT INTO orders VALUES (74,3,'000315182736','','8000000000001001','01/05');
INSERT INTO orders VALUES (74,4,'000423134322','','8000000000001001','01/05');
INSERT INTO orders VALUES (74,5,'000503141748','','8000000000001001','01/05');
INSERT INTO orders VALUES (75,1,'000116091244','','8000000000001001','01/05');
INSERT INTO orders VALUES (75,2,'000219141722','','8000000000001001','01/05');
INSERT INTO orders VALUES (75,3,'000313101853','','8000000000001001','01/05');
INSERT INTO orders VALUES (75,4,'000403071115','','8000000000001001','01/05');
INSERT INTO orders VALUES (75,5,'000526194610','','8000000000001001','01/05');
INSERT INTO orders VALUES (76,1,'000111215737','','8000000000001001','01/05');
INSERT INTO orders VALUES (76,2,'000218111746','','8000000000001001','01/05');
INSERT INTO orders VALUES (76,3,'000302162623','','8000000000001001','01/05');
INSERT INTO orders VALUES (76,4,'000412211620','','8000000000001001','01/05');
INSERT INTO orders VALUES (76,5,'000518072138','','8000000000001001','01/05');
INSERT INTO orders VALUES (77,1,'000109205728','','8000000000001001','01/05');
INSERT INTO orders VALUES (78,1,'000110080456','','8000000000001001','01/05');
INSERT INTO orders VALUES (78,2,'000215172214','','8000000000001001','01/05');
INSERT INTO orders VALUES (78,3,'000302144955','','8000000000001001','01/05');
INSERT INTO orders VALUES (78,4,'000426083818','','8000000000001001','01/05');
INSERT INTO orders VALUES (78,5,'000508075119','','8000000000001001','01/05');
INSERT INTO orders VALUES (79,1,'000119161703','','8000000000001001','01/05');
INSERT INTO orders VALUES (79,2,'000204121835','','8000000000001001','01/05');
INSERT INTO orders VALUES (79,3,'000304125854','','8000000000001001','01/05');
INSERT INTO orders VALUES (79,4,'000428195805','','8000000000001001','01/05');
INSERT INTO orders VALUES (79,5,'000511221126','','8000000000001001','01/05');
INSERT INTO orders VALUES (80,1,'000129203608','','8000000000001001','01/05');
INSERT INTO orders VALUES (81,1,'000106225851','','8000000000001001','01/05');
INSERT INTO orders VALUES (81,2,'000219123257','','8000000000001001','01/05');
INSERT INTO orders VALUES (81,3,'000326135629','','8000000000001001','01/05');
INSERT INTO orders VALUES (81,4,'000428071915','','8000000000001001','01/05');
INSERT INTO orders VALUES (82,1,'000111100753','','8000000000001001','01/05');
INSERT INTO orders VALUES (82,2,'000203064637','','8000000000001001','01/05');
INSERT INTO orders VALUES (82,3,'000303081639','','8000000000001001','01/05');
INSERT INTO orders VALUES (82,4,'000422073630','','8000000000001001','01/05');
INSERT INTO orders VALUES (83,1,'000113160903','','8000000000001001','01/05');
INSERT INTO orders VALUES (83,2,'000214164633','','8000000000001001','01/05');
INSERT INTO orders VALUES (83,3,'000323141358','','8000000000001001','01/05');
INSERT INTO orders VALUES (83,4,'000422172055','','8000000000001001','01/05');
INSERT INTO orders VALUES (83,5,'000512064337','','8000000000001001','01/05');
INSERT INTO orders VALUES (83,6,'000616181017','','8000000000001001','01/05');
INSERT INTO orders VALUES (84,1,'000115063423','','8000000000001001','01/05');
INSERT INTO orders VALUES (85,1,'000108163727','','8000000000001001','01/05');
INSERT INTO orders VALUES (85,2,'000216112526','','8000000000001001','01/05');
INSERT INTO orders VALUES (86,1,'000113065056','','8000000000001001','01/05');
INSERT INTO orders VALUES (86,2,'000203223132','','8000000000001001','01/05');
INSERT INTO orders VALUES (86,3,'000328114659','','8000000000001001','01/05');
INSERT INTO orders VALUES (87,1,'000124170046','','8000000000001001','01/05');
INSERT INTO orders VALUES (88,1,'000109230545','','8000000000001001','01/05');
INSERT INTO orders VALUES (88,2,'000210163405','','8000000000001001','01/05');
INSERT INTO orders VALUES (88,3,'000326200045','','8000000000001001','01/05');
INSERT INTO orders VALUES (88,4,'000413094311','','8000000000001001','01/05');
INSERT INTO orders VALUES (88,5,'000516091032','','8000000000001001','01/05');
INSERT INTO orders VALUES (88,6,'000624103745','','8000000000001001','01/05');
INSERT INTO orders VALUES (89,1,'000109111448','','8000000000001001','01/05');
INSERT INTO orders VALUES (90,1,'000102121736','','8000000000001001','01/05');
INSERT INTO orders VALUES (90,2,'000218212754','','8000000000001001','01/05');
INSERT INTO orders VALUES (90,3,'000312114628','','8000000000001001','01/05');
INSERT INTO orders VALUES (90,4,'000419132925','','8000000000001001','01/05');
INSERT INTO orders VALUES (90,5,'000510120955','','8000000000001001','01/05');
INSERT INTO orders VALUES (91,1,'000111120148','','8000000000001001','01/05');
INSERT INTO orders VALUES (91,2,'000201235100','','8000000000001001','01/05');
INSERT INTO orders VALUES (92,1,'000110093641','','8000000000001001','01/05');
INSERT INTO orders VALUES (92,2,'000214093528','','8000000000001001','01/05');
INSERT INTO orders VALUES (93,1,'000127191547','','8000000000001001','01/05');
INSERT INTO orders VALUES (93,2,'000203070906','','8000000000001001','01/05');
INSERT INTO orders VALUES (93,3,'000304195057','','8000000000001001','01/05');
INSERT INTO orders VALUES (93,4,'000416104041','','8000000000001001','01/05');
INSERT INTO orders VALUES (93,5,'000517164611','','8000000000001001','01/05');
INSERT INTO orders VALUES (93,6,'000629185038','','8000000000001001','01/05');
INSERT INTO orders VALUES (94,1,'000102174239','','8000000000001001','01/05');
INSERT INTO orders VALUES (94,2,'000210075700','','8000000000001001','01/05');
INSERT INTO orders VALUES (95,1,'000114190745','','8000000000001001','01/05');
INSERT INTO orders VALUES (95,2,'000206121112','','8000000000001001','01/05');
INSERT INTO orders VALUES (95,3,'000316130007','','8000000000001001','01/05');
INSERT INTO orders VALUES (95,4,'000429185246','','8000000000001001','01/05');
INSERT INTO orders VALUES (95,5,'000506173418','','8000000000001001','01/05');
INSERT INTO orders VALUES (95,6,'000629221657','','8000000000001001','01/05');
INSERT INTO orders VALUES (96,1,'000105095821','','8000000000001001','01/05');
INSERT INTO orders VALUES (96,2,'000218083142','','8000000000001001','01/05');
INSERT INTO orders VALUES (96,3,'000308231952','','8000000000001001','01/05');
INSERT INTO orders VALUES (96,4,'000408082836','','8000000000001001','01/05');
INSERT INTO orders VALUES (96,5,'000514183151','','8000000000001001','01/05');
INSERT INTO orders VALUES (97,1,'000118111507','','8000000000001001','01/05');
INSERT INTO orders VALUES (97,2,'000228190552','','8000000000001001','01/05');
INSERT INTO orders VALUES (98,1,'000118151344','','8000000000001001','01/05');
INSERT INTO orders VALUES (98,2,'000212195203','','8000000000001001','01/05');
INSERT INTO orders VALUES (99,1,'000111072906','','8000000000001001','01/05');
INSERT INTO orders VALUES (99,2,'000227111912','','8000000000001001','01/05');
INSERT INTO orders VALUES (99,3,'000319222355','','8000000000001001','01/05');
INSERT INTO orders VALUES (99,4,'000424081654','','8000000000001001','01/05');
INSERT INTO orders VALUES (100,1,'000128223133','','8000000000001001','01/05');
INSERT INTO orders VALUES (100,2,'000219131445','','8000000000001001','01/05');
INSERT INTO orders VALUES (100,3,'000305223707','','8000000000001001','01/05');
INSERT INTO orders VALUES (100,4,'000412084833','','8000000000001001','01/05');
INSERT INTO orders VALUES (100,5,'000508172255','','8000000000001001','01/05');
INSERT INTO orders VALUES (101,1,'000101073255','','8000000000001001','01/05');
INSERT INTO orders VALUES (102,1,'000128104019','','8000000000001001','01/05');
INSERT INTO orders VALUES (103,1,'000111222822','','8000000000001001','01/05');
INSERT INTO orders VALUES (103,2,'000227101537','','8000000000001001','01/05');
INSERT INTO orders VALUES (103,3,'000319062733','','8000000000001001','01/05');
INSERT INTO orders VALUES (103,4,'000405152225','','8000000000001001','01/05');
INSERT INTO orders VALUES (103,5,'000528161749','','8000000000001001','01/05');
INSERT INTO orders VALUES (103,6,'000618140220','','8000000000001001','01/05');
INSERT INTO orders VALUES (104,1,'000112074113','','8000000000001001','01/05');
INSERT INTO orders VALUES (104,2,'000228083621','','8000000000001001','01/05');
INSERT INTO orders VALUES (104,3,'000318090741','','8000000000001001','01/05');
INSERT INTO orders VALUES (104,4,'000423071918','','8000000000001001','01/05');
INSERT INTO orders VALUES (105,1,'000109191935','','8000000000001001','01/05');
INSERT INTO orders VALUES (105,2,'000215112950','','8000000000001001','01/05');
INSERT INTO orders VALUES (105,3,'000304164426','','8000000000001001','01/05');
INSERT INTO orders VALUES (106,1,'000107121716','','8000000000001001','01/05');
INSERT INTO orders VALUES (106,2,'000202082701','','8000000000001001','01/05');
INSERT INTO orders VALUES (107,1,'000119070344','','8000000000001001','01/05');
INSERT INTO orders VALUES (107,2,'000227074541','','8000000000001001','01/05');
INSERT INTO orders VALUES (108,1,'000110210000','','8000000000001001','01/05');
INSERT INTO orders VALUES (108,2,'000205135251','','8000000000001001','01/05');
INSERT INTO orders VALUES (108,3,'000325213010','','8000000000001001','01/05');
INSERT INTO orders VALUES (108,4,'000419094149','','8000000000001001','01/05');
INSERT INTO orders VALUES (108,5,'000524140452','','8000000000001001','01/05');
INSERT INTO orders VALUES (108,6,'000620114111','','8000000000001001','01/05');
INSERT INTO orders VALUES (109,1,'000126110219','','8000000000001001','01/05');
INSERT INTO orders VALUES (109,2,'000219184106','','8000000000001001','01/05');
INSERT INTO orders VALUES (109,3,'000305204801','','8000000000001001','01/05');
INSERT INTO orders VALUES (109,4,'000429183136','','8000000000001001','01/05');
INSERT INTO orders VALUES (110,1,'000111193723','','8000000000001001','01/05');
INSERT INTO orders VALUES (110,2,'000219111742','','8000000000001001','01/05');
INSERT INTO orders VALUES (110,3,'000307112333','','8000000000001001','01/05');
INSERT INTO orders VALUES (110,4,'000421114945','','8000000000001001','01/05');
INSERT INTO orders VALUES (110,5,'000514231151','','8000000000001001','01/05');
INSERT INTO orders VALUES (110,6,'000614163217','','8000000000001001','01/05');
INSERT INTO orders VALUES (111,1,'000129175508','','8000000000001001','01/05');
INSERT INTO orders VALUES (111,2,'000205073432','','8000000000001001','01/05');
INSERT INTO orders VALUES (111,3,'000318212557','','8000000000001001','01/05');
INSERT INTO orders VALUES (111,4,'000420191304','','8000000000001001','01/05');
INSERT INTO orders VALUES (111,5,'000519175918','','8000000000001001','01/05');
INSERT INTO orders VALUES (112,1,'000123225630','','8000000000001001','01/05');
INSERT INTO orders VALUES (112,2,'000225093528','','8000000000001001','01/05');
INSERT INTO orders VALUES (112,3,'000311094510','','8000000000001001','01/05');
INSERT INTO orders VALUES (112,4,'000427112818','','8000000000001001','01/05');
INSERT INTO orders VALUES (112,5,'000521234805','','8000000000001001','01/05');
INSERT INTO orders VALUES (113,1,'000126232519','','8000000000001001','01/05');
INSERT INTO orders VALUES (114,1,'000116173502','','8000000000001001','01/05');
INSERT INTO orders VALUES (114,2,'000220221708','','8000000000001001','01/05');
INSERT INTO orders VALUES (114,3,'000321231108','','8000000000001001','01/05');
INSERT INTO orders VALUES (114,4,'000412183003','','8000000000001001','01/05');
INSERT INTO orders VALUES (115,1,'000104061048','','8000000000001001','01/05');
INSERT INTO orders VALUES (115,2,'000204115355','','8000000000001001','01/05');
INSERT INTO orders VALUES (115,3,'000310073228','','8000000000001001','01/05');
INSERT INTO orders VALUES (116,1,'000126134629','','8000000000001001','01/05');
INSERT INTO orders VALUES (116,2,'000222085329','','8000000000001001','01/05');
INSERT INTO orders VALUES (116,3,'000308082332','','8000000000001001','01/05');
INSERT INTO orders VALUES (117,1,'000101073109','','8000000000001001','01/05');
INSERT INTO orders VALUES (117,2,'000214142349','','8000000000001001','01/05');
INSERT INTO orders VALUES (117,3,'000302193027','','8000000000001001','01/05');
INSERT INTO orders VALUES (118,1,'000117153404','','8000000000001001','01/05');
INSERT INTO orders VALUES (118,2,'000227154954','','8000000000001001','01/05');
INSERT INTO orders VALUES (118,3,'000308095149','','8000000000001001','01/05');
INSERT INTO orders VALUES (118,4,'000404081718','','8000000000001001','01/05');
INSERT INTO orders VALUES (118,5,'000503125256','','8000000000001001','01/05');
INSERT INTO orders VALUES (118,6,'000618185251','','8000000000001001','01/05');
INSERT INTO orders VALUES (119,1,'000119214423','','8000000000001001','01/05');
INSERT INTO orders VALUES (119,2,'000202074345','','8000000000001001','01/05');
INSERT INTO orders VALUES (119,3,'000309075756','','8000000000001001','01/05');
INSERT INTO orders VALUES (119,4,'000427074651','','8000000000001001','01/05');
INSERT INTO orders VALUES (119,5,'000513114624','','8000000000001001','01/05');
INSERT INTO orders VALUES (119,6,'000622150743','','8000000000001001','01/05');
INSERT INTO orders VALUES (120,1,'000116183937','','8000000000001001','01/05');
INSERT INTO orders VALUES (121,1,'000126211959','','8000000000001001','01/05');
INSERT INTO orders VALUES (121,2,'000213160458','','8000000000001001','01/05');
INSERT INTO orders VALUES (121,3,'000314075526','','8000000000001001','01/05');
INSERT INTO orders VALUES (122,1,'000112145605','','8000000000001001','01/05');
INSERT INTO orders VALUES (122,2,'000213172921','','8000000000001001','01/05');
INSERT INTO orders VALUES (122,3,'000308213540','','8000000000001001','01/05');
INSERT INTO orders VALUES (122,4,'000415100058','','8000000000001001','01/05');
INSERT INTO orders VALUES (123,1,'000117235325','','8000000000001001','01/05');
INSERT INTO orders VALUES (123,2,'000213111015','','8000000000001001','01/05');
INSERT INTO orders VALUES (123,3,'000314141720','','8000000000001001','01/05');
INSERT INTO orders VALUES (123,4,'000414140938','','8000000000001001','01/05');
INSERT INTO orders VALUES (123,5,'000518122829','','8000000000001001','01/05');
INSERT INTO orders VALUES (124,1,'000117203212','','8000000000001001','01/05');
INSERT INTO orders VALUES (124,2,'000214095915','','8000000000001001','01/05');
INSERT INTO orders VALUES (125,1,'000107231003','','8000000000001001','01/05');
INSERT INTO orders VALUES (125,2,'000225114623','','8000000000001001','01/05');
INSERT INTO orders VALUES (125,3,'000316093807','','8000000000001001','01/05');
INSERT INTO orders VALUES (125,4,'000408060044','','8000000000001001','01/05');
INSERT INTO orders VALUES (126,1,'000105100043','','8000000000001001','01/05');
INSERT INTO orders VALUES (126,2,'000206161913','','8000000000001001','01/05');
INSERT INTO orders VALUES (126,3,'000321142022','','8000000000001001','01/05');
INSERT INTO orders VALUES (126,4,'000408183713','','8000000000001001','01/05');
INSERT INTO orders VALUES (127,1,'000104085703','','8000000000001001','01/05');
INSERT INTO orders VALUES (127,2,'000205210136','','8000000000001001','01/05');
INSERT INTO orders VALUES (127,3,'000310161158','','8000000000001001','01/05');
INSERT INTO orders VALUES (127,4,'000407062458','','8000000000001001','01/05');
INSERT INTO orders VALUES (128,1,'000108094630','','8000000000001001','01/05');
INSERT INTO orders VALUES (128,2,'000212064428','','8000000000001001','01/05');
INSERT INTO orders VALUES (128,3,'000321065756','','8000000000001001','01/05');
INSERT INTO orders VALUES (128,4,'000405135201','','8000000000001001','01/05');
INSERT INTO orders VALUES (128,5,'000513123937','','8000000000001001','01/05');
INSERT INTO orders VALUES (129,1,'000108153955','','8000000000001001','01/05');
INSERT INTO orders VALUES (129,2,'000222074627','','8000000000001001','01/05');
INSERT INTO orders VALUES (129,3,'000308211239','','8000000000001001','01/05');
INSERT INTO orders VALUES (130,1,'000118193110','','8000000000001001','01/05');
INSERT INTO orders VALUES (130,2,'000214133634','','8000000000001001','01/05');
INSERT INTO orders VALUES (130,3,'000313150701','','8000000000001001','01/05');
INSERT INTO orders VALUES (130,4,'000411135553','','8000000000001001','01/05');
INSERT INTO orders VALUES (130,5,'000527090911','','8000000000001001','01/05');
INSERT INTO orders VALUES (130,6,'000601171957','','8000000000001001','01/05');
INSERT INTO orders VALUES (131,1,'000126130705','','8000000000001001','01/05');
INSERT INTO orders VALUES (131,2,'000208133612','','8000000000001001','01/05');
INSERT INTO orders VALUES (132,1,'000126061627','','8000000000001001','01/05');
INSERT INTO orders VALUES (133,1,'000106074529','','8000000000001001','01/05');
INSERT INTO orders VALUES (133,2,'000219180616','','8000000000001001','01/05');
INSERT INTO orders VALUES (133,3,'000319200138','','8000000000001001','01/05');
INSERT INTO orders VALUES (133,4,'000410162312','','8000000000001001','01/05');
INSERT INTO orders VALUES (133,5,'000527123037','','8000000000001001','01/05');
INSERT INTO orders VALUES (133,6,'000611183109','','8000000000001001','01/05');
INSERT INTO orders VALUES (134,1,'000104125922','','8000000000001001','01/05');
INSERT INTO orders VALUES (134,2,'000223121507','','8000000000001001','01/05');
INSERT INTO orders VALUES (134,3,'000324140812','','8000000000001001','01/05');
INSERT INTO orders VALUES (134,4,'000401235414','','8000000000001001','01/05');
INSERT INTO orders VALUES (134,5,'000502132849','','8000000000001001','01/05');
INSERT INTO orders VALUES (135,1,'000116160819','','8000000000001001','01/05');
INSERT INTO orders VALUES (135,2,'000217155310','','8000000000001001','01/05');
INSERT INTO orders VALUES (135,3,'000310073240','','8000000000001001','01/05');
INSERT INTO orders VALUES (135,4,'000414163802','','8000000000001001','01/05');
INSERT INTO orders VALUES (135,5,'000516142517','','8000000000001001','01/05');
INSERT INTO orders VALUES (135,6,'000602155548','','8000000000001001','01/05');
INSERT INTO orders VALUES (136,1,'000103135450','','8000000000001001','01/05');
INSERT INTO orders VALUES (136,2,'000223200635','','8000000000001001','01/05');
INSERT INTO orders VALUES (136,3,'000303100158','','8000000000001001','01/05');
INSERT INTO orders VALUES (136,4,'000426153653','','8000000000001001','01/05');
INSERT INTO orders VALUES (136,5,'000502183214','','8000000000001001','01/05');
INSERT INTO orders VALUES (136,6,'000612074816','','8000000000001001','01/05');
INSERT INTO orders VALUES (137,1,'000122062450','','8000000000001001','01/05');
INSERT INTO orders VALUES (137,2,'000204211011','','8000000000001001','01/05');
INSERT INTO orders VALUES (137,3,'000328182440','','8000000000001001','01/05');
INSERT INTO orders VALUES (137,4,'000423233956','','8000000000001001','01/05');
INSERT INTO orders VALUES (137,5,'000520064037','','8000000000001001','01/05');
INSERT INTO orders VALUES (138,1,'000120111555','','8000000000001001','01/05');
INSERT INTO orders VALUES (138,2,'000226085627','','8000000000001001','01/05');
INSERT INTO orders VALUES (138,3,'000319200620','','8000000000001001','01/05');
INSERT INTO orders VALUES (138,4,'000403130549','','8000000000001001','01/05');
INSERT INTO orders VALUES (138,5,'000506081714','','8000000000001001','01/05');
INSERT INTO orders VALUES (138,6,'000617114611','','8000000000001001','01/05');
INSERT INTO orders VALUES (139,1,'000113231958','','8000000000001001','01/05');
INSERT INTO orders VALUES (139,2,'000217105029','','8000000000001001','01/05');
INSERT INTO orders VALUES (139,3,'000303234553','','8000000000001001','01/05');
INSERT INTO orders VALUES (139,4,'000409191315','','8000000000001001','01/05');
INSERT INTO orders VALUES (139,5,'000523060455','','8000000000001001','01/05');
INSERT INTO orders VALUES (140,1,'000108092443','','8000000000001001','01/05');
INSERT INTO orders VALUES (141,1,'000125201449','','8000000000001001','01/05');
INSERT INTO orders VALUES (141,2,'000220155723','','8000000000001001','01/05');
INSERT INTO orders VALUES (141,3,'000315131745','','8000000000001001','01/05');
INSERT INTO orders VALUES (142,1,'000112231938','','8000000000001001','01/05');
INSERT INTO orders VALUES (142,2,'000217123903','','8000000000001001','01/05');
INSERT INTO orders VALUES (142,3,'000311083454','','8000000000001001','01/05');
INSERT INTO orders VALUES (142,4,'000407092046','','8000000000001001','01/05');
INSERT INTO orders VALUES (143,1,'000104123317','','8000000000001001','01/05');
INSERT INTO orders VALUES (144,1,'000113211108','','8000000000001001','01/05');
INSERT INTO orders VALUES (144,2,'000201192129','','8000000000001001','01/05');
INSERT INTO orders VALUES (144,3,'000305164109','','8000000000001001','01/05');
INSERT INTO orders VALUES (144,4,'000417083820','','8000000000001001','01/05');
INSERT INTO orders VALUES (144,5,'000521085336','','8000000000001001','01/05');
INSERT INTO orders VALUES (144,6,'000620083734','','8000000000001001','01/05');
INSERT INTO orders VALUES (145,1,'000126153957','','8000000000001001','01/05');
INSERT INTO orders VALUES (145,2,'000211085820','','8000000000001001','01/05');
INSERT INTO orders VALUES (145,3,'000318072128','','8000000000001001','01/05');
INSERT INTO orders VALUES (146,1,'000125202050','','8000000000001001','01/05');
INSERT INTO orders VALUES (146,2,'000214230433','','8000000000001001','01/05');
INSERT INTO orders VALUES (146,3,'000303101417','','8000000000001001','01/05');
INSERT INTO orders VALUES (147,1,'000127083541','','8000000000001001','01/05');
INSERT INTO orders VALUES (147,2,'000221134155','','8000000000001001','01/05');
INSERT INTO orders VALUES (147,3,'000326122344','','8000000000001001','01/05');
INSERT INTO orders VALUES (147,4,'000417142151','','8000000000001001','01/05');
INSERT INTO orders VALUES (149,1,'000107134356','','8000000000001001','01/05');
INSERT INTO orders VALUES (149,2,'000215203829','','8000000000001001','01/05');
INSERT INTO orders VALUES (149,3,'000329233347','','8000000000001001','01/05');
INSERT INTO orders VALUES (150,1,'000108112623','','8000000000001001','01/05');
INSERT INTO orders VALUES (150,2,'000204113053','','8000000000001001','01/05');
INSERT INTO orders VALUES (150,3,'000327162717','','8000000000001001','01/05');
INSERT INTO orders VALUES (150,4,'000418142852','','8000000000001001','01/05');
INSERT INTO orders VALUES (151,1,'000120142824','','8000000000001001','01/05');
INSERT INTO orders VALUES (152,1,'000127234233','','8000000000001001','01/05');
INSERT INTO orders VALUES (152,2,'000212154247','','8000000000001001','01/05');
INSERT INTO orders VALUES (152,3,'000323143317','','8000000000001001','01/05');
INSERT INTO orders VALUES (153,1,'000115141512','','8000000000001001','01/05');
INSERT INTO orders VALUES (153,2,'000205121717','','8000000000001001','01/05');
INSERT INTO orders VALUES (153,3,'000305213324','','8000000000001001','01/05');
INSERT INTO orders VALUES (153,4,'000403065432','','8000000000001001','01/05');
INSERT INTO orders VALUES (154,1,'000104093308','','8000000000001001','01/05');
INSERT INTO orders VALUES (154,2,'000226230826','','8000000000001001','01/05');
INSERT INTO orders VALUES (154,3,'000327205402','','8000000000001001','01/05');
INSERT INTO orders VALUES (155,1,'000121082739','','8000000000001001','01/05');
INSERT INTO orders VALUES (155,2,'000222121918','','8000000000001001','01/05');
INSERT INTO orders VALUES (155,3,'000315112901','','8000000000001001','01/05');
INSERT INTO orders VALUES (155,4,'000411155156','','8000000000001001','01/05');
INSERT INTO orders VALUES (155,5,'000517201308','','8000000000001001','01/05');
INSERT INTO orders VALUES (155,6,'000615132021','','8000000000001001','01/05');
INSERT INTO orders VALUES (156,1,'000124100734','','8000000000001001','01/05');
INSERT INTO orders VALUES (156,2,'000225101812','','8000000000001001','01/05');
INSERT INTO orders VALUES (156,3,'000307095037','','8000000000001001','01/05');
INSERT INTO orders VALUES (156,4,'000402175955','','8000000000001001','01/05');
INSERT INTO orders VALUES (157,1,'000117131909','','8000000000001001','01/05');
INSERT INTO orders VALUES (158,1,'000102074242','','8000000000001001','01/05');
INSERT INTO orders VALUES (158,2,'000205075732','','8000000000001001','01/05');
INSERT INTO orders VALUES (158,3,'000328134839','','8000000000001001','01/05');
INSERT INTO orders VALUES (158,4,'000409120101','','8000000000001001','01/05');
INSERT INTO orders VALUES (158,5,'000529203631','','8000000000001001','01/05');
INSERT INTO orders VALUES (158,6,'000615204148','','8000000000001001','01/05');
INSERT INTO orders VALUES (159,1,'000126131356','','8000000000001001','01/05');
INSERT INTO orders VALUES (159,2,'000214162715','','8000000000001001','01/05');
INSERT INTO orders VALUES (159,3,'000317134340','','8000000000001001','01/05');
INSERT INTO orders VALUES (159,4,'000418115355','','8000000000001001','01/05');
INSERT INTO orders VALUES (160,1,'000128212237','','8000000000001001','01/05');
INSERT INTO orders VALUES (160,2,'000202124322','','8000000000001001','01/05');
INSERT INTO orders VALUES (160,3,'000329152019','','8000000000001001','01/05');
INSERT INTO orders VALUES (161,1,'000108140806','','8000000000001001','01/05');
INSERT INTO orders VALUES (161,2,'000205115428','','8000000000001001','01/05');
INSERT INTO orders VALUES (161,3,'000318125643','','8000000000001001','01/05');
INSERT INTO orders VALUES (161,4,'000423184540','','8000000000001001','01/05');
INSERT INTO orders VALUES (161,5,'000521172909','','8000000000001001','01/05');
INSERT INTO orders VALUES (161,6,'000620143047','','8000000000001001','01/05');
INSERT INTO orders VALUES (162,1,'000124180928','','8000000000001001','01/05');
INSERT INTO orders VALUES (162,2,'000201092530','','8000000000001001','01/05');
INSERT INTO orders VALUES (163,1,'000101110331','','8000000000001001','01/05');
INSERT INTO orders VALUES (163,2,'000203120644','','8000000000001001','01/05');
INSERT INTO orders VALUES (163,3,'000309173300','','8000000000001001','01/05');
INSERT INTO orders VALUES (163,4,'000417191405','','8000000000001001','01/05');
INSERT INTO orders VALUES (163,5,'000524184050','','8000000000001001','01/05');
INSERT INTO orders VALUES (164,1,'000110231145','','8000000000001001','01/05');
INSERT INTO orders VALUES (164,2,'000223092036','','8000000000001001','01/05');
INSERT INTO orders VALUES (164,3,'000301184755','','8000000000001001','01/05');
INSERT INTO orders VALUES (164,4,'000416073052','','8000000000001001','01/05');
INSERT INTO orders VALUES (164,5,'000526124351','','8000000000001001','01/05');
INSERT INTO orders VALUES (164,6,'000608131345','','8000000000001001','01/05');
INSERT INTO orders VALUES (165,1,'000122122918','','8000000000001001','01/05');
INSERT INTO orders VALUES (166,1,'000106234319','','8000000000001001','01/05');
INSERT INTO orders VALUES (166,2,'000226135016','','8000000000001001','01/05');
INSERT INTO orders VALUES (166,3,'000316105513','','8000000000001001','01/05');
INSERT INTO orders VALUES (166,4,'000419200940','','8000000000001001','01/05');
INSERT INTO orders VALUES (166,5,'000514152259','','8000000000001001','01/05');
INSERT INTO orders VALUES (167,1,'000109203612','','8000000000001001','01/05');
INSERT INTO orders VALUES (167,2,'000224180317','','8000000000001001','01/05');
INSERT INTO orders VALUES (167,3,'000308173751','','8000000000001001','01/05');
INSERT INTO orders VALUES (167,4,'000423084115','','8000000000001001','01/05');
INSERT INTO orders VALUES (167,5,'000528091453','','8000000000001001','01/05');
INSERT INTO orders VALUES (167,6,'000616141814','','8000000000001001','01/05');
INSERT INTO orders VALUES (168,1,'000101121811','','8000000000001001','01/05');
INSERT INTO orders VALUES (169,1,'000114113710','','8000000000001001','01/05');
INSERT INTO orders VALUES (169,2,'000205083542','','8000000000001001','01/05');
INSERT INTO orders VALUES (170,1,'000109160235','','8000000000001001','01/05');
INSERT INTO orders VALUES (170,2,'000209065825','','8000000000001001','01/05');
INSERT INTO orders VALUES (170,3,'000313232343','','8000000000001001','01/05');
INSERT INTO orders VALUES (171,1,'000123120012','','8000000000001001','01/05');
INSERT INTO orders VALUES (171,2,'000223221629','','8000000000001001','01/05');
INSERT INTO orders VALUES (172,1,'000128110226','','8000000000001001','01/05');
INSERT INTO orders VALUES (172,2,'000212082517','','8000000000001001','01/05');
INSERT INTO orders VALUES (172,3,'000324131351','','8000000000001001','01/05');
INSERT INTO orders VALUES (172,4,'000403230050','','8000000000001001','01/05');
INSERT INTO orders VALUES (173,1,'000116101324','','8000000000001001','01/05');
INSERT INTO orders VALUES (173,2,'000226200320','','8000000000001001','01/05');
INSERT INTO orders VALUES (173,3,'000312071153','','8000000000001001','01/05');
INSERT INTO orders VALUES (173,4,'000422185735','','8000000000001001','01/05');
INSERT INTO orders VALUES (173,5,'000503094756','','8000000000001001','01/05');
INSERT INTO orders VALUES (173,6,'000624173530','','8000000000001001','01/05');
INSERT INTO orders VALUES (174,1,'000128155510','','8000000000001001','01/05');
INSERT INTO orders VALUES (174,2,'000217085905','','8000000000001001','01/05');
INSERT INTO orders VALUES (174,3,'000302063659','','8000000000001001','01/05');
INSERT INTO orders VALUES (174,4,'000425230049','','8000000000001001','01/05');
INSERT INTO orders VALUES (175,1,'000108075219','','8000000000001001','01/05');
INSERT INTO orders VALUES (175,2,'000226205416','','8000000000001001','01/05');
INSERT INTO orders VALUES (175,3,'000302201618','','8000000000001001','01/05');
INSERT INTO orders VALUES (175,4,'000412151732','','8000000000001001','01/05');
INSERT INTO orders VALUES (176,1,'000112191918','','8000000000001001','01/05');
INSERT INTO orders VALUES (176,2,'000223133340','','8000000000001001','01/05');
INSERT INTO orders VALUES (176,3,'000304195239','','8000000000001001','01/05');
INSERT INTO orders VALUES (176,4,'000409210504','','8000000000001001','01/05');
INSERT INTO orders VALUES (176,5,'000504061130','','8000000000001001','01/05');
INSERT INTO orders VALUES (176,6,'000609134834','','8000000000001001','01/05');
INSERT INTO orders VALUES (177,1,'000115184950','','8000000000001001','01/05');
INSERT INTO orders VALUES (177,2,'000212200857','','8000000000001001','01/05');
INSERT INTO orders VALUES (178,1,'000101224150','','8000000000001001','01/05');
INSERT INTO orders VALUES (178,2,'000201222419','','8000000000001001','01/05');
INSERT INTO orders VALUES (178,3,'000325075452','','8000000000001001','01/05');
INSERT INTO orders VALUES (178,4,'000401133950','','8000000000001001','01/05');
INSERT INTO orders VALUES (179,1,'000105061001','','8000000000001001','01/05');
INSERT INTO orders VALUES (179,2,'000204151745','','8000000000001001','01/05');
INSERT INTO orders VALUES (179,3,'000307193109','','8000000000001001','01/05');
INSERT INTO orders VALUES (179,4,'000411160100','','8000000000001001','01/05');
INSERT INTO orders VALUES (179,5,'000523213909','','8000000000001001','01/05');
INSERT INTO orders VALUES (179,6,'000605114829','','8000000000001001','01/05');
INSERT INTO orders VALUES (180,1,'000126152448','','8000000000001001','01/05');
INSERT INTO orders VALUES (180,2,'000203201654','','8000000000001001','01/05');
INSERT INTO orders VALUES (180,3,'000319235102','','8000000000001001','01/05');
INSERT INTO orders VALUES (180,4,'000404084523','','8000000000001001','01/05');
INSERT INTO orders VALUES (180,5,'000515173353','','8000000000001001','01/05');
INSERT INTO orders VALUES (180,6,'000605215045','','8000000000001001','01/05');
INSERT INTO orders VALUES (181,1,'000115093603','','8000000000001001','01/05');
INSERT INTO orders VALUES (181,2,'000203225731','','8000000000001001','01/05');
INSERT INTO orders VALUES (181,3,'000303194333','','8000000000001001','01/05');
INSERT INTO orders VALUES (181,4,'000415211954','','8000000000001001','01/05');
INSERT INTO orders VALUES (182,1,'000128150055','','8000000000001001','01/05');
INSERT INTO orders VALUES (182,2,'000203221431','','8000000000001001','01/05');
INSERT INTO orders VALUES (182,3,'000305113604','','8000000000001001','01/05');
INSERT INTO orders VALUES (182,4,'000426065052','','8000000000001001','01/05');
INSERT INTO orders VALUES (182,5,'000525195625','','8000000000001001','01/05');
INSERT INTO orders VALUES (182,6,'000629190834','','8000000000001001','01/05');
INSERT INTO orders VALUES (183,1,'000114103754','','8000000000001001','01/05');
INSERT INTO orders VALUES (183,2,'000204131541','','8000000000001001','01/05');
INSERT INTO orders VALUES (183,3,'000323221554','','8000000000001001','01/05');
INSERT INTO orders VALUES (183,4,'000401082008','','8000000000001001','01/05');
INSERT INTO orders VALUES (183,5,'000518235131','','8000000000001001','01/05');
INSERT INTO orders VALUES (184,1,'000117133347','','8000000000001001','01/05');
INSERT INTO orders VALUES (184,2,'000213173921','','8000000000001001','01/05');
INSERT INTO orders VALUES (184,3,'000317140309','','8000000000001001','01/05');
INSERT INTO orders VALUES (184,4,'000409171157','','8000000000001001','01/05');
INSERT INTO orders VALUES (185,1,'000116155540','','8000000000001001','01/05');
INSERT INTO orders VALUES (186,1,'000116084413','','8000000000001001','01/05');
INSERT INTO orders VALUES (186,2,'000208065107','','8000000000001001','01/05');
INSERT INTO orders VALUES (186,3,'000317075703','','8000000000001001','01/05');
INSERT INTO orders VALUES (186,4,'000413074358','','8000000000001001','01/05');
INSERT INTO orders VALUES (186,5,'000521151241','','8000000000001001','01/05');
INSERT INTO orders VALUES (186,6,'000614095152','','8000000000001001','01/05');
INSERT INTO orders VALUES (187,1,'000105092613','','8000000000001001','01/05');
INSERT INTO orders VALUES (187,2,'000215100308','','8000000000001001','01/05');
INSERT INTO orders VALUES (188,1,'000125065353','','8000000000001001','01/05');
INSERT INTO orders VALUES (188,2,'000229195106','','8000000000001001','01/05');
INSERT INTO orders VALUES (188,3,'000320155931','','8000000000001001','01/05');
INSERT INTO orders VALUES (189,1,'000120093525','','8000000000001001','01/05');
INSERT INTO orders VALUES (189,2,'000213222659','','8000000000001001','01/05');
INSERT INTO orders VALUES (189,3,'000329130434','','8000000000001001','01/05');
INSERT INTO orders VALUES (190,1,'000124063422','','8000000000001001','01/05');
INSERT INTO orders VALUES (190,2,'000221202505','','8000000000001001','01/05');
INSERT INTO orders VALUES (191,1,'000128174303','','8000000000001001','01/05');
INSERT INTO orders VALUES (191,2,'000227094841','','8000000000001001','01/05');
INSERT INTO orders VALUES (191,3,'000307115644','','8000000000001001','01/05');
INSERT INTO orders VALUES (191,4,'000425101338','','8000000000001001','01/05');
INSERT INTO orders VALUES (191,5,'000509151931','','8000000000001001','01/05');
INSERT INTO orders VALUES (191,6,'000606100901','','8000000000001001','01/05');
INSERT INTO orders VALUES (192,1,'000128233243','','8000000000001001','01/05');
INSERT INTO orders VALUES (192,2,'000227234157','','8000000000001001','01/05');
INSERT INTO orders VALUES (192,3,'000325140935','','8000000000001001','01/05');
INSERT INTO orders VALUES (192,4,'000411205139','','8000000000001001','01/05');
INSERT INTO orders VALUES (192,5,'000525222547','','8000000000001001','01/05');
INSERT INTO orders VALUES (193,1,'000101131050','','8000000000001001','01/05');
INSERT INTO orders VALUES (193,2,'000216143301','','8000000000001001','01/05');
INSERT INTO orders VALUES (193,3,'000319093026','','8000000000001001','01/05');
INSERT INTO orders VALUES (193,4,'000422103330','','8000000000001001','01/05');
INSERT INTO orders VALUES (193,5,'000527173157','','8000000000001001','01/05');
INSERT INTO orders VALUES (194,1,'000124071406','','8000000000001001','01/05');
INSERT INTO orders VALUES (195,1,'000114224040','','8000000000001001','01/05');
INSERT INTO orders VALUES (195,2,'000204090533','','8000000000001001','01/05');
INSERT INTO orders VALUES (195,3,'000315103752','','8000000000001001','01/05');
INSERT INTO orders VALUES (196,1,'000127064727','','8000000000001001','01/05');
INSERT INTO orders VALUES (196,2,'000226091018','','8000000000001001','01/05');
INSERT INTO orders VALUES (196,3,'000320164927','','8000000000001001','01/05');
INSERT INTO orders VALUES (196,4,'000417071257','','8000000000001001','01/05');
INSERT INTO orders VALUES (196,5,'000525235659','','8000000000001001','01/05');
INSERT INTO orders VALUES (197,1,'000102143307','','8000000000001001','01/05');
INSERT INTO orders VALUES (197,2,'000208204741','','8000000000001001','01/05');
INSERT INTO orders VALUES (197,3,'000317180437','','8000000000001001','01/05');
INSERT INTO orders VALUES (197,4,'000421142758','','8000000000001001','01/05');
INSERT INTO orders VALUES (199,1,'000117223150','','8000000000001001','01/05');
INSERT INTO orders VALUES (199,2,'000205165956','','8000000000001001','01/05');
INSERT INTO orders VALUES (199,3,'000317072005','','8000000000001001','01/05');
INSERT INTO orders VALUES (200,1,'000129202953','','8000000000001001','01/05');
INSERT INTO orders VALUES (200,2,'000222094514','','8000000000001001','01/05');
INSERT INTO orders VALUES (200,3,'000314070326','','8000000000001001','01/05');
INSERT INTO orders VALUES (200,4,'000407135858','','8000000000001001','01/05');
INSERT INTO orders VALUES (200,5,'000518204236','','8000000000001001','01/05');
INSERT INTO orders VALUES (200,6,'000621124656','','8000000000001001','01/05');
INSERT INTO orders VALUES (201,1,'000110233945','','8000000000001001','01/05');
INSERT INTO orders VALUES (201,2,'000208060401','','8000000000001001','01/05');
INSERT INTO orders VALUES (202,1,'000111220407','','8000000000001001','01/05');
INSERT INTO orders VALUES (202,2,'000223095247','','8000000000001001','01/05');
INSERT INTO orders VALUES (202,3,'000322125647','','8000000000001001','01/05');
INSERT INTO orders VALUES (202,4,'000411124501','','8000000000001001','01/05');
INSERT INTO orders VALUES (202,5,'000528101339','','8000000000001001','01/05');
INSERT INTO orders VALUES (202,6,'000626144953','','8000000000001001','01/05');
INSERT INTO orders VALUES (203,1,'000117105110','','8000000000001001','01/05');
INSERT INTO orders VALUES (204,1,'000111131330','','8000000000001001','01/05');
INSERT INTO orders VALUES (204,2,'000222232521','','8000000000001001','01/05');
INSERT INTO orders VALUES (205,1,'000119134848','','8000000000001001','01/05');
INSERT INTO orders VALUES (206,1,'000113133954','','8000000000001001','01/05');
INSERT INTO orders VALUES (207,1,'000119164135','','8000000000001001','01/05');
INSERT INTO orders VALUES (207,2,'000214171345','','8000000000001001','01/05');
INSERT INTO orders VALUES (207,3,'000322222425','','8000000000001001','01/05');
INSERT INTO orders VALUES (207,4,'000409221422','','8000000000001001','01/05');
INSERT INTO orders VALUES (207,5,'000517091404','','8000000000001001','01/05');
INSERT INTO orders VALUES (208,1,'000129134127','','8000000000001001','01/05');
INSERT INTO orders VALUES (208,2,'000220154230','','8000000000001001','01/05');
INSERT INTO orders VALUES (208,3,'000312105106','','8000000000001001','01/05');
INSERT INTO orders VALUES (208,4,'000402175443','','8000000000001001','01/05');
INSERT INTO orders VALUES (208,5,'000516135306','','8000000000001001','01/05');
INSERT INTO orders VALUES (209,1,'000125102128','','8000000000001001','01/05');
INSERT INTO orders VALUES (209,2,'000228111825','','8000000000001001','01/05');
INSERT INTO orders VALUES (210,1,'000121212027','','8000000000001001','01/05');
INSERT INTO orders VALUES (210,2,'000203160424','','8000000000001001','01/05');
INSERT INTO orders VALUES (210,3,'000306074952','','8000000000001001','01/05');
INSERT INTO orders VALUES (211,1,'000108154615','','8000000000001001','01/05');
INSERT INTO orders VALUES (212,1,'000117152831','','8000000000001001','01/05');
INSERT INTO orders VALUES (213,1,'000124092554','','8000000000001001','01/05');
INSERT INTO orders VALUES (213,2,'000215065701','','8000000000001001','01/05');
INSERT INTO orders VALUES (213,3,'000329061147','','8000000000001001','01/05');
INSERT INTO orders VALUES (214,1,'000105163029','','8000000000001001','01/05');
INSERT INTO orders VALUES (214,2,'000211092908','','8000000000001001','01/05');
INSERT INTO orders VALUES (214,3,'000301083805','','8000000000001001','01/05');
INSERT INTO orders VALUES (214,4,'000418084807','','8000000000001001','01/05');
INSERT INTO orders VALUES (215,1,'000118100342','','8000000000001001','01/05');
INSERT INTO orders VALUES (215,2,'000225195057','','8000000000001001','01/05');
INSERT INTO orders VALUES (215,3,'000314214103','','8000000000001001','01/05');
INSERT INTO orders VALUES (215,4,'000428115057','','8000000000001001','01/05');
INSERT INTO orders VALUES (215,5,'000505081156','','8000000000001001','01/05');
INSERT INTO orders VALUES (215,6,'000621210926','','8000000000001001','01/05');
INSERT INTO orders VALUES (216,1,'000124062509','','8000000000001001','01/05');
INSERT INTO orders VALUES (217,1,'000122235250','','8000000000001001','01/05');
INSERT INTO orders VALUES (217,2,'000223145954','','8000000000001001','01/05');
INSERT INTO orders VALUES (217,3,'000318062628','','8000000000001001','01/05');
INSERT INTO orders VALUES (217,4,'000410092119','','8000000000001001','01/05');
INSERT INTO orders VALUES (217,5,'000519125310','','8000000000001001','01/05');
INSERT INTO orders VALUES (217,6,'000605180544','','8000000000001001','01/05');
INSERT INTO orders VALUES (218,1,'000127105017','','8000000000001001','01/05');
INSERT INTO orders VALUES (218,2,'000228200539','','8000000000001001','01/05');
INSERT INTO orders VALUES (218,3,'000315230814','','8000000000001001','01/05');
INSERT INTO orders VALUES (218,4,'000410094115','','8000000000001001','01/05');
INSERT INTO orders VALUES (218,5,'000528144127','','8000000000001001','01/05');
INSERT INTO orders VALUES (218,6,'000607233749','','8000000000001001','01/05');
INSERT INTO orders VALUES (219,1,'000128103847','','8000000000001001','01/05');
INSERT INTO orders VALUES (219,2,'000207070913','','8000000000001001','01/05');
INSERT INTO orders VALUES (219,3,'000315123119','','8000000000001001','01/05');
INSERT INTO orders VALUES (219,4,'000417062544','','8000000000001001','01/05');
INSERT INTO orders VALUES (219,5,'000506235332','','8000000000001001','01/05');
INSERT INTO orders VALUES (220,1,'000125214929','','8000000000001001','01/05');
INSERT INTO orders VALUES (220,2,'000224224331','','8000000000001001','01/05');
INSERT INTO orders VALUES (221,1,'000118175850','','8000000000001001','01/05');
INSERT INTO orders VALUES (221,2,'000218072425','','8000000000001001','01/05');
INSERT INTO orders VALUES (221,3,'000329201342','','8000000000001001','01/05');
INSERT INTO orders VALUES (221,4,'000428142322','','8000000000001001','01/05');
INSERT INTO orders VALUES (221,5,'000507063426','','8000000000001001','01/05');
INSERT INTO orders VALUES (221,6,'000615230552','','8000000000001001','01/05');
INSERT INTO orders VALUES (222,1,'000101213019','','8000000000001001','01/05');
INSERT INTO orders VALUES (223,1,'000127094615','','8000000000001001','01/05');
INSERT INTO orders VALUES (224,1,'000104181349','','8000000000001001','01/05');
INSERT INTO orders VALUES (224,2,'000211105934','','8000000000001001','01/05');
INSERT INTO orders VALUES (225,1,'000110140007','','8000000000001001','01/05');
INSERT INTO orders VALUES (226,1,'000113120725','','8000000000001001','01/05');
INSERT INTO orders VALUES (226,2,'000202234056','','8000000000001001','01/05');
INSERT INTO orders VALUES (226,3,'000324171712','','8000000000001001','01/05');
INSERT INTO orders VALUES (227,1,'000101080720','','8000000000001001','01/05');
INSERT INTO orders VALUES (227,2,'000203161542','','8000000000001001','01/05');
INSERT INTO orders VALUES (227,3,'000317075631','','8000000000001001','01/05');
INSERT INTO orders VALUES (227,4,'000415224939','','8000000000001001','01/05');
INSERT INTO orders VALUES (228,1,'000121170203','','8000000000001001','01/05');
INSERT INTO orders VALUES (229,1,'000102162741','','8000000000001001','01/05');
INSERT INTO orders VALUES (229,2,'000212215028','','8000000000001001','01/05');
INSERT INTO orders VALUES (229,3,'000328161100','','8000000000001001','01/05');
INSERT INTO orders VALUES (230,1,'000125133141','','8000000000001001','01/05');
INSERT INTO orders VALUES (230,2,'000202090550','','8000000000001001','01/05');
INSERT INTO orders VALUES (230,3,'000305135738','','8000000000001001','01/05');
INSERT INTO orders VALUES (230,4,'000417062412','','8000000000001001','01/05');
INSERT INTO orders VALUES (231,1,'000126103922','','8000000000001001','01/05');
INSERT INTO orders VALUES (231,2,'000222101613','','8000000000001001','01/05');
INSERT INTO orders VALUES (231,3,'000327124342','','8000000000001001','01/05');
INSERT INTO orders VALUES (231,4,'000416140055','','8000000000001001','01/05');
INSERT INTO orders VALUES (231,5,'000503193201','','8000000000001001','01/05');
INSERT INTO orders VALUES (231,6,'000626173409','','8000000000001001','01/05');
INSERT INTO orders VALUES (232,1,'000117094116','','8000000000001001','01/05');
INSERT INTO orders VALUES (232,2,'000227225432','','8000000000001001','01/05');
INSERT INTO orders VALUES (232,3,'000320152951','','8000000000001001','01/05');
INSERT INTO orders VALUES (232,4,'000403144824','','8000000000001001','01/05');
INSERT INTO orders VALUES (233,1,'000126145815','','8000000000001001','01/05');
INSERT INTO orders VALUES (233,2,'000207061717','','8000000000001001','01/05');
INSERT INTO orders VALUES (233,3,'000310223017','','8000000000001001','01/05');
INSERT INTO orders VALUES (233,4,'000405154234','','8000000000001001','01/05');
INSERT INTO orders VALUES (234,1,'000111140926','','8000000000001001','01/05');
INSERT INTO orders VALUES (234,2,'000202220327','','8000000000001001','01/05');
INSERT INTO orders VALUES (235,1,'000103070258','','8000000000001001','01/05');
INSERT INTO orders VALUES (235,2,'000212194438','','8000000000001001','01/05');
INSERT INTO orders VALUES (235,3,'000328091431','','8000000000001001','01/05');
INSERT INTO orders VALUES (235,4,'000420191826','','8000000000001001','01/05');
INSERT INTO orders VALUES (236,1,'000102145517','','8000000000001001','01/05');
INSERT INTO orders VALUES (236,2,'000201200928','','8000000000001001','01/05');
INSERT INTO orders VALUES (236,3,'000307155456','','8000000000001001','01/05');
INSERT INTO orders VALUES (236,4,'000413221135','','8000000000001001','01/05');
INSERT INTO orders VALUES (236,5,'000501131614','','8000000000001001','01/05');
INSERT INTO orders VALUES (236,6,'000629160237','','8000000000001001','01/05');
INSERT INTO orders VALUES (237,1,'000112143538','','8000000000001001','01/05');
INSERT INTO orders VALUES (238,1,'000113090647','','8000000000001001','01/05');
INSERT INTO orders VALUES (238,2,'000202072622','','8000000000001001','01/05');
INSERT INTO orders VALUES (239,1,'000107083525','','8000000000001001','01/05');
INSERT INTO orders VALUES (240,1,'000106140409','','8000000000001001','01/05');
INSERT INTO orders VALUES (240,2,'000206172021','','8000000000001001','01/05');
INSERT INTO orders VALUES (240,3,'000308205412','','8000000000001001','01/05');
INSERT INTO orders VALUES (240,4,'000408131050','','8000000000001001','01/05');
INSERT INTO orders VALUES (240,5,'000514091231','','8000000000001001','01/05');
INSERT INTO orders VALUES (240,6,'000617174644','','8000000000001001','01/05');
INSERT INTO orders VALUES (241,1,'000114155223','','8000000000001001','01/05');
INSERT INTO orders VALUES (241,2,'000210113241','','8000000000001001','01/05');
INSERT INTO orders VALUES (241,3,'000315092828','','8000000000001001','01/05');
INSERT INTO orders VALUES (241,4,'000403213224','','8000000000001001','01/05');
INSERT INTO orders VALUES (241,5,'000517185203','','8000000000001001','01/05');
INSERT INTO orders VALUES (241,6,'000612092647','','8000000000001001','01/05');
INSERT INTO orders VALUES (242,1,'000112071729','','8000000000001001','01/05');
INSERT INTO orders VALUES (242,2,'000206124046','','8000000000001001','01/05');
INSERT INTO orders VALUES (242,3,'000311111424','','8000000000001001','01/05');
INSERT INTO orders VALUES (242,4,'000404124313','','8000000000001001','01/05');
INSERT INTO orders VALUES (242,5,'000515180851','','8000000000001001','01/05');
INSERT INTO orders VALUES (242,6,'000623071709','','8000000000001001','01/05');
INSERT INTO orders VALUES (243,1,'000121213508','','8000000000001001','01/05');
INSERT INTO orders VALUES (243,2,'000208191604','','8000000000001001','01/05');
INSERT INTO orders VALUES (244,1,'000110094021','','8000000000001001','01/05');
INSERT INTO orders VALUES (244,2,'000205204426','','8000000000001001','01/05');
INSERT INTO orders VALUES (244,3,'000313152706','','8000000000001001','01/05');
INSERT INTO orders VALUES (244,4,'000419164223','','8000000000001001','01/05');
INSERT INTO orders VALUES (244,5,'000516110157','','8000000000001001','01/05');
INSERT INTO orders VALUES (245,1,'000117154758','','8000000000001001','01/05');
INSERT INTO orders VALUES (245,2,'000202172323','','8000000000001001','01/05');
INSERT INTO orders VALUES (245,3,'000323201521','','8000000000001001','01/05');
INSERT INTO orders VALUES (245,4,'000420152239','','8000000000001001','01/05');
INSERT INTO orders VALUES (245,5,'000513062546','','8000000000001001','01/05');
INSERT INTO orders VALUES (245,6,'000607205405','','8000000000001001','01/05');
INSERT INTO orders VALUES (246,1,'000112151509','','8000000000001001','01/05');
INSERT INTO orders VALUES (246,2,'000226172927','','8000000000001001','01/05');
INSERT INTO orders VALUES (246,3,'000304060530','','8000000000001001','01/05');
INSERT INTO orders VALUES (247,1,'000123193044','','8000000000001001','01/05');
INSERT INTO orders VALUES (247,2,'000211173724','','8000000000001001','01/05');
INSERT INTO orders VALUES (247,3,'000314104803','','8000000000001001','01/05');
INSERT INTO orders VALUES (248,1,'000111181227','','8000000000001001','01/05');
INSERT INTO orders VALUES (249,1,'000108072119','','8000000000001001','01/05');
INSERT INTO orders VALUES (249,2,'000207112040','','8000000000001001','01/05');
INSERT INTO orders VALUES (249,3,'000320181014','','8000000000001001','01/05');
INSERT INTO orders VALUES (249,4,'000426080127','','8000000000001001','01/05');
INSERT INTO orders VALUES (249,5,'000512165810','','8000000000001001','01/05');
INSERT INTO orders VALUES (249,6,'000620160521','','8000000000001001','01/05');
INSERT INTO orders VALUES (250,1,'000102230119','','8000000000001001','01/05');
INSERT INTO orders VALUES (250,2,'000219191713','','8000000000001001','01/05');
INSERT INTO orders VALUES (250,3,'000321144155','','8000000000001001','01/05');
INSERT INTO orders VALUES (250,4,'000426091210','','8000000000001001','01/05');
INSERT INTO orders VALUES (250,5,'000505090127','','8000000000001001','01/05');
INSERT INTO orders VALUES (250,6,'000619070114','','8000000000001001','01/05');
INSERT INTO orders VALUES (251,1,'000118135425','','8000000000001001','01/05');
INSERT INTO orders VALUES (251,2,'000202063452','','8000000000001001','01/05');
INSERT INTO orders VALUES (251,3,'000305214239','','8000000000001001','01/05');
INSERT INTO orders VALUES (251,4,'000426104057','','8000000000001001','01/05');
INSERT INTO orders VALUES (251,5,'000502223745','','8000000000001001','01/05');
INSERT INTO orders VALUES (251,6,'000628142450','','8000000000001001','01/05');
INSERT INTO orders VALUES (252,1,'000101132125','','8000000000001001','01/05');
INSERT INTO orders VALUES (252,2,'000226214327','','8000000000001001','01/05');
INSERT INTO orders VALUES (252,3,'000309140939','','8000000000001001','01/05');
INSERT INTO orders VALUES (252,4,'000407150220','','8000000000001001','01/05');
INSERT INTO orders VALUES (252,5,'000508155043','','8000000000001001','01/05');
INSERT INTO orders VALUES (253,1,'000129182328','','8000000000001001','01/05');
INSERT INTO orders VALUES (253,2,'000207083344','','8000000000001001','01/05');
INSERT INTO orders VALUES (253,3,'000315123953','','8000000000001001','01/05');
INSERT INTO orders VALUES (253,4,'000402070656','','8000000000001001','01/05');
INSERT INTO orders VALUES (253,5,'000516180455','','8000000000001001','01/05');
INSERT INTO orders VALUES (254,1,'000104165404','','8000000000001001','01/05');
INSERT INTO orders VALUES (254,2,'000214093208','','8000000000001001','01/05');
INSERT INTO orders VALUES (254,3,'000319184407','','8000000000001001','01/05');
INSERT INTO orders VALUES (254,4,'000424164004','','8000000000001001','01/05');
INSERT INTO orders VALUES (255,1,'000102234656','','8000000000001001','01/05');
INSERT INTO orders VALUES (255,2,'000203153842','','8000000000001001','01/05');
INSERT INTO orders VALUES (255,3,'000310155857','','8000000000001001','01/05');
INSERT INTO orders VALUES (255,4,'000405174937','','8000000000001001','01/05');
INSERT INTO orders VALUES (255,5,'000505224024','','8000000000001001','01/05');
INSERT INTO orders VALUES (255,6,'000622063855','','8000000000001001','01/05');
INSERT INTO orders VALUES (256,1,'000123211753','','8000000000001001','01/05');
INSERT INTO orders VALUES (256,2,'000220090652','','8000000000001001','01/05');
INSERT INTO orders VALUES (256,3,'000326154534','','8000000000001001','01/05');
INSERT INTO orders VALUES (256,4,'000428222951','','8000000000001001','01/05');
INSERT INTO orders VALUES (256,5,'000520184921','','8000000000001001','01/05');
INSERT INTO orders VALUES (257,1,'000106154334','','8000000000001001','01/05');
INSERT INTO orders VALUES (257,2,'000224164131','','8000000000001001','01/05');
INSERT INTO orders VALUES (257,3,'000323131154','','8000000000001001','01/05');
INSERT INTO orders VALUES (257,4,'000418163838','','8000000000001001','01/05');
INSERT INTO orders VALUES (257,5,'000519152123','','8000000000001001','01/05');
INSERT INTO orders VALUES (257,6,'000608071750','','8000000000001001','01/05');
INSERT INTO orders VALUES (258,1,'000102214752','','8000000000001001','01/05');
INSERT INTO orders VALUES (258,2,'000206214802','','8000000000001001','01/05');
INSERT INTO orders VALUES (259,1,'000116131124','','8000000000001001','01/05');
INSERT INTO orders VALUES (259,2,'000203144934','','8000000000001001','01/05');
INSERT INTO orders VALUES (259,3,'000309142412','','8000000000001001','01/05');
INSERT INTO orders VALUES (259,4,'000414181242','','8000000000001001','01/05');
INSERT INTO orders VALUES (259,5,'000501064237','','8000000000001001','01/05');
INSERT INTO orders VALUES (259,6,'000622110104','','8000000000001001','01/05');
INSERT INTO orders VALUES (260,1,'000105093040','','8000000000001001','01/05');
INSERT INTO orders VALUES (260,2,'000211203140','','8000000000001001','01/05');
INSERT INTO orders VALUES (260,3,'000324175119','','8000000000001001','01/05');
INSERT INTO orders VALUES (260,4,'000412130611','','8000000000001001','01/05');
INSERT INTO orders VALUES (261,1,'000115104411','','8000000000001001','01/05');
INSERT INTO orders VALUES (261,2,'000219210449','','8000000000001001','01/05');
INSERT INTO orders VALUES (262,1,'000113151936','','8000000000001001','01/05');
INSERT INTO orders VALUES (262,2,'000229152848','','8000000000001001','01/05');
INSERT INTO orders VALUES (263,1,'000111144818','','8000000000001001','01/05');
INSERT INTO orders VALUES (263,2,'000215132817','','8000000000001001','01/05');
INSERT INTO orders VALUES (263,3,'000304113737','','8000000000001001','01/05');
INSERT INTO orders VALUES (263,4,'000421205021','','8000000000001001','01/05');
INSERT INTO orders VALUES (263,5,'000517211901','','8000000000001001','01/05');
INSERT INTO orders VALUES (264,1,'000103124943','','8000000000001001','01/05');
INSERT INTO orders VALUES (264,2,'000226215213','','8000000000001001','01/05');
INSERT INTO orders VALUES (264,3,'000301114530','','8000000000001001','01/05');
INSERT INTO orders VALUES (265,1,'000122103904','','8000000000001001','01/05');
INSERT INTO orders VALUES (265,2,'000225112532','','8000000000001001','01/05');
INSERT INTO orders VALUES (265,3,'000327153252','','8000000000001001','01/05');
INSERT INTO orders VALUES (265,4,'000424063310','','8000000000001001','01/05');
INSERT INTO orders VALUES (265,5,'000519155108','','8000000000001001','01/05');
INSERT INTO orders VALUES (266,1,'000101061356','','8000000000001001','01/05');
INSERT INTO orders VALUES (267,1,'000123062043','','8000000000001001','01/05');
INSERT INTO orders VALUES (267,2,'000226072801','','8000000000001001','01/05');
INSERT INTO orders VALUES (268,1,'000114142310','','8000000000001001','01/05');
INSERT INTO orders VALUES (268,2,'000215203347','','8000000000001001','01/05');
INSERT INTO orders VALUES (268,3,'000327154020','','8000000000001001','01/05');
INSERT INTO orders VALUES (269,1,'000108062620','','8000000000001001','01/05');
INSERT INTO orders VALUES (269,2,'000212095655','','8000000000001001','01/05');
INSERT INTO orders VALUES (270,1,'000121112902','','8000000000001001','01/05');
INSERT INTO orders VALUES (270,2,'000213195108','','8000000000001001','01/05');
INSERT INTO orders VALUES (271,1,'000123080613','','8000000000001001','01/05');
INSERT INTO orders VALUES (272,1,'000129182256','','8000000000001001','01/05');
INSERT INTO orders VALUES (272,2,'000225170759','','8000000000001001','01/05');
INSERT INTO orders VALUES (272,3,'000316173855','','8000000000001001','01/05');
INSERT INTO orders VALUES (272,4,'000410231726','','8000000000001001','01/05');
INSERT INTO orders VALUES (272,5,'000525200920','','8000000000001001','01/05');
INSERT INTO orders VALUES (272,6,'000622090740','','8000000000001001','01/05');
INSERT INTO orders VALUES (273,1,'000125112911','','8000000000001001','01/05');
INSERT INTO orders VALUES (273,2,'000224082824','','8000000000001001','01/05');
INSERT INTO orders VALUES (273,3,'000324074328','','8000000000001001','01/05');
INSERT INTO orders VALUES (274,1,'000114142811','','8000000000001001','01/05');
INSERT INTO orders VALUES (274,2,'000212202001','','8000000000001001','01/05');
INSERT INTO orders VALUES (274,3,'000311193521','','8000000000001001','01/05');
INSERT INTO orders VALUES (274,4,'000409202556','','8000000000001001','01/05');
INSERT INTO orders VALUES (275,1,'000106112431','','8000000000001001','01/05');
INSERT INTO orders VALUES (275,2,'000225155847','','8000000000001001','01/05');
INSERT INTO orders VALUES (276,1,'000124235121','','8000000000001001','01/05');
INSERT INTO orders VALUES (276,2,'000209213247','','8000000000001001','01/05');
INSERT INTO orders VALUES (276,3,'000324181331','','8000000000001001','01/05');
INSERT INTO orders VALUES (276,4,'000405090718','','8000000000001001','01/05');
INSERT INTO orders VALUES (276,5,'000508200048','','8000000000001001','01/05');
INSERT INTO orders VALUES (277,1,'000111175140','','8000000000001001','01/05');
INSERT INTO orders VALUES (277,2,'000220073527','','8000000000001001','01/05');
INSERT INTO orders VALUES (277,3,'000318213339','','8000000000001001','01/05');
INSERT INTO orders VALUES (278,1,'000116100556','','8000000000001001','01/05');
INSERT INTO orders VALUES (278,2,'000206081017','','8000000000001001','01/05');
INSERT INTO orders VALUES (278,3,'000311105321','','8000000000001001','01/05');
INSERT INTO orders VALUES (278,4,'000427122246','','8000000000001001','01/05');
INSERT INTO orders VALUES (278,5,'000505094907','','8000000000001001','01/05');
INSERT INTO orders VALUES (279,1,'000101225131','','8000000000001001','01/05');
INSERT INTO orders VALUES (279,2,'000208191825','','8000000000001001','01/05');
INSERT INTO orders VALUES (279,3,'000322150636','','8000000000001001','01/05');
INSERT INTO orders VALUES (279,4,'000429181914','','8000000000001001','01/05');
INSERT INTO orders VALUES (279,5,'000529190527','','8000000000001001','01/05');
INSERT INTO orders VALUES (280,1,'000105210716','','8000000000001001','01/05');
INSERT INTO orders VALUES (280,2,'000203191355','','8000000000001001','01/05');
INSERT INTO orders VALUES (281,1,'000128195938','','8000000000001001','01/05');
INSERT INTO orders VALUES (281,2,'000209105918','','8000000000001001','01/05');
INSERT INTO orders VALUES (281,3,'000323184118','','8000000000001001','01/05');
INSERT INTO orders VALUES (281,4,'000404231505','','8000000000001001','01/05');
INSERT INTO orders VALUES (281,5,'000504061549','','8000000000001001','01/05');
INSERT INTO orders VALUES (281,6,'000607200433','','8000000000001001','01/05');
INSERT INTO orders VALUES (282,1,'000106171341','','8000000000001001','01/05');
INSERT INTO orders VALUES (282,2,'000217113607','','8000000000001001','01/05');
INSERT INTO orders VALUES (282,3,'000310222014','','8000000000001001','01/05');
INSERT INTO orders VALUES (282,4,'000406071147','','8000000000001001','01/05');
INSERT INTO orders VALUES (282,5,'000527121635','','8000000000001001','01/05');
INSERT INTO orders VALUES (282,6,'000615092141','','8000000000001001','01/05');
INSERT INTO orders VALUES (283,1,'000126192654','','8000000000001001','01/05');
INSERT INTO orders VALUES (283,2,'000223135419','','8000000000001001','01/05');
INSERT INTO orders VALUES (283,3,'000329191724','','8000000000001001','01/05');
INSERT INTO orders VALUES (283,4,'000417222526','','8000000000001001','01/05');
INSERT INTO orders VALUES (283,5,'000509201932','','8000000000001001','01/05');
INSERT INTO orders VALUES (284,1,'000122080410','','8000000000001001','01/05');
INSERT INTO orders VALUES (284,2,'000201151339','','8000000000001001','01/05');
INSERT INTO orders VALUES (285,1,'000112212531','','8000000000001001','01/05');
INSERT INTO orders VALUES (285,2,'000212221803','','8000000000001001','01/05');
INSERT INTO orders VALUES (286,1,'000116182721','','8000000000001001','01/05');
INSERT INTO orders VALUES (287,1,'000106144812','','8000000000001001','01/05');
INSERT INTO orders VALUES (288,1,'000117062234','','8000000000001001','01/05');
INSERT INTO orders VALUES (288,2,'000227134201','','8000000000001001','01/05');
INSERT INTO orders VALUES (288,3,'000312082909','','8000000000001001','01/05');
INSERT INTO orders VALUES (288,4,'000412162758','','8000000000001001','01/05');
INSERT INTO orders VALUES (288,5,'000501221754','','8000000000001001','01/05');
INSERT INTO orders VALUES (289,1,'000120174439','','8000000000001001','01/05');
INSERT INTO orders VALUES (290,1,'000129105316','','8000000000001001','01/05');
INSERT INTO orders VALUES (290,2,'000211084900','','8000000000001001','01/05');
INSERT INTO orders VALUES (291,1,'000106181226','','8000000000001001','01/05');
INSERT INTO orders VALUES (291,2,'000208133944','','8000000000001001','01/05');
INSERT INTO orders VALUES (291,3,'000316111230','','8000000000001001','01/05');
INSERT INTO orders VALUES (292,1,'000115130313','','8000000000001001','01/05');
INSERT INTO orders VALUES (292,2,'000202105812','','8000000000001001','01/05');
INSERT INTO orders VALUES (292,3,'000304065410','','8000000000001001','01/05');
INSERT INTO orders VALUES (292,4,'000401164541','','8000000000001001','01/05');
INSERT INTO orders VALUES (293,1,'000117235611','','8000000000001001','01/05');
INSERT INTO orders VALUES (293,2,'000223102346','','8000000000001001','01/05');
INSERT INTO orders VALUES (293,3,'000309204551','','8000000000001001','01/05');
INSERT INTO orders VALUES (293,4,'000418074217','','8000000000001001','01/05');
INSERT INTO orders VALUES (293,5,'000522130333','','8000000000001001','01/05');
INSERT INTO orders VALUES (294,1,'000103221240','','8000000000001001','01/05');
INSERT INTO orders VALUES (295,1,'000118211138','','8000000000001001','01/05');
INSERT INTO orders VALUES (296,1,'000122185711','','8000000000001001','01/05');
INSERT INTO orders VALUES (296,2,'000201100811','','8000000000001001','01/05');
INSERT INTO orders VALUES (296,3,'000313212252','','8000000000001001','01/05');
INSERT INTO orders VALUES (297,1,'000109063303','','8000000000001001','01/05');
INSERT INTO orders VALUES (297,2,'000226162401','','8000000000001001','01/05');
INSERT INTO orders VALUES (298,1,'000104143709','','8000000000001001','01/05');
INSERT INTO orders VALUES (298,2,'000212091748','','8000000000001001','01/05');
INSERT INTO orders VALUES (299,1,'000101110443','','8000000000001001','01/05');
INSERT INTO orders VALUES (300,1,'000104155031','','8000000000001001','01/05');
INSERT INTO orders VALUES (301,1,'000101231704','','8000000000001001','01/05');
INSERT INTO orders VALUES (301,2,'000217152204','','8000000000001001','01/05');
INSERT INTO orders VALUES (301,3,'000311110651','','8000000000001001','01/05');
INSERT INTO orders VALUES (301,4,'000408171538','','8000000000001001','01/05');
INSERT INTO orders VALUES (301,5,'000514203149','','8000000000001001','01/05');
INSERT INTO orders VALUES (302,1,'000119162208','','8000000000001001','01/05');
INSERT INTO orders VALUES (303,1,'000107151045','','8000000000001001','01/05');
INSERT INTO orders VALUES (304,1,'000120084740','','8000000000001001','01/05');
INSERT INTO orders VALUES (304,2,'000218170009','','8000000000001001','01/05');
INSERT INTO orders VALUES (304,3,'000306154559','','8000000000001001','01/05');
INSERT INTO orders VALUES (304,4,'000411195353','','8000000000001001','01/05');
INSERT INTO orders VALUES (304,5,'000511185733','','8000000000001001','01/05');
INSERT INTO orders VALUES (304,6,'000611092844','','8000000000001001','01/05');
INSERT INTO orders VALUES (305,1,'000102070935','','8000000000001001','01/05');
INSERT INTO orders VALUES (305,2,'000216092454','','8000000000001001','01/05');
INSERT INTO orders VALUES (305,3,'000327175313','','8000000000001001','01/05');
INSERT INTO orders VALUES (306,1,'000123101251','','8000000000001001','01/05');
INSERT INTO orders VALUES (307,1,'000110231743','','8000000000001001','01/05');
INSERT INTO orders VALUES (307,2,'000219205605','','8000000000001001','01/05');
INSERT INTO orders VALUES (307,3,'000324121416','','8000000000001001','01/05');
INSERT INTO orders VALUES (308,1,'000116233520','','8000000000001001','01/05');
INSERT INTO orders VALUES (308,2,'000216095853','','8000000000001001','01/05');
INSERT INTO orders VALUES (309,1,'000110071208','','8000000000001001','01/05');
INSERT INTO orders VALUES (309,2,'000203145459','','8000000000001001','01/05');
INSERT INTO orders VALUES (310,1,'000104164312','','8000000000001001','01/05');
INSERT INTO orders VALUES (310,2,'000207170441','','8000000000001001','01/05');
INSERT INTO orders VALUES (310,3,'000313112533','','8000000000001001','01/05');
INSERT INTO orders VALUES (310,4,'000410133413','','8000000000001001','01/05');
INSERT INTO orders VALUES (311,1,'000113182330','','8000000000001001','01/05');
INSERT INTO orders VALUES (311,2,'000201224514','','8000000000001001','01/05');
INSERT INTO orders VALUES (311,3,'000313195148','','8000000000001001','01/05');
INSERT INTO orders VALUES (312,1,'000129194348','','8000000000001001','01/05');
INSERT INTO orders VALUES (313,1,'000124225018','','8000000000001001','01/05');
INSERT INTO orders VALUES (313,2,'000206200659','','8000000000001001','01/05');
INSERT INTO orders VALUES (313,3,'000318075022','','8000000000001001','01/05');
INSERT INTO orders VALUES (313,4,'000421185718','','8000000000001001','01/05');
INSERT INTO orders VALUES (313,5,'000523224300','','8000000000001001','01/05');
INSERT INTO orders VALUES (313,6,'000629214505','','8000000000001001','01/05');
INSERT INTO orders VALUES (314,1,'000106224550','','8000000000001001','01/05');
INSERT INTO orders VALUES (314,2,'000225231858','','8000000000001001','01/05');
INSERT INTO orders VALUES (314,3,'000319063326','','8000000000001001','01/05');
INSERT INTO orders VALUES (314,4,'000429082214','','8000000000001001','01/05');
INSERT INTO orders VALUES (314,5,'000515122813','','8000000000001001','01/05');
INSERT INTO orders VALUES (314,6,'000602093912','','8000000000001001','01/05');
INSERT INTO orders VALUES (315,1,'000107063927','','8000000000001001','01/05');
INSERT INTO orders VALUES (315,2,'000215120024','','8000000000001001','01/05');
INSERT INTO orders VALUES (315,3,'000306175025','','8000000000001001','01/05');
INSERT INTO orders VALUES (315,4,'000413190330','','8000000000001001','01/05');
INSERT INTO orders VALUES (315,5,'000523174916','','8000000000001001','01/05');
INSERT INTO orders VALUES (316,1,'000110130506','','8000000000001001','01/05');
INSERT INTO orders VALUES (316,2,'000213100330','','8000000000001001','01/05');
INSERT INTO orders VALUES (316,3,'000324195954','','8000000000001001','01/05');
INSERT INTO orders VALUES (316,4,'000426201423','','8000000000001001','01/05');
INSERT INTO orders VALUES (317,1,'000126205535','','8000000000001001','01/05');
INSERT INTO orders VALUES (317,2,'000205151958','','8000000000001001','01/05');
INSERT INTO orders VALUES (318,1,'000112080031','','8000000000001001','01/05');
INSERT INTO orders VALUES (319,1,'000108074251','','8000000000001001','01/05');
INSERT INTO orders VALUES (319,2,'000219104446','','8000000000001001','01/05');
INSERT INTO orders VALUES (320,1,'000108184406','','8000000000001001','01/05');
INSERT INTO orders VALUES (320,2,'000219132757','','8000000000001001','01/05');
INSERT INTO orders VALUES (320,3,'000319064818','','8000000000001001','01/05');
INSERT INTO orders VALUES (320,4,'000408221252','','8000000000001001','01/05');
INSERT INTO orders VALUES (321,1,'000104185749','','8000000000001001','01/05');
INSERT INTO orders VALUES (321,2,'000217225556','','8000000000001001','01/05');
INSERT INTO orders VALUES (321,3,'000303164723','','8000000000001001','01/05');
INSERT INTO orders VALUES (321,4,'000403135020','','8000000000001001','01/05');
INSERT INTO orders VALUES (321,5,'000525123729','','8000000000001001','01/05');
INSERT INTO orders VALUES (322,1,'000126134912','','8000000000001001','01/05');
INSERT INTO orders VALUES (322,2,'000203101125','','8000000000001001','01/05');
INSERT INTO orders VALUES (322,3,'000327080747','','8000000000001001','01/05');
INSERT INTO orders VALUES (322,4,'000404230952','','8000000000001001','01/05');
INSERT INTO orders VALUES (322,5,'000523073455','','8000000000001001','01/05');
INSERT INTO orders VALUES (322,6,'000620161429','','8000000000001001','01/05');
INSERT INTO orders VALUES (323,1,'000105161414','','8000000000001001','01/05');
INSERT INTO orders VALUES (323,2,'000225131639','','8000000000001001','01/05');
INSERT INTO orders VALUES (323,3,'000320120549','','8000000000001001','01/05');
INSERT INTO orders VALUES (323,4,'000409190632','','8000000000001001','01/05');
INSERT INTO orders VALUES (324,1,'000101170123','','8000000000001001','01/05');
INSERT INTO orders VALUES (325,1,'000111190326','','8000000000001001','01/05');
INSERT INTO orders VALUES (325,2,'000229235950','','8000000000001001','01/05');
INSERT INTO orders VALUES (325,3,'000317182305','','8000000000001001','01/05');
INSERT INTO orders VALUES (325,4,'000418220209','','8000000000001001','01/05');
INSERT INTO orders VALUES (325,5,'000512093801','','8000000000001001','01/05');
INSERT INTO orders VALUES (325,6,'000610153341','','8000000000001001','01/05');
INSERT INTO orders VALUES (326,1,'000124170359','','8000000000001001','01/05');
INSERT INTO orders VALUES (326,2,'000218082320','','8000000000001001','01/05');
INSERT INTO orders VALUES (326,3,'000303191653','','8000000000001001','01/05');
INSERT INTO orders VALUES (326,4,'000402134738','','8000000000001001','01/05');
INSERT INTO orders VALUES (327,1,'000114073302','','8000000000001001','01/05');
INSERT INTO orders VALUES (327,2,'000221234106','','8000000000001001','01/05');
INSERT INTO orders VALUES (328,1,'000122221346','','8000000000001001','01/05');
INSERT INTO orders VALUES (328,2,'000227123813','','8000000000001001','01/05');
INSERT INTO orders VALUES (328,3,'000303110747','','8000000000001001','01/05');
INSERT INTO orders VALUES (328,4,'000428101057','','8000000000001001','01/05');
INSERT INTO orders VALUES (328,5,'000514214835','','8000000000001001','01/05');
INSERT INTO orders VALUES (328,6,'000623115015','','8000000000001001','01/05');
INSERT INTO orders VALUES (329,1,'000105173439','','8000000000001001','01/05');
INSERT INTO orders VALUES (329,2,'000215132845','','8000000000001001','01/05');
INSERT INTO orders VALUES (329,3,'000318221739','','8000000000001001','01/05');
INSERT INTO orders VALUES (329,4,'000402142444','','8000000000001001','01/05');
INSERT INTO orders VALUES (329,5,'000510225636','','8000000000001001','01/05');
INSERT INTO orders VALUES (329,6,'000625081752','','8000000000001001','01/05');
INSERT INTO orders VALUES (330,1,'000123095348','','8000000000001001','01/05');
INSERT INTO orders VALUES (330,2,'000206082017','','8000000000001001','01/05');
INSERT INTO orders VALUES (330,3,'000325234845','','8000000000001001','01/05');
INSERT INTO orders VALUES (330,4,'000414120254','','8000000000001001','01/05');
INSERT INTO orders VALUES (330,5,'000517211724','','8000000000001001','01/05');
INSERT INTO orders VALUES (331,1,'000110070846','','8000000000001001','01/05');
INSERT INTO orders VALUES (331,2,'000204111231','','8000000000001001','01/05');
INSERT INTO orders VALUES (331,3,'000311113754','','8000000000001001','01/05');
INSERT INTO orders VALUES (331,4,'000411093733','','8000000000001001','01/05');
INSERT INTO orders VALUES (331,5,'000514164355','','8000000000001001','01/05');
INSERT INTO orders VALUES (332,1,'000113111149','','8000000000001001','01/05');
INSERT INTO orders VALUES (332,2,'000225114825','','8000000000001001','01/05');
INSERT INTO orders VALUES (332,3,'000320120226','','8000000000001001','01/05');
INSERT INTO orders VALUES (332,4,'000417145805','','8000000000001001','01/05');
INSERT INTO orders VALUES (333,1,'000124181606','','8000000000001001','01/05');
INSERT INTO orders VALUES (333,2,'000228121311','','8000000000001001','01/05');
INSERT INTO orders VALUES (333,3,'000325064939','','8000000000001001','01/05');
INSERT INTO orders VALUES (333,4,'000429192239','','8000000000001001','01/05');
INSERT INTO orders VALUES (334,1,'000114215603','','8000000000001001','01/05');
INSERT INTO orders VALUES (334,2,'000217060420','','8000000000001001','01/05');
INSERT INTO orders VALUES (334,3,'000329140536','','8000000000001001','01/05');
INSERT INTO orders VALUES (334,4,'000403092540','','8000000000001001','01/05');
INSERT INTO orders VALUES (335,1,'000115073804','','8000000000001001','01/05');
INSERT INTO orders VALUES (335,2,'000221085529','','8000000000001001','01/05');
INSERT INTO orders VALUES (335,3,'000325135031','','8000000000001001','01/05');
INSERT INTO orders VALUES (336,1,'000127112846','','8000000000001001','01/05');
INSERT INTO orders VALUES (336,2,'000226184805','','8000000000001001','01/05');
INSERT INTO orders VALUES (336,3,'000302224737','','8000000000001001','01/05');
INSERT INTO orders VALUES (337,1,'000111203720','','8000000000001001','01/05');
INSERT INTO orders VALUES (337,2,'000227111241','','8000000000001001','01/05');
INSERT INTO orders VALUES (337,3,'000329111543','','8000000000001001','01/05');
INSERT INTO orders VALUES (337,4,'000423100207','','8000000000001001','01/05');
INSERT INTO orders VALUES (338,1,'000124104316','','8000000000001001','01/05');
INSERT INTO orders VALUES (338,2,'000224225012','','8000000000001001','01/05');
INSERT INTO orders VALUES (338,3,'000320121652','','8000000000001001','01/05');
INSERT INTO orders VALUES (338,4,'000421125731','','8000000000001001','01/05');
INSERT INTO orders VALUES (338,5,'000529095157','','8000000000001001','01/05');
INSERT INTO orders VALUES (338,6,'000624141909','','8000000000001001','01/05');
INSERT INTO orders VALUES (339,1,'000102112807','','8000000000001001','01/05');
INSERT INTO orders VALUES (339,2,'000226102659','','8000000000001001','01/05');
INSERT INTO orders VALUES (339,3,'000325070732','','8000000000001001','01/05');
INSERT INTO orders VALUES (339,4,'000421080508','','8000000000001001','01/05');
INSERT INTO orders VALUES (340,1,'000118194202','','8000000000001001','01/05');
INSERT INTO orders VALUES (340,2,'000223154053','','8000000000001001','01/05');
INSERT INTO orders VALUES (340,3,'000320234517','','8000000000001001','01/05');
INSERT INTO orders VALUES (340,4,'000429070546','','8000000000001001','01/05');
INSERT INTO orders VALUES (340,5,'000503112847','','8000000000001001','01/05');
INSERT INTO orders VALUES (341,1,'000114095632','','8000000000001001','01/05');
INSERT INTO orders VALUES (342,1,'000125164819','','8000000000001001','01/05');
INSERT INTO orders VALUES (342,2,'000203143401','','8000000000001001','01/05');
INSERT INTO orders VALUES (342,3,'000319103706','','8000000000001001','01/05');
INSERT INTO orders VALUES (343,1,'000112234226','','8000000000001001','01/05');
INSERT INTO orders VALUES (343,2,'000229081212','','8000000000001001','01/05');
INSERT INTO orders VALUES (343,3,'000318102604','','8000000000001001','01/05');
INSERT INTO orders VALUES (344,1,'000104162633','','8000000000001001','01/05');
INSERT INTO orders VALUES (344,2,'000216171636','','8000000000001001','01/05');
INSERT INTO orders VALUES (344,3,'000318190656','','8000000000001001','01/05');
INSERT INTO orders VALUES (345,1,'000118100715','','8000000000001001','01/05');
INSERT INTO orders VALUES (345,2,'000206105252','','8000000000001001','01/05');
INSERT INTO orders VALUES (345,3,'000309064537','','8000000000001001','01/05');
INSERT INTO orders VALUES (346,1,'000127232058','','8000000000001001','01/05');
INSERT INTO orders VALUES (347,1,'000107172541','','8000000000001001','01/05');
INSERT INTO orders VALUES (347,2,'000204234245','','8000000000001001','01/05');
INSERT INTO orders VALUES (347,3,'000324065330','','8000000000001001','01/05');
INSERT INTO orders VALUES (347,4,'000415220437','','8000000000001001','01/05');
INSERT INTO orders VALUES (347,5,'000515062717','','8000000000001001','01/05');
INSERT INTO orders VALUES (348,1,'000122155821','','8000000000001001','01/05');
INSERT INTO orders VALUES (348,2,'000218123954','','8000000000001001','01/05');
INSERT INTO orders VALUES (348,3,'000327161112','','8000000000001001','01/05');
INSERT INTO orders VALUES (348,4,'000419061720','','8000000000001001','01/05');
INSERT INTO orders VALUES (349,1,'000128063352','','8000000000001001','01/05');
INSERT INTO orders VALUES (349,2,'000220150349','','8000000000001001','01/05');
INSERT INTO orders VALUES (349,3,'000326075621','','8000000000001001','01/05');
INSERT INTO orders VALUES (350,1,'000104163628','','8000000000001001','01/05');
INSERT INTO orders VALUES (350,2,'000210094323','','8000000000001001','01/05');
INSERT INTO orders VALUES (350,3,'000311152417','','8000000000001001','01/05');
INSERT INTO orders VALUES (350,4,'000413185354','','8000000000001001','01/05');
INSERT INTO orders VALUES (350,5,'000523090809','','8000000000001001','01/05');
INSERT INTO orders VALUES (351,1,'000104141400','','8000000000001001','01/05');
INSERT INTO orders VALUES (352,1,'000121120229','','8000000000001001','01/05');
INSERT INTO orders VALUES (352,2,'000203091802','','8000000000001001','01/05');
INSERT INTO orders VALUES (352,3,'000328143239','','8000000000001001','01/05');
INSERT INTO orders VALUES (353,1,'000114135213','','8000000000001001','01/05');
INSERT INTO orders VALUES (353,2,'000206151606','','8000000000001001','01/05');
INSERT INTO orders VALUES (353,3,'000329160227','','8000000000001001','01/05');
INSERT INTO orders VALUES (354,1,'000126100007','','8000000000001001','01/05');
INSERT INTO orders VALUES (355,1,'000106205818','','8000000000001001','01/05');
INSERT INTO orders VALUES (355,2,'000203131318','','8000000000001001','01/05');
INSERT INTO orders VALUES (355,3,'000326182305','','8000000000001001','01/05');
INSERT INTO orders VALUES (355,4,'000405142706','','8000000000001001','01/05');
INSERT INTO orders VALUES (356,1,'000118121519','','8000000000001001','01/05');
INSERT INTO orders VALUES (357,1,'000102081930','','8000000000001001','01/05');
INSERT INTO orders VALUES (358,1,'000121153557','','8000000000001001','01/05');
INSERT INTO orders VALUES (359,1,'000108125015','','8000000000001001','01/05');
INSERT INTO orders VALUES (359,2,'000220162736','','8000000000001001','01/05');
INSERT INTO orders VALUES (359,3,'000303081719','','8000000000001001','01/05');
INSERT INTO orders VALUES (359,4,'000401112342','','8000000000001001','01/05');
INSERT INTO orders VALUES (359,5,'000511165926','','8000000000001001','01/05');
INSERT INTO orders VALUES (359,6,'000613121849','','8000000000001001','01/05');
INSERT INTO orders VALUES (362,1,'000124150904','','8000000000001001','01/05');
INSERT INTO orders VALUES (362,2,'000208151434','','8000000000001001','01/05');
INSERT INTO orders VALUES (362,3,'000324161136','','8000000000001001','01/05');
INSERT INTO orders VALUES (363,1,'000102234837','','8000000000001001','01/05');
INSERT INTO orders VALUES (363,2,'000225192525','','8000000000001001','01/05');
INSERT INTO orders VALUES (363,3,'000325201329','','8000000000001001','01/05');
INSERT INTO orders VALUES (364,1,'000120120817','','8000000000001001','01/05');
INSERT INTO orders VALUES (364,2,'000215090022','','8000000000001001','01/05');
INSERT INTO orders VALUES (364,3,'000317201746','','8000000000001001','01/05');
INSERT INTO orders VALUES (364,4,'000416161430','','8000000000001001','01/05');
INSERT INTO orders VALUES (365,1,'000115060418','','8000000000001001','01/05');
INSERT INTO orders VALUES (366,1,'000122205534','','8000000000001001','01/05');
INSERT INTO orders VALUES (366,2,'000221091902','','8000000000001001','01/05');
INSERT INTO orders VALUES (366,3,'000328111126','','8000000000001001','01/05');
INSERT INTO orders VALUES (366,4,'000422220504','','8000000000001001','01/05');
INSERT INTO orders VALUES (367,1,'000120232557','','8000000000001001','01/05');
INSERT INTO orders VALUES (367,2,'000214083033','','8000000000001001','01/05');
INSERT INTO orders VALUES (367,3,'000304074433','','8000000000001001','01/05');
INSERT INTO orders VALUES (368,1,'000118094608','','8000000000001001','01/05');
INSERT INTO orders VALUES (369,1,'000113224409','','8000000000001001','01/05');
INSERT INTO orders VALUES (369,2,'000222080159','','8000000000001001','01/05');
INSERT INTO orders VALUES (369,3,'000301174725','','8000000000001001','01/05');
INSERT INTO orders VALUES (369,4,'000417170437','','8000000000001001','01/05');
INSERT INTO orders VALUES (369,5,'000502103734','','8000000000001001','01/05');
INSERT INTO orders VALUES (370,1,'000118073013','','8000000000001001','01/05');
INSERT INTO orders VALUES (371,1,'000121121014','','8000000000001001','01/05');
INSERT INTO orders VALUES (371,2,'000209124922','','8000000000001001','01/05');
INSERT INTO orders VALUES (371,3,'000302174450','','8000000000001001','01/05');
INSERT INTO orders VALUES (371,4,'000410212629','','8000000000001001','01/05');
INSERT INTO orders VALUES (371,5,'000521145617','','8000000000001001','01/05');
INSERT INTO orders VALUES (371,6,'000610104740','','8000000000001001','01/05');
INSERT INTO orders VALUES (372,1,'000103153912','','8000000000001001','01/05');
INSERT INTO orders VALUES (372,2,'000211144338','','8000000000001001','01/05');
INSERT INTO orders VALUES (373,1,'000120231152','','8000000000001001','01/05');
INSERT INTO orders VALUES (373,2,'000225120713','','8000000000001001','01/05');
INSERT INTO orders VALUES (373,3,'000328104146','','8000000000001001','01/05');
INSERT INTO orders VALUES (374,1,'000104141314','','8000000000001001','01/05');
INSERT INTO orders VALUES (375,1,'000122200501','','8000000000001001','01/05');
INSERT INTO orders VALUES (375,2,'000227101056','','8000000000001001','01/05');
INSERT INTO orders VALUES (376,1,'000119120027','','8000000000001001','01/05');
INSERT INTO orders VALUES (377,1,'000114090057','','8000000000001001','01/05');
INSERT INTO orders VALUES (377,2,'000210135840','','8000000000001001','01/05');
INSERT INTO orders VALUES (377,3,'000311152612','','8000000000001001','01/05');
INSERT INTO orders VALUES (377,4,'000415205950','','8000000000001001','01/05');
INSERT INTO orders VALUES (377,5,'000523181500','','8000000000001001','01/05');
INSERT INTO orders VALUES (378,1,'000124134746','','8000000000001001','01/05');
INSERT INTO orders VALUES (378,2,'000211091358','','8000000000001001','01/05');
INSERT INTO orders VALUES (378,3,'000326101449','','8000000000001001','01/05');
INSERT INTO orders VALUES (378,4,'000428225856','','8000000000001001','01/05');
INSERT INTO orders VALUES (379,1,'000122172312','','8000000000001001','01/05');
INSERT INTO orders VALUES (379,2,'000224215344','','8000000000001001','01/05');
INSERT INTO orders VALUES (379,3,'000314084312','','8000000000001001','01/05');
INSERT INTO orders VALUES (379,4,'000415090626','','8000000000001001','01/05');
INSERT INTO orders VALUES (379,5,'000515192537','','8000000000001001','01/05');
INSERT INTO orders VALUES (380,1,'000118145814','','8000000000001001','01/05');
INSERT INTO orders VALUES (381,1,'000120071904','','8000000000001001','01/05');
INSERT INTO orders VALUES (381,2,'000211191651','','8000000000001001','01/05');
INSERT INTO orders VALUES (381,3,'000319151819','','8000000000001001','01/05');
INSERT INTO orders VALUES (381,4,'000416150233','','8000000000001001','01/05');
INSERT INTO orders VALUES (382,1,'000112190859','','8000000000001001','01/05');
INSERT INTO orders VALUES (383,1,'000126222123','','8000000000001001','01/05');
INSERT INTO orders VALUES (383,2,'000201142735','','8000000000001001','01/05');
INSERT INTO orders VALUES (383,3,'000316202513','','8000000000001001','01/05');
INSERT INTO orders VALUES (383,4,'000407222236','','8000000000001001','01/05');
INSERT INTO orders VALUES (384,1,'000115094617','','8000000000001001','01/05');
INSERT INTO orders VALUES (384,2,'000214160423','','8000000000001001','01/05');
INSERT INTO orders VALUES (384,3,'000314060409','','8000000000001001','01/05');
INSERT INTO orders VALUES (384,4,'000406233808','','8000000000001001','01/05');
INSERT INTO orders VALUES (384,5,'000519142359','','8000000000001001','01/05');
INSERT INTO orders VALUES (385,1,'000123155555','','8000000000001001','01/05');
INSERT INTO orders VALUES (385,2,'000226193222','','8000000000001001','01/05');
INSERT INTO orders VALUES (385,3,'000317174747','','8000000000001001','01/05');
INSERT INTO orders VALUES (385,4,'000419080145','','8000000000001001','01/05');
INSERT INTO orders VALUES (386,1,'000121232855','','8000000000001001','01/05');
INSERT INTO orders VALUES (386,2,'000216185529','','8000000000001001','01/05');
INSERT INTO orders VALUES (386,3,'000315181835','','8000000000001001','01/05');
INSERT INTO orders VALUES (387,1,'000128100702','','8000000000001001','01/05');
INSERT INTO orders VALUES (387,2,'000206135826','','8000000000001001','01/05');
INSERT INTO orders VALUES (387,3,'000307170409','','8000000000001001','01/05');
INSERT INTO orders VALUES (387,4,'000416175749','','8000000000001001','01/05');
INSERT INTO orders VALUES (387,5,'000505194729','','8000000000001001','01/05');
INSERT INTO orders VALUES (388,1,'000127220526','','8000000000001001','01/05');
INSERT INTO orders VALUES (388,2,'000206191959','','8000000000001001','01/05');
INSERT INTO orders VALUES (388,3,'000320064601','','8000000000001001','01/05');
INSERT INTO orders VALUES (388,4,'000405102128','','8000000000001001','01/05');
INSERT INTO orders VALUES (389,1,'000113114737','','8000000000001001','01/05');
INSERT INTO orders VALUES (389,2,'000210131917','','8000000000001001','01/05');
INSERT INTO orders VALUES (389,3,'000302220056','','8000000000001001','01/05');
INSERT INTO orders VALUES (389,4,'000413191925','','8000000000001001','01/05');
INSERT INTO orders VALUES (389,5,'000514123241','','8000000000001001','01/05');
INSERT INTO orders VALUES (389,6,'000623063502','','8000000000001001','01/05');
INSERT INTO orders VALUES (390,1,'000107214950','','8000000000001001','01/05');
INSERT INTO orders VALUES (390,2,'000226175939','','8000000000001001','01/05');
INSERT INTO orders VALUES (391,1,'000116080421','','8000000000001001','01/05');
INSERT INTO orders VALUES (391,2,'000227155828','','8000000000001001','01/05');
INSERT INTO orders VALUES (391,3,'000316100442','','8000000000001001','01/05');
INSERT INTO orders VALUES (391,4,'000421195213','','8000000000001001','01/05');
INSERT INTO orders VALUES (391,5,'000520180110','','8000000000001001','01/05');
INSERT INTO orders VALUES (392,1,'000114091037','','8000000000001001','01/05');
INSERT INTO orders VALUES (392,2,'000209211135','','8000000000001001','01/05');
INSERT INTO orders VALUES (392,3,'000317085831','','8000000000001001','01/05');
INSERT INTO orders VALUES (393,1,'000120153132','','8000000000001001','01/05');
INSERT INTO orders VALUES (394,1,'000110204112','','8000000000001001','01/05');
INSERT INTO orders VALUES (394,2,'000227100828','','8000000000001001','01/05');
INSERT INTO orders VALUES (394,3,'000304131725','','8000000000001001','01/05');
INSERT INTO orders VALUES (395,1,'000123142810','','8000000000001001','01/05');
INSERT INTO orders VALUES (396,1,'000116202910','','8000000000001001','01/05');
INSERT INTO orders VALUES (396,2,'000224165954','','8000000000001001','01/05');
INSERT INTO orders VALUES (396,3,'000313134838','','8000000000001001','01/05');
INSERT INTO orders VALUES (396,4,'000418071624','','8000000000001001','01/05');
INSERT INTO orders VALUES (397,1,'000120195545','','8000000000001001','01/05');
INSERT INTO orders VALUES (397,2,'000218102017','','8000000000001001','01/05');
INSERT INTO orders VALUES (397,3,'000326230432','','8000000000001001','01/05');
INSERT INTO orders VALUES (397,4,'000423080939','','8000000000001001','01/05');
INSERT INTO orders VALUES (397,5,'000512102300','','8000000000001001','01/05');
INSERT INTO orders VALUES (398,1,'000109070757','','8000000000001001','01/05');
INSERT INTO orders VALUES (398,2,'000221215929','','8000000000001001','01/05');
INSERT INTO orders VALUES (398,3,'000314113400','','8000000000001001','01/05');
INSERT INTO orders VALUES (399,1,'000128115748','','8000000000001001','01/05');
INSERT INTO orders VALUES (400,1,'000120181452','','8000000000001001','01/05');
INSERT INTO orders VALUES (400,2,'000220092148','','8000000000001001','01/05');
INSERT INTO orders VALUES (400,3,'000318065216','','8000000000001001','01/05');
INSERT INTO orders VALUES (400,4,'000422145905','','8000000000001001','01/05');
INSERT INTO orders VALUES (400,5,'000525115307','','8000000000001001','01/05');
INSERT INTO orders VALUES (401,1,'000123235402','','8000000000001001','01/05');
INSERT INTO orders VALUES (402,1,'000103074835','','8000000000001001','01/05');
INSERT INTO orders VALUES (402,2,'000221152434','','8000000000001001','01/05');
INSERT INTO orders VALUES (403,1,'000120173539','','8000000000001001','01/05');
INSERT INTO orders VALUES (404,1,'000108110723','','8000000000001001','01/05');
INSERT INTO orders VALUES (404,2,'000226062132','','8000000000001001','01/05');
INSERT INTO orders VALUES (405,1,'000124102529','','8000000000001001','01/05');
INSERT INTO orders VALUES (405,2,'000229154454','','8000000000001001','01/05');
INSERT INTO orders VALUES (405,3,'000314232849','','8000000000001001','01/05');
INSERT INTO orders VALUES (405,4,'000418184503','','8000000000001001','01/05');
INSERT INTO orders VALUES (406,1,'000120075539','','8000000000001001','01/05');
INSERT INTO orders VALUES (406,2,'000217074643','','8000000000001001','01/05');
INSERT INTO orders VALUES (406,3,'000324080221','','8000000000001001','01/05');
INSERT INTO orders VALUES (406,4,'000410231559','','8000000000001001','01/05');
INSERT INTO orders VALUES (406,5,'000515125107','','8000000000001001','01/05');
INSERT INTO orders VALUES (407,1,'000109205531','','8000000000001001','01/05');
INSERT INTO orders VALUES (408,1,'000114111957','','8000000000001001','01/05');
INSERT INTO orders VALUES (408,2,'000214222622','','8000000000001001','01/05');
INSERT INTO orders VALUES (408,3,'000305194108','','8000000000001001','01/05');
INSERT INTO orders VALUES (408,4,'000416072357','','8000000000001001','01/05');
INSERT INTO orders VALUES (409,1,'000121170049','','8000000000001001','01/05');
INSERT INTO orders VALUES (409,2,'000224205646','','8000000000001001','01/05');
INSERT INTO orders VALUES (409,3,'000321104942','','8000000000001001','01/05');
INSERT INTO orders VALUES (409,4,'000408083953','','8000000000001001','01/05');
INSERT INTO orders VALUES (409,5,'000524113830','','8000000000001001','01/05');
INSERT INTO orders VALUES (409,6,'000616203410','','8000000000001001','01/05');
INSERT INTO orders VALUES (412,1,'000108213447','','8000000000001001','01/05');
INSERT INTO orders VALUES (412,2,'000208225417','','8000000000001001','01/05');
INSERT INTO orders VALUES (413,1,'000105233449','','8000000000001001','01/05');
INSERT INTO orders VALUES (413,2,'000204210301','','8000000000001001','01/05');
INSERT INTO orders VALUES (413,3,'000329231340','','8000000000001001','01/05');
INSERT INTO orders VALUES (413,4,'000411092556','','8000000000001001','01/05');
INSERT INTO orders VALUES (413,5,'000507153510','','8000000000001001','01/05');
INSERT INTO orders VALUES (414,1,'000123080820','','8000000000001001','01/05');
INSERT INTO orders VALUES (414,2,'000226103625','','8000000000001001','01/05');
INSERT INTO orders VALUES (415,1,'000109124223','','8000000000001001','01/05');
INSERT INTO orders VALUES (415,2,'000224105411','','8000000000001001','01/05');
INSERT INTO orders VALUES (416,1,'000116181315','','8000000000001001','01/05');
INSERT INTO orders VALUES (417,1,'000118125438','','8000000000001001','01/05');
INSERT INTO orders VALUES (417,2,'000220060420','','8000000000001001','01/05');
INSERT INTO orders VALUES (417,3,'000315160605','','8000000000001001','01/05');
INSERT INTO orders VALUES (417,4,'000410072850','','8000000000001001','01/05');
INSERT INTO orders VALUES (417,5,'000516132310','','8000000000001001','01/05');
INSERT INTO orders VALUES (417,6,'000608145321','','8000000000001001','01/05');
INSERT INTO orders VALUES (418,1,'000117134859','','8000000000001001','01/05');
INSERT INTO orders VALUES (418,2,'000201221301','','8000000000001001','01/05');
INSERT INTO orders VALUES (418,3,'000329212031','','8000000000001001','01/05');
INSERT INTO orders VALUES (418,4,'000426065507','','8000000000001001','01/05');
INSERT INTO orders VALUES (418,5,'000508062912','','8000000000001001','01/05');
INSERT INTO orders VALUES (418,6,'000602081427','','8000000000001001','01/05');
INSERT INTO orders VALUES (419,1,'000120112656','','8000000000001001','01/05');
INSERT INTO orders VALUES (420,1,'000103165646','','8000000000001001','01/05');
INSERT INTO orders VALUES (420,2,'000215171626','','8000000000001001','01/05');
INSERT INTO orders VALUES (421,1,'000124161748','','8000000000001001','01/05');
INSERT INTO orders VALUES (421,2,'000217065101','','8000000000001001','01/05');
INSERT INTO orders VALUES (421,3,'000306175959','','8000000000001001','01/05');
INSERT INTO orders VALUES (421,4,'000417105207','','8000000000001001','01/05');
INSERT INTO orders VALUES (421,5,'000515161041','','8000000000001001','01/05');
INSERT INTO orders VALUES (421,6,'000628121430','','8000000000001001','01/05');
INSERT INTO orders VALUES (422,1,'000114113031','','8000000000001001','01/05');
INSERT INTO orders VALUES (422,2,'000219124305','','8000000000001001','01/05');
INSERT INTO orders VALUES (422,3,'000307154220','','8000000000001001','01/05');
INSERT INTO orders VALUES (422,4,'000408202418','','8000000000001001','01/05');
INSERT INTO orders VALUES (422,5,'000522153526','','8000000000001001','01/05');
INSERT INTO orders VALUES (422,6,'000622094508','','8000000000001001','01/05');
INSERT INTO orders VALUES (423,1,'000117213014','','8000000000001001','01/05');
INSERT INTO orders VALUES (424,1,'000110163454','','8000000000001001','01/05');
INSERT INTO orders VALUES (425,1,'000109181351','','8000000000001001','01/05');
INSERT INTO orders VALUES (425,2,'000206060322','','8000000000001001','01/05');
INSERT INTO orders VALUES (425,3,'000307144943','','8000000000001001','01/05');
INSERT INTO orders VALUES (425,4,'000424135944','','8000000000001001','01/05');
INSERT INTO orders VALUES (426,1,'000106182740','','8000000000001001','01/05');
INSERT INTO orders VALUES (426,2,'000225104211','','8000000000001001','01/05');
INSERT INTO orders VALUES (426,3,'000322172457','','8000000000001001','01/05');
INSERT INTO orders VALUES (426,4,'000426094036','','8000000000001001','01/05');
INSERT INTO orders VALUES (426,5,'000515121349','','8000000000001001','01/05');
INSERT INTO orders VALUES (427,1,'000104062129','','8000000000001001','01/05');
INSERT INTO orders VALUES (427,2,'000220174430','','8000000000001001','01/05');
INSERT INTO orders VALUES (427,3,'000326162416','','8000000000001001','01/05');
INSERT INTO orders VALUES (428,1,'000112093254','','8000000000001001','01/05');
INSERT INTO orders VALUES (428,2,'000203102225','','8000000000001001','01/05');
INSERT INTO orders VALUES (428,3,'000308212317','','8000000000001001','01/05');
INSERT INTO orders VALUES (428,4,'000423075607','','8000000000001001','01/05');
INSERT INTO orders VALUES (429,1,'000111130532','','8000000000001001','01/05');
INSERT INTO orders VALUES (429,2,'000212181004','','8000000000001001','01/05');
INSERT INTO orders VALUES (430,1,'000120100648','','8000000000001001','01/05');
INSERT INTO orders VALUES (431,1,'000117061632','','8000000000001001','01/05');
INSERT INTO orders VALUES (431,2,'000205151258','','8000000000001001','01/05');
INSERT INTO orders VALUES (431,3,'000327083305','','8000000000001001','01/05');
INSERT INTO orders VALUES (431,4,'000415195842','','8000000000001001','01/05');
INSERT INTO orders VALUES (431,5,'000507191009','','8000000000001001','01/05');
INSERT INTO orders VALUES (431,6,'000618172906','','8000000000001001','01/05');
INSERT INTO orders VALUES (432,1,'000109224527','','8000000000001001','01/05');
INSERT INTO orders VALUES (433,1,'000118085812','','8000000000001001','01/05');
INSERT INTO orders VALUES (434,1,'000122145302','','8000000000001001','01/05');
INSERT INTO orders VALUES (434,2,'000218234045','','8000000000001001','01/05');
INSERT INTO orders VALUES (434,3,'000324152219','','8000000000001001','01/05');
INSERT INTO orders VALUES (435,1,'000125110017','','8000000000001001','01/05');
INSERT INTO orders VALUES (435,2,'000205175239','','8000000000001001','01/05');
INSERT INTO orders VALUES (435,3,'000301142652','','8000000000001001','01/05');
INSERT INTO orders VALUES (436,1,'000112062309','','8000000000001001','01/05');
INSERT INTO orders VALUES (436,2,'000210125046','','8000000000001001','01/05');
INSERT INTO orders VALUES (436,3,'000308071736','','8000000000001001','01/05');
INSERT INTO orders VALUES (436,4,'000417155424','','8000000000001001','01/05');
INSERT INTO orders VALUES (437,1,'000128231401','','8000000000001001','01/05');
INSERT INTO orders VALUES (437,2,'000207130240','','8000000000001001','01/05');
INSERT INTO orders VALUES (437,3,'000306065108','','8000000000001001','01/05');
INSERT INTO orders VALUES (437,4,'000426082341','','8000000000001001','01/05');
INSERT INTO orders VALUES (437,5,'000518223442','','8000000000001001','01/05');
INSERT INTO orders VALUES (437,6,'000605215539','','8000000000001001','01/05');
INSERT INTO orders VALUES (438,1,'000118070731','','8000000000001001','01/05');
INSERT INTO orders VALUES (438,2,'000207190953','','8000000000001001','01/05');
INSERT INTO orders VALUES (438,3,'000315084611','','8000000000001001','01/05');
INSERT INTO orders VALUES (438,4,'000425101051','','8000000000001001','01/05');
INSERT INTO orders VALUES (439,1,'000102140119','','8000000000001001','01/05');
INSERT INTO orders VALUES (439,2,'000211160559','','8000000000001001','01/05');
INSERT INTO orders VALUES (440,1,'000117235101','','8000000000001001','01/05');
INSERT INTO orders VALUES (440,2,'000210073417','','8000000000001001','01/05');
INSERT INTO orders VALUES (440,3,'000302101753','','8000000000001001','01/05');
INSERT INTO orders VALUES (441,1,'000112061815','','8000000000001001','01/05');
INSERT INTO orders VALUES (441,2,'000224212023','','8000000000001001','01/05');
INSERT INTO orders VALUES (441,3,'000301144226','','8000000000001001','01/05');
INSERT INTO orders VALUES (442,1,'000128084111','','8000000000001001','01/05');
INSERT INTO orders VALUES (442,2,'000229132424','','8000000000001001','01/05');
INSERT INTO orders VALUES (443,1,'000112095757','','8000000000001001','01/05');
INSERT INTO orders VALUES (443,2,'000220233003','','8000000000001001','01/05');
INSERT INTO orders VALUES (443,3,'000301210558','','8000000000001001','01/05');
INSERT INTO orders VALUES (443,4,'000422170305','','8000000000001001','01/05');
INSERT INTO orders VALUES (443,5,'000527113810','','8000000000001001','01/05');
INSERT INTO orders VALUES (443,6,'000627123057','','8000000000001001','01/05');
INSERT INTO orders VALUES (445,1,'000120175010','','8000000000001001','01/05');
INSERT INTO orders VALUES (445,2,'000202161734','','8000000000001001','01/05');
INSERT INTO orders VALUES (445,3,'000312163502','','8000000000001001','01/05');
INSERT INTO orders VALUES (445,4,'000425224708','','8000000000001001','01/05');
INSERT INTO orders VALUES (445,5,'000506185403','','8000000000001001','01/05');
INSERT INTO orders VALUES (446,1,'000120173043','','8000000000001001','01/05');
INSERT INTO orders VALUES (446,2,'000216190714','','8000000000001001','01/05');
INSERT INTO orders VALUES (446,3,'000321124923','','8000000000001001','01/05');
INSERT INTO orders VALUES (446,4,'000421160138','','8000000000001001','01/05');
INSERT INTO orders VALUES (446,5,'000517194302','','8000000000001001','01/05');
INSERT INTO orders VALUES (446,6,'000609183550','','8000000000001001','01/05');
INSERT INTO orders VALUES (447,1,'000112191553','','8000000000001001','01/05');
INSERT INTO orders VALUES (447,2,'000215131854','','8000000000001001','01/05');
INSERT INTO orders VALUES (447,3,'000329204735','','8000000000001001','01/05');
INSERT INTO orders VALUES (447,4,'000427133825','','8000000000001001','01/05');
INSERT INTO orders VALUES (448,1,'000102212343','','8000000000001001','01/05');
INSERT INTO orders VALUES (449,1,'000119133511','','8000000000001001','01/05');
INSERT INTO orders VALUES (449,2,'000216172927','','8000000000001001','01/05');
INSERT INTO orders VALUES (449,3,'000304195602','','8000000000001001','01/05');
INSERT INTO orders VALUES (449,4,'000427094527','','8000000000001001','01/05');
INSERT INTO orders VALUES (449,5,'000512161522','','8000000000001001','01/05');
INSERT INTO orders VALUES (451,1,'000106202333','','8000000000001001','01/05');
INSERT INTO orders VALUES (451,2,'000215123420','','8000000000001001','01/05');
INSERT INTO orders VALUES (451,3,'000314061443','','8000000000001001','01/05');
INSERT INTO orders VALUES (452,1,'000111174816','','8000000000001001','01/05');
INSERT INTO orders VALUES (452,2,'000217193401','','8000000000001001','01/05');
INSERT INTO orders VALUES (453,1,'000113183357','','8000000000001001','01/05');
INSERT INTO orders VALUES (453,2,'000223222923','','8000000000001001','01/05');
INSERT INTO orders VALUES (454,1,'000117061647','','8000000000001001','01/05');
INSERT INTO orders VALUES (454,2,'000222060311','','8000000000001001','01/05');
INSERT INTO orders VALUES (454,3,'000301193927','','8000000000001001','01/05');
INSERT INTO orders VALUES (454,4,'000410120116','','8000000000001001','01/05');
INSERT INTO orders VALUES (455,1,'000120075841','','8000000000001001','01/05');
INSERT INTO orders VALUES (455,2,'000208173549','','8000000000001001','01/05');
INSERT INTO orders VALUES (455,3,'000315093628','','8000000000001001','01/05');
INSERT INTO orders VALUES (455,4,'000424192817','','8000000000001001','01/05');
INSERT INTO orders VALUES (456,1,'000125131908','','8000000000001001','01/05');
INSERT INTO orders VALUES (456,2,'000225150842','','8000000000001001','01/05');
INSERT INTO orders VALUES (456,3,'000303070355','','8000000000001001','01/05');
INSERT INTO orders VALUES (456,4,'000421083125','','8000000000001001','01/05');
INSERT INTO orders VALUES (457,1,'000117173245','','8000000000001001','01/05');
INSERT INTO orders VALUES (457,2,'000218103726','','8000000000001001','01/05');
INSERT INTO orders VALUES (458,1,'000124124454','','8000000000001001','01/05');
INSERT INTO orders VALUES (458,2,'000217153449','','8000000000001001','01/05');
INSERT INTO orders VALUES (458,3,'000307094555','','8000000000001001','01/05');
INSERT INTO orders VALUES (458,4,'000408190710','','8000000000001001','01/05');
INSERT INTO orders VALUES (458,5,'000509062941','','8000000000001001','01/05');
INSERT INTO orders VALUES (459,1,'000106174924','','8000000000001001','01/05');
INSERT INTO orders VALUES (459,2,'000204210948','','8000000000001001','01/05');
INSERT INTO orders VALUES (459,3,'000322145337','','8000000000001001','01/05');
INSERT INTO orders VALUES (460,1,'000124163136','','8000000000001001','01/05');
INSERT INTO orders VALUES (460,2,'000208163123','','8000000000001001','01/05');
INSERT INTO orders VALUES (460,3,'000323181826','','8000000000001001','01/05');
INSERT INTO orders VALUES (460,4,'000416143752','','8000000000001001','01/05');
INSERT INTO orders VALUES (460,5,'000502212035','','8000000000001001','01/05');
INSERT INTO orders VALUES (461,1,'000124185639','','8000000000001001','01/05');
INSERT INTO orders VALUES (461,2,'000217205909','','8000000000001001','01/05');
INSERT INTO orders VALUES (462,1,'000113113605','','8000000000001001','01/05');
INSERT INTO orders VALUES (462,2,'000210140351','','8000000000001001','01/05');
INSERT INTO orders VALUES (462,3,'000329064435','','8000000000001001','01/05');
INSERT INTO orders VALUES (462,4,'000427171614','','8000000000001001','01/05');
INSERT INTO orders VALUES (463,1,'000103094104','','8000000000001001','01/05');
INSERT INTO orders VALUES (463,2,'000221083651','','8000000000001001','01/05');
INSERT INTO orders VALUES (463,3,'000320142641','','8000000000001001','01/05');
INSERT INTO orders VALUES (463,4,'000411075146','','8000000000001001','01/05');
INSERT INTO orders VALUES (463,5,'000520115602','','8000000000001001','01/05');
INSERT INTO orders VALUES (464,1,'000120213826','','8000000000001001','01/05');
INSERT INTO orders VALUES (464,2,'000206103447','','8000000000001001','01/05');
INSERT INTO orders VALUES (464,3,'000311150101','','8000000000001001','01/05');
INSERT INTO orders VALUES (464,4,'000403105932','','8000000000001001','01/05');
INSERT INTO orders VALUES (464,5,'000515211143','','8000000000001001','01/05');
INSERT INTO orders VALUES (465,1,'000109214150','','8000000000001001','01/05');
INSERT INTO orders VALUES (465,2,'000203105647','','8000000000001001','01/05');
INSERT INTO orders VALUES (466,1,'000120185146','','8000000000001001','01/05');
INSERT INTO orders VALUES (466,2,'000223152004','','8000000000001001','01/05');
INSERT INTO orders VALUES (466,3,'000313175908','','8000000000001001','01/05');
INSERT INTO orders VALUES (466,4,'000401131148','','8000000000001001','01/05');
INSERT INTO orders VALUES (467,1,'000120192818','','8000000000001001','01/05');
INSERT INTO orders VALUES (467,2,'000208223141','','8000000000001001','01/05');
INSERT INTO orders VALUES (467,3,'000305214039','','8000000000001001','01/05');
INSERT INTO orders VALUES (467,4,'000421221503','','8000000000001001','01/05');
INSERT INTO orders VALUES (467,5,'000513111335','','8000000000001001','01/05');
INSERT INTO orders VALUES (469,1,'000117233238','','8000000000001001','01/05');
INSERT INTO orders VALUES (469,2,'000213140906','','8000000000001001','01/05');
INSERT INTO orders VALUES (469,3,'000304164833','','8000000000001001','01/05');
INSERT INTO orders VALUES (470,1,'000120162041','','8000000000001001','01/05');
INSERT INTO orders VALUES (470,2,'000207210346','','8000000000001001','01/05');
INSERT INTO orders VALUES (470,3,'000320172800','','8000000000001001','01/05');
INSERT INTO orders VALUES (471,1,'000122104437','','8000000000001001','01/05');
INSERT INTO orders VALUES (471,2,'000223214246','','8000000000001001','01/05');
INSERT INTO orders VALUES (471,3,'000311111021','','8000000000001001','01/05');
INSERT INTO orders VALUES (471,4,'000416115814','','8000000000001001','01/05');
INSERT INTO orders VALUES (471,5,'000510151341','','8000000000001001','01/05');
INSERT INTO orders VALUES (471,6,'000609070813','','8000000000001001','01/05');
INSERT INTO orders VALUES (472,1,'000113081830','','8000000000001001','01/05');
INSERT INTO orders VALUES (473,1,'000112185641','','8000000000001001','01/05');
INSERT INTO orders VALUES (473,2,'000213131831','','8000000000001001','01/05');
INSERT INTO orders VALUES (473,3,'000308172950','','8000000000001001','01/05');
INSERT INTO orders VALUES (473,4,'000421082147','','8000000000001001','01/05');
INSERT INTO orders VALUES (473,5,'000522061101','','8000000000001001','01/05');
INSERT INTO orders VALUES (474,1,'000118110706','','8000000000001001','01/05');
INSERT INTO orders VALUES (474,2,'000207144013','','8000000000001001','01/05');
INSERT INTO orders VALUES (474,3,'000324145324','','8000000000001001','01/05');
INSERT INTO orders VALUES (474,4,'000407194643','','8000000000001001','01/05');
INSERT INTO orders VALUES (475,1,'000117064904','','8000000000001001','01/05');
INSERT INTO orders VALUES (475,2,'000210200012','','8000000000001001','01/05');
INSERT INTO orders VALUES (475,3,'000311065257','','8000000000001001','01/05');
INSERT INTO orders VALUES (475,4,'000401141501','','8000000000001001','01/05');
INSERT INTO orders VALUES (476,1,'000113234426','','8000000000001001','01/05');
INSERT INTO orders VALUES (476,2,'000218191802','','8000000000001001','01/05');
INSERT INTO orders VALUES (477,1,'000103120902','','8000000000001001','01/05');
INSERT INTO orders VALUES (477,2,'000211112039','','8000000000001001','01/05');
INSERT INTO orders VALUES (477,3,'000309182101','','8000000000001001','01/05');
INSERT INTO orders VALUES (477,4,'000422153229','','8000000000001001','01/05');
INSERT INTO orders VALUES (477,5,'000513164647','','8000000000001001','01/05');
INSERT INTO orders VALUES (477,6,'000622090019','','8000000000001001','01/05');
INSERT INTO orders VALUES (478,1,'000101072718','','8000000000001001','01/05');
INSERT INTO orders VALUES (478,2,'000227110025','','8000000000001001','01/05');
INSERT INTO orders VALUES (478,3,'000321114543','','8000000000001001','01/05');
INSERT INTO orders VALUES (478,4,'000408195516','','8000000000001001','01/05');
INSERT INTO orders VALUES (478,5,'000521195153','','8000000000001001','01/05');
INSERT INTO orders VALUES (478,6,'000617172145','','8000000000001001','01/05');
INSERT INTO orders VALUES (479,1,'000113204819','','8000000000001001','01/05');
INSERT INTO orders VALUES (480,1,'000119120700','','8000000000001001','01/05');
INSERT INTO orders VALUES (480,2,'000202214050','','8000000000001001','01/05');
INSERT INTO orders VALUES (480,3,'000316150010','','8000000000001001','01/05');
INSERT INTO orders VALUES (480,4,'000404230853','','8000000000001001','01/05');
INSERT INTO orders VALUES (480,5,'000508234805','','8000000000001001','01/05');
INSERT INTO orders VALUES (481,1,'000128183650','','8000000000001001','01/05');
INSERT INTO orders VALUES (481,2,'000210091048','','8000000000001001','01/05');
INSERT INTO orders VALUES (481,3,'000302180615','','8000000000001001','01/05');
INSERT INTO orders VALUES (481,4,'000425161542','','8000000000001001','01/05');
INSERT INTO orders VALUES (481,5,'000527171800','','8000000000001001','01/05');
INSERT INTO orders VALUES (482,1,'000116193206','','8000000000001001','01/05');
INSERT INTO orders VALUES (482,2,'000229094531','','8000000000001001','01/05');
INSERT INTO orders VALUES (482,3,'000309180150','','8000000000001001','01/05');
INSERT INTO orders VALUES (482,4,'000407122912','','8000000000001001','01/05');
INSERT INTO orders VALUES (482,5,'000508172346','','8000000000001001','01/05');
INSERT INTO orders VALUES (482,6,'000606211041','','8000000000001001','01/05');
INSERT INTO orders VALUES (483,1,'000101200106','','8000000000001001','01/05');
INSERT INTO orders VALUES (483,2,'000201082850','','8000000000001001','01/05');
INSERT INTO orders VALUES (483,3,'000325115813','','8000000000001001','01/05');
INSERT INTO orders VALUES (483,4,'000407171505','','8000000000001001','01/05');
INSERT INTO orders VALUES (484,1,'000117202951','','8000000000001001','01/05');
INSERT INTO orders VALUES (484,2,'000226151038','','8000000000001001','01/05');
INSERT INTO orders VALUES (484,3,'000311090219','','8000000000001001','01/05');
INSERT INTO orders VALUES (484,4,'000420221109','','8000000000001001','01/05');
INSERT INTO orders VALUES (484,5,'000528130919','','8000000000001001','01/05');
INSERT INTO orders VALUES (484,6,'000610175443','','8000000000001001','01/05');
INSERT INTO orders VALUES (485,1,'000124230208','','8000000000001001','01/05');
INSERT INTO orders VALUES (485,2,'000219110121','','8000000000001001','01/05');
INSERT INTO orders VALUES (485,3,'000309100119','','8000000000001001','01/05');
INSERT INTO orders VALUES (485,4,'000426181933','','8000000000001001','01/05');
INSERT INTO orders VALUES (486,1,'000112183847','','8000000000001001','01/05');
INSERT INTO orders VALUES (487,1,'000111221814','','8000000000001001','01/05');
INSERT INTO orders VALUES (487,2,'000217223118','','8000000000001001','01/05');
INSERT INTO orders VALUES (487,3,'000324075037','','8000000000001001','01/05');
INSERT INTO orders VALUES (487,4,'000414071627','','8000000000001001','01/05');
INSERT INTO orders VALUES (487,5,'000528175622','','8000000000001001','01/05');
INSERT INTO orders VALUES (488,1,'000116072459','','8000000000001001','01/05');
INSERT INTO orders VALUES (488,2,'000222070226','','8000000000001001','01/05');
INSERT INTO orders VALUES (488,3,'000301134358','','8000000000001001','01/05');
INSERT INTO orders VALUES (488,4,'000404221309','','8000000000001001','01/05');
INSERT INTO orders VALUES (488,5,'000502143111','','8000000000001001','01/05');
INSERT INTO orders VALUES (488,6,'000615100942','','8000000000001001','01/05');
INSERT INTO orders VALUES (489,1,'000125233102','','8000000000001001','01/05');
INSERT INTO orders VALUES (489,2,'000209122704','','8000000000001001','01/05');
INSERT INTO orders VALUES (489,3,'000324130140','','8000000000001001','01/05');
INSERT INTO orders VALUES (489,4,'000413164454','','8000000000001001','01/05');
INSERT INTO orders VALUES (490,1,'000123125347','','8000000000001001','01/05');
INSERT INTO orders VALUES (490,2,'000207091359','','8000000000001001','01/05');
INSERT INTO orders VALUES (490,3,'000309100552','','8000000000001001','01/05');
INSERT INTO orders VALUES (491,1,'000128204332','','8000000000001001','01/05');
INSERT INTO orders VALUES (492,1,'000126201746','','8000000000001001','01/05');
INSERT INTO orders VALUES (492,2,'000219140724','','8000000000001001','01/05');
INSERT INTO orders VALUES (492,3,'000329060749','','8000000000001001','01/05');
INSERT INTO orders VALUES (492,4,'000406112016','','8000000000001001','01/05');
INSERT INTO orders VALUES (492,5,'000521060842','','8000000000001001','01/05');
INSERT INTO orders VALUES (492,6,'000603122325','','8000000000001001','01/05');
INSERT INTO orders VALUES (493,1,'000115141012','','8000000000001001','01/05');
INSERT INTO orders VALUES (493,2,'000228095151','','8000000000001001','01/05');
INSERT INTO orders VALUES (493,3,'000325173650','','8000000000001001','01/05');
INSERT INTO orders VALUES (494,1,'000105062852','','8000000000001001','01/05');
INSERT INTO orders VALUES (494,2,'000207215248','','8000000000001001','01/05');
INSERT INTO orders VALUES (494,3,'000301171829','','8000000000001001','01/05');
INSERT INTO orders VALUES (494,4,'000420144353','','8000000000001001','01/05');
INSERT INTO orders VALUES (495,1,'000104112045','','8000000000001001','01/05');
INSERT INTO orders VALUES (495,2,'000216122848','','8000000000001001','01/05');
INSERT INTO orders VALUES (495,3,'000311142759','','8000000000001001','01/05');
INSERT INTO orders VALUES (495,4,'000401141057','','8000000000001001','01/05');
INSERT INTO orders VALUES (495,5,'000510123051','','8000000000001001','01/05');
INSERT INTO orders VALUES (495,6,'000608222731','','8000000000001001','01/05');
INSERT INTO orders VALUES (496,1,'000111112232','','8000000000001001','01/05');
INSERT INTO orders VALUES (496,2,'000228074516','','8000000000001001','01/05');
INSERT INTO orders VALUES (496,3,'000309165713','','8000000000001001','01/05');
INSERT INTO orders VALUES (496,4,'000416163317','','8000000000001001','01/05');
INSERT INTO orders VALUES (497,1,'000120062744','','8000000000001001','01/05');
INSERT INTO orders VALUES (497,2,'000217220539','','8000000000001001','01/05');
INSERT INTO orders VALUES (497,3,'000329223838','','8000000000001001','01/05');
INSERT INTO orders VALUES (498,1,'000124134412','','8000000000001001','01/05');
INSERT INTO orders VALUES (498,2,'000224231745','','8000000000001001','01/05');
INSERT INTO orders VALUES (498,3,'000328075620','','8000000000001001','01/05');
INSERT INTO orders VALUES (498,4,'000425235207','','8000000000001001','01/05');
INSERT INTO orders VALUES (498,5,'000529070158','','8000000000001001','01/05');
INSERT INTO orders VALUES (498,6,'000603091457','','8000000000001001','01/05');
INSERT INTO orders VALUES (499,1,'000113153724','','8000000000001001','01/05');
INSERT INTO orders VALUES (499,2,'000227114247','','8000000000001001','01/05');
INSERT INTO orders VALUES (499,3,'000311144354','','8000000000001001','01/05');
INSERT INTO orders VALUES (500,1,'000123111502','','8000000000001001','01/05');
INSERT INTO orders VALUES (500,2,'000219074123','','8000000000001001','01/05');
INSERT INTO orders VALUES (500,3,'000305073052','','8000000000001001','01/05');
INSERT INTO orders VALUES (502,1,'000113134916','','8000000000001001','01/05');
INSERT INTO orders VALUES (502,2,'000207104557','','8000000000001001','01/05');
INSERT INTO orders VALUES (502,3,'000325231717','','8000000000001001','01/05');
INSERT INTO orders VALUES (502,4,'000404205220','','8000000000001001','01/05');
INSERT INTO orders VALUES (503,1,'000103174423','','8000000000001001','01/05');
INSERT INTO orders VALUES (504,1,'000103090113','','8000000000001001','01/05');
INSERT INTO orders VALUES (504,2,'000227223117','','8000000000001001','01/05');
INSERT INTO orders VALUES (504,3,'000316184843','','8000000000001001','01/05');
INSERT INTO orders VALUES (505,1,'000123231151','','8000000000001001','01/05');
INSERT INTO orders VALUES (506,1,'000112094309','','8000000000001001','01/05');
INSERT INTO orders VALUES (506,2,'000222204706','','8000000000001001','01/05');
INSERT INTO orders VALUES (506,3,'000324072448','','8000000000001001','01/05');
INSERT INTO orders VALUES (507,1,'000113182532','','8000000000001001','01/05');
INSERT INTO orders VALUES (507,2,'000220142831','','8000000000001001','01/05');
INSERT INTO orders VALUES (507,3,'000326184302','','8000000000001001','01/05');
INSERT INTO orders VALUES (507,4,'000403221025','','8000000000001001','01/05');
INSERT INTO orders VALUES (507,5,'000527191727','','8000000000001001','01/05');
INSERT INTO orders VALUES (507,6,'000625142506','','8000000000001001','01/05');
INSERT INTO orders VALUES (508,1,'000125182629','','8000000000001001','01/05');
INSERT INTO orders VALUES (508,2,'000214120434','','8000000000001001','01/05');
INSERT INTO orders VALUES (509,1,'000102103825','','8000000000001001','01/05');
INSERT INTO orders VALUES (509,2,'000211064256','','8000000000001001','01/05');
INSERT INTO orders VALUES (510,1,'000124171233','','8000000000001001','01/05');
INSERT INTO orders VALUES (510,2,'000217062712','','8000000000001001','01/05');
INSERT INTO orders VALUES (510,3,'000307151056','','8000000000001001','01/05');
INSERT INTO orders VALUES (510,4,'000408074419','','8000000000001001','01/05');
INSERT INTO orders VALUES (510,5,'000517141703','','8000000000001001','01/05');
INSERT INTO orders VALUES (511,1,'000102123636','','8000000000001001','01/05');
INSERT INTO orders VALUES (511,2,'000213134202','','8000000000001001','01/05');
INSERT INTO orders VALUES (511,3,'000301133437','','8000000000001001','01/05');
INSERT INTO orders VALUES (511,4,'000421063958','','8000000000001001','01/05');
INSERT INTO orders VALUES (511,5,'000507162242','','8000000000001001','01/05');
INSERT INTO orders VALUES (512,1,'000112113054','','8000000000001001','01/05');
INSERT INTO orders VALUES (512,2,'000218132415','','8000000000001001','01/05');
INSERT INTO orders VALUES (513,1,'000112084040','','8000000000001001','01/05');
INSERT INTO orders VALUES (513,2,'000219223805','','8000000000001001','01/05');
INSERT INTO orders VALUES (514,1,'000102115511','','8000000000001001','01/05');
INSERT INTO orders VALUES (514,2,'000214160142','','8000000000001001','01/05');
INSERT INTO orders VALUES (514,3,'000303181259','','8000000000001001','01/05');
INSERT INTO orders VALUES (514,4,'000405071421','','8000000000001001','01/05');
INSERT INTO orders VALUES (514,5,'000505185313','','8000000000001001','01/05');
INSERT INTO orders VALUES (514,6,'000624072657','','8000000000001001','01/05');
INSERT INTO orders VALUES (515,1,'000129060157','','8000000000001001','01/05');
INSERT INTO orders VALUES (515,2,'000219114400','','8000000000001001','01/05');
INSERT INTO orders VALUES (515,3,'000309113708','','8000000000001001','01/05');
INSERT INTO orders VALUES (516,1,'000106192518','','8000000000001001','01/05');
INSERT INTO orders VALUES (517,1,'000124095706','','8000000000001001','01/05');
INSERT INTO orders VALUES (518,1,'000122144244','','8000000000001001','01/05');
INSERT INTO orders VALUES (519,1,'000129101818','','8000000000001001','01/05');
INSERT INTO orders VALUES (520,1,'000129154805','','8000000000001001','01/05');
INSERT INTO orders VALUES (520,2,'000219104755','','8000000000001001','01/05');
INSERT INTO orders VALUES (521,1,'000113173759','','8000000000001001','01/05');
INSERT INTO orders VALUES (521,2,'000225103650','','8000000000001001','01/05');
INSERT INTO orders VALUES (522,1,'000119164916','','8000000000001001','01/05');
INSERT INTO orders VALUES (522,2,'000207161128','','8000000000001001','01/05');
INSERT INTO orders VALUES (522,3,'000319185537','','8000000000001001','01/05');
INSERT INTO orders VALUES (522,4,'000402124024','','8000000000001001','01/05');
INSERT INTO orders VALUES (522,5,'000518172714','','8000000000001001','01/05');
INSERT INTO orders VALUES (522,6,'000602115728','','8000000000001001','01/05');
INSERT INTO orders VALUES (523,1,'000110090517','','8000000000001001','01/05');
INSERT INTO orders VALUES (523,2,'000218093910','','8000000000001001','01/05');
INSERT INTO orders VALUES (523,3,'000308105940','','8000000000001001','01/05');
INSERT INTO orders VALUES (524,1,'000101234644','','8000000000001001','01/05');
INSERT INTO orders VALUES (525,1,'000120125308','','8000000000001001','01/05');
INSERT INTO orders VALUES (526,1,'000129120227','','8000000000001001','01/05');
INSERT INTO orders VALUES (527,1,'000126114509','','8000000000001001','01/05');
INSERT INTO orders VALUES (527,2,'000216230253','','8000000000001001','01/05');
INSERT INTO orders VALUES (527,3,'000302094157','','8000000000001001','01/05');
INSERT INTO orders VALUES (527,4,'000402215637','','8000000000001001','01/05');
INSERT INTO orders VALUES (527,5,'000504155640','','8000000000001001','01/05');
INSERT INTO orders VALUES (528,1,'000112184516','','8000000000001001','01/05');
INSERT INTO orders VALUES (528,2,'000224185936','','8000000000001001','01/05');
INSERT INTO orders VALUES (528,3,'000303102443','','8000000000001001','01/05');
INSERT INTO orders VALUES (528,4,'000426081418','','8000000000001001','01/05');
INSERT INTO orders VALUES (528,5,'000524231518','','8000000000001001','01/05');
INSERT INTO orders VALUES (528,6,'000619223057','','8000000000001001','01/05');
INSERT INTO orders VALUES (529,1,'000110224935','','8000000000001001','01/05');
INSERT INTO orders VALUES (530,1,'000118092413','','8000000000001001','01/05');
INSERT INTO orders VALUES (530,2,'000202101752','','8000000000001001','01/05');
INSERT INTO orders VALUES (530,3,'000313221651','','8000000000001001','01/05');
INSERT INTO orders VALUES (530,4,'000424165239','','8000000000001001','01/05');
INSERT INTO orders VALUES (530,5,'000518195750','','8000000000001001','01/05');
INSERT INTO orders VALUES (531,1,'000125235538','','8000000000001001','01/05');
INSERT INTO orders VALUES (531,2,'000206225333','','8000000000001001','01/05');
INSERT INTO orders VALUES (531,3,'000317200129','','8000000000001001','01/05');
INSERT INTO orders VALUES (531,4,'000411200957','','8000000000001001','01/05');
INSERT INTO orders VALUES (531,5,'000518083846','','8000000000001001','01/05');
INSERT INTO orders VALUES (531,6,'000618223757','','8000000000001001','01/05');
INSERT INTO orders VALUES (532,1,'000116214506','','8000000000001001','01/05');
INSERT INTO orders VALUES (533,1,'000126141033','','8000000000001001','01/05');
INSERT INTO orders VALUES (533,2,'000206130240','','8000000000001001','01/05');
INSERT INTO orders VALUES (533,3,'000310072812','','8000000000001001','01/05');
INSERT INTO orders VALUES (533,4,'000420133624','','8000000000001001','01/05');
INSERT INTO orders VALUES (533,5,'000506204151','','8000000000001001','01/05');
INSERT INTO orders VALUES (534,1,'000104115832','','8000000000001001','01/05');
INSERT INTO orders VALUES (534,2,'000211133220','','8000000000001001','01/05');
INSERT INTO orders VALUES (534,3,'000302131726','','8000000000001001','01/05');
INSERT INTO orders VALUES (534,4,'000404123939','','8000000000001001','01/05');
INSERT INTO orders VALUES (535,1,'000118082025','','8000000000001001','01/05');
INSERT INTO orders VALUES (535,2,'000229133419','','8000000000001001','01/05');
INSERT INTO orders VALUES (535,3,'000323130523','','8000000000001001','01/05');
INSERT INTO orders VALUES (535,4,'000429170545','','8000000000001001','01/05');
INSERT INTO orders VALUES (535,5,'000521065859','','8000000000001001','01/05');
INSERT INTO orders VALUES (536,1,'000129184637','','8000000000001001','01/05');
INSERT INTO orders VALUES (536,2,'000226115433','','8000000000001001','01/05');
INSERT INTO orders VALUES (536,3,'000325235248','','8000000000001001','01/05');
INSERT INTO orders VALUES (536,4,'000411144302','','8000000000001001','01/05');
INSERT INTO orders VALUES (536,5,'000515195043','','8000000000001001','01/05');
INSERT INTO orders VALUES (537,1,'000113124454','','8000000000001001','01/05');
INSERT INTO orders VALUES (537,2,'000207080809','','8000000000001001','01/05');
INSERT INTO orders VALUES (537,3,'000319173916','','8000000000001001','01/05');
INSERT INTO orders VALUES (537,4,'000409141724','','8000000000001001','01/05');
INSERT INTO orders VALUES (538,1,'000122060622','','8000000000001001','01/05');
INSERT INTO orders VALUES (538,2,'000204184139','','8000000000001001','01/05');
INSERT INTO orders VALUES (539,1,'000114215230','','8000000000001001','01/05');
INSERT INTO orders VALUES (539,2,'000222080927','','8000000000001001','01/05');
INSERT INTO orders VALUES (539,3,'000309073124','','8000000000001001','01/05');
INSERT INTO orders VALUES (540,1,'000119144707','','8000000000001001','01/05');
INSERT INTO orders VALUES (540,2,'000209205755','','8000000000001001','01/05');
INSERT INTO orders VALUES (540,3,'000303173043','','8000000000001001','01/05');
INSERT INTO orders VALUES (540,4,'000421134729','','8000000000001001','01/05');
INSERT INTO orders VALUES (540,5,'000502083908','','8000000000001001','01/05');
INSERT INTO orders VALUES (540,6,'000629092428','','8000000000001001','01/05');
INSERT INTO orders VALUES (541,1,'000112114528','','8000000000001001','01/05');
INSERT INTO orders VALUES (541,2,'000221125904','','8000000000001001','01/05');
INSERT INTO orders VALUES (541,3,'000301223224','','8000000000001001','01/05');
INSERT INTO orders VALUES (542,1,'000104180212','','8000000000001001','01/05');
INSERT INTO orders VALUES (542,2,'000224081813','','8000000000001001','01/05');
INSERT INTO orders VALUES (543,1,'000102230345','','8000000000001001','01/05');
INSERT INTO orders VALUES (544,1,'000118190854','','8000000000001001','01/05');
INSERT INTO orders VALUES (544,2,'000214090626','','8000000000001001','01/05');
INSERT INTO orders VALUES (544,3,'000307113542','','8000000000001001','01/05');
INSERT INTO orders VALUES (544,4,'000418101103','','8000000000001001','01/05');
INSERT INTO orders VALUES (544,5,'000522061326','','8000000000001001','01/05');
INSERT INTO orders VALUES (544,6,'000625222102','','8000000000001001','01/05');
INSERT INTO orders VALUES (545,1,'000123081412','','8000000000001001','01/05');
INSERT INTO orders VALUES (545,2,'000204114037','','8000000000001001','01/05');
INSERT INTO orders VALUES (546,1,'000113165935','','8000000000001001','01/05');
INSERT INTO orders VALUES (546,2,'000206223619','','8000000000001001','01/05');
INSERT INTO orders VALUES (546,3,'000318060202','','8000000000001001','01/05');
INSERT INTO orders VALUES (546,4,'000411232350','','8000000000001001','01/05');
INSERT INTO orders VALUES (547,1,'000105185734','','8000000000001001','01/05');
INSERT INTO orders VALUES (547,2,'000216073806','','8000000000001001','01/05');
INSERT INTO orders VALUES (547,3,'000308174721','','8000000000001001','01/05');
INSERT INTO orders VALUES (547,4,'000428070357','','8000000000001001','01/05');
INSERT INTO orders VALUES (547,5,'000507165439','','8000000000001001','01/05');
INSERT INTO orders VALUES (548,1,'000128101819','','8000000000001001','01/05');
INSERT INTO orders VALUES (548,2,'000206181144','','8000000000001001','01/05');
INSERT INTO orders VALUES (548,3,'000324212205','','8000000000001001','01/05');
INSERT INTO orders VALUES (549,1,'000101162048','','8000000000001001','01/05');
INSERT INTO orders VALUES (549,2,'000202072137','','8000000000001001','01/05');
INSERT INTO orders VALUES (549,3,'000326121654','','8000000000001001','01/05');
INSERT INTO orders VALUES (549,4,'000428170943','','8000000000001001','01/05');
INSERT INTO orders VALUES (549,5,'000516075829','','8000000000001001','01/05');
INSERT INTO orders VALUES (549,6,'000606230047','','8000000000001001','01/05');
INSERT INTO orders VALUES (550,1,'000111172037','','8000000000001001','01/05');
INSERT INTO orders VALUES (550,2,'000210073107','','8000000000001001','01/05');
INSERT INTO orders VALUES (550,3,'000301104557','','8000000000001001','01/05');
INSERT INTO orders VALUES (550,4,'000421203220','','8000000000001001','01/05');
INSERT INTO orders VALUES (550,5,'000520065014','','8000000000001001','01/05');
INSERT INTO orders VALUES (550,6,'000621140109','','8000000000001001','01/05');
INSERT INTO orders VALUES (551,1,'000112081631','','8000000000001001','01/05');
INSERT INTO orders VALUES (552,1,'000125110217','','8000000000001001','01/05');
INSERT INTO orders VALUES (552,2,'000223084817','','8000000000001001','01/05');
INSERT INTO orders VALUES (552,3,'000308124505','','8000000000001001','01/05');
INSERT INTO orders VALUES (553,1,'000129133343','','8000000000001001','01/05');
INSERT INTO orders VALUES (553,2,'000214092226','','8000000000001001','01/05');
INSERT INTO orders VALUES (553,3,'000310072135','','8000000000001001','01/05');
INSERT INTO orders VALUES (553,4,'000425161436','','8000000000001001','01/05');
INSERT INTO orders VALUES (554,1,'000128104830','','8000000000001001','01/05');
INSERT INTO orders VALUES (555,1,'000121234556','','8000000000001001','01/05');
INSERT INTO orders VALUES (556,1,'000111072706','','8000000000001001','01/05');
INSERT INTO orders VALUES (556,2,'000216094221','','8000000000001001','01/05');
INSERT INTO orders VALUES (556,3,'000304114447','','8000000000001001','01/05');
INSERT INTO orders VALUES (557,1,'000116191722','','8000000000001001','01/05');
INSERT INTO orders VALUES (558,1,'000128234908','','8000000000001001','01/05');
INSERT INTO orders VALUES (558,2,'000228172044','','8000000000001001','01/05');
INSERT INTO orders VALUES (558,3,'000302140522','','8000000000001001','01/05');
INSERT INTO orders VALUES (558,4,'000414152925','','8000000000001001','01/05');
INSERT INTO orders VALUES (559,1,'000125175054','','8000000000001001','01/05');
INSERT INTO orders VALUES (560,1,'000126215104','','8000000000001001','01/05');
INSERT INTO orders VALUES (560,2,'000203210649','','8000000000001001','01/05');
INSERT INTO orders VALUES (560,3,'000324164337','','8000000000001001','01/05');
INSERT INTO orders VALUES (561,1,'000110135710','','8000000000001001','01/05');
INSERT INTO orders VALUES (561,2,'000223194140','','8000000000001001','01/05');
INSERT INTO orders VALUES (562,1,'000124201458','','8000000000001001','01/05');
INSERT INTO orders VALUES (562,2,'000207153849','','8000000000001001','01/05');
INSERT INTO orders VALUES (562,3,'000310225126','','8000000000001001','01/05');
INSERT INTO orders VALUES (563,1,'000120174853','','8000000000001001','01/05');
INSERT INTO orders VALUES (563,2,'000211210437','','8000000000001001','01/05');
INSERT INTO orders VALUES (563,3,'000309230705','','8000000000001001','01/05');
INSERT INTO orders VALUES (564,1,'000123095514','','8000000000001001','01/05');
INSERT INTO orders VALUES (564,2,'000217202213','','8000000000001001','01/05');
INSERT INTO orders VALUES (565,1,'000112075936','','8000000000001001','01/05');
INSERT INTO orders VALUES (565,2,'000202232028','','8000000000001001','01/05');
INSERT INTO orders VALUES (565,3,'000309121817','','8000000000001001','01/05');
INSERT INTO orders VALUES (566,1,'000120230307','','8000000000001001','01/05');
INSERT INTO orders VALUES (567,1,'000128063054','','8000000000001001','01/05');
INSERT INTO orders VALUES (567,2,'000214221825','','8000000000001001','01/05');
INSERT INTO orders VALUES (567,3,'000322165422','','8000000000001001','01/05');
INSERT INTO orders VALUES (567,4,'000410160918','','8000000000001001','01/05');
INSERT INTO orders VALUES (567,5,'000514230922','','8000000000001001','01/05');
INSERT INTO orders VALUES (568,1,'000126060829','','8000000000001001','01/05');
INSERT INTO orders VALUES (568,2,'000227213228','','8000000000001001','01/05');
INSERT INTO orders VALUES (569,1,'000110220621','','8000000000001001','01/05');
INSERT INTO orders VALUES (569,2,'000211235713','','8000000000001001','01/05');
INSERT INTO orders VALUES (569,3,'000329222818','','8000000000001001','01/05');
INSERT INTO orders VALUES (569,4,'000401171622','','8000000000001001','01/05');
INSERT INTO orders VALUES (569,5,'000521140440','','8000000000001001','01/05');
INSERT INTO orders VALUES (569,6,'000613200120','','8000000000001001','01/05');
INSERT INTO orders VALUES (571,1,'000106072259','','8000000000001001','01/05');
INSERT INTO orders VALUES (571,2,'000213154959','','8000000000001001','01/05');
INSERT INTO orders VALUES (571,3,'000309193251','','8000000000001001','01/05');
INSERT INTO orders VALUES (571,4,'000401143348','','8000000000001001','01/05');
INSERT INTO orders VALUES (572,1,'000111191756','','8000000000001001','01/05');
INSERT INTO orders VALUES (572,2,'000221233008','','8000000000001001','01/05');
INSERT INTO orders VALUES (572,3,'000319225941','','8000000000001001','01/05');
INSERT INTO orders VALUES (572,4,'000404212532','','8000000000001001','01/05');
INSERT INTO orders VALUES (573,1,'000106143309','','8000000000001001','01/05');
INSERT INTO orders VALUES (573,2,'000224064451','','8000000000001001','01/05');
INSERT INTO orders VALUES (574,1,'000103182511','','8000000000001001','01/05');
INSERT INTO orders VALUES (574,2,'000219150326','','8000000000001001','01/05');
INSERT INTO orders VALUES (575,1,'000104201408','','8000000000001001','01/05');
INSERT INTO orders VALUES (575,2,'000225062417','','8000000000001001','01/05');
INSERT INTO orders VALUES (575,3,'000327190851','','8000000000001001','01/05');
INSERT INTO orders VALUES (576,1,'000108181657','','8000000000001001','01/05');
INSERT INTO orders VALUES (576,2,'000216143233','','8000000000001001','01/05');
INSERT INTO orders VALUES (576,3,'000329071609','','8000000000001001','01/05');
INSERT INTO orders VALUES (577,1,'000120065319','','8000000000001001','01/05');
INSERT INTO orders VALUES (577,2,'000215123810','','8000000000001001','01/05');
INSERT INTO orders VALUES (577,3,'000307235019','','8000000000001001','01/05');
INSERT INTO orders VALUES (578,1,'000124083644','','8000000000001001','01/05');
INSERT INTO orders VALUES (578,2,'000202112906','','8000000000001001','01/05');
INSERT INTO orders VALUES (579,1,'000109081709','','8000000000001001','01/05');
INSERT INTO orders VALUES (579,2,'000224160711','','8000000000001001','01/05');
INSERT INTO orders VALUES (579,3,'000313113752','','8000000000001001','01/05');
INSERT INTO orders VALUES (580,1,'000115214810','','8000000000001001','01/05');
INSERT INTO orders VALUES (580,2,'000208072634','','8000000000001001','01/05');
INSERT INTO orders VALUES (580,3,'000323154910','','8000000000001001','01/05');
INSERT INTO orders VALUES (580,4,'000425103220','','8000000000001001','01/05');
INSERT INTO orders VALUES (581,1,'000125124002','','8000000000001001','01/05');
INSERT INTO orders VALUES (581,2,'000207102533','','8000000000001001','01/05');
INSERT INTO orders VALUES (581,3,'000308182007','','8000000000001001','01/05');
INSERT INTO orders VALUES (581,4,'000419184947','','8000000000001001','01/05');
INSERT INTO orders VALUES (581,5,'000512170510','','8000000000001001','01/05');
INSERT INTO orders VALUES (582,1,'000103082235','','8000000000001001','01/05');
INSERT INTO orders VALUES (582,2,'000223173656','','8000000000001001','01/05');
INSERT INTO orders VALUES (582,3,'000325140738','','8000000000001001','01/05');
INSERT INTO orders VALUES (583,1,'000103080127','','8000000000001001','01/05');
INSERT INTO orders VALUES (583,2,'000203205734','','8000000000001001','01/05');
INSERT INTO orders VALUES (583,3,'000313101928','','8000000000001001','01/05');
INSERT INTO orders VALUES (583,4,'000413134530','','8000000000001001','01/05');
INSERT INTO orders VALUES (583,5,'000512180742','','8000000000001001','01/05');
INSERT INTO orders VALUES (583,6,'000622232649','','8000000000001001','01/05');
INSERT INTO orders VALUES (584,1,'000128141508','','8000000000001001','01/05');
INSERT INTO orders VALUES (584,2,'000219185523','','8000000000001001','01/05');
INSERT INTO orders VALUES (584,3,'000301234811','','8000000000001001','01/05');
INSERT INTO orders VALUES (584,4,'000428090133','','8000000000001001','01/05');
INSERT INTO orders VALUES (585,1,'000119174750','','8000000000001001','01/05');
INSERT INTO orders VALUES (585,2,'000209084529','','8000000000001001','01/05');
INSERT INTO orders VALUES (585,3,'000314065848','','8000000000001001','01/05');
INSERT INTO orders VALUES (585,4,'000413221906','','8000000000001001','01/05');
INSERT INTO orders VALUES (585,5,'000514122556','','8000000000001001','01/05');
INSERT INTO orders VALUES (586,1,'000108083111','','8000000000001001','01/05');
INSERT INTO orders VALUES (586,2,'000225090235','','8000000000001001','01/05');
INSERT INTO orders VALUES (586,3,'000316140502','','8000000000001001','01/05');
INSERT INTO orders VALUES (587,1,'000118142810','','8000000000001001','01/05');
INSERT INTO orders VALUES (587,2,'000228094224','','8000000000001001','01/05');
INSERT INTO orders VALUES (588,1,'000113151110','','8000000000001001','01/05');
INSERT INTO orders VALUES (588,2,'000222180708','','8000000000001001','01/05');
INSERT INTO orders VALUES (588,3,'000329090747','','8000000000001001','01/05');
INSERT INTO orders VALUES (588,4,'000412153155','','8000000000001001','01/05');
INSERT INTO orders VALUES (589,1,'000108120650','','8000000000001001','01/05');
INSERT INTO orders VALUES (590,1,'000123115514','','8000000000001001','01/05');
INSERT INTO orders VALUES (590,2,'000206194236','','8000000000001001','01/05');
INSERT INTO orders VALUES (590,3,'000307160844','','8000000000001001','01/05');
INSERT INTO orders VALUES (590,4,'000411150913','','8000000000001001','01/05');
INSERT INTO orders VALUES (591,1,'000101112255','','8000000000001001','01/05');
INSERT INTO orders VALUES (591,2,'000219174809','','8000000000001001','01/05');
INSERT INTO orders VALUES (591,3,'000312200355','','8000000000001001','01/05');
INSERT INTO orders VALUES (591,4,'000427174845','','8000000000001001','01/05');
INSERT INTO orders VALUES (592,1,'000104201255','','8000000000001001','01/05');
INSERT INTO orders VALUES (593,1,'000113155146','','8000000000001001','01/05');
INSERT INTO orders VALUES (594,1,'000114161631','','8000000000001001','01/05');
INSERT INTO orders VALUES (595,1,'000106072602','','8000000000001001','01/05');
INSERT INTO orders VALUES (595,2,'000229065322','','8000000000001001','01/05');
INSERT INTO orders VALUES (595,3,'000324073425','','8000000000001001','01/05');
INSERT INTO orders VALUES (595,4,'000410134502','','8000000000001001','01/05');
INSERT INTO orders VALUES (596,1,'000107201617','','8000000000001001','01/05');
INSERT INTO orders VALUES (596,2,'000205154523','','8000000000001001','01/05');
INSERT INTO orders VALUES (597,1,'000113232014','','8000000000001001','01/05');
INSERT INTO orders VALUES (597,2,'000215182309','','8000000000001001','01/05');
INSERT INTO orders VALUES (597,3,'000308131253','','8000000000001001','01/05');
INSERT INTO orders VALUES (597,4,'000410125043','','8000000000001001','01/05');
INSERT INTO orders VALUES (598,1,'000109130842','','8000000000001001','01/05');
INSERT INTO orders VALUES (598,2,'000211114532','','8000000000001001','01/05');
INSERT INTO orders VALUES (598,3,'000303235959','','8000000000001001','01/05');
INSERT INTO orders VALUES (598,4,'000420121223','','8000000000001001','01/05');
INSERT INTO orders VALUES (598,5,'000527124800','','8000000000001001','01/05');
INSERT INTO orders VALUES (598,6,'000613060842','','8000000000001001','01/05');
INSERT INTO orders VALUES (599,1,'000106135138','','8000000000001001','01/05');
INSERT INTO orders VALUES (599,2,'000226115639','','8000000000001001','01/05');
INSERT INTO orders VALUES (599,3,'000325202114','','8000000000001001','01/05');
INSERT INTO orders VALUES (600,1,'000118134210','','8000000000001001','01/05');
INSERT INTO orders VALUES (600,2,'000202204052','','8000000000001001','01/05');
INSERT INTO orders VALUES (600,3,'000327155038','','8000000000001001','01/05');
INSERT INTO orders VALUES (600,4,'000416172419','','8000000000001001','01/05');
INSERT INTO orders VALUES (600,5,'000512152704','','8000000000001001','01/05');
INSERT INTO orders VALUES (601,1,'000103113444','','8000000000001001','01/05');
INSERT INTO orders VALUES (601,2,'000220070003','','8000000000001001','01/05');
INSERT INTO orders VALUES (601,3,'000327132637','','8000000000001001','01/05');
INSERT INTO orders VALUES (601,4,'000414195551','','8000000000001001','01/05');
INSERT INTO orders VALUES (601,5,'000523145050','','8000000000001001','01/05');
INSERT INTO orders VALUES (601,6,'000628215022','','8000000000001001','01/05');
INSERT INTO orders VALUES (602,1,'000121195048','','8000000000001001','01/05');
INSERT INTO orders VALUES (602,2,'000225232412','','8000000000001001','01/05');
INSERT INTO orders VALUES (602,3,'000319103408','','8000000000001001','01/05');
INSERT INTO orders VALUES (603,1,'000118125443','','8000000000001001','01/05');
INSERT INTO orders VALUES (603,2,'000207093826','','8000000000001001','01/05');
INSERT INTO orders VALUES (603,3,'000329204943','','8000000000001001','01/05');
INSERT INTO orders VALUES (603,4,'000409225554','','8000000000001001','01/05');
INSERT INTO orders VALUES (603,5,'000528231446','','8000000000001001','01/05');
INSERT INTO orders VALUES (604,1,'000129101840','','8000000000001001','01/05');
INSERT INTO orders VALUES (604,2,'000201155534','','8000000000001001','01/05');
INSERT INTO orders VALUES (604,3,'000322230343','','8000000000001001','01/05');
INSERT INTO orders VALUES (605,1,'000101204026','','8000000000001001','01/05');
INSERT INTO orders VALUES (605,2,'000211082512','','8000000000001001','01/05');
INSERT INTO orders VALUES (605,3,'000312093105','','8000000000001001','01/05');
INSERT INTO orders VALUES (605,4,'000412153758','','8000000000001001','01/05');
INSERT INTO orders VALUES (605,5,'000515081108','','8000000000001001','01/05');
INSERT INTO orders VALUES (606,1,'000104073038','','8000000000001001','01/05');
INSERT INTO orders VALUES (606,2,'000227150450','','8000000000001001','01/05');
INSERT INTO orders VALUES (606,3,'000317065720','','8000000000001001','01/05');
INSERT INTO orders VALUES (606,4,'000405080050','','8000000000001001','01/05');
INSERT INTO orders VALUES (606,5,'000505205829','','8000000000001001','01/05');
INSERT INTO orders VALUES (607,1,'000120152948','','8000000000001001','01/05');
INSERT INTO orders VALUES (607,2,'000222213914','','8000000000001001','01/05');
INSERT INTO orders VALUES (607,3,'000303192300','','8000000000001001','01/05');
INSERT INTO orders VALUES (607,4,'000408094711','','8000000000001001','01/05');
INSERT INTO orders VALUES (607,5,'000519185542','','8000000000001001','01/05');
INSERT INTO orders VALUES (608,1,'000128213308','','8000000000001001','01/05');
INSERT INTO orders VALUES (608,2,'000217132016','','8000000000001001','01/05');
INSERT INTO orders VALUES (608,3,'000328095236','','8000000000001001','01/05');
INSERT INTO orders VALUES (608,4,'000413080533','','8000000000001001','01/05');
INSERT INTO orders VALUES (609,1,'000120184443','','8000000000001001','01/05');
INSERT INTO orders VALUES (609,2,'000224062906','','8000000000001001','01/05');
INSERT INTO orders VALUES (609,3,'000304225252','','8000000000001001','01/05');
INSERT INTO orders VALUES (609,4,'000404103158','','8000000000001001','01/05');
INSERT INTO orders VALUES (609,5,'000515162044','','8000000000001001','01/05');
INSERT INTO orders VALUES (609,6,'000623100711','','8000000000001001','01/05');
INSERT INTO orders VALUES (610,1,'000123124020','','8000000000001001','01/05');
INSERT INTO orders VALUES (610,2,'000219214054','','8000000000001001','01/05');
INSERT INTO orders VALUES (610,3,'000305194551','','8000000000001001','01/05');
INSERT INTO orders VALUES (610,4,'000428190615','','8000000000001001','01/05');
INSERT INTO orders VALUES (610,5,'000510074305','','8000000000001001','01/05');
INSERT INTO orders VALUES (610,6,'000608195220','','8000000000001001','01/05');
INSERT INTO orders VALUES (611,1,'000127072826','','8000000000001001','01/05');
INSERT INTO orders VALUES (612,1,'000119150531','','8000000000001001','01/05');
INSERT INTO orders VALUES (612,2,'000202062044','','8000000000001001','01/05');
INSERT INTO orders VALUES (613,1,'000121204913','','8000000000001001','01/05');
INSERT INTO orders VALUES (613,2,'000211190036','','8000000000001001','01/05');
INSERT INTO orders VALUES (613,3,'000315185508','','8000000000001001','01/05');
INSERT INTO orders VALUES (614,1,'000127161525','','8000000000001001','01/05');
INSERT INTO orders VALUES (614,2,'000215152329','','8000000000001001','01/05');
INSERT INTO orders VALUES (615,1,'000103111625','','8000000000001001','01/05');
INSERT INTO orders VALUES (615,2,'000226075348','','8000000000001001','01/05');
INSERT INTO orders VALUES (616,1,'000107060945','','8000000000001001','01/05');
INSERT INTO orders VALUES (616,2,'000214173703','','8000000000001001','01/05');
INSERT INTO orders VALUES (617,1,'000101214845','','8000000000001001','01/05');
INSERT INTO orders VALUES (617,2,'000215135609','','8000000000001001','01/05');
INSERT INTO orders VALUES (617,3,'000301104109','','8000000000001001','01/05');
INSERT INTO orders VALUES (617,4,'000405181501','','8000000000001001','01/05');
INSERT INTO orders VALUES (617,5,'000519132936','','8000000000001001','01/05');
INSERT INTO orders VALUES (617,6,'000623144413','','8000000000001001','01/05');
INSERT INTO orders VALUES (618,1,'000106210000','','8000000000001001','01/05');
INSERT INTO orders VALUES (618,2,'000218220422','','8000000000001001','01/05');
INSERT INTO orders VALUES (619,1,'000127090947','','8000000000001001','01/05');
INSERT INTO orders VALUES (619,2,'000228234311','','8000000000001001','01/05');
INSERT INTO orders VALUES (619,3,'000320123115','','8000000000001001','01/05');
INSERT INTO orders VALUES (620,1,'000121121055','','8000000000001001','01/05');
INSERT INTO orders VALUES (620,2,'000204190719','','8000000000001001','01/05');
INSERT INTO orders VALUES (621,1,'000103070258','','8000000000001001','01/05');
INSERT INTO orders VALUES (622,1,'000104162634','','8000000000001001','01/05');
INSERT INTO orders VALUES (622,2,'000229133605','','8000000000001001','01/05');
INSERT INTO orders VALUES (623,1,'000124072019','','8000000000001001','01/05');
INSERT INTO orders VALUES (623,2,'000207180733','','8000000000001001','01/05');
INSERT INTO orders VALUES (623,3,'000322214254','','8000000000001001','01/05');
INSERT INTO orders VALUES (623,4,'000401075629','','8000000000001001','01/05');
INSERT INTO orders VALUES (624,1,'000119215432','','8000000000001001','01/05');
INSERT INTO orders VALUES (624,2,'000229075803','','8000000000001001','01/05');
INSERT INTO orders VALUES (624,3,'000326083046','','8000000000001001','01/05');
INSERT INTO orders VALUES (624,4,'000404162909','','8000000000001001','01/05');
INSERT INTO orders VALUES (624,5,'000517141511','','8000000000001001','01/05');
INSERT INTO orders VALUES (624,6,'000601065233','','8000000000001001','01/05');
INSERT INTO orders VALUES (625,1,'000113135752','','8000000000001001','01/05');
INSERT INTO orders VALUES (625,2,'000207231531','','8000000000001001','01/05');
INSERT INTO orders VALUES (625,3,'000329192423','','8000000000001001','01/05');
INSERT INTO orders VALUES (626,1,'000113180018','','8000000000001001','01/05');
INSERT INTO orders VALUES (626,2,'000214204652','','8000000000001001','01/05');
INSERT INTO orders VALUES (626,3,'000310232245','','8000000000001001','01/05');
INSERT INTO orders VALUES (626,4,'000410214449','','8000000000001001','01/05');
INSERT INTO orders VALUES (626,5,'000523072205','','8000000000001001','01/05');
INSERT INTO orders VALUES (626,6,'000621235721','','8000000000001001','01/05');
INSERT INTO orders VALUES (627,1,'000105125053','','8000000000001001','01/05');
INSERT INTO orders VALUES (627,2,'000218102458','','8000000000001001','01/05');
INSERT INTO orders VALUES (628,1,'000110161605','','8000000000001001','01/05');
INSERT INTO orders VALUES (629,1,'000114141136','','8000000000001001','01/05');
INSERT INTO orders VALUES (629,2,'000223081245','','8000000000001001','01/05');
INSERT INTO orders VALUES (629,3,'000326153543','','8000000000001001','01/05');
INSERT INTO orders VALUES (629,4,'000404124018','','8000000000001001','01/05');
INSERT INTO orders VALUES (629,5,'000515093527','','8000000000001001','01/05');
INSERT INTO orders VALUES (629,6,'000602080542','','8000000000001001','01/05');
INSERT INTO orders VALUES (630,1,'000103183851','','8000000000001001','01/05');
INSERT INTO orders VALUES (630,2,'000227094736','','8000000000001001','01/05');
INSERT INTO orders VALUES (630,3,'000306071242','','8000000000001001','01/05');
INSERT INTO orders VALUES (630,4,'000425120225','','8000000000001001','01/05');
INSERT INTO orders VALUES (630,5,'000511230945','','8000000000001001','01/05');
INSERT INTO orders VALUES (630,6,'000609114251','','8000000000001001','01/05');
INSERT INTO orders VALUES (631,1,'000104155505','','8000000000001001','01/05');
INSERT INTO orders VALUES (631,2,'000214071056','','8000000000001001','01/05');
INSERT INTO orders VALUES (632,1,'000124161454','','8000000000001001','01/05');
INSERT INTO orders VALUES (633,1,'000115185108','','8000000000001001','01/05');
INSERT INTO orders VALUES (633,2,'000207205109','','8000000000001001','01/05');
INSERT INTO orders VALUES (634,1,'000118095544','','8000000000001001','01/05');
INSERT INTO orders VALUES (634,2,'000228070806','','8000000000001001','01/05');
INSERT INTO orders VALUES (634,3,'000326183157','','8000000000001001','01/05');
INSERT INTO orders VALUES (635,1,'000111202027','','8000000000001001','01/05');
INSERT INTO orders VALUES (635,2,'000224113330','','8000000000001001','01/05');
INSERT INTO orders VALUES (635,3,'000304230047','','8000000000001001','01/05');
INSERT INTO orders VALUES (635,4,'000426110827','','8000000000001001','01/05');
INSERT INTO orders VALUES (635,5,'000523123759','','8000000000001001','01/05');
INSERT INTO orders VALUES (636,1,'000106162049','','8000000000001001','01/05');
INSERT INTO orders VALUES (637,1,'000123205917','','8000000000001001','01/05');
INSERT INTO orders VALUES (637,2,'000226103227','','8000000000001001','01/05');
INSERT INTO orders VALUES (638,1,'000121093530','','8000000000001001','01/05');
INSERT INTO orders VALUES (638,2,'000202094424','','8000000000001001','01/05');
INSERT INTO orders VALUES (639,1,'000110111100','','8000000000001001','01/05');
INSERT INTO orders VALUES (639,2,'000225095215','','8000000000001001','01/05');
INSERT INTO orders VALUES (639,3,'000327140215','','8000000000001001','01/05');
INSERT INTO orders VALUES (639,4,'000424130247','','8000000000001001','01/05');
INSERT INTO orders VALUES (640,1,'000109091931','','8000000000001001','01/05');
INSERT INTO orders VALUES (640,2,'000203064127','','8000000000001001','01/05');
INSERT INTO orders VALUES (640,3,'000329071544','','8000000000001001','01/05');
INSERT INTO orders VALUES (640,4,'000410180130','','8000000000001001','01/05');
INSERT INTO orders VALUES (640,5,'000501090458','','8000000000001001','01/05');
INSERT INTO orders VALUES (641,1,'000104165742','','8000000000001001','01/05');
INSERT INTO orders VALUES (641,2,'000202221924','','8000000000001001','01/05');
INSERT INTO orders VALUES (642,1,'000112212706','','8000000000001001','01/05');
INSERT INTO orders VALUES (642,2,'000202072408','','8000000000001001','01/05');
INSERT INTO orders VALUES (643,1,'000124092505','','8000000000001001','01/05');
INSERT INTO orders VALUES (643,2,'000222204906','','8000000000001001','01/05');
INSERT INTO orders VALUES (644,1,'000125151444','','8000000000001001','01/05');
INSERT INTO orders VALUES (644,2,'000214085417','','8000000000001001','01/05');
INSERT INTO orders VALUES (644,3,'000311220553','','8000000000001001','01/05');
INSERT INTO orders VALUES (645,1,'000119200356','','8000000000001001','01/05');
INSERT INTO orders VALUES (645,2,'000205195537','','8000000000001001','01/05');
INSERT INTO orders VALUES (645,3,'000305070413','','8000000000001001','01/05');
INSERT INTO orders VALUES (645,4,'000426122300','','8000000000001001','01/05');
INSERT INTO orders VALUES (645,5,'000520214312','','8000000000001001','01/05');
INSERT INTO orders VALUES (646,1,'000118205702','','8000000000001001','01/05');
INSERT INTO orders VALUES (646,2,'000228095808','','8000000000001001','01/05');
INSERT INTO orders VALUES (646,3,'000306114609','','8000000000001001','01/05');
INSERT INTO orders VALUES (646,4,'000411222319','','8000000000001001','01/05');
INSERT INTO orders VALUES (646,5,'000525085414','','8000000000001001','01/05');
INSERT INTO orders VALUES (647,1,'000109225921','','8000000000001001','01/05');
INSERT INTO orders VALUES (647,2,'000210125312','','8000000000001001','01/05');
INSERT INTO orders VALUES (647,3,'000303092829','','8000000000001001','01/05');
INSERT INTO orders VALUES (647,4,'000414191418','','8000000000001001','01/05');
INSERT INTO orders VALUES (647,5,'000512101843','','8000000000001001','01/05');
INSERT INTO orders VALUES (648,1,'000111194024','','8000000000001001','01/05');
INSERT INTO orders VALUES (648,2,'000209094932','','8000000000001001','01/05');
INSERT INTO orders VALUES (648,3,'000324235411','','8000000000001001','01/05');
INSERT INTO orders VALUES (648,4,'000419222327','','8000000000001001','01/05');
INSERT INTO orders VALUES (649,1,'000108174811','','8000000000001001','01/05');
INSERT INTO orders VALUES (650,1,'000111211045','','8000000000001001','01/05');
INSERT INTO orders VALUES (650,2,'000212060755','','8000000000001001','01/05');

INSERT INTO region VALUES (1,'All');
INSERT INTO region VALUES (2,'Goulburn Valley');
INSERT INTO region VALUES (3,'Rutherglen');
INSERT INTO region VALUES (4,'Coonawarra');
INSERT INTO region VALUES (5,'Upper Hunter Valley');
INSERT INTO region VALUES (6,'Lower Hunter Valley');
INSERT INTO region VALUES (7,'Barossa Valley');
INSERT INTO region VALUES (8,'Riverland');
INSERT INTO region VALUES (9,'Margaret River');
INSERT INTO region VALUES (10,'Swan Valley');

INSERT INTO wine_type VALUES (1, 'All');
INSERT INTO wine_type VALUES (2, 'Sparkling');
INSERT INTO wine_type VALUES (3, 'Fortified');
INSERT INTO wine_type VALUES (4, 'Sweet');
INSERT INTO wine_type VALUES (5, 'White');
INSERT INTO wine_type VALUES (6, 'Red');

INSERT INTO wine VALUES (1,'Archibald',2,1997,1,NULL);
INSERT INTO wine VALUES (2,'Pattendon',3,1975,1,NULL);
INSERT INTO wine VALUES (3,'Lombardi',4,1985,2,NULL);
INSERT INTO wine VALUES (4,'Tonkin',2,1984,2,NULL);
INSERT INTO wine VALUES (5,'Titshall',5,1986,2,NULL);
INSERT INTO wine VALUES (6,'Serrong',6,1995,2,NULL);
INSERT INTO wine VALUES (7,'Mettaxus',5,1996,2,NULL);
INSERT INTO wine VALUES (8,'Titshall',4,1987,3,NULL);
INSERT INTO wine VALUES (9,'Serrong',3,1981,3,NULL);
INSERT INTO wine VALUES (10,'Chester',5,1999,3,NULL);
INSERT INTO wine VALUES (11,'Chemnis',2,1980,3,NULL);
INSERT INTO wine VALUES (12,'Holdenson',6,1979,4,NULL);
INSERT INTO wine VALUES (13,'Skerry',2,1975,4,NULL);
INSERT INTO wine VALUES (14,'Pattendon',5,1978,4,NULL);
INSERT INTO wine VALUES (15,'Titshall',3,1999,4,NULL);
INSERT INTO wine VALUES (16,'Belcombe',3,1998,4,NULL);
INSERT INTO wine VALUES (17,'Dimitria',5,1981,5,NULL);
INSERT INTO wine VALUES (18,'Titshall',5,1977,5,NULL);
INSERT INTO wine VALUES (19,'Holdenson',4,1986,6,NULL);
INSERT INTO wine VALUES (20,'Sears',2,1999,6,NULL);
INSERT INTO wine VALUES (21,'Sorrenti',3,1970,6,NULL);
INSERT INTO wine VALUES (22,'Belcombe',3,1972,7,NULL);
INSERT INTO wine VALUES (23,'Sears',4,1986,8,NULL);
INSERT INTO wine VALUES (24,'Kinsala',3,1985,8,NULL);
INSERT INTO wine VALUES (25,'Skerry',5,1973,8,NULL);
INSERT INTO wine VALUES (26,'Keisling',6,1973,8,NULL);
INSERT INTO wine VALUES (27,'Mellaseca',6,1973,8,NULL);
INSERT INTO wine VALUES (28,'Keisling',6,1985,8,NULL);
INSERT INTO wine VALUES (29,'Chester',2,1983,9,NULL);
INSERT INTO wine VALUES (30,'Nancarral',5,1988,9,NULL);
INSERT INTO wine VALUES (31,'Mockridge',6,1970,9,NULL);
INSERT INTO wine VALUES (32,'Dimitria',6,1977,9,NULL);
INSERT INTO wine VALUES (33,'Barneshaw',2,1973,10,NULL);
INSERT INTO wine VALUES (34,'Lombardi',4,1985,10,NULL);
INSERT INTO wine VALUES (35,'Chester',4,1970,10,NULL);
INSERT INTO wine VALUES (36,'Mettaxus',2,1971,10,NULL);
INSERT INTO wine VALUES (37,'Stribling',6,1975,10,NULL);
INSERT INTO wine VALUES (38,'Tonkin',6,1986,10,NULL);
INSERT INTO wine VALUES (39,'Sears',3,1975,11,NULL);
INSERT INTO wine VALUES (40,'Rosenthal',5,1981,12,NULL);
INSERT INTO wine VALUES (41,'Florenini',6,1998,13,NULL);
INSERT INTO wine VALUES (42,'Mettaxus',3,1982,13,NULL);
INSERT INTO wine VALUES (43,'Pattendon',6,1984,14,NULL);
INSERT INTO wine VALUES (44,'Barneshaw',4,1978,14,NULL);
INSERT INTO wine VALUES (45,'Ruscina',3,1977,15,NULL);
INSERT INTO wine VALUES (46,'Marzalla',3,1991,15,NULL);
INSERT INTO wine VALUES (47,'Marzalla',6,1999,16,NULL);
INSERT INTO wine VALUES (48,'Lombardi',3,1975,17,NULL);
INSERT INTO wine VALUES (49,'Oaton',3,1993,17,NULL);
INSERT INTO wine VALUES (50,'Sears',5,1993,17,NULL);
INSERT INTO wine VALUES (51,'Mockridge',4,1983,17,NULL);
INSERT INTO wine VALUES (52,'Tonkin',6,1989,17,NULL);
INSERT INTO wine VALUES (53,'Triskit',6,1990,18,NULL);
INSERT INTO wine VALUES (54,'Eggelston',2,1996,18,NULL);
INSERT INTO wine VALUES (55,'Morfooney',3,1985,18,NULL);
INSERT INTO wine VALUES (56,'Oaton',3,1980,18,NULL);
INSERT INTO wine VALUES (57,'Stribling',2,1998,19,NULL);
INSERT INTO wine VALUES (58,'Florenini',3,1996,19,NULL);
INSERT INTO wine VALUES (59,'Galti',5,1984,19,NULL);
INSERT INTO wine VALUES (60,'Serrong',6,1998,20,NULL);
INSERT INTO wine VALUES (61,'Mockridge',3,1975,20,NULL);
INSERT INTO wine VALUES (62,'Marzalla',6,1979,20,NULL);
INSERT INTO wine VALUES (63,'Serrong',2,1970,20,NULL);
INSERT INTO wine VALUES (64,'Triskit',2,1988,20,NULL);
INSERT INTO wine VALUES (65,'Sears',3,1971,20,NULL);
INSERT INTO wine VALUES (66,'Ruscina',5,1975,21,NULL);
INSERT INTO wine VALUES (67,'Krennan',3,1976,21,NULL);
INSERT INTO wine VALUES (68,'Mockridge',5,1996,21,NULL);
INSERT INTO wine VALUES (69,'Holdenson',6,1972,21,NULL);
INSERT INTO wine VALUES (70,'Taggendharf',3,1974,21,NULL);
INSERT INTO wine VALUES (71,'Barneshaw',5,1998,22,NULL);
INSERT INTO wine VALUES (72,'Barneshaw',3,1972,23,NULL);
INSERT INTO wine VALUES (73,'Nancarral',3,1991,23,NULL);
INSERT INTO wine VALUES (74,'Ruscina',5,1970,23,NULL);
INSERT INTO wine VALUES (75,'Tonkin',2,1988,23,NULL);
INSERT INTO wine VALUES (76,'Ritterman',3,1974,23,NULL);
INSERT INTO wine VALUES (77,'Marzalla',4,1994,24,NULL);
INSERT INTO wine VALUES (78,'Dalion',3,1992,24,NULL);
INSERT INTO wine VALUES (79,'Mellaseca',2,1990,24,NULL);
INSERT INTO wine VALUES (80,'Leramonth',3,1976,24,NULL);
INSERT INTO wine VALUES (81,'Kinsala',5,1976,24,NULL);
INSERT INTO wine VALUES (82,'Oaton',5,1979,24,NULL);
INSERT INTO wine VALUES (83,'Belcombe',3,1977,25,NULL);
INSERT INTO wine VALUES (84,'Dalion',4,1971,25,NULL);
INSERT INTO wine VALUES (85,'Morfooney',5,1989,26,NULL);
INSERT INTO wine VALUES (86,'Mellili',6,1988,26,NULL);
INSERT INTO wine VALUES (87,'Mockridge',3,1984,26,NULL);
INSERT INTO wine VALUES (88,'Dalion',2,1975,26,NULL);
INSERT INTO wine VALUES (89,'Mellili',5,1980,26,NULL);
INSERT INTO wine VALUES (90,'Chemnis',6,1990,27,NULL);
INSERT INTO wine VALUES (91,'Nancarral',6,1987,27,NULL);
INSERT INTO wine VALUES (92,'Florenini',6,1985,27,NULL);
INSERT INTO wine VALUES (93,'Stribling',6,1976,28,NULL);
INSERT INTO wine VALUES (94,'Oaton',5,1972,29,NULL);
INSERT INTO wine VALUES (95,'Chester',5,1977,29,NULL);
INSERT INTO wine VALUES (96,'Skerry',3,1976,29,NULL);
INSERT INTO wine VALUES (97,'Galti',5,1986,29,NULL);
INSERT INTO wine VALUES (98,'Triskit',6,1987,29,NULL);
INSERT INTO wine VALUES (99,'Stribling',6,1975,29,NULL);
INSERT INTO wine VALUES (100,'Titshall',5,1984,30,NULL);
INSERT INTO wine VALUES (101,'Woodestock',6,1980,30,NULL);
INSERT INTO wine VALUES (102,'Morfooney',5,1991,30,NULL);
INSERT INTO wine VALUES (103,'Krennan',2,1984,30,NULL);
INSERT INTO wine VALUES (104,'Sears',3,1986,30,NULL);
INSERT INTO wine VALUES (105,'Eggelston',5,1994,30,NULL);
INSERT INTO wine VALUES (106,'Archibald',3,1971,31,NULL);
INSERT INTO wine VALUES (107,'Ruscina',2,1971,31,NULL);
INSERT INTO wine VALUES (108,'Taggendharf',6,1988,32,NULL);
INSERT INTO wine VALUES (109,'Holdenson',3,1974,32,NULL);
INSERT INTO wine VALUES (110,'Oaton',6,1975,32,NULL);
INSERT INTO wine VALUES (111,'Dalion',5,1991,32,NULL);
INSERT INTO wine VALUES (112,'Nancarral',6,1975,32,NULL);
INSERT INTO wine VALUES (113,'Sears',5,1971,32,NULL);
INSERT INTO wine VALUES (114,'Patton',4,1982,33,NULL);
INSERT INTO wine VALUES (115,'Dalion',6,1982,33,NULL);
INSERT INTO wine VALUES (116,'Florenini',2,1979,33,NULL);
INSERT INTO wine VALUES (117,'Patton',6,1996,33,'This is one shot out of the blue! With striking colour, this is a fruit-driven wine, with intense blueberry and blackberry fruit aromas, which carry on to the well crafted, full-flavoured palate, which has great persistence of flavour.');
INSERT INTO wine VALUES (118,'Belcombe',5,1976,33,NULL);
INSERT INTO wine VALUES (119,'Chemnis',3,1988,34,NULL);
INSERT INTO wine VALUES (120,'Skerry',3,1996,35,NULL);
INSERT INTO wine VALUES (121,'Holdenson',3,1974,36,NULL);
INSERT INTO wine VALUES (122,'Stribling',6,1979,36,NULL);
INSERT INTO wine VALUES (123,'Sorrenti',2,1973,36,NULL);
INSERT INTO wine VALUES (124,'Titshall',3,1995,36,NULL);
INSERT INTO wine VALUES (125,'Mockridge',3,1976,37,NULL);
INSERT INTO wine VALUES (126,'Mettaxus',5,1971,37,NULL);
INSERT INTO wine VALUES (127,'Belcombe',2,1984,37,NULL);
INSERT INTO wine VALUES (128,'Taggendharf',6,1982,37,NULL);
INSERT INTO wine VALUES (129,'Ritterman',6,1998,37,NULL);
INSERT INTO wine VALUES (130,'Florenini',2,1972,37,NULL);
INSERT INTO wine VALUES (131,'Mellili',5,1995,38,NULL);
INSERT INTO wine VALUES (132,'Krennan',4,1995,39,NULL);
INSERT INTO wine VALUES (133,'Galti',5,1999,39,NULL);
INSERT INTO wine VALUES (134,'Kinsala',4,1970,39,NULL);
INSERT INTO wine VALUES (135,'Florenini',5,1989,39,NULL);
INSERT INTO wine VALUES (136,'Chemnis',5,1998,39,NULL);
INSERT INTO wine VALUES (137,'Archibald',6,1994,39,NULL);
INSERT INTO wine VALUES (138,'Morfooney',2,1987,40,NULL);
INSERT INTO wine VALUES (139,'Woodburne',6,1985,40,NULL);
INSERT INTO wine VALUES (140,'Galti',5,1979,40,NULL);
INSERT INTO wine VALUES (141,'Dalion',2,1970,40,NULL);
INSERT INTO wine VALUES (142,'Eggelston',6,1999,41,NULL);
INSERT INTO wine VALUES (143,'Belcombe',5,1974,41,NULL);
INSERT INTO wine VALUES (144,'Mockridge',5,1991,41,NULL);
INSERT INTO wine VALUES (145,'Mockridge',6,1991,42,NULL);
INSERT INTO wine VALUES (146,'Galti',5,1990,43,NULL);
INSERT INTO wine VALUES (147,'Taggendharf',6,1987,44,NULL);
INSERT INTO wine VALUES (148,'Belcombe',5,1984,44,NULL);
INSERT INTO wine VALUES (149,'Marzalla',5,1989,44,NULL);
INSERT INTO wine VALUES (150,'Dimitria',3,1980,45,NULL);
INSERT INTO wine VALUES (151,'Serrong',5,1970,46,NULL);
INSERT INTO wine VALUES (152,'Woodburne',2,1986,46,NULL);
INSERT INTO wine VALUES (153,'Skerry',5,1986,46,NULL);
INSERT INTO wine VALUES (154,'Florenini',6,1975,46,NULL);
INSERT INTO wine VALUES (155,'Barneshaw',5,1987,46,NULL);
INSERT INTO wine VALUES (156,'Pattendon',5,1988,46,NULL);
INSERT INTO wine VALUES (157,'Lombardi',3,1972,47,NULL);
INSERT INTO wine VALUES (158,'Tonnibrook',6,1977,47,NULL);
INSERT INTO wine VALUES (159,'Woodburne',5,1975,47,NULL);
INSERT INTO wine VALUES (160,'Lombardi',6,1993,47,NULL);
INSERT INTO wine VALUES (161,'Galti',2,1988,47,NULL);
INSERT INTO wine VALUES (162,'Mettaxus',2,1994,48,NULL);
INSERT INTO wine VALUES (163,'Galti',5,1995,48,NULL);
INSERT INTO wine VALUES (164,'Mellili',2,1990,48,NULL);
INSERT INTO wine VALUES (165,'Mockridge',2,1999,48,'A very good example of Margaret River chardonnay. Peach and melon scents are followed by a full palate of ripe fruit tastes and a long, dry finish. Chicken dishes, hot or cold, will match it well now or cellar it until 2003.');
INSERT INTO wine VALUES (166,'Belcombe',5,1996,49,NULL);
INSERT INTO wine VALUES (167,'Cassisi',6,1983,49,NULL);
INSERT INTO wine VALUES (168,'Rosenthal',6,1984,49,NULL);
INSERT INTO wine VALUES (169,'Barneshaw',2,1989,49,NULL);
INSERT INTO wine VALUES (170,'Cassisi',2,1988,49,NULL);
INSERT INTO wine VALUES (171,'Morfooney',6,1979,50,NULL);
INSERT INTO wine VALUES (172,'Kinsala',6,1970,50,NULL);
INSERT INTO wine VALUES (173,'Barneshaw',2,1975,50,NULL);
INSERT INTO wine VALUES (174,'Mettaxus',5,1996,50,NULL);
INSERT INTO wine VALUES (175,'Titshall',5,1972,51,NULL);
INSERT INTO wine VALUES (176,'Oaton',2,1984,51,NULL);
INSERT INTO wine VALUES (177,'Mockridge',5,1992,52,NULL);
INSERT INTO wine VALUES (178,'Sorrenti',3,1970,52,NULL);
INSERT INTO wine VALUES (179,'Keisling',6,1982,53,NULL);
INSERT INTO wine VALUES (180,'Serrong',2,1979,54,NULL);
INSERT INTO wine VALUES (181,'Ritterman',5,1993,54,NULL);
INSERT INTO wine VALUES (182,'Belcombe',6,1975,54,NULL);
INSERT INTO wine VALUES (183,'Chester',4,1980,55,NULL);
INSERT INTO wine VALUES (184,'Chester',2,1994,55,NULL);
INSERT INTO wine VALUES (185,'Florenini',6,1983,55,NULL);
INSERT INTO wine VALUES (186,'Eggelston',6,1988,55,NULL);
INSERT INTO wine VALUES (187,'Skerry',5,1982,55,NULL);
INSERT INTO wine VALUES (188,'Krennan',3,1995,55,NULL);
INSERT INTO wine VALUES (189,'Sorrenti',4,1976,56,NULL);
INSERT INTO wine VALUES (190,'Sears',5,1991,57,NULL);
INSERT INTO wine VALUES (191,'Belcombe',6,1997,58,'Rich ruby colour with purple tinges it has a suggestion of peppermint and ripe red berry aromas. It''s a biggish wine with a well-structured, richly flavoured palate and firm tannins. Try it with rare beef dishes or cellar until 2005.');
INSERT INTO wine VALUES (192,'Sorrenti',6,1977,58,NULL);
INSERT INTO wine VALUES (193,'Skerry',6,1984,58,NULL);
INSERT INTO wine VALUES (194,'Rosenthal',5,1990,58,NULL);
INSERT INTO wine VALUES (195,'Mellili',2,1996,59,NULL);
INSERT INTO wine VALUES (196,'Eggelston',3,1990,59,NULL);
INSERT INTO wine VALUES (197,'Serrong',2,1997,59,NULL);
INSERT INTO wine VALUES (198,'Sears',2,1989,59,NULL);
INSERT INTO wine VALUES (199,'Marzalla',4,1971,59,NULL);
INSERT INTO wine VALUES (200,'Skerry',2,1978,59,NULL);
INSERT INTO wine VALUES (201,'Keisling',6,1982,60,NULL);
INSERT INTO wine VALUES (202,'Galti',4,1996,60,NULL);
INSERT INTO wine VALUES (203,'Sorrenti',5,1987,60,NULL);
INSERT INTO wine VALUES (204,'Keisling',5,1998,60,NULL);
INSERT INTO wine VALUES (205,'Triskit',6,1985,60,NULL);
INSERT INTO wine VALUES (206,'Stribling',5,1980,61,NULL);
INSERT INTO wine VALUES (207,'Galti',5,1973,61,NULL);
INSERT INTO wine VALUES (208,'Woodburne',3,1971,61,NULL);
INSERT INTO wine VALUES (209,'Stribling',5,1975,62,NULL);
INSERT INTO wine VALUES (210,'Mockridge',6,1984,62,NULL);
INSERT INTO wine VALUES (211,'Belcombe',3,1987,62,NULL);
INSERT INTO wine VALUES (212,'Morfooney',6,1998,62,NULL);
INSERT INTO wine VALUES (213,'Titshall',6,1974,62,NULL);
INSERT INTO wine VALUES (214,'Dimitria',6,1977,63,NULL);
INSERT INTO wine VALUES (215,'Eggelston',6,1998,63,NULL);
INSERT INTO wine VALUES (216,'Taggendharf',3,1993,63,NULL);
INSERT INTO wine VALUES (217,'Taggendharf',5,1972,63,NULL);
INSERT INTO wine VALUES (218,'Mettaxus',6,1975,63,NULL);
INSERT INTO wine VALUES (219,'Lombardi',3,1992,64,NULL);
INSERT INTO wine VALUES (220,'Mellili',6,1991,64,NULL);
INSERT INTO wine VALUES (221,'Leramonth',3,1994,64,NULL);
INSERT INTO wine VALUES (222,'Serrong',5,1981,64,NULL);
INSERT INTO wine VALUES (223,'Dimitria',5,1970,64,NULL);
INSERT INTO wine VALUES (224,'Mockridge',2,1976,64,NULL);
INSERT INTO wine VALUES (225,'Chemnis',2,1995,65,NULL);
INSERT INTO wine VALUES (226,'Mellaseca',4,1991,65,NULL);
INSERT INTO wine VALUES (227,'Sears',6,1989,65,NULL);
INSERT INTO wine VALUES (228,'Woodburne',5,1982,65,NULL);
INSERT INTO wine VALUES (229,'Triskit',6,1977,66,NULL);
INSERT INTO wine VALUES (230,'Nancarral',2,1988,66,NULL);
INSERT INTO wine VALUES (231,'Chemnis',6,1995,67,'This richly flavoured, soft and succulent drink is surely one of the best dry red buys around. Crafted by master South Australian winemaker John Petersen, this is a serious wine that''s a great accompaniment for veal dishes.');
INSERT INTO wine VALUES (232,'Stribling',3,1997,67,NULL);
INSERT INTO wine VALUES (233,'Marzalla',6,1977,67,NULL);
INSERT INTO wine VALUES (234,'Dalion',5,1988,67,NULL);
INSERT INTO wine VALUES (235,'Mockridge',3,1986,68,NULL);
INSERT INTO wine VALUES (236,'Chester',3,1982,68,NULL);
INSERT INTO wine VALUES (237,'Kinsala',6,1989,68,NULL);
INSERT INTO wine VALUES (238,'Mockridge',2,1982,68,NULL);
INSERT INTO wine VALUES (239,'Sorrenti',5,1987,68,NULL);
INSERT INTO wine VALUES (240,'Tonkin',5,1973,69,NULL);
INSERT INTO wine VALUES (241,'Woodburne',5,1973,69,NULL);
INSERT INTO wine VALUES (242,'Chemnis',5,1984,69,NULL);
INSERT INTO wine VALUES (243,'Dalion',3,1998,69,NULL);
INSERT INTO wine VALUES (244,'Triskit',5,1999,70,NULL);
INSERT INTO wine VALUES (245,'Holdenson',6,1999,70,NULL);
INSERT INTO wine VALUES (246,'Krennan',6,1972,70,NULL);
INSERT INTO wine VALUES (247,'Titshall',3,1977,70,NULL);
INSERT INTO wine VALUES (248,'Leramonth',3,1993,71,NULL);
INSERT INTO wine VALUES (249,'Skerry',6,1974,71,NULL);
INSERT INTO wine VALUES (250,'Mellili',4,1981,71,NULL);
INSERT INTO wine VALUES (251,'Skerry',2,1998,71,NULL);
INSERT INTO wine VALUES (252,'Lombardi',6,1972,71,NULL);
INSERT INTO wine VALUES (253,'Nancarral',3,1994,72,NULL);
INSERT INTO wine VALUES (254,'Stribling',6,1978,72,NULL);
INSERT INTO wine VALUES (255,'Ritterman',6,1979,72,NULL);
INSERT INTO wine VALUES (256,'Dalion',2,1982,72,NULL);
INSERT INTO wine VALUES (257,'Mettaxus',6,1980,72,NULL);
INSERT INTO wine VALUES (258,'Sears',2,1996,72,NULL);
INSERT INTO wine VALUES (259,'Kinsala',2,1995,73,NULL);
INSERT INTO wine VALUES (260,'Woodestock',6,1990,74,NULL);
INSERT INTO wine VALUES (261,'Woodestock',6,1996,74,NULL);
INSERT INTO wine VALUES (262,'Mellaseca',2,1987,74,NULL);
INSERT INTO wine VALUES (263,'Ruscina',5,1974,74,NULL);
INSERT INTO wine VALUES (264,'Chemnis',2,1996,74,NULL);
INSERT INTO wine VALUES (265,'Sorrenti',2,1990,75,NULL);
INSERT INTO wine VALUES (266,'Ritterman',5,1998,75,NULL);
INSERT INTO wine VALUES (267,'Belcombe',5,1988,75,NULL);
INSERT INTO wine VALUES (268,'Morfooney',4,1976,75,NULL);
INSERT INTO wine VALUES (269,'Titshall',3,1988,75,NULL);
INSERT INTO wine VALUES (270,'Titshall',2,1975,75,NULL);
INSERT INTO wine VALUES (271,'Holdenson',3,1976,76,NULL);
INSERT INTO wine VALUES (272,'Morfooney',5,1977,76,NULL);
INSERT INTO wine VALUES (273,'Cassisi',2,1989,76,NULL);
INSERT INTO wine VALUES (274,'Barneshaw',3,1973,76,NULL);
INSERT INTO wine VALUES (275,'Chester',6,1970,76,NULL);
INSERT INTO wine VALUES (276,'Barneshaw',5,1971,77,NULL);
INSERT INTO wine VALUES (277,'Chemnis',5,1975,77,NULL);
INSERT INTO wine VALUES (278,'Florenini',4,1993,78,NULL);
INSERT INTO wine VALUES (279,'Kinsala',3,1974,78,NULL);
INSERT INTO wine VALUES (280,'Mettaxus',3,1971,79,NULL);
INSERT INTO wine VALUES (281,'Chemnis',3,1990,80,NULL);
INSERT INTO wine VALUES (282,'Kinsala',3,1982,80,NULL);
INSERT INTO wine VALUES (283,'Krennan',2,1994,80,NULL);
INSERT INTO wine VALUES (284,'Woodestock',2,1985,80,NULL);
INSERT INTO wine VALUES (285,'Skerry',4,1997,80,NULL);
INSERT INTO wine VALUES (286,'Holdenson',2,1993,80,NULL);
INSERT INTO wine VALUES (287,'Holdenson',5,1987,81,NULL);
INSERT INTO wine VALUES (288,'Rosenthal',6,1971,81,NULL);
INSERT INTO wine VALUES (289,'Cassisi',3,1973,81,NULL);
INSERT INTO wine VALUES (290,'Ritterman',2,1978,81,NULL);
INSERT INTO wine VALUES (291,'Kinsala',2,1992,81,NULL);
INSERT INTO wine VALUES (292,'Mockridge',2,1987,82,NULL);
INSERT INTO wine VALUES (293,'Mellaseca',5,1988,83,NULL);
INSERT INTO wine VALUES (294,'Stribling',4,1984,83,NULL);
INSERT INTO wine VALUES (295,'Pattendon',5,1992,83,NULL);
INSERT INTO wine VALUES (296,'Archibald',6,1978,83,NULL);
INSERT INTO wine VALUES (297,'Dimitria',4,1984,84,NULL);
INSERT INTO wine VALUES (298,'Archibald',4,1994,84,NULL);
INSERT INTO wine VALUES (299,'Belcombe',5,1976,84,NULL);
INSERT INTO wine VALUES (300,'Triskit',5,1976,85,NULL);
INSERT INTO wine VALUES (301,'Chemnis',3,1982,85,NULL);
INSERT INTO wine VALUES (302,'Cassisi',3,1978,85,NULL);
INSERT INTO wine VALUES (303,'Woodburne',2,1974,85,NULL);
INSERT INTO wine VALUES (304,'Skerry',4,1993,85,NULL);
INSERT INTO wine VALUES (305,'Skerry',3,1999,86,NULL);
INSERT INTO wine VALUES (306,'Nancarral',6,1973,86,NULL);
INSERT INTO wine VALUES (307,'Dalion',5,1970,87,NULL);
INSERT INTO wine VALUES (308,'Sears',5,1984,87,NULL);
INSERT INTO wine VALUES (309,'Chemnis',6,1973,87,NULL);
INSERT INTO wine VALUES (310,'Pattendon',3,1973,87,NULL);
INSERT INTO wine VALUES (311,'Taggendharf',5,1979,88,NULL);
INSERT INTO wine VALUES (312,'Patton',5,1986,88,NULL);
INSERT INTO wine VALUES (313,'Belcombe',3,1979,88,NULL);
INSERT INTO wine VALUES (314,'Triskit',6,1971,88,NULL);
INSERT INTO wine VALUES (315,'Stribling',6,1973,88,NULL);
INSERT INTO wine VALUES (316,'Tonkin',3,1986,88,NULL);
INSERT INTO wine VALUES (317,'Mellili',5,1985,89,NULL);
INSERT INTO wine VALUES (318,'Krennan',5,1970,90,NULL);
INSERT INTO wine VALUES (319,'Cassisi',2,1986,90,NULL);
INSERT INTO wine VALUES (320,'Rosenthal',6,1987,91,NULL);
INSERT INTO wine VALUES (321,'Patton',6,1981,91,NULL);
INSERT INTO wine VALUES (322,'Sears',3,1987,92,NULL);
INSERT INTO wine VALUES (323,'Ritterman',5,1990,92,NULL);
INSERT INTO wine VALUES (324,'Archibald',6,1988,92,NULL);
INSERT INTO wine VALUES (325,'Rosenthal',2,1977,93,NULL);
INSERT INTO wine VALUES (326,'Chester',2,1987,93,NULL);
INSERT INTO wine VALUES (327,'Mellili',2,1997,93,NULL);
INSERT INTO wine VALUES (328,'Galti',6,1974,93,NULL);
INSERT INTO wine VALUES (329,'Lombardi',6,1978,94,NULL);
INSERT INTO wine VALUES (330,'Barneshaw',5,1975,94,NULL);
INSERT INTO wine VALUES (331,'Krennan',2,1978,94,NULL);
INSERT INTO wine VALUES (332,'Rosenthal',4,1997,94,NULL);
INSERT INTO wine VALUES (333,'Skerry',3,1984,94,NULL);
INSERT INTO wine VALUES (334,'Pattendon',6,1986,95,NULL);
INSERT INTO wine VALUES (335,'Dimitria',5,1988,95,NULL);
INSERT INTO wine VALUES (336,'Marzalla',6,1974,96,NULL);
INSERT INTO wine VALUES (337,'Morfooney',2,1977,96,NULL);
INSERT INTO wine VALUES (338,'Titshall',3,1977,97,NULL);
INSERT INTO wine VALUES (339,'Mockridge',5,1971,97,NULL);
INSERT INTO wine VALUES (340,'Belcombe',2,1986,97,NULL);
INSERT INTO wine VALUES (341,'Lombardi',2,1988,97,NULL);
INSERT INTO wine VALUES (342,'Mockridge',5,1971,97,NULL);
INSERT INTO wine VALUES (343,'Mellaseca',2,1982,98,NULL);
INSERT INTO wine VALUES (344,'Mellili',3,1972,98,NULL);
INSERT INTO wine VALUES (345,'Archibald',3,1998,98,NULL);
INSERT INTO wine VALUES (346,'Mockridge',6,1980,98,NULL);
INSERT INTO wine VALUES (347,'Belcombe',5,1990,98,NULL);
INSERT INTO wine VALUES (348,'Barneshaw',6,1996,99,NULL);
INSERT INTO wine VALUES (349,'Mellili',4,1996,100,NULL);
INSERT INTO wine VALUES (350,'Taggendharf',2,1999,101,NULL);
INSERT INTO wine VALUES (351,'Mettaxus',2,1984,101,NULL);
INSERT INTO wine VALUES (352,'Sorrenti',3,1992,101,NULL);
INSERT INTO wine VALUES (353,'Dalion',3,1981,101,NULL);
INSERT INTO wine VALUES (354,'Titshall',4,1990,101,NULL);
INSERT INTO wine VALUES (355,'Mellili',5,1991,102,NULL);
INSERT INTO wine VALUES (356,'Chemnis',2,1985,103,NULL);
INSERT INTO wine VALUES (357,'Florenini',6,1979,103,NULL);
INSERT INTO wine VALUES (358,'Woodburne',5,1970,104,NULL);
INSERT INTO wine VALUES (359,'Mellili',6,1988,104,NULL);
INSERT INTO wine VALUES (360,'Mettaxus',6,1993,104,NULL);
INSERT INTO wine VALUES (361,'Keisling',2,1984,105,NULL);
INSERT INTO wine VALUES (362,'Eggelston',6,1975,105,NULL);
INSERT INTO wine VALUES (363,'Taggendharf',4,1984,105,NULL);
INSERT INTO wine VALUES (364,'Patton',4,1989,106,NULL);
INSERT INTO wine VALUES (365,'Mettaxus',5,1996,106,NULL);
INSERT INTO wine VALUES (366,'Archibald',6,1989,106,NULL);
INSERT INTO wine VALUES (367,'Morfooney',5,1985,107,NULL);
INSERT INTO wine VALUES (368,'Titshall',5,1984,108,NULL);
INSERT INTO wine VALUES (369,'Ritterman',4,1993,108,NULL);
INSERT INTO wine VALUES (370,'Leramonth',2,1999,108,NULL);
INSERT INTO wine VALUES (371,'Mockridge',5,1990,108,NULL);
INSERT INTO wine VALUES (372,'Woodestock',3,1976,109,NULL);
INSERT INTO wine VALUES (373,'Sorrenti',4,1983,109,NULL);
INSERT INTO wine VALUES (374,'Chester',5,1989,109,NULL);
INSERT INTO wine VALUES (375,'Holdenson',5,1995,109,NULL);
INSERT INTO wine VALUES (376,'Lombardi',5,1992,109,NULL);
INSERT INTO wine VALUES (377,'Galti',5,1996,110,NULL);
INSERT INTO wine VALUES (378,'Galti',3,1973,110,NULL);
INSERT INTO wine VALUES (379,'Mettaxus',2,1974,110,NULL);
INSERT INTO wine VALUES (380,'Ruscina',2,1995,110,NULL);
INSERT INTO wine VALUES (381,'Galti',6,1982,110,'Sorry, but you shouldn''t really be able to get this much flavour from a wine this cheap. Then again, if you can, why complain? There''s heaps of attractive fresh grapey fruit flavour and ever-so-slightly sweet grape-pulpy juiciness. Just drink it. Don''t question the price.');
INSERT INTO wine VALUES (382,'Ruscina',2,1970,110,NULL);
INSERT INTO wine VALUES (383,'Titshall',3,1982,111,NULL);
INSERT INTO wine VALUES (384,'Taggendharf',6,1992,111,NULL);
INSERT INTO wine VALUES (385,'Woodburne',4,1982,112,NULL);
INSERT INTO wine VALUES (386,'Belcombe',5,1986,112,NULL);
INSERT INTO wine VALUES (387,'Galti',4,1974,112,NULL);
INSERT INTO wine VALUES (388,'Sorrenti',6,1991,112,NULL);
INSERT INTO wine VALUES (389,'Mellili',6,1999,112,NULL);
INSERT INTO wine VALUES (390,'Woodburne',6,1978,112,NULL);
INSERT INTO wine VALUES (391,'Cassisi',3,1970,113,NULL);
INSERT INTO wine VALUES (392,'Ritterman',5,1986,113,NULL);
INSERT INTO wine VALUES (393,'Holdenson',4,1993,113,NULL);
INSERT INTO wine VALUES (394,'Stribling',5,1995,113,NULL);
INSERT INTO wine VALUES (395,'Eggelston',5,1997,113,NULL);
INSERT INTO wine VALUES (396,'Marzalla',6,1973,113,NULL);
INSERT INTO wine VALUES (397,'Holdenson',2,1990,114,NULL);
INSERT INTO wine VALUES (398,'Stribling',5,1992,114,NULL);
INSERT INTO wine VALUES (399,'Sears',5,1981,114,NULL);
INSERT INTO wine VALUES (400,'Ritterman',3,1985,114,NULL);
INSERT INTO wine VALUES (401,'Serrong',6,1995,115,NULL);
INSERT INTO wine VALUES (402,'Rosenthal',5,1996,115,NULL);
INSERT INTO wine VALUES (403,'Kinsala',2,1997,115,NULL);
INSERT INTO wine VALUES (404,'Holdenson',3,1980,115,NULL);
INSERT INTO wine VALUES (405,'Woodestock',6,1981,116,NULL);
INSERT INTO wine VALUES (406,'Florenini',6,1995,117,NULL);
INSERT INTO wine VALUES (407,'Dimitria',4,1993,118,NULL);
INSERT INTO wine VALUES (408,'Triskit',2,1976,119,NULL);
INSERT INTO wine VALUES (409,'Sorrenti',2,1999,119,NULL);
INSERT INTO wine VALUES (410,'Sears',6,1971,119,NULL);
INSERT INTO wine VALUES (411,'Kinsala',6,1975,119,NULL);
INSERT INTO wine VALUES (412,'Skerry',2,1977,119,NULL);
INSERT INTO wine VALUES (413,'Morfooney',3,1970,119,NULL);
INSERT INTO wine VALUES (414,'Morfooney',5,1976,120,NULL);
INSERT INTO wine VALUES (415,'Dalion',6,1987,120,NULL);
INSERT INTO wine VALUES (416,'Kinsala',6,1995,120,NULL);
INSERT INTO wine VALUES (417,'Eggelston',6,1993,120,NULL);
INSERT INTO wine VALUES (418,'Galti',4,1988,121,NULL);
INSERT INTO wine VALUES (419,'Archibald',2,1982,121,NULL);
INSERT INTO wine VALUES (420,'Triskit',5,1970,122,NULL);
INSERT INTO wine VALUES (421,'Sorrenti',5,1980,122,NULL);
INSERT INTO wine VALUES (422,'Leramonth',6,1990,122,NULL);
INSERT INTO wine VALUES (423,'Skerry',4,1977,122,NULL);
INSERT INTO wine VALUES (424,'Lombardi',6,1997,122,NULL);
INSERT INTO wine VALUES (425,'Woodestock',3,1976,122,NULL);
INSERT INTO wine VALUES (426,'Holdenson',6,1970,123,NULL);
INSERT INTO wine VALUES (427,'Holdenson',5,1997,123,NULL);
INSERT INTO wine VALUES (428,'Nancarral',4,1998,123,NULL);
INSERT INTO wine VALUES (429,'Rosenthal',5,1986,123,NULL);
INSERT INTO wine VALUES (430,'Belcombe',6,1975,124,NULL);
INSERT INTO wine VALUES (431,'Marzalla',2,1977,124,NULL);
INSERT INTO wine VALUES (432,'Leramonth',5,1988,124,NULL);
INSERT INTO wine VALUES (433,'Rosenthal',2,1987,124,NULL);
INSERT INTO wine VALUES (434,'Triskit',6,1972,124,NULL);
INSERT INTO wine VALUES (435,'Patton',5,1979,124,NULL);
INSERT INTO wine VALUES (436,'Holdenson',2,1974,125,NULL);
INSERT INTO wine VALUES (437,'Mockridge',3,1985,125,NULL);
INSERT INTO wine VALUES (438,'Pattendon',6,1973,125,NULL);
INSERT INTO wine VALUES (439,'Kinsala',6,1975,125,NULL);
INSERT INTO wine VALUES (440,'Pattendon',5,1978,125,NULL);
INSERT INTO wine VALUES (441,'Pattendon',5,1997,125,NULL);
INSERT INTO wine VALUES (442,'Cassisi',5,1974,126,NULL);
INSERT INTO wine VALUES (443,'Ritterman',6,1975,126,NULL);
INSERT INTO wine VALUES (444,'Barneshaw',6,1978,127,NULL);
INSERT INTO wine VALUES (445,'Mellaseca',3,1970,127,NULL);
INSERT INTO wine VALUES (446,'Skerry',3,1984,127,NULL);
INSERT INTO wine VALUES (447,'Dalion',2,1979,128,NULL);
INSERT INTO wine VALUES (448,'Pattendon',2,1996,129,NULL);
INSERT INTO wine VALUES (449,'Ruscina',6,1972,129,NULL);
INSERT INTO wine VALUES (450,'Skerry',4,1977,130,NULL);
INSERT INTO wine VALUES (451,'Woodburne',6,1980,131,NULL);
INSERT INTO wine VALUES (452,'Tonnibrook',4,1971,131,NULL);
INSERT INTO wine VALUES (453,'Skerry',3,1998,131,NULL);
INSERT INTO wine VALUES (454,'Mellili',5,1974,131,NULL);
INSERT INTO wine VALUES (455,'Pattendon',5,1993,131,NULL);
INSERT INTO wine VALUES (456,'Triskit',2,1982,131,NULL);
INSERT INTO wine VALUES (457,'Sears',5,1985,132,NULL);
INSERT INTO wine VALUES (458,'Woodburne',2,1998,132,NULL);
INSERT INTO wine VALUES (459,'Ruscina',6,1997,132,NULL);
INSERT INTO wine VALUES (460,'Holdenson',5,1986,132,NULL);
INSERT INTO wine VALUES (461,'Holdenson',3,1999,132,NULL);
INSERT INTO wine VALUES (462,'Taggendharf',2,1978,133,NULL);
INSERT INTO wine VALUES (463,'Woodestock',6,1987,133,NULL);
INSERT INTO wine VALUES (464,'Holdenson',3,1982,134,NULL);
INSERT INTO wine VALUES (465,'Mettaxus',6,1983,134,NULL);
INSERT INTO wine VALUES (466,'Mettaxus',5,1985,134,NULL);
INSERT INTO wine VALUES (467,'Ruscina',2,1991,134,NULL);
INSERT INTO wine VALUES (468,'Archibald',6,1984,134,NULL);
INSERT INTO wine VALUES (469,'Holdenson',4,1972,135,NULL);
INSERT INTO wine VALUES (470,'Tonkin',5,1976,135,NULL);
INSERT INTO wine VALUES (471,'Mellili',5,1991,135,NULL);
INSERT INTO wine VALUES (472,'Cassisi',5,1984,136,NULL);
INSERT INTO wine VALUES (473,'Triskit',6,1985,137,NULL);
INSERT INTO wine VALUES (474,'Florenini',4,1975,137,NULL);
INSERT INTO wine VALUES (475,'Archibald',2,1986,137,NULL);
INSERT INTO wine VALUES (476,'Dalion',6,1999,137,NULL);
INSERT INTO wine VALUES (477,'Mellaseca',5,1971,138,NULL);
INSERT INTO wine VALUES (478,'Archibald',3,1994,138,NULL);
INSERT INTO wine VALUES (479,'Titshall',6,1985,138,NULL);
INSERT INTO wine VALUES (480,'Woodburne',6,1998,139,NULL);
INSERT INTO wine VALUES (481,'Barneshaw',3,1976,139,NULL);
INSERT INTO wine VALUES (482,'Stribling',4,1987,139,NULL);
INSERT INTO wine VALUES (483,'Taggendharf',3,1972,139,NULL);
INSERT INTO wine VALUES (484,'Mellaseca',6,1972,139,NULL);
INSERT INTO wine VALUES (485,'Stribling',5,1996,140,NULL);
INSERT INTO wine VALUES (486,'Triskit',5,1997,140,NULL);
INSERT INTO wine VALUES (487,'Dalion',6,1980,141,NULL);
INSERT INTO wine VALUES (488,'Patton',5,1978,141,NULL);
INSERT INTO wine VALUES (489,'Sears',5,1974,141,NULL);
INSERT INTO wine VALUES (490,'Oaton',3,1986,141,NULL);
INSERT INTO wine VALUES (491,'Mellaseca',4,1997,142,NULL);
INSERT INTO wine VALUES (492,'Belcombe',2,1975,142,NULL);
INSERT INTO wine VALUES (493,'Taggendharf',5,1992,142,NULL);
INSERT INTO wine VALUES (494,'Ruscina',3,1981,142,NULL);
INSERT INTO wine VALUES (495,'Triskit',5,1971,142,NULL);
INSERT INTO wine VALUES (496,'Tonkin',4,1979,142,NULL);
INSERT INTO wine VALUES (497,'Woodburne',4,1985,143,NULL);
INSERT INTO wine VALUES (498,'Leramonth',3,1981,143,NULL);
INSERT INTO wine VALUES (499,'Rosenthal',6,1979,144,NULL);
INSERT INTO wine VALUES (500,'Nancarral',3,1998,144,NULL);
INSERT INTO wine VALUES (501,'Taggendharf',6,1980,144,NULL);
INSERT INTO wine VALUES (502,'Nancarral',3,1981,144,NULL);
INSERT INTO wine VALUES (503,'Sorrenti',6,1973,145,NULL);
INSERT INTO wine VALUES (504,'Chemnis',2,1990,145,NULL);
INSERT INTO wine VALUES (505,'Galti',6,1986,145,NULL);
INSERT INTO wine VALUES (506,'Stribling',5,1982,145,NULL);
INSERT INTO wine VALUES (507,'Keisling',5,1975,145,NULL);
INSERT INTO wine VALUES (508,'Chester',2,1996,146,NULL);
INSERT INTO wine VALUES (509,'Archibald',6,1987,146,NULL);
INSERT INTO wine VALUES (510,'Mellaseca',6,1976,146,NULL);
INSERT INTO wine VALUES (511,'Woodburne',3,1986,147,NULL);
INSERT INTO wine VALUES (512,'Taggendharf',2,1972,147,NULL);
INSERT INTO wine VALUES (513,'Mockridge',5,1997,147,NULL);
INSERT INTO wine VALUES (514,'Mettaxus',2,1985,147,NULL);
INSERT INTO wine VALUES (515,'Sorrenti',6,1985,147,NULL);
INSERT INTO wine VALUES (516,'Eggelston',2,1973,148,NULL);
INSERT INTO wine VALUES (517,'Tonnibrook',6,1987,148,NULL);
INSERT INTO wine VALUES (518,'Tonkin',5,1989,149,NULL);
INSERT INTO wine VALUES (519,'Chemnis',5,1991,149,NULL);
INSERT INTO wine VALUES (520,'Mockridge',6,1980,149,NULL);
INSERT INTO wine VALUES (521,'Woodestock',5,1980,149,NULL);
INSERT INTO wine VALUES (522,'Marzalla',3,1977,149,NULL);
INSERT INTO wine VALUES (523,'Titshall',2,1988,150,NULL);
INSERT INTO wine VALUES (524,'Mellaseca',5,1982,150,NULL);
INSERT INTO wine VALUES (525,'Krennan',2,1978,151,NULL);
INSERT INTO wine VALUES (526,'Cassisi',6,1989,151,NULL);
INSERT INTO wine VALUES (527,'Dalion',6,1992,151,NULL);
INSERT INTO wine VALUES (528,'Sorrenti',6,1992,151,NULL);
INSERT INTO wine VALUES (529,'Pattendon',6,1994,152,NULL);
INSERT INTO wine VALUES (530,'Mellaseca',6,1991,152,NULL);
INSERT INTO wine VALUES (531,'Belcombe',6,1975,152,NULL);
INSERT INTO wine VALUES (532,'Sorrenti',6,1984,152,NULL);
INSERT INTO wine VALUES (533,'Kinsala',5,1984,152,NULL);
INSERT INTO wine VALUES (534,'Woodburne',6,1986,153,NULL);
INSERT INTO wine VALUES (535,'Sears',3,1975,153,NULL);
INSERT INTO wine VALUES (536,'Woodburne',2,1971,153,NULL);
INSERT INTO wine VALUES (537,'Archibald',6,1987,153,NULL);
INSERT INTO wine VALUES (538,'Ritterman',2,1981,154,NULL);
INSERT INTO wine VALUES (539,'Galti',3,1991,155,NULL);
INSERT INTO wine VALUES (540,'Triskit',4,1983,155,NULL);
INSERT INTO wine VALUES (541,'Leramonth',5,1983,155,NULL);
INSERT INTO wine VALUES (542,'Oaton',5,1985,155,NULL);
INSERT INTO wine VALUES (543,'Florenini',2,1975,155,NULL);
INSERT INTO wine VALUES (544,'Krennan',5,1988,155,NULL);
INSERT INTO wine VALUES (545,'Lombardi',5,1976,156,NULL);
INSERT INTO wine VALUES (546,'Ritterman',6,1981,156,NULL);
INSERT INTO wine VALUES (547,'Archibald',5,1971,156,NULL);
INSERT INTO wine VALUES (548,'Nancarral',3,1992,156,NULL);
INSERT INTO wine VALUES (549,'Lombardi',4,1970,156,NULL);
INSERT INTO wine VALUES (550,'Skerry',6,1999,157,NULL);
INSERT INTO wine VALUES (551,'Marzalla',2,1981,157,NULL);
INSERT INTO wine VALUES (552,'Titshall',5,1983,158,NULL);
INSERT INTO wine VALUES (553,'Patton',5,1992,158,NULL);
INSERT INTO wine VALUES (554,'Mellili',3,1997,159,NULL);
INSERT INTO wine VALUES (555,'Pattendon',2,1979,159,NULL);
INSERT INTO wine VALUES (556,'Mettaxus',6,1983,159,NULL);
INSERT INTO wine VALUES (557,'Marzalla',6,1986,159,NULL);
INSERT INTO wine VALUES (558,'Ritterman',5,1998,160,NULL);
INSERT INTO wine VALUES (559,'Woodburne',2,1970,160,NULL);
INSERT INTO wine VALUES (560,'Kinsala',6,1996,160,NULL);
INSERT INTO wine VALUES (561,'Galti',2,1972,160,NULL);
INSERT INTO wine VALUES (562,'Marzalla',2,1973,161,NULL);
INSERT INTO wine VALUES (563,'Ruscina',2,1988,161,NULL);
INSERT INTO wine VALUES (564,'Dalion',5,1998,161,NULL);
INSERT INTO wine VALUES (565,'Morfooney',6,1982,162,NULL);
INSERT INTO wine VALUES (566,'Leramonth',6,1987,162,NULL);
INSERT INTO wine VALUES (567,'Woodburne',6,1989,162,NULL);
INSERT INTO wine VALUES (568,'Galti',5,1998,162,NULL);
INSERT INTO wine VALUES (569,'Woodestock',3,1999,162,NULL);
INSERT INTO wine VALUES (570,'Morfooney',4,1977,163,NULL);
INSERT INTO wine VALUES (571,'Taggendharf',6,1991,163,NULL);
INSERT INTO wine VALUES (572,'Leramonth',5,1970,163,NULL);
INSERT INTO wine VALUES (573,'Dimitria',3,1991,163,NULL);
INSERT INTO wine VALUES (574,'Titshall',5,1978,163,NULL);
INSERT INTO wine VALUES (575,'Mockridge',3,1981,163,NULL);
INSERT INTO wine VALUES (576,'Keisling',2,1999,164,NULL);
INSERT INTO wine VALUES (577,'Mellili',2,1980,165,NULL);
INSERT INTO wine VALUES (578,'Ruscina',5,1982,165,NULL);
INSERT INTO wine VALUES (579,'Skerry',6,1977,165,NULL);
INSERT INTO wine VALUES (580,'Cassisi',3,1996,165,NULL);
INSERT INTO wine VALUES (581,'Oaton',5,1994,165,NULL);
INSERT INTO wine VALUES (582,'Mockridge',2,1985,166,NULL);
INSERT INTO wine VALUES (583,'Mellaseca',5,1992,166,NULL);
INSERT INTO wine VALUES (584,'Galti',4,1996,166,NULL);
INSERT INTO wine VALUES (585,'Ruscina',3,1994,167,NULL);
INSERT INTO wine VALUES (586,'Tonkin',2,1998,167,NULL);
INSERT INTO wine VALUES (587,'Mellaseca',6,1997,167,NULL);
INSERT INTO wine VALUES (588,'Mettaxus',6,1982,167,NULL);
INSERT INTO wine VALUES (589,'Patton',6,1974,168,NULL);
INSERT INTO wine VALUES (590,'Dalion',3,1978,168,NULL);
INSERT INTO wine VALUES (591,'Ritterman',5,1983,169,NULL);
INSERT INTO wine VALUES (592,'Holdenson',5,1982,169,NULL);
INSERT INTO wine VALUES (593,'Mellaseca',2,1999,169,NULL);
INSERT INTO wine VALUES (594,'Woodburne',3,1979,169,NULL);
INSERT INTO wine VALUES (595,'Stribling',3,1979,170,NULL);
INSERT INTO wine VALUES (596,'Barneshaw',5,1997,170,NULL);
INSERT INTO wine VALUES (597,'Dimitria',3,1988,170,NULL);
INSERT INTO wine VALUES (598,'Kinsala',5,1980,170,NULL);
INSERT INTO wine VALUES (599,'Tonkin',2,1979,170,NULL);
INSERT INTO wine VALUES (600,'Woodburne',5,1984,171,NULL);
INSERT INTO wine VALUES (601,'Mockridge',5,1988,171,NULL);
INSERT INTO wine VALUES (602,'Patton',5,1973,171,NULL);
INSERT INTO wine VALUES (603,'Krennan',3,1994,171,NULL);
INSERT INTO wine VALUES (604,'Nancarral',5,1986,171,NULL);
INSERT INTO wine VALUES (605,'Holdenson',2,1997,171,NULL);
INSERT INTO wine VALUES (606,'Chester',5,1974,172,NULL);
INSERT INTO wine VALUES (607,'Woodburne',6,1989,172,NULL);
INSERT INTO wine VALUES (608,'Triskit',5,1999,172,NULL);
INSERT INTO wine VALUES (609,'Mettaxus',6,1983,172,NULL);
INSERT INTO wine VALUES (610,'Ruscina',6,1993,172,NULL);
INSERT INTO wine VALUES (611,'Pattendon',5,1987,172,NULL);
INSERT INTO wine VALUES (612,'Barneshaw',6,1991,173,NULL);
INSERT INTO wine VALUES (613,'Oaton',3,1972,174,NULL);
INSERT INTO wine VALUES (614,'Ruscina',4,1987,174,NULL);
INSERT INTO wine VALUES (615,'Woodburne',2,1984,175,NULL);
INSERT INTO wine VALUES (616,'Mockridge',3,1986,175,NULL);
INSERT INTO wine VALUES (617,'Holdenson',6,1985,175,NULL);
INSERT INTO wine VALUES (618,'Mellaseca',3,1982,175,NULL);
INSERT INTO wine VALUES (619,'Triskit',3,1990,176,NULL);
INSERT INTO wine VALUES (620,'Titshall',5,1983,176,NULL);
INSERT INTO wine VALUES (621,'Woodestock',6,1995,176,NULL);
INSERT INTO wine VALUES (622,'Barneshaw',5,1991,176,NULL);
INSERT INTO wine VALUES (623,'Mettaxus',3,1976,176,NULL);
INSERT INTO wine VALUES (624,'Morfooney',6,1999,176,'The wine is a deep crimson colour with aromas of ripe crushed berries and plums as well as spicy vanillin oak. The palate delivers layers of strong flavours of ripe plum and berries built around a robust structure of firm oak and silky tannins. The cellaring potential of this wine is 15-25 years. This wine is suited to richly flavoured red meat and game dishes.');
INSERT INTO wine VALUES (625,'Eggelston',3,1982,177,NULL);
INSERT INTO wine VALUES (626,'Mellaseca',6,1983,178,NULL);
INSERT INTO wine VALUES (627,'Archibald',4,1987,178,NULL);
INSERT INTO wine VALUES (628,'Barneshaw',5,1995,179,NULL);
INSERT INTO wine VALUES (629,'Barneshaw',3,1991,179,NULL);
INSERT INTO wine VALUES (630,'Dimitria',5,1983,179,NULL);
INSERT INTO wine VALUES (631,'Ruscina',6,1972,180,NULL);
INSERT INTO wine VALUES (632,'Skerry',2,1978,180,NULL);
INSERT INTO wine VALUES (633,'Sorrenti',3,1993,180,NULL);
INSERT INTO wine VALUES (634,'Patton',2,1970,180,NULL);
INSERT INTO wine VALUES (635,'Sears',5,1978,180,NULL);
INSERT INTO wine VALUES (636,'Serrong',6,1973,181,NULL);
INSERT INTO wine VALUES (637,'Barneshaw',4,1987,181,NULL);
INSERT INTO wine VALUES (638,'Florenini',5,1995,181,NULL);
INSERT INTO wine VALUES (639,'Lombardi',2,1980,181,NULL);
INSERT INTO wine VALUES (640,'Marzalla',4,1986,181,NULL);
INSERT INTO wine VALUES (641,'Chemnis',4,1980,181,NULL);
INSERT INTO wine VALUES (642,'Stribling',2,1998,182,NULL);
INSERT INTO wine VALUES (643,'Ruscina',2,1977,182,NULL);
INSERT INTO wine VALUES (644,'Florenini',4,1982,182,NULL);
INSERT INTO wine VALUES (645,'Kinsala',3,1974,182,NULL);
INSERT INTO wine VALUES (646,'Morfooney',4,1981,183,NULL);
INSERT INTO wine VALUES (647,'Tonkin',2,1982,183,NULL);
INSERT INTO wine VALUES (648,'Mockridge',4,1970,183,NULL);
INSERT INTO wine VALUES (649,'Titshall',4,1992,184,NULL);
INSERT INTO wine VALUES (650,'Skerry',4,1990,184,NULL);
INSERT INTO wine VALUES (651,'Kinsala',4,1982,184,NULL);
INSERT INTO wine VALUES (652,'Sorrenti',5,1998,185,NULL);
INSERT INTO wine VALUES (653,'Ritterman',3,1985,185,NULL);
INSERT INTO wine VALUES (654,'Tonkin',5,1989,185,NULL);
INSERT INTO wine VALUES (655,'Rosenthal',2,1977,186,NULL);
INSERT INTO wine VALUES (656,'Titshall',3,1999,186,NULL);
INSERT INTO wine VALUES (657,'Oaton',5,1972,186,NULL);
INSERT INTO wine VALUES (658,'Krennan',5,1981,186,NULL);
INSERT INTO wine VALUES (659,'Patton',5,1985,187,NULL);
INSERT INTO wine VALUES (660,'Mockridge',6,1970,187,NULL);
INSERT INTO wine VALUES (661,'Mellili',2,1998,187,NULL);
INSERT INTO wine VALUES (662,'Morfooney',5,1987,188,NULL);
INSERT INTO wine VALUES (663,'Eggelston',4,1989,188,NULL);
INSERT INTO wine VALUES (664,'Dalion',2,1973,189,NULL);
INSERT INTO wine VALUES (665,'Mettaxus',3,1994,189,NULL);
INSERT INTO wine VALUES (666,'Cassisi',6,1972,189,NULL);
INSERT INTO wine VALUES (667,'Titshall',5,1981,189,NULL);
INSERT INTO wine VALUES (668,'Mockridge',5,1978,189,NULL);
INSERT INTO wine VALUES (669,'Galti',6,1981,189,NULL);
INSERT INTO wine VALUES (670,'Taggendharf',3,1998,190,NULL);
INSERT INTO wine VALUES (671,'Leramonth',6,1974,190,NULL);
INSERT INTO wine VALUES (672,'Kinsala',5,1971,190,NULL);
INSERT INTO wine VALUES (673,'Keisling',6,1980,191,NULL);
INSERT INTO wine VALUES (674,'Woodburne',2,1997,191,NULL);
INSERT INTO wine VALUES (675,'Oaton',5,1996,192,NULL);
INSERT INTO wine VALUES (676,'Pattendon',3,1998,193,NULL);
INSERT INTO wine VALUES (677,'Keisling',2,1980,193,NULL);
INSERT INTO wine VALUES (678,'Chester',2,1976,193,NULL);
INSERT INTO wine VALUES (679,'Leramonth',3,1991,194,NULL);
INSERT INTO wine VALUES (680,'Tonnibrook',5,1986,194,NULL);
INSERT INTO wine VALUES (681,'Krennan',5,1989,194,NULL);
INSERT INTO wine VALUES (682,'Dimitria',2,1981,194,NULL);
INSERT INTO wine VALUES (683,'Woodburne',5,1980,194,NULL);
INSERT INTO wine VALUES (684,'Stribling',3,1976,195,NULL);
INSERT INTO wine VALUES (685,'Belcombe',6,1984,195,NULL);
INSERT INTO wine VALUES (686,'Krennan',2,1986,195,NULL);
INSERT INTO wine VALUES (687,'Florenini',2,1990,195,NULL);
INSERT INTO wine VALUES (688,'Belcombe',6,1977,195,NULL);
INSERT INTO wine VALUES (689,'Woodestock',5,1998,195,NULL);
INSERT INTO wine VALUES (690,'Mellili',6,1993,196,NULL);
INSERT INTO wine VALUES (691,'Mellaseca',3,1987,196,NULL);
INSERT INTO wine VALUES (692,'Cassisi',4,1997,196,NULL);
INSERT INTO wine VALUES (693,'Lombardi',5,1982,196,NULL);
INSERT INTO wine VALUES (694,'Belcombe',5,1993,196,NULL);
INSERT INTO wine VALUES (695,'Titshall',6,1978,196,NULL);
INSERT INTO wine VALUES (696,'Mockridge',2,1987,197,NULL);
INSERT INTO wine VALUES (697,'Pattendon',3,1970,197,NULL);
INSERT INTO wine VALUES (698,'Stribling',5,1994,197,NULL);
INSERT INTO wine VALUES (699,'Stribling',6,1995,197,NULL);
INSERT INTO wine VALUES (700,'Mockridge',5,1978,197,NULL);
INSERT INTO wine VALUES (701,'Krennan',5,1999,197,NULL);
INSERT INTO wine VALUES (702,'Tonnibrook',4,1971,198,NULL);
INSERT INTO wine VALUES (703,'Dimitria',6,1995,198,NULL);
INSERT INTO wine VALUES (704,'Mettaxus',3,1979,198,NULL);
INSERT INTO wine VALUES (705,'Tonnibrook',6,1981,198,NULL);
INSERT INTO wine VALUES (706,'Sears',5,1992,198,NULL);
INSERT INTO wine VALUES (707,'Dimitria',5,1978,198,NULL);
INSERT INTO wine VALUES (708,'Kinsala',5,1986,199,NULL);
INSERT INTO wine VALUES (709,'Dalion',2,1999,199,NULL);
INSERT INTO wine VALUES (710,'Kinsala',3,1986,199,NULL);
INSERT INTO wine VALUES (711,'Triskit',5,1992,199,NULL);
INSERT INTO wine VALUES (712,'Eggelston',6,1996,199,NULL);
INSERT INTO wine VALUES (713,'Woodestock',5,1989,200,NULL);
INSERT INTO wine VALUES (714,'Stribling',3,1993,200,NULL);
INSERT INTO wine VALUES (715,'Archibald',2,1973,200,NULL);
INSERT INTO wine VALUES (716,'Keisling',6,1973,200,NULL);
INSERT INTO wine VALUES (717,'Mockridge',5,1980,201,NULL);
INSERT INTO wine VALUES (718,'Mellaseca',4,1993,201,NULL);
INSERT INTO wine VALUES (719,'Skerry',5,1992,202,NULL);
INSERT INTO wine VALUES (720,'Oaton',4,1975,202,NULL);
INSERT INTO wine VALUES (721,'Chemnis',3,1982,202,NULL);
INSERT INTO wine VALUES (722,'Oaton',5,1986,202,NULL);
INSERT INTO wine VALUES (723,'Kinsala',6,1979,202,NULL);
INSERT INTO wine VALUES (724,'Rosenthal',6,1977,203,NULL);
INSERT INTO wine VALUES (725,'Mellaseca',2,1976,203,NULL);
INSERT INTO wine VALUES (726,'Keisling',4,1984,203,NULL);
INSERT INTO wine VALUES (727,'Oaton',3,1987,203,NULL);
INSERT INTO wine VALUES (728,'Rosenthal',5,1975,204,NULL);
INSERT INTO wine VALUES (729,'Chemnis',5,1989,204,NULL);
INSERT INTO wine VALUES (730,'Krennan',6,1993,204,NULL);
INSERT INTO wine VALUES (731,'Morfooney',2,1974,204,NULL);
INSERT INTO wine VALUES (732,'Woodestock',6,1997,204,NULL);
INSERT INTO wine VALUES (733,'Tonnibrook',6,1977,205,NULL);
INSERT INTO wine VALUES (734,'Lombardi',5,1995,205,NULL);
INSERT INTO wine VALUES (735,'Morfooney',3,1998,205,NULL);
INSERT INTO wine VALUES (736,'Eggelston',6,1989,205,NULL);
INSERT INTO wine VALUES (737,'Galti',6,1977,206,NULL);
INSERT INTO wine VALUES (738,'Dimitria',2,1978,206,NULL);
INSERT INTO wine VALUES (739,'Holdenson',5,1990,206,NULL);
INSERT INTO wine VALUES (740,'Chester',5,1980,206,NULL);
INSERT INTO wine VALUES (741,'Mockridge',5,1976,207,NULL);
INSERT INTO wine VALUES (742,'Titshall',6,1973,207,NULL);
INSERT INTO wine VALUES (743,'Keisling',2,1999,207,NULL);
INSERT INTO wine VALUES (744,'Dimitria',4,1989,207,NULL);
INSERT INTO wine VALUES (745,'Mettaxus',3,1976,208,NULL);
INSERT INTO wine VALUES (746,'Mockridge',5,1991,208,NULL);
INSERT INTO wine VALUES (747,'Mellili',6,1991,208,NULL);
INSERT INTO wine VALUES (748,'Krennan',6,1997,208,NULL);
INSERT INTO wine VALUES (749,'Galti',5,1990,208,NULL);
INSERT INTO wine VALUES (750,'Barneshaw',5,1982,209,NULL);
INSERT INTO wine VALUES (751,'Dalion',4,1976,209,NULL);
INSERT INTO wine VALUES (752,'Kinsala',2,1987,210,NULL);
INSERT INTO wine VALUES (753,'Skerry',2,1976,210,NULL);
INSERT INTO wine VALUES (754,'Sears',2,1973,210,NULL);
INSERT INTO wine VALUES (755,'Woodestock',6,1974,210,NULL);
INSERT INTO wine VALUES (756,'Sorrenti',5,1984,211,NULL);
INSERT INTO wine VALUES (757,'Mettaxus',5,1973,211,NULL);
INSERT INTO wine VALUES (758,'Pattendon',5,1993,212,NULL);
INSERT INTO wine VALUES (759,'Marzalla',5,1973,212,NULL);
INSERT INTO wine VALUES (760,'Nancarral',6,1983,212,NULL);
INSERT INTO wine VALUES (761,'Leramonth',4,1973,212,NULL);
INSERT INTO wine VALUES (762,'Cassisi',6,1985,213,NULL);
INSERT INTO wine VALUES (763,'Woodburne',3,1999,214,NULL);
INSERT INTO wine VALUES (764,'Kinsala',5,1978,214,NULL);
INSERT INTO wine VALUES (765,'Morfooney',5,1988,214,NULL);
INSERT INTO wine VALUES (766,'Skerry',5,1978,214,NULL);
INSERT INTO wine VALUES (767,'Mockridge',6,1995,214,NULL);
INSERT INTO wine VALUES (768,'Chester',3,1974,215,NULL);
INSERT INTO wine VALUES (769,'Ruscina',5,1989,215,NULL);
INSERT INTO wine VALUES (770,'Lombardi',6,1985,215,NULL);
INSERT INTO wine VALUES (771,'Sears',5,1982,215,NULL);
INSERT INTO wine VALUES (772,'Nancarral',4,1992,215,NULL);
INSERT INTO wine VALUES (773,'Patton',3,1981,215,NULL);
INSERT INTO wine VALUES (774,'Stribling',6,1983,216,NULL);
INSERT INTO wine VALUES (775,'Cassisi',2,1975,216,NULL);
INSERT INTO wine VALUES (776,'Pattendon',2,1993,216,NULL);
INSERT INTO wine VALUES (777,'Sorrenti',2,1999,217,NULL);
INSERT INTO wine VALUES (778,'Archibald',4,1993,217,NULL);
INSERT INTO wine VALUES (779,'Mellaseca',3,1987,218,NULL);
INSERT INTO wine VALUES (780,'Belcombe',5,1985,218,NULL);
INSERT INTO wine VALUES (781,'Morfooney',5,1986,218,NULL);
INSERT INTO wine VALUES (782,'Keisling',5,1987,219,NULL);
INSERT INTO wine VALUES (783,'Sorrenti',3,1987,219,NULL);
INSERT INTO wine VALUES (784,'Archibald',6,1993,219,NULL);
INSERT INTO wine VALUES (785,'Eggelston',5,1987,219,NULL);
INSERT INTO wine VALUES (786,'Tonnibrook',6,1991,220,NULL);
INSERT INTO wine VALUES (787,'Serrong',4,1981,221,NULL);
INSERT INTO wine VALUES (788,'Nancarral',6,1976,221,NULL);
INSERT INTO wine VALUES (789,'Skerry',3,1999,221,NULL);
INSERT INTO wine VALUES (790,'Cassisi',5,1972,221,NULL);
INSERT INTO wine VALUES (791,'Mellili',3,1999,221,NULL);
INSERT INTO wine VALUES (792,'Chemnis',5,1982,221,NULL);
INSERT INTO wine VALUES (793,'Galti',2,1999,222,NULL);
INSERT INTO wine VALUES (794,'Sears',5,1977,222,NULL);
INSERT INTO wine VALUES (795,'Galti',5,1985,222,NULL);
INSERT INTO wine VALUES (796,'Marzalla',5,1983,222,NULL);
INSERT INTO wine VALUES (797,'Cassisi',3,1973,223,NULL);
INSERT INTO wine VALUES (798,'Serrong',2,1983,223,NULL);
INSERT INTO wine VALUES (799,'Nancarral',2,1996,223,NULL);
INSERT INTO wine VALUES (800,'Barneshaw',5,1987,223,NULL);
INSERT INTO wine VALUES (801,'Archibald',3,1998,224,'Quite a luscious after-dinner drink made from super-ripe pedro grapes. The nose is alive with the smells of butterscotch, honey and caramel and the wine fills the mouth with sweet richness, yet the finish is surprisingly dry. Serve it with dessert or cellar until 2012.');
INSERT INTO wine VALUES (802,'Cassisi',5,1996,225,NULL);
INSERT INTO wine VALUES (803,'Rosenthal',5,1996,226,NULL);
INSERT INTO wine VALUES (804,'Chemnis',5,1992,226,NULL);
INSERT INTO wine VALUES (805,'Barneshaw',6,1984,226,NULL);
INSERT INTO wine VALUES (806,'Belcombe',6,1970,226,NULL);
INSERT INTO wine VALUES (807,'Woodestock',5,1997,226,NULL);
INSERT INTO wine VALUES (808,'Rosenthal',5,1982,226,NULL);
INSERT INTO wine VALUES (809,'Titshall',3,1972,227,NULL);
INSERT INTO wine VALUES (810,'Kinsala',6,1983,228,NULL);
INSERT INTO wine VALUES (811,'Dimitria',2,1998,228,NULL);
INSERT INTO wine VALUES (812,'Woodestock',2,1971,228,NULL);
INSERT INTO wine VALUES (813,'Belcombe',6,1972,228,NULL);
INSERT INTO wine VALUES (814,'Morfooney',5,1988,229,NULL);
INSERT INTO wine VALUES (815,'Mettaxus',3,1994,229,NULL);
INSERT INTO wine VALUES (816,'Stribling',6,1976,229,NULL);
INSERT INTO wine VALUES (817,'Taggendharf',5,1996,229,NULL);
INSERT INTO wine VALUES (818,'Mellili',5,1982,230,NULL);
INSERT INTO wine VALUES (819,'Chester',5,1983,230,NULL);
INSERT INTO wine VALUES (820,'Mockridge',4,1976,231,NULL);
INSERT INTO wine VALUES (821,'Tonnibrook',6,1994,232,NULL);
INSERT INTO wine VALUES (822,'Mellaseca',3,1989,232,NULL);
INSERT INTO wine VALUES (823,'Lombardi',2,1999,232,NULL);
INSERT INTO wine VALUES (824,'Taggendharf',6,1991,233,NULL);
INSERT INTO wine VALUES (825,'Galti',5,1988,233,NULL);
INSERT INTO wine VALUES (826,'Woodburne',2,1988,234,NULL);
INSERT INTO wine VALUES (827,'Sorrenti',3,1970,234,NULL);
INSERT INTO wine VALUES (828,'Rosenthal',6,1971,235,NULL);
INSERT INTO wine VALUES (829,'Rosenthal',5,1997,235,NULL);
INSERT INTO wine VALUES (830,'Dalion',5,1978,236,NULL);
INSERT INTO wine VALUES (831,'Morfooney',6,1982,236,NULL);
INSERT INTO wine VALUES (832,'Woodburne',2,1974,236,NULL);
INSERT INTO wine VALUES (833,'Barneshaw',6,1993,236,NULL);
INSERT INTO wine VALUES (834,'Barneshaw',2,1972,236,NULL);
INSERT INTO wine VALUES (835,'Marzalla',3,1972,236,NULL);
INSERT INTO wine VALUES (836,'Mettaxus',6,1992,237,NULL);
INSERT INTO wine VALUES (837,'Tonkin',3,1976,238,NULL);
INSERT INTO wine VALUES (838,'Archibald',5,1985,238,NULL);
INSERT INTO wine VALUES (839,'Chester',5,1975,239,NULL);
INSERT INTO wine VALUES (840,'Galti',3,1999,239,NULL);
INSERT INTO wine VALUES (841,'Sorrenti',2,1996,239,NULL);
INSERT INTO wine VALUES (842,'Rosenthal',6,1979,239,NULL);
INSERT INTO wine VALUES (843,'Nancarral',2,1983,240,NULL);
INSERT INTO wine VALUES (844,'Skerry',5,1978,240,NULL);
INSERT INTO wine VALUES (845,'Dimitria',6,1992,240,NULL);
INSERT INTO wine VALUES (846,'Serrong',3,1978,241,NULL);
INSERT INTO wine VALUES (847,'Barneshaw',5,1970,241,NULL);
INSERT INTO wine VALUES (848,'Tonnibrook',3,1991,241,NULL);
INSERT INTO wine VALUES (849,'Krennan',3,1970,241,NULL);
INSERT INTO wine VALUES (850,'Galti',6,1995,241,NULL);
INSERT INTO wine VALUES (851,'Mockridge',3,1980,242,NULL);
INSERT INTO wine VALUES (852,'Barneshaw',6,1981,242,NULL);
INSERT INTO wine VALUES (853,'Eggelston',5,1983,243,NULL);
INSERT INTO wine VALUES (854,'Taggendharf',5,1988,243,NULL);
INSERT INTO wine VALUES (855,'Sorrenti',6,1985,244,NULL);
INSERT INTO wine VALUES (856,'Pattendon',2,1993,245,NULL);
INSERT INTO wine VALUES (857,'Barneshaw',4,1976,245,NULL);
INSERT INTO wine VALUES (858,'Cassisi',6,1981,246,NULL);
INSERT INTO wine VALUES (859,'Archibald',3,1986,247,NULL);
INSERT INTO wine VALUES (860,'Dalion',5,1987,247,NULL);
INSERT INTO wine VALUES (861,'Kinsala',2,1975,247,NULL);
INSERT INTO wine VALUES (862,'Mettaxus',2,1998,247,NULL);
INSERT INTO wine VALUES (863,'Skerry',6,1973,247,NULL);
INSERT INTO wine VALUES (864,'Tonnibrook',6,1994,247,NULL);
INSERT INTO wine VALUES (865,'Kinsala',5,1987,248,NULL);
INSERT INTO wine VALUES (866,'Ritterman',5,1980,248,NULL);
INSERT INTO wine VALUES (867,'Kinsala',5,1978,248,NULL);
INSERT INTO wine VALUES (868,'Tonnibrook',4,1993,248,NULL);
INSERT INTO wine VALUES (869,'Mockridge',2,1993,248,NULL);
INSERT INTO wine VALUES (870,'Kinsala',2,1989,249,NULL);
INSERT INTO wine VALUES (871,'Sorrenti',5,1995,249,NULL);
INSERT INTO wine VALUES (872,'Stribling',3,1973,249,NULL);
INSERT INTO wine VALUES (873,'Ritterman',2,1977,250,NULL);
INSERT INTO wine VALUES (874,'Sears',6,1987,251,NULL);
INSERT INTO wine VALUES (875,'Keisling',5,1985,252,NULL);
INSERT INTO wine VALUES (876,'Chemnis',2,1973,252,NULL);
INSERT INTO wine VALUES (877,'Sorrenti',4,1983,252,NULL);
INSERT INTO wine VALUES (878,'Lombardi',5,1989,252,NULL);
INSERT INTO wine VALUES (879,'Leramonth',2,1986,253,NULL);
INSERT INTO wine VALUES (880,'Mellaseca',2,1995,254,NULL);
INSERT INTO wine VALUES (881,'Barneshaw',3,1987,254,NULL);
INSERT INTO wine VALUES (882,'Nancarral',2,1975,255,NULL);
INSERT INTO wine VALUES (883,'Dimitria',2,1980,255,NULL);
INSERT INTO wine VALUES (884,'Patton',6,1993,255,NULL);
INSERT INTO wine VALUES (885,'Tonkin',6,1997,255,NULL);
INSERT INTO wine VALUES (886,'Skerry',2,1982,256,NULL);
INSERT INTO wine VALUES (887,'Sorrenti',6,1978,256,NULL);
INSERT INTO wine VALUES (888,'Dimitria',5,1985,256,NULL);
INSERT INTO wine VALUES (889,'Morfooney',5,1988,257,NULL);
INSERT INTO wine VALUES (890,'Keisling',2,1997,257,NULL);
INSERT INTO wine VALUES (891,'Serrong',6,1977,257,NULL);
INSERT INTO wine VALUES (892,'Woodestock',2,1991,257,NULL);
INSERT INTO wine VALUES (893,'Ritterman',5,1974,257,NULL);
INSERT INTO wine VALUES (894,'Barneshaw',4,1973,258,NULL);
INSERT INTO wine VALUES (895,'Galti',6,1981,258,NULL);
INSERT INTO wine VALUES (896,'Mellili',5,1971,258,NULL);
INSERT INTO wine VALUES (897,'Patton',2,1997,258,NULL);
INSERT INTO wine VALUES (898,'Skerry',6,1982,258,NULL);
INSERT INTO wine VALUES (899,'Chester',2,1991,259,NULL);
INSERT INTO wine VALUES (900,'Mettaxus',4,1999,259,NULL);
INSERT INTO wine VALUES (901,'Belcombe',2,1971,259,NULL);
INSERT INTO wine VALUES (902,'Chemnis',5,1998,259,NULL);
INSERT INTO wine VALUES (903,'Keisling',2,1982,259,NULL);
INSERT INTO wine VALUES (904,'Mellaseca',3,1977,260,NULL);
INSERT INTO wine VALUES (905,'Marzalla',6,1983,260,NULL);
INSERT INTO wine VALUES (906,'Morfooney',6,1982,260,NULL);
INSERT INTO wine VALUES (907,'Krennan',5,1991,260,NULL);
INSERT INTO wine VALUES (908,'Belcombe',3,1989,260,NULL);
INSERT INTO wine VALUES (909,'Serrong',6,1974,261,NULL);
INSERT INTO wine VALUES (910,'Dimitria',6,1970,261,NULL);
INSERT INTO wine VALUES (911,'Krennan',6,1984,261,NULL);
INSERT INTO wine VALUES (912,'Ruscina',5,1977,261,NULL);
INSERT INTO wine VALUES (913,'Nancarral',2,1970,261,NULL);
INSERT INTO wine VALUES (914,'Patton',3,1975,262,NULL);
INSERT INTO wine VALUES (915,'Florenini',5,1973,263,NULL);
INSERT INTO wine VALUES (916,'Mellaseca',5,1993,263,NULL);
INSERT INTO wine VALUES (917,'Keisling',2,1976,263,NULL);
INSERT INTO wine VALUES (918,'Skerry',3,1980,264,NULL);
INSERT INTO wine VALUES (919,'Nancarral',6,1997,264,NULL);
INSERT INTO wine VALUES (920,'Galti',5,1976,264,NULL);
INSERT INTO wine VALUES (921,'Rosenthal',5,1987,264,NULL);
INSERT INTO wine VALUES (922,'Leramonth',5,1994,265,NULL);
INSERT INTO wine VALUES (923,'Kinsala',5,1985,265,NULL);
INSERT INTO wine VALUES (924,'Barneshaw',6,1973,265,NULL);
INSERT INTO wine VALUES (925,'Krennan',4,1975,266,NULL);
INSERT INTO wine VALUES (926,'Patton',5,1996,266,NULL);
INSERT INTO wine VALUES (927,'Titshall',4,1995,266,NULL);
INSERT INTO wine VALUES (928,'Kinsala',5,1974,266,NULL);
INSERT INTO wine VALUES (929,'Eggelston',2,1995,267,NULL);
INSERT INTO wine VALUES (930,'Florenini',5,1984,267,NULL);
INSERT INTO wine VALUES (931,'Pattendon',5,1990,267,NULL);
INSERT INTO wine VALUES (932,'Dimitria',2,1976,267,NULL);
INSERT INTO wine VALUES (933,'Titshall',2,1971,267,NULL);
INSERT INTO wine VALUES (934,'Cassisi',6,1978,267,NULL);
INSERT INTO wine VALUES (935,'Skerry',6,1997,268,NULL);
INSERT INTO wine VALUES (936,'Ritterman',6,1975,268,NULL);
INSERT INTO wine VALUES (937,'Mettaxus',5,1983,268,NULL);
INSERT INTO wine VALUES (938,'Mockridge',5,1972,269,NULL);
INSERT INTO wine VALUES (939,'Morfooney',2,1974,269,NULL);
INSERT INTO wine VALUES (940,'Serrong',2,1983,269,NULL);
INSERT INTO wine VALUES (941,'Tonnibrook',3,1984,270,NULL);
INSERT INTO wine VALUES (942,'Patton',2,1971,270,NULL);
INSERT INTO wine VALUES (943,'Woodburne',6,1996,270,NULL);
INSERT INTO wine VALUES (944,'Nancarral',4,1979,270,NULL);
INSERT INTO wine VALUES (945,'Mettaxus',6,1983,270,NULL);
INSERT INTO wine VALUES (946,'Woodburne',5,1975,271,NULL);
INSERT INTO wine VALUES (947,'Sears',6,1973,271,NULL);
INSERT INTO wine VALUES (948,'Triskit',6,1995,271,NULL);
INSERT INTO wine VALUES (949,'Galti',3,1993,271,NULL);
INSERT INTO wine VALUES (950,'Nancarral',5,1974,271,NULL);
INSERT INTO wine VALUES (951,'Sorrenti',5,1993,271,NULL);
INSERT INTO wine VALUES (952,'Tonnibrook',5,1988,272,NULL);
INSERT INTO wine VALUES (953,'Marzalla',3,1993,272,NULL);
INSERT INTO wine VALUES (954,'Sears',5,1973,273,NULL);
INSERT INTO wine VALUES (955,'Dimitria',3,1985,273,NULL);
INSERT INTO wine VALUES (956,'Marzalla',3,1995,273,NULL);
INSERT INTO wine VALUES (957,'Ruscina',5,1973,274,NULL);
INSERT INTO wine VALUES (958,'Serrong',5,1990,274,NULL);
INSERT INTO wine VALUES (959,'Cassisi',5,1975,274,NULL);
INSERT INTO wine VALUES (960,'Krennan',2,1996,274,NULL);
INSERT INTO wine VALUES (961,'Rosenthal',5,1972,275,NULL);
INSERT INTO wine VALUES (962,'Woodestock',2,1998,275,NULL);
INSERT INTO wine VALUES (963,'Tonnibrook',6,1983,275,NULL);
INSERT INTO wine VALUES (964,'Cassisi',6,1978,276,NULL);
INSERT INTO wine VALUES (965,'Taggendharf',6,1984,276,NULL);
INSERT INTO wine VALUES (966,'Dalion',2,1997,276,NULL);
INSERT INTO wine VALUES (967,'Keisling',6,1978,277,NULL);
INSERT INTO wine VALUES (968,'Mellaseca',5,1978,277,NULL);
INSERT INTO wine VALUES (969,'Belcombe',3,1999,277,NULL);
INSERT INTO wine VALUES (970,'Krennan',5,1985,277,NULL);
INSERT INTO wine VALUES (971,'Ritterman',3,1999,277,NULL);
INSERT INTO wine VALUES (972,'Sears',5,1989,277,NULL);
INSERT INTO wine VALUES (973,'Barneshaw',2,1989,278,NULL);
INSERT INTO wine VALUES (974,'Oaton',5,1972,278,NULL);
INSERT INTO wine VALUES (975,'Skerry',6,1997,278,NULL);
INSERT INTO wine VALUES (976,'Galti',5,1974,279,NULL);
INSERT INTO wine VALUES (977,'Titshall',6,1984,279,NULL);
INSERT INTO wine VALUES (978,'Stribling',3,1994,279,NULL);
INSERT INTO wine VALUES (979,'Skerry',2,1981,279,NULL);
INSERT INTO wine VALUES (980,'Tonkin',6,1998,279,NULL);
INSERT INTO wine VALUES (981,'Nancarral',5,1993,279,NULL);
INSERT INTO wine VALUES (982,'Marzalla',2,1987,280,NULL);
INSERT INTO wine VALUES (983,'Woodestock',3,1998,281,NULL);
INSERT INTO wine VALUES (984,'Ruscina',2,1977,281,NULL);
INSERT INTO wine VALUES (985,'Chester',5,1981,281,NULL);
INSERT INTO wine VALUES (986,'Chester',4,1971,281,NULL);
INSERT INTO wine VALUES (987,'Sears',6,1977,282,NULL);
INSERT INTO wine VALUES (988,'Galti',3,1998,282,NULL);
INSERT INTO wine VALUES (989,'Ruscina',6,1982,282,NULL);
INSERT INTO wine VALUES (990,'Kinsala',2,1992,283,NULL);
INSERT INTO wine VALUES (991,'Sorrenti',6,1970,284,NULL);
INSERT INTO wine VALUES (992,'Cassisi',6,1992,284,NULL);
INSERT INTO wine VALUES (993,'Patton',5,1981,284,NULL);
INSERT INTO wine VALUES (994,'Eggelston',5,1977,284,NULL);
INSERT INTO wine VALUES (995,'Cassisi',5,1975,284,NULL);
INSERT INTO wine VALUES (996,'Barneshaw',2,1982,285,NULL);
INSERT INTO wine VALUES (997,'Sorrenti',5,1986,286,NULL);
INSERT INTO wine VALUES (998,'Mellaseca',6,1995,286,NULL);
INSERT INTO wine VALUES (999,'Cassisi',5,1985,286,NULL);
INSERT INTO wine VALUES (1000,'Triskit',6,1993,286,NULL);
INSERT INTO wine VALUES (1001,'Mellili',5,1991,286,NULL);
INSERT INTO wine VALUES (1002,'Rosenthal',3,1983,287,NULL);
INSERT INTO wine VALUES (1003,'Mellili',6,1984,287,NULL);
INSERT INTO wine VALUES (1004,'Mellaseca',6,1981,288,NULL);
INSERT INTO wine VALUES (1005,'Mellaseca',3,1990,288,NULL);
INSERT INTO wine VALUES (1006,'Chemnis',5,1992,288,NULL);
INSERT INTO wine VALUES (1007,'Chemnis',3,1977,288,NULL);
INSERT INTO wine VALUES (1008,'Chemnis',5,1985,288,NULL);
INSERT INTO wine VALUES (1009,'Nancarral',3,1971,289,NULL);
INSERT INTO wine VALUES (1010,'Tonnibrook',6,1978,289,NULL);
INSERT INTO wine VALUES (1011,'Triskit',5,1977,289,NULL);
INSERT INTO wine VALUES (1012,'Galti',6,1999,289,NULL);
INSERT INTO wine VALUES (1013,'Dimitria',3,1980,289,NULL);
INSERT INTO wine VALUES (1014,'Cassisi',4,1988,290,NULL);
INSERT INTO wine VALUES (1015,'Rosenthal',5,1988,290,NULL);
INSERT INTO wine VALUES (1016,'Chemnis',6,1981,290,NULL);
INSERT INTO wine VALUES (1017,'Mockridge',6,1987,290,NULL);
INSERT INTO wine VALUES (1018,'Skerry',2,1998,291,NULL);
INSERT INTO wine VALUES (1019,'Sorrenti',5,1996,291,NULL);
INSERT INTO wine VALUES (1020,'Galti',2,1994,291,NULL);
INSERT INTO wine VALUES (1021,'Chester',5,1971,291,NULL);
INSERT INTO wine VALUES (1022,'Krennan',3,1995,291,NULL);
INSERT INTO wine VALUES (1023,'Serrong',6,1975,292,NULL);
INSERT INTO wine VALUES (1024,'Serrong',5,1983,292,NULL);
INSERT INTO wine VALUES (1025,'Holdenson',6,1978,292,NULL);
INSERT INTO wine VALUES (1026,'Sears',6,1986,292,NULL);
INSERT INTO wine VALUES (1027,'Ruscina',3,1986,293,NULL);
INSERT INTO wine VALUES (1028,'Pattendon',6,1993,293,NULL);
INSERT INTO wine VALUES (1029,'Taggendharf',2,1994,293,NULL);
INSERT INTO wine VALUES (1030,'Mettaxus',5,1997,293,NULL);
INSERT INTO wine VALUES (1031,'Belcombe',3,1977,293,NULL);
INSERT INTO wine VALUES (1032,'Tonkin',4,1987,294,NULL);
INSERT INTO wine VALUES (1033,'Rosenthal',5,1979,294,NULL);
INSERT INTO wine VALUES (1034,'Taggendharf',2,1978,294,NULL);
INSERT INTO wine VALUES (1035,'Mellili',3,1989,295,NULL);
INSERT INTO wine VALUES (1036,'Archibald',5,1997,296,NULL);
INSERT INTO wine VALUES (1037,'Oaton',6,1985,296,NULL);
INSERT INTO wine VALUES (1038,'Keisling',2,1989,296,NULL);
INSERT INTO wine VALUES (1039,'Triskit',2,1989,296,NULL);
INSERT INTO wine VALUES (1040,'Skerry',2,1975,297,NULL);
INSERT INTO wine VALUES (1041,'Tonnibrook',2,1984,297,NULL);
INSERT INTO wine VALUES (1042,'Sears',6,1998,298,NULL);
INSERT INTO wine VALUES (1043,'Ruscina',6,1974,298,NULL);
INSERT INTO wine VALUES (1044,'Woodestock',3,1999,298,NULL);
INSERT INTO wine VALUES (1045,'Tonkin',3,1988,298,NULL);
INSERT INTO wine VALUES (1046,'Leramonth',6,1972,298,NULL);
INSERT INTO wine VALUES (1047,'Mettaxus',4,1984,299,NULL);
INSERT INTO wine VALUES (1048,'Titshall',5,1983,300,NULL);

INSERT INTO wine_variety VALUES (1,19,1);
INSERT INTO wine_variety VALUES (1,20,2);
INSERT INTO wine_variety VALUES (2,16,1);
INSERT INTO wine_variety VALUES (3,14,1);
INSERT INTO wine_variety VALUES (4,18,1);
INSERT INTO wine_variety VALUES (5,5,1);
INSERT INTO wine_variety VALUES (5,3,2);
INSERT INTO wine_variety VALUES (5,4,3);
INSERT INTO wine_variety VALUES (6,12,1);
INSERT INTO wine_variety VALUES (6,11,2);
INSERT INTO wine_variety VALUES (7,6,1);
INSERT INTO wine_variety VALUES (7,7,2);
INSERT INTO wine_variety VALUES (8,14,1);
INSERT INTO wine_variety VALUES (9,16,1);
INSERT INTO wine_variety VALUES (10,2,1);
INSERT INTO wine_variety VALUES (11,18,1);
INSERT INTO wine_variety VALUES (12,11,1);
INSERT INTO wine_variety VALUES (12,13,2);
INSERT INTO wine_variety VALUES (13,19,1);
INSERT INTO wine_variety VALUES (13,21,2);
INSERT INTO wine_variety VALUES (14,2,1);
INSERT INTO wine_variety VALUES (15,15,1);
INSERT INTO wine_variety VALUES (16,17,1);
INSERT INTO wine_variety VALUES (17,3,1);
INSERT INTO wine_variety VALUES (17,4,2);
INSERT INTO wine_variety VALUES (18,1,1);
INSERT INTO wine_variety VALUES (19,14,1);
INSERT INTO wine_variety VALUES (20,18,1);
INSERT INTO wine_variety VALUES (21,15,1);
INSERT INTO wine_variety VALUES (22,16,1);
INSERT INTO wine_variety VALUES (23,14,1);
INSERT INTO wine_variety VALUES (24,17,1);
INSERT INTO wine_variety VALUES (25,5,1);
INSERT INTO wine_variety VALUES (26,9,1);
INSERT INTO wine_variety VALUES (27,13,1);
INSERT INTO wine_variety VALUES (28,11,1);
INSERT INTO wine_variety VALUES (28,3,2);
INSERT INTO wine_variety VALUES (29,19,1);
INSERT INTO wine_variety VALUES (29,20,2);
INSERT INTO wine_variety VALUES (30,6,1);
INSERT INTO wine_variety VALUES (30,7,2);
INSERT INTO wine_variety VALUES (31,11,1);
INSERT INTO wine_variety VALUES (31,13,2);
INSERT INTO wine_variety VALUES (32,11,1);
INSERT INTO wine_variety VALUES (32,3,2);
INSERT INTO wine_variety VALUES (33,18,1);
INSERT INTO wine_variety VALUES (34,14,1);
INSERT INTO wine_variety VALUES (35,14,1);
INSERT INTO wine_variety VALUES (36,18,1);
INSERT INTO wine_variety VALUES (37,13,1);
INSERT INTO wine_variety VALUES (38,12,1);
INSERT INTO wine_variety VALUES (38,11,2);
INSERT INTO wine_variety VALUES (39,16,1);
INSERT INTO wine_variety VALUES (40,5,1);
INSERT INTO wine_variety VALUES (40,3,2);
INSERT INTO wine_variety VALUES (40,4,3);
INSERT INTO wine_variety VALUES (41,11,1);
INSERT INTO wine_variety VALUES (41,13,2);
INSERT INTO wine_variety VALUES (42,17,1);
INSERT INTO wine_variety VALUES (43,6,1);
INSERT INTO wine_variety VALUES (43,10,2);
INSERT INTO wine_variety VALUES (44,14,1);
INSERT INTO wine_variety VALUES (45,16,1);
INSERT INTO wine_variety VALUES (46,16,1);
INSERT INTO wine_variety VALUES (47,12,1);
INSERT INTO wine_variety VALUES (47,11,2);
INSERT INTO wine_variety VALUES (47,13,3);
INSERT INTO wine_variety VALUES (48,17,1);
INSERT INTO wine_variety VALUES (49,16,1);
INSERT INTO wine_variety VALUES (50,1,1);
INSERT INTO wine_variety VALUES (51,14,1);
INSERT INTO wine_variety VALUES (52,12,1);
INSERT INTO wine_variety VALUES (52,11,2);
INSERT INTO wine_variety VALUES (53,9,1);
INSERT INTO wine_variety VALUES (54,18,1);
INSERT INTO wine_variety VALUES (55,17,1);
INSERT INTO wine_variety VALUES (56,15,1);
INSERT INTO wine_variety VALUES (57,19,1);
INSERT INTO wine_variety VALUES (57,20,2);
INSERT INTO wine_variety VALUES (58,17,1);
INSERT INTO wine_variety VALUES (59,2,1);
INSERT INTO wine_variety VALUES (60,12,1);
INSERT INTO wine_variety VALUES (60,11,2);
INSERT INTO wine_variety VALUES (61,17,1);
INSERT INTO wine_variety VALUES (62,9,1);
INSERT INTO wine_variety VALUES (63,18,1);
INSERT INTO wine_variety VALUES (64,19,1);
INSERT INTO wine_variety VALUES (64,21,2);
INSERT INTO wine_variety VALUES (65,15,1);
INSERT INTO wine_variety VALUES (66,1,1);
INSERT INTO wine_variety VALUES (67,15,1);
INSERT INTO wine_variety VALUES (68,3,1);
INSERT INTO wine_variety VALUES (68,4,2);
INSERT INTO wine_variety VALUES (69,12,1);
INSERT INTO wine_variety VALUES (70,17,1);
INSERT INTO wine_variety VALUES (71,6,1);
INSERT INTO wine_variety VALUES (71,7,2);
INSERT INTO wine_variety VALUES (72,17,1);
INSERT INTO wine_variety VALUES (73,15,1);
INSERT INTO wine_variety VALUES (74,5,1);
INSERT INTO wine_variety VALUES (75,18,1);
INSERT INTO wine_variety VALUES (76,15,1);
INSERT INTO wine_variety VALUES (77,14,1);
INSERT INTO wine_variety VALUES (78,17,1);
INSERT INTO wine_variety VALUES (79,19,1);
INSERT INTO wine_variety VALUES (79,21,2);
INSERT INTO wine_variety VALUES (80,16,1);
INSERT INTO wine_variety VALUES (81,2,1);
INSERT INTO wine_variety VALUES (82,5,1);
INSERT INTO wine_variety VALUES (83,15,1);
INSERT INTO wine_variety VALUES (84,14,1);
INSERT INTO wine_variety VALUES (85,5,1);
INSERT INTO wine_variety VALUES (85,3,2);
INSERT INTO wine_variety VALUES (85,4,3);
INSERT INTO wine_variety VALUES (86,12,1);
INSERT INTO wine_variety VALUES (86,11,2);
INSERT INTO wine_variety VALUES (87,16,1);
INSERT INTO wine_variety VALUES (88,19,1);
INSERT INTO wine_variety VALUES (88,20,2);
INSERT INTO wine_variety VALUES (89,3,1);
INSERT INTO wine_variety VALUES (89,4,2);
INSERT INTO wine_variety VALUES (90,12,1);
INSERT INTO wine_variety VALUES (90,11,2);
INSERT INTO wine_variety VALUES (91,12,1);
INSERT INTO wine_variety VALUES (92,12,1);
INSERT INTO wine_variety VALUES (92,11,2);
INSERT INTO wine_variety VALUES (93,12,1);
INSERT INTO wine_variety VALUES (93,11,2);
INSERT INTO wine_variety VALUES (93,13,3);
INSERT INTO wine_variety VALUES (94,3,1);
INSERT INTO wine_variety VALUES (94,4,2);
INSERT INTO wine_variety VALUES (95,5,1);
INSERT INTO wine_variety VALUES (95,3,2);
INSERT INTO wine_variety VALUES (95,4,3);
INSERT INTO wine_variety VALUES (96,16,1);
INSERT INTO wine_variety VALUES (97,5,1);
INSERT INTO wine_variety VALUES (97,3,2);
INSERT INTO wine_variety VALUES (97,4,3);
INSERT INTO wine_variety VALUES (98,11,1);
INSERT INTO wine_variety VALUES (98,3,2);
INSERT INTO wine_variety VALUES (99,11,1);
INSERT INTO wine_variety VALUES (99,3,2);
INSERT INTO wine_variety VALUES (100,3,1);
INSERT INTO wine_variety VALUES (100,4,2);
INSERT INTO wine_variety VALUES (101,9,1);
INSERT INTO wine_variety VALUES (102,3,1);
INSERT INTO wine_variety VALUES (102,4,2);
INSERT INTO wine_variety VALUES (103,19,1);
INSERT INTO wine_variety VALUES (103,20,2);
INSERT INTO wine_variety VALUES (104,17,1);
INSERT INTO wine_variety VALUES (105,5,1);
INSERT INTO wine_variety VALUES (106,16,1);
INSERT INTO wine_variety VALUES (107,18,1);
INSERT INTO wine_variety VALUES (108,6,1);
INSERT INTO wine_variety VALUES (108,10,2);
INSERT INTO wine_variety VALUES (109,17,1);
INSERT INTO wine_variety VALUES (110,11,1);
INSERT INTO wine_variety VALUES (110,13,2);
INSERT INTO wine_variety VALUES (111,1,1);
INSERT INTO wine_variety VALUES (112,11,1);
INSERT INTO wine_variety VALUES (112,3,2);
INSERT INTO wine_variety VALUES (113,3,1);
INSERT INTO wine_variety VALUES (113,4,2);
INSERT INTO wine_variety VALUES (114,14,1);
INSERT INTO wine_variety VALUES (115,11,1);
INSERT INTO wine_variety VALUES (115,3,2);
INSERT INTO wine_variety VALUES (116,18,1);
INSERT INTO wine_variety VALUES (117,11,1);
INSERT INTO wine_variety VALUES (117,3,2);
INSERT INTO wine_variety VALUES (118,8,1);
INSERT INTO wine_variety VALUES (119,16,1);
INSERT INTO wine_variety VALUES (120,16,1);
INSERT INTO wine_variety VALUES (121,15,1);
INSERT INTO wine_variety VALUES (122,9,1);
INSERT INTO wine_variety VALUES (123,19,1);
INSERT INTO wine_variety VALUES (123,20,2);
INSERT INTO wine_variety VALUES (124,15,1);
INSERT INTO wine_variety VALUES (125,15,1);
INSERT INTO wine_variety VALUES (126,6,1);
INSERT INTO wine_variety VALUES (126,7,2);
INSERT INTO wine_variety VALUES (127,19,1);
INSERT INTO wine_variety VALUES (127,21,2);
INSERT INTO wine_variety VALUES (128,6,1);
INSERT INTO wine_variety VALUES (128,10,2);
INSERT INTO wine_variety VALUES (129,12,1);
INSERT INTO wine_variety VALUES (129,11,2);
INSERT INTO wine_variety VALUES (130,19,1);
INSERT INTO wine_variety VALUES (130,21,2);
INSERT INTO wine_variety VALUES (131,8,1);
INSERT INTO wine_variety VALUES (132,14,1);
INSERT INTO wine_variety VALUES (133,8,1);
INSERT INTO wine_variety VALUES (134,14,1);
INSERT INTO wine_variety VALUES (135,5,1);
INSERT INTO wine_variety VALUES (136,1,1);
INSERT INTO wine_variety VALUES (137,12,1);
INSERT INTO wine_variety VALUES (138,19,1);
INSERT INTO wine_variety VALUES (138,20,2);
INSERT INTO wine_variety VALUES (139,12,1);
INSERT INTO wine_variety VALUES (139,11,2);
INSERT INTO wine_variety VALUES (140,5,1);
INSERT INTO wine_variety VALUES (140,3,2);
INSERT INTO wine_variety VALUES (140,4,3);
INSERT INTO wine_variety VALUES (141,19,1);
INSERT INTO wine_variety VALUES (141,20,2);
INSERT INTO wine_variety VALUES (142,12,1);
INSERT INTO wine_variety VALUES (143,1,1);
INSERT INTO wine_variety VALUES (144,5,1);
INSERT INTO wine_variety VALUES (144,3,2);
INSERT INTO wine_variety VALUES (144,4,3);
INSERT INTO wine_variety VALUES (145,13,1);
INSERT INTO wine_variety VALUES (146,3,1);
INSERT INTO wine_variety VALUES (146,4,2);
INSERT INTO wine_variety VALUES (147,11,1);
INSERT INTO wine_variety VALUES (147,13,2);
INSERT INTO wine_variety VALUES (148,5,1);
INSERT INTO wine_variety VALUES (148,3,2);
INSERT INTO wine_variety VALUES (148,4,3);
INSERT INTO wine_variety VALUES (149,1,1);
INSERT INTO wine_variety VALUES (150,15,1);
INSERT INTO wine_variety VALUES (151,1,1);
INSERT INTO wine_variety VALUES (152,19,1);
INSERT INTO wine_variety VALUES (152,21,2);
INSERT INTO wine_variety VALUES (153,8,1);
INSERT INTO wine_variety VALUES (154,11,1);
INSERT INTO wine_variety VALUES (154,3,2);
INSERT INTO wine_variety VALUES (155,3,1);
INSERT INTO wine_variety VALUES (155,4,2);
INSERT INTO wine_variety VALUES (156,5,1);
INSERT INTO wine_variety VALUES (156,3,2);
INSERT INTO wine_variety VALUES (156,4,3);
INSERT INTO wine_variety VALUES (157,16,1);
INSERT INTO wine_variety VALUES (158,11,1);
INSERT INTO wine_variety VALUES (158,3,2);
INSERT INTO wine_variety VALUES (159,6,1);
INSERT INTO wine_variety VALUES (159,7,2);
INSERT INTO wine_variety VALUES (160,9,1);
INSERT INTO wine_variety VALUES (161,18,1);
INSERT INTO wine_variety VALUES (162,19,1);
INSERT INTO wine_variety VALUES (162,21,2);
INSERT INTO wine_variety VALUES (163,8,1);
INSERT INTO wine_variety VALUES (164,19,1);
INSERT INTO wine_variety VALUES (164,20,2);
INSERT INTO wine_variety VALUES (165,19,1);
INSERT INTO wine_variety VALUES (165,21,2);
INSERT INTO wine_variety VALUES (166,5,1);
INSERT INTO wine_variety VALUES (166,3,2);
INSERT INTO wine_variety VALUES (166,4,3);
INSERT INTO wine_variety VALUES (167,6,1);
INSERT INTO wine_variety VALUES (167,10,2);
INSERT INTO wine_variety VALUES (168,9,1);
INSERT INTO wine_variety VALUES (169,19,1);
INSERT INTO wine_variety VALUES (169,21,2);
INSERT INTO wine_variety VALUES (170,19,1);
INSERT INTO wine_variety VALUES (170,21,2);
INSERT INTO wine_variety VALUES (171,6,1);
INSERT INTO wine_variety VALUES (171,10,2);
INSERT INTO wine_variety VALUES (172,9,1);
INSERT INTO wine_variety VALUES (173,18,1);
INSERT INTO wine_variety VALUES (174,5,1);
INSERT INTO wine_variety VALUES (175,5,1);
INSERT INTO wine_variety VALUES (175,3,2);
INSERT INTO wine_variety VALUES (175,4,3);
INSERT INTO wine_variety VALUES (176,19,1);
INSERT INTO wine_variety VALUES (176,21,2);
INSERT INTO wine_variety VALUES (177,1,1);
INSERT INTO wine_variety VALUES (178,15,1);
INSERT INTO wine_variety VALUES (179,6,1);
INSERT INTO wine_variety VALUES (179,10,2);
INSERT INTO wine_variety VALUES (180,19,1);
INSERT INTO wine_variety VALUES (180,20,2);
INSERT INTO wine_variety VALUES (181,2,1);
INSERT INTO wine_variety VALUES (182,12,1);
INSERT INTO wine_variety VALUES (182,11,2);
INSERT INTO wine_variety VALUES (182,13,3);
INSERT INTO wine_variety VALUES (183,14,1);
INSERT INTO wine_variety VALUES (184,19,1);
INSERT INTO wine_variety VALUES (184,20,2);
INSERT INTO wine_variety VALUES (185,9,1);
INSERT INTO wine_variety VALUES (186,11,1);
INSERT INTO wine_variety VALUES (186,13,2);
INSERT INTO wine_variety VALUES (187,5,1);
INSERT INTO wine_variety VALUES (188,17,1);
INSERT INTO wine_variety VALUES (189,14,1);
INSERT INTO wine_variety VALUES (190,1,1);
INSERT INTO wine_variety VALUES (191,9,1);
INSERT INTO wine_variety VALUES (192,11,1);
INSERT INTO wine_variety VALUES (192,3,2);
INSERT INTO wine_variety VALUES (193,9,1);
INSERT INTO wine_variety VALUES (194,1,1);
INSERT INTO wine_variety VALUES (195,19,1);
INSERT INTO wine_variety VALUES (195,21,2);
INSERT INTO wine_variety VALUES (196,15,1);
INSERT INTO wine_variety VALUES (197,19,1);
INSERT INTO wine_variety VALUES (197,21,2);
INSERT INTO wine_variety VALUES (198,18,1);
INSERT INTO wine_variety VALUES (199,14,1);
INSERT INTO wine_variety VALUES (200,19,1);
INSERT INTO wine_variety VALUES (200,21,2);
INSERT INTO wine_variety VALUES (201,11,1);
INSERT INTO wine_variety VALUES (201,3,2);
INSERT INTO wine_variety VALUES (202,14,1);
INSERT INTO wine_variety VALUES (203,3,1);
INSERT INTO wine_variety VALUES (203,4,2);
INSERT INTO wine_variety VALUES (204,5,1);
INSERT INTO wine_variety VALUES (205,12,1);
INSERT INTO wine_variety VALUES (205,11,2);
INSERT INTO wine_variety VALUES (206,3,1);
INSERT INTO wine_variety VALUES (206,4,2);
INSERT INTO wine_variety VALUES (207,1,1);
INSERT INTO wine_variety VALUES (208,16,1);
INSERT INTO wine_variety VALUES (209,6,1);
INSERT INTO wine_variety VALUES (209,7,2);
INSERT INTO wine_variety VALUES (210,12,1);
INSERT INTO wine_variety VALUES (210,11,2);
INSERT INTO wine_variety VALUES (211,16,1);
INSERT INTO wine_variety VALUES (212,11,1);
INSERT INTO wine_variety VALUES (212,3,2);
INSERT INTO wine_variety VALUES (213,11,1);
INSERT INTO wine_variety VALUES (213,13,2);
INSERT INTO wine_variety VALUES (214,11,1);
INSERT INTO wine_variety VALUES (214,3,2);
INSERT INTO wine_variety VALUES (215,9,1);
INSERT INTO wine_variety VALUES (216,17,1);
INSERT INTO wine_variety VALUES (217,8,1);
INSERT INTO wine_variety VALUES (218,6,1);
INSERT INTO wine_variety VALUES (218,10,2);
INSERT INTO wine_variety VALUES (219,16,1);
INSERT INTO wine_variety VALUES (220,6,1);
INSERT INTO wine_variety VALUES (220,10,2);
INSERT INTO wine_variety VALUES (221,17,1);
INSERT INTO wine_variety VALUES (222,2,1);
INSERT INTO wine_variety VALUES (223,8,1);
INSERT INTO wine_variety VALUES (224,19,1);
INSERT INTO wine_variety VALUES (224,20,2);
INSERT INTO wine_variety VALUES (225,18,1);
INSERT INTO wine_variety VALUES (226,14,1);
INSERT INTO wine_variety VALUES (227,12,1);
INSERT INTO wine_variety VALUES (228,1,1);
INSERT INTO wine_variety VALUES (229,12,1);
INSERT INTO wine_variety VALUES (229,11,2);
INSERT INTO wine_variety VALUES (230,19,1);
INSERT INTO wine_variety VALUES (230,20,2);
INSERT INTO wine_variety VALUES (231,6,1);
INSERT INTO wine_variety VALUES (231,10,2);
INSERT INTO wine_variety VALUES (232,16,1);
INSERT INTO wine_variety VALUES (233,11,1);
INSERT INTO wine_variety VALUES (233,13,2);
INSERT INTO wine_variety VALUES (234,5,1);
INSERT INTO wine_variety VALUES (234,3,2);
INSERT INTO wine_variety VALUES (234,4,3);
INSERT INTO wine_variety VALUES (235,17,1);
INSERT INTO wine_variety VALUES (236,17,1);
INSERT INTO wine_variety VALUES (237,9,1);
INSERT INTO wine_variety VALUES (238,18,1);
INSERT INTO wine_variety VALUES (239,3,1);
INSERT INTO wine_variety VALUES (239,4,2);
INSERT INTO wine_variety VALUES (240,8,1);
INSERT INTO wine_variety VALUES (241,3,1);
INSERT INTO wine_variety VALUES (241,4,2);
INSERT INTO wine_variety VALUES (242,2,1);
INSERT INTO wine_variety VALUES (243,16,1);
INSERT INTO wine_variety VALUES (244,2,1);
INSERT INTO wine_variety VALUES (245,12,1);
INSERT INTO wine_variety VALUES (246,9,1);
INSERT INTO wine_variety VALUES (247,16,1);
INSERT INTO wine_variety VALUES (248,17,1);
INSERT INTO wine_variety VALUES (249,11,1);
INSERT INTO wine_variety VALUES (249,13,2);
INSERT INTO wine_variety VALUES (250,14,1);
INSERT INTO wine_variety VALUES (251,19,1);
INSERT INTO wine_variety VALUES (251,20,2);
INSERT INTO wine_variety VALUES (252,13,1);
INSERT INTO wine_variety VALUES (253,16,1);
INSERT INTO wine_variety VALUES (254,12,1);
INSERT INTO wine_variety VALUES (255,11,1);
INSERT INTO wine_variety VALUES (255,13,2);
INSERT INTO wine_variety VALUES (256,18,1);
INSERT INTO wine_variety VALUES (257,12,1);
INSERT INTO wine_variety VALUES (257,11,2);
INSERT INTO wine_variety VALUES (258,18,1);
INSERT INTO wine_variety VALUES (259,19,1);
INSERT INTO wine_variety VALUES (259,20,2);
INSERT INTO wine_variety VALUES (260,12,1);
INSERT INTO wine_variety VALUES (261,9,1);
INSERT INTO wine_variety VALUES (262,18,1);
INSERT INTO wine_variety VALUES (263,2,1);
INSERT INTO wine_variety VALUES (264,19,1);
INSERT INTO wine_variety VALUES (264,20,2);
INSERT INTO wine_variety VALUES (265,18,1);
INSERT INTO wine_variety VALUES (266,3,1);
INSERT INTO wine_variety VALUES (266,4,2);
INSERT INTO wine_variety VALUES (267,2,1);
INSERT INTO wine_variety VALUES (268,14,1);
INSERT INTO wine_variety VALUES (269,15,1);
INSERT INTO wine_variety VALUES (270,19,1);
INSERT INTO wine_variety VALUES (270,20,2);
INSERT INTO wine_variety VALUES (271,16,1);
INSERT INTO wine_variety VALUES (272,1,1);
INSERT INTO wine_variety VALUES (273,19,1);
INSERT INTO wine_variety VALUES (273,21,2);
INSERT INTO wine_variety VALUES (274,17,1);
INSERT INTO wine_variety VALUES (275,11,1);
INSERT INTO wine_variety VALUES (275,13,2);
INSERT INTO wine_variety VALUES (276,1,1);
INSERT INTO wine_variety VALUES (277,5,1);
INSERT INTO wine_variety VALUES (277,3,2);
INSERT INTO wine_variety VALUES (277,4,3);
INSERT INTO wine_variety VALUES (278,14,1);
INSERT INTO wine_variety VALUES (279,15,1);
INSERT INTO wine_variety VALUES (280,17,1);
INSERT INTO wine_variety VALUES (281,17,1);
INSERT INTO wine_variety VALUES (282,17,1);
INSERT INTO wine_variety VALUES (283,19,1);
INSERT INTO wine_variety VALUES (283,20,2);
INSERT INTO wine_variety VALUES (284,19,1);
INSERT INTO wine_variety VALUES (284,20,2);
INSERT INTO wine_variety VALUES (285,14,1);
INSERT INTO wine_variety VALUES (286,19,1);
INSERT INTO wine_variety VALUES (286,21,2);
INSERT INTO wine_variety VALUES (287,5,1);
INSERT INTO wine_variety VALUES (287,3,2);
INSERT INTO wine_variety VALUES (287,4,3);
INSERT INTO wine_variety VALUES (288,6,1);
INSERT INTO wine_variety VALUES (288,10,2);
INSERT INTO wine_variety VALUES (289,15,1);
INSERT INTO wine_variety VALUES (290,19,1);
INSERT INTO wine_variety VALUES (290,21,2);
INSERT INTO wine_variety VALUES (291,19,1);
INSERT INTO wine_variety VALUES (291,20,2);
INSERT INTO wine_variety VALUES (292,18,1);
INSERT INTO wine_variety VALUES (293,2,1);
INSERT INTO wine_variety VALUES (294,14,1);
INSERT INTO wine_variety VALUES (295,8,1);
INSERT INTO wine_variety VALUES (296,13,1);
INSERT INTO wine_variety VALUES (297,14,1);
INSERT INTO wine_variety VALUES (298,14,1);
INSERT INTO wine_variety VALUES (299,5,1);
INSERT INTO wine_variety VALUES (300,8,1);
INSERT INTO wine_variety VALUES (301,15,1);
INSERT INTO wine_variety VALUES (302,16,1);
INSERT INTO wine_variety VALUES (303,19,1);
INSERT INTO wine_variety VALUES (303,20,2);
INSERT INTO wine_variety VALUES (304,14,1);
INSERT INTO wine_variety VALUES (305,15,1);
INSERT INTO wine_variety VALUES (306,6,1);
INSERT INTO wine_variety VALUES (306,10,2);
INSERT INTO wine_variety VALUES (307,5,1);
INSERT INTO wine_variety VALUES (308,8,1);
INSERT INTO wine_variety VALUES (309,6,1);
INSERT INTO wine_variety VALUES (309,10,2);
INSERT INTO wine_variety VALUES (310,17,1);
INSERT INTO wine_variety VALUES (311,2,1);
INSERT INTO wine_variety VALUES (312,2,1);
INSERT INTO wine_variety VALUES (313,17,1);
INSERT INTO wine_variety VALUES (314,12,1);
INSERT INTO wine_variety VALUES (314,11,2);
INSERT INTO wine_variety VALUES (315,12,1);
INSERT INTO wine_variety VALUES (315,11,2);
INSERT INTO wine_variety VALUES (316,17,1);
INSERT INTO wine_variety VALUES (317,6,1);
INSERT INTO wine_variety VALUES (317,7,2);
INSERT INTO wine_variety VALUES (318,3,1);
INSERT INTO wine_variety VALUES (318,4,2);
INSERT INTO wine_variety VALUES (319,18,1);
INSERT INTO wine_variety VALUES (320,9,1);
INSERT INTO wine_variety VALUES (321,11,1);
INSERT INTO wine_variety VALUES (321,3,2);
INSERT INTO wine_variety VALUES (322,16,1);
INSERT INTO wine_variety VALUES (323,2,1);
INSERT INTO wine_variety VALUES (324,12,1);
INSERT INTO wine_variety VALUES (325,19,1);
INSERT INTO wine_variety VALUES (325,21,2);
INSERT INTO wine_variety VALUES (326,19,1);
INSERT INTO wine_variety VALUES (326,20,2);
INSERT INTO wine_variety VALUES (327,19,1);
INSERT INTO wine_variety VALUES (327,21,2);
INSERT INTO wine_variety VALUES (328,12,1);
INSERT INTO wine_variety VALUES (328,11,2);
INSERT INTO wine_variety VALUES (328,13,3);
INSERT INTO wine_variety VALUES (329,12,1);
INSERT INTO wine_variety VALUES (329,11,2);
INSERT INTO wine_variety VALUES (329,13,3);
INSERT INTO wine_variety VALUES (330,5,1);
INSERT INTO wine_variety VALUES (331,19,1);
INSERT INTO wine_variety VALUES (331,20,2);
INSERT INTO wine_variety VALUES (332,14,1);
INSERT INTO wine_variety VALUES (333,17,1);
INSERT INTO wine_variety VALUES (334,11,1);
INSERT INTO wine_variety VALUES (334,13,2);
INSERT INTO wine_variety VALUES (335,8,1);
INSERT INTO wine_variety VALUES (336,12,1);
INSERT INTO wine_variety VALUES (337,18,1);
INSERT INTO wine_variety VALUES (338,15,1);
INSERT INTO wine_variety VALUES (339,6,1);
INSERT INTO wine_variety VALUES (339,7,2);
INSERT INTO wine_variety VALUES (340,18,1);
INSERT INTO wine_variety VALUES (341,19,1);
INSERT INTO wine_variety VALUES (341,21,2);
INSERT INTO wine_variety VALUES (342,5,1);
INSERT INTO wine_variety VALUES (342,3,2);
INSERT INTO wine_variety VALUES (342,4,3);
INSERT INTO wine_variety VALUES (343,18,1);
INSERT INTO wine_variety VALUES (344,15,1);
INSERT INTO wine_variety VALUES (345,15,1);
INSERT INTO wine_variety VALUES (346,9,1);
INSERT INTO wine_variety VALUES (347,5,1);
INSERT INTO wine_variety VALUES (348,13,1);
INSERT INTO wine_variety VALUES (349,14,1);
INSERT INTO wine_variety VALUES (350,19,1);
INSERT INTO wine_variety VALUES (350,21,2);
INSERT INTO wine_variety VALUES (351,18,1);
INSERT INTO wine_variety VALUES (352,16,1);
INSERT INTO wine_variety VALUES (353,17,1);
INSERT INTO wine_variety VALUES (354,14,1);
INSERT INTO wine_variety VALUES (355,6,1);
INSERT INTO wine_variety VALUES (355,7,2);
INSERT INTO wine_variety VALUES (356,19,1);
INSERT INTO wine_variety VALUES (356,21,2);
INSERT INTO wine_variety VALUES (357,9,1);
INSERT INTO wine_variety VALUES (358,5,1);
INSERT INTO wine_variety VALUES (359,12,1);
INSERT INTO wine_variety VALUES (360,12,1);
INSERT INTO wine_variety VALUES (360,11,2);
INSERT INTO wine_variety VALUES (360,13,3);
INSERT INTO wine_variety VALUES (361,18,1);
INSERT INTO wine_variety VALUES (362,12,1);
INSERT INTO wine_variety VALUES (362,11,2);
INSERT INTO wine_variety VALUES (363,14,1);
INSERT INTO wine_variety VALUES (364,14,1);
INSERT INTO wine_variety VALUES (365,5,1);
INSERT INTO wine_variety VALUES (365,3,2);
INSERT INTO wine_variety VALUES (365,4,3);
INSERT INTO wine_variety VALUES (366,12,1);
INSERT INTO wine_variety VALUES (366,11,2);
INSERT INTO wine_variety VALUES (367,5,1);
INSERT INTO wine_variety VALUES (367,3,2);
INSERT INTO wine_variety VALUES (367,4,3);
INSERT INTO wine_variety VALUES (368,5,1);
INSERT INTO wine_variety VALUES (368,3,2);
INSERT INTO wine_variety VALUES (368,4,3);
INSERT INTO wine_variety VALUES (369,14,1);
INSERT INTO wine_variety VALUES (370,19,1);
INSERT INTO wine_variety VALUES (370,21,2);
INSERT INTO wine_variety VALUES (371,8,1);
INSERT INTO wine_variety VALUES (372,16,1);
INSERT INTO wine_variety VALUES (373,14,1);
INSERT INTO wine_variety VALUES (374,5,1);
INSERT INTO wine_variety VALUES (375,5,1);
INSERT INTO wine_variety VALUES (375,3,2);
INSERT INTO wine_variety VALUES (375,4,3);
INSERT INTO wine_variety VALUES (376,5,1);
INSERT INTO wine_variety VALUES (377,5,1);
INSERT INTO wine_variety VALUES (377,3,2);
INSERT INTO wine_variety VALUES (377,4,3);
INSERT INTO wine_variety VALUES (378,17,1);
INSERT INTO wine_variety VALUES (379,19,1);
INSERT INTO wine_variety VALUES (379,20,2);
INSERT INTO wine_variety VALUES (380,19,1);
INSERT INTO wine_variety VALUES (380,21,2);
INSERT INTO wine_variety VALUES (381,11,1);
INSERT INTO wine_variety VALUES (381,3,2);
INSERT INTO wine_variety VALUES (382,18,1);
INSERT INTO wine_variety VALUES (383,16,1);
INSERT INTO wine_variety VALUES (384,13,1);
INSERT INTO wine_variety VALUES (385,14,1);
INSERT INTO wine_variety VALUES (386,8,1);
INSERT INTO wine_variety VALUES (387,14,1);
INSERT INTO wine_variety VALUES (388,12,1);
INSERT INTO wine_variety VALUES (389,12,1);
INSERT INTO wine_variety VALUES (389,11,2);
INSERT INTO wine_variety VALUES (390,11,1);
INSERT INTO wine_variety VALUES (390,3,2);
INSERT INTO wine_variety VALUES (391,15,1);
INSERT INTO wine_variety VALUES (392,5,1);
INSERT INTO wine_variety VALUES (393,14,1);
INSERT INTO wine_variety VALUES (394,8,1);
INSERT INTO wine_variety VALUES (395,5,1);
INSERT INTO wine_variety VALUES (395,3,2);
INSERT INTO wine_variety VALUES (395,4,3);
INSERT INTO wine_variety VALUES (396,11,1);
INSERT INTO wine_variety VALUES (396,13,2);
INSERT INTO wine_variety VALUES (397,18,1);
INSERT INTO wine_variety VALUES (398,1,1);
INSERT INTO wine_variety VALUES (399,3,1);
INSERT INTO wine_variety VALUES (399,4,2);
INSERT INTO wine_variety VALUES (400,15,1);
INSERT INTO wine_variety VALUES (401,11,1);
INSERT INTO wine_variety VALUES (401,13,2);
INSERT INTO wine_variety VALUES (402,8,1);
INSERT INTO wine_variety VALUES (403,18,1);
INSERT INTO wine_variety VALUES (404,16,1);
INSERT INTO wine_variety VALUES (405,6,1);
INSERT INTO wine_variety VALUES (405,10,2);
INSERT INTO wine_variety VALUES (406,12,1);
INSERT INTO wine_variety VALUES (406,11,2);
INSERT INTO wine_variety VALUES (407,14,1);
INSERT INTO wine_variety VALUES (408,19,1);
INSERT INTO wine_variety VALUES (408,21,2);
INSERT INTO wine_variety VALUES (409,18,1);
INSERT INTO wine_variety VALUES (410,11,1);
INSERT INTO wine_variety VALUES (410,3,2);
INSERT INTO wine_variety VALUES (411,12,1);
INSERT INTO wine_variety VALUES (411,11,2);
INSERT INTO wine_variety VALUES (411,13,3);
INSERT INTO wine_variety VALUES (412,18,1);
INSERT INTO wine_variety VALUES (413,17,1);
INSERT INTO wine_variety VALUES (414,5,1);
INSERT INTO wine_variety VALUES (414,3,2);
INSERT INTO wine_variety VALUES (414,4,3);
INSERT INTO wine_variety VALUES (415,6,1);
INSERT INTO wine_variety VALUES (415,10,2);
INSERT INTO wine_variety VALUES (416,12,1);
INSERT INTO wine_variety VALUES (416,11,2);
INSERT INTO wine_variety VALUES (416,13,3);
INSERT INTO wine_variety VALUES (417,6,1);
INSERT INTO wine_variety VALUES (417,10,2);
INSERT INTO wine_variety VALUES (418,14,1);
INSERT INTO wine_variety VALUES (419,18,1);
INSERT INTO wine_variety VALUES (420,5,1);
INSERT INTO wine_variety VALUES (421,2,1);
INSERT INTO wine_variety VALUES (422,11,1);
INSERT INTO wine_variety VALUES (422,13,2);
INSERT INTO wine_variety VALUES (423,14,1);
INSERT INTO wine_variety VALUES (424,12,1);
INSERT INTO wine_variety VALUES (425,15,1);
INSERT INTO wine_variety VALUES (426,6,1);
INSERT INTO wine_variety VALUES (426,10,2);
INSERT INTO wine_variety VALUES (427,8,1);
INSERT INTO wine_variety VALUES (428,14,1);
INSERT INTO wine_variety VALUES (429,5,1);
INSERT INTO wine_variety VALUES (430,11,1);
INSERT INTO wine_variety VALUES (430,13,2);
INSERT INTO wine_variety VALUES (431,19,1);
INSERT INTO wine_variety VALUES (431,21,2);
INSERT INTO wine_variety VALUES (432,1,1);
INSERT INTO wine_variety VALUES (433,19,1);
INSERT INTO wine_variety VALUES (433,20,2);
INSERT INTO wine_variety VALUES (434,12,1);
INSERT INTO wine_variety VALUES (434,11,2);
INSERT INTO wine_variety VALUES (435,6,1);
INSERT INTO wine_variety VALUES (435,7,2);
INSERT INTO wine_variety VALUES (436,19,1);
INSERT INTO wine_variety VALUES (436,21,2);
INSERT INTO wine_variety VALUES (437,15,1);
INSERT INTO wine_variety VALUES (438,6,1);
INSERT INTO wine_variety VALUES (438,10,2);
INSERT INTO wine_variety VALUES (439,12,1);
INSERT INTO wine_variety VALUES (440,5,1);
INSERT INTO wine_variety VALUES (441,2,1);
INSERT INTO wine_variety VALUES (442,5,1);
INSERT INTO wine_variety VALUES (443,11,1);
INSERT INTO wine_variety VALUES (443,13,2);
INSERT INTO wine_variety VALUES (444,6,1);
INSERT INTO wine_variety VALUES (444,10,2);
INSERT INTO wine_variety VALUES (445,17,1);
INSERT INTO wine_variety VALUES (446,16,1);
INSERT INTO wine_variety VALUES (447,19,1);
INSERT INTO wine_variety VALUES (447,20,2);
INSERT INTO wine_variety VALUES (448,18,1);
INSERT INTO wine_variety VALUES (449,12,1);
INSERT INTO wine_variety VALUES (449,11,2);
INSERT INTO wine_variety VALUES (449,13,3);
INSERT INTO wine_variety VALUES (450,14,1);
INSERT INTO wine_variety VALUES (451,12,1);
INSERT INTO wine_variety VALUES (451,11,2);
INSERT INTO wine_variety VALUES (452,14,1);
INSERT INTO wine_variety VALUES (453,16,1);
INSERT INTO wine_variety VALUES (454,5,1);
INSERT INTO wine_variety VALUES (455,6,1);
INSERT INTO wine_variety VALUES (455,7,2);
INSERT INTO wine_variety VALUES (456,18,1);
INSERT INTO wine_variety VALUES (457,5,1);
INSERT INTO wine_variety VALUES (457,3,2);
INSERT INTO wine_variety VALUES (457,4,3);
INSERT INTO wine_variety VALUES (458,18,1);
INSERT INTO wine_variety VALUES (459,9,1);
INSERT INTO wine_variety VALUES (460,6,1);
INSERT INTO wine_variety VALUES (460,7,2);
INSERT INTO wine_variety VALUES (461,16,1);
INSERT INTO wine_variety VALUES (462,19,1);
INSERT INTO wine_variety VALUES (462,20,2);
INSERT INTO wine_variety VALUES (463,11,1);
INSERT INTO wine_variety VALUES (463,3,2);
INSERT INTO wine_variety VALUES (464,17,1);
INSERT INTO wine_variety VALUES (465,9,1);
INSERT INTO wine_variety VALUES (466,6,1);
INSERT INTO wine_variety VALUES (466,7,2);
INSERT INTO wine_variety VALUES (467,19,1);
INSERT INTO wine_variety VALUES (467,21,2);
INSERT INTO wine_variety VALUES (468,12,1);
INSERT INTO wine_variety VALUES (468,11,2);
INSERT INTO wine_variety VALUES (468,13,3);
INSERT INTO wine_variety VALUES (469,14,1);
INSERT INTO wine_variety VALUES (470,3,1);
INSERT INTO wine_variety VALUES (470,4,2);
INSERT INTO wine_variety VALUES (471,8,1);
INSERT INTO wine_variety VALUES (472,5,1);
INSERT INTO wine_variety VALUES (473,12,1);
INSERT INTO wine_variety VALUES (473,11,2);
INSERT INTO wine_variety VALUES (473,13,3);
INSERT INTO wine_variety VALUES (474,14,1);
INSERT INTO wine_variety VALUES (475,19,1);
INSERT INTO wine_variety VALUES (475,20,2);
INSERT INTO wine_variety VALUES (476,12,1);
INSERT INTO wine_variety VALUES (477,6,1);
INSERT INTO wine_variety VALUES (477,7,2);
INSERT INTO wine_variety VALUES (478,17,1);
INSERT INTO wine_variety VALUES (479,11,1);
INSERT INTO wine_variety VALUES (479,3,2);
INSERT INTO wine_variety VALUES (480,12,1);
INSERT INTO wine_variety VALUES (480,11,2);
INSERT INTO wine_variety VALUES (481,17,1);
INSERT INTO wine_variety VALUES (482,14,1);
INSERT INTO wine_variety VALUES (483,17,1);
INSERT INTO wine_variety VALUES (484,11,1);
INSERT INTO wine_variety VALUES (484,3,2);
INSERT INTO wine_variety VALUES (485,1,1);
INSERT INTO wine_variety VALUES (486,2,1);
INSERT INTO wine_variety VALUES (487,9,1);
INSERT INTO wine_variety VALUES (488,1,1);
INSERT INTO wine_variety VALUES (489,2,1);
INSERT INTO wine_variety VALUES (490,17,1);
INSERT INTO wine_variety VALUES (491,14,1);
INSERT INTO wine_variety VALUES (492,18,1);
INSERT INTO wine_variety VALUES (493,2,1);
INSERT INTO wine_variety VALUES (494,17,1);
INSERT INTO wine_variety VALUES (495,6,1);
INSERT INTO wine_variety VALUES (495,7,2);
INSERT INTO wine_variety VALUES (496,14,1);
INSERT INTO wine_variety VALUES (497,14,1);
INSERT INTO wine_variety VALUES (498,15,1);
INSERT INTO wine_variety VALUES (499,6,1);
INSERT INTO wine_variety VALUES (499,10,2);
INSERT INTO wine_variety VALUES (500,16,1);
INSERT INTO wine_variety VALUES (501,11,1);
INSERT INTO wine_variety VALUES (501,13,2);
INSERT INTO wine_variety VALUES (502,16,1);
INSERT INTO wine_variety VALUES (503,6,1);
INSERT INTO wine_variety VALUES (503,10,2);
INSERT INTO wine_variety VALUES (504,18,1);
INSERT INTO wine_variety VALUES (505,12,1);
INSERT INTO wine_variety VALUES (506,6,1);
INSERT INTO wine_variety VALUES (506,7,2);
INSERT INTO wine_variety VALUES (507,1,1);
INSERT INTO wine_variety VALUES (508,19,1);
INSERT INTO wine_variety VALUES (508,21,2);
INSERT INTO wine_variety VALUES (509,13,1);
INSERT INTO wine_variety VALUES (510,12,1);
INSERT INTO wine_variety VALUES (510,11,2);
INSERT INTO wine_variety VALUES (510,13,3);
INSERT INTO wine_variety VALUES (511,16,1);
INSERT INTO wine_variety VALUES (512,18,1);
INSERT INTO wine_variety VALUES (513,2,1);
INSERT INTO wine_variety VALUES (514,18,1);
INSERT INTO wine_variety VALUES (515,12,1);
INSERT INTO wine_variety VALUES (516,19,1);
INSERT INTO wine_variety VALUES (516,20,2);
INSERT INTO wine_variety VALUES (517,12,1);
INSERT INTO wine_variety VALUES (518,5,1);
INSERT INTO wine_variety VALUES (519,2,1);
INSERT INTO wine_variety VALUES (520,13,1);
INSERT INTO wine_variety VALUES (521,8,1);
INSERT INTO wine_variety VALUES (522,17,1);
INSERT INTO wine_variety VALUES (523,19,1);
INSERT INTO wine_variety VALUES (523,21,2);
INSERT INTO wine_variety VALUES (524,1,1);
INSERT INTO wine_variety VALUES (525,19,1);
INSERT INTO wine_variety VALUES (525,21,2);
INSERT INTO wine_variety VALUES (526,12,1);
INSERT INTO wine_variety VALUES (526,11,2);
INSERT INTO wine_variety VALUES (527,9,1);
INSERT INTO wine_variety VALUES (528,11,1);
INSERT INTO wine_variety VALUES (528,3,2);
INSERT INTO wine_variety VALUES (529,12,1);
INSERT INTO wine_variety VALUES (529,11,2);
INSERT INTO wine_variety VALUES (529,13,3);
INSERT INTO wine_variety VALUES (530,12,1);
INSERT INTO wine_variety VALUES (531,11,1);
INSERT INTO wine_variety VALUES (531,13,2);
INSERT INTO wine_variety VALUES (532,11,1);
INSERT INTO wine_variety VALUES (532,3,2);
INSERT INTO wine_variety VALUES (533,8,1);
INSERT INTO wine_variety VALUES (534,11,1);
INSERT INTO wine_variety VALUES (534,3,2);
INSERT INTO wine_variety VALUES (535,17,1);
INSERT INTO wine_variety VALUES (536,19,1);
INSERT INTO wine_variety VALUES (536,21,2);
INSERT INTO wine_variety VALUES (537,11,1);
INSERT INTO wine_variety VALUES (537,13,2);
INSERT INTO wine_variety VALUES (538,19,1);
INSERT INTO wine_variety VALUES (538,20,2);
INSERT INTO wine_variety VALUES (539,17,1);
INSERT INTO wine_variety VALUES (540,14,1);
INSERT INTO wine_variety VALUES (541,8,1);
INSERT INTO wine_variety VALUES (542,2,1);
INSERT INTO wine_variety VALUES (543,18,1);
INSERT INTO wine_variety VALUES (544,6,1);
INSERT INTO wine_variety VALUES (544,7,2);
INSERT INTO wine_variety VALUES (545,5,1);
INSERT INTO wine_variety VALUES (546,12,1);
INSERT INTO wine_variety VALUES (546,11,2);
INSERT INTO wine_variety VALUES (546,13,3);
INSERT INTO wine_variety VALUES (547,3,1);
INSERT INTO wine_variety VALUES (547,4,2);
INSERT INTO wine_variety VALUES (548,16,1);
INSERT INTO wine_variety VALUES (549,14,1);
INSERT INTO wine_variety VALUES (550,11,1);
INSERT INTO wine_variety VALUES (550,3,2);
INSERT INTO wine_variety VALUES (551,18,1);
INSERT INTO wine_variety VALUES (552,5,1);
INSERT INTO wine_variety VALUES (553,6,1);
INSERT INTO wine_variety VALUES (553,7,2);
INSERT INTO wine_variety VALUES (554,17,1);
INSERT INTO wine_variety VALUES (555,19,1);
INSERT INTO wine_variety VALUES (555,20,2);
INSERT INTO wine_variety VALUES (556,13,1);
INSERT INTO wine_variety VALUES (557,11,1);
INSERT INTO wine_variety VALUES (557,3,2);
INSERT INTO wine_variety VALUES (558,6,1);
INSERT INTO wine_variety VALUES (558,7,2);
INSERT INTO wine_variety VALUES (559,18,1);
INSERT INTO wine_variety VALUES (560,6,1);
INSERT INTO wine_variety VALUES (560,10,2);
INSERT INTO wine_variety VALUES (561,19,1);
INSERT INTO wine_variety VALUES (561,21,2);
INSERT INTO wine_variety VALUES (562,18,1);
INSERT INTO wine_variety VALUES (563,19,1);
INSERT INTO wine_variety VALUES (563,20,2);
INSERT INTO wine_variety VALUES (564,2,1);
INSERT INTO wine_variety VALUES (565,11,1);
INSERT INTO wine_variety VALUES (565,3,2);
INSERT INTO wine_variety VALUES (566,6,1);
INSERT INTO wine_variety VALUES (566,10,2);
INSERT INTO wine_variety VALUES (567,9,1);
INSERT INTO wine_variety VALUES (568,2,1);
INSERT INTO wine_variety VALUES (569,16,1);
INSERT INTO wine_variety VALUES (570,14,1);
INSERT INTO wine_variety VALUES (571,12,1);
INSERT INTO wine_variety VALUES (571,11,2);
INSERT INTO wine_variety VALUES (571,13,3);
INSERT INTO wine_variety VALUES (572,3,1);
INSERT INTO wine_variety VALUES (572,4,2);
INSERT INTO wine_variety VALUES (573,16,1);
INSERT INTO wine_variety VALUES (574,2,1);
INSERT INTO wine_variety VALUES (575,16,1);
INSERT INTO wine_variety VALUES (576,19,1);
INSERT INTO wine_variety VALUES (576,21,2);
INSERT INTO wine_variety VALUES (577,19,1);
INSERT INTO wine_variety VALUES (577,20,2);
INSERT INTO wine_variety VALUES (578,8,1);
INSERT INTO wine_variety VALUES (579,13,1);
INSERT INTO wine_variety VALUES (580,15,1);
INSERT INTO wine_variety VALUES (581,8,1);
INSERT INTO wine_variety VALUES (582,19,1);
INSERT INTO wine_variety VALUES (582,21,2);
INSERT INTO wine_variety VALUES (583,2,1);
INSERT INTO wine_variety VALUES (584,14,1);
INSERT INTO wine_variety VALUES (585,17,1);
INSERT INTO wine_variety VALUES (586,18,1);
INSERT INTO wine_variety VALUES (587,11,1);
INSERT INTO wine_variety VALUES (587,13,2);
INSERT INTO wine_variety VALUES (588,11,1);
INSERT INTO wine_variety VALUES (588,3,2);
INSERT INTO wine_variety VALUES (589,11,1);
INSERT INTO wine_variety VALUES (589,3,2);
INSERT INTO wine_variety VALUES (590,16,1);
INSERT INTO wine_variety VALUES (591,1,1);
INSERT INTO wine_variety VALUES (592,3,1);
INSERT INTO wine_variety VALUES (592,4,2);
INSERT INTO wine_variety VALUES (593,19,1);
INSERT INTO wine_variety VALUES (593,21,2);
INSERT INTO wine_variety VALUES (594,16,1);
INSERT INTO wine_variety VALUES (595,17,1);
INSERT INTO wine_variety VALUES (596,6,1);
INSERT INTO wine_variety VALUES (596,7,2);
INSERT INTO wine_variety VALUES (597,17,1);
INSERT INTO wine_variety VALUES (598,2,1);
INSERT INTO wine_variety VALUES (599,18,1);
INSERT INTO wine_variety VALUES (600,5,1);
INSERT INTO wine_variety VALUES (601,3,1);
INSERT INTO wine_variety VALUES (601,4,2);
INSERT INTO wine_variety VALUES (602,5,1);
INSERT INTO wine_variety VALUES (603,15,1);
INSERT INTO wine_variety VALUES (604,1,1);
INSERT INTO wine_variety VALUES (605,19,1);
INSERT INTO wine_variety VALUES (605,21,2);
INSERT INTO wine_variety VALUES (606,5,1);
INSERT INTO wine_variety VALUES (607,13,1);
INSERT INTO wine_variety VALUES (608,6,1);
INSERT INTO wine_variety VALUES (608,7,2);
INSERT INTO wine_variety VALUES (609,12,1);
INSERT INTO wine_variety VALUES (609,11,2);
INSERT INTO wine_variety VALUES (610,6,1);
INSERT INTO wine_variety VALUES (610,10,2);
INSERT INTO wine_variety VALUES (611,5,1);
INSERT INTO wine_variety VALUES (612,13,1);
INSERT INTO wine_variety VALUES (613,16,1);
INSERT INTO wine_variety VALUES (614,14,1);
INSERT INTO wine_variety VALUES (615,19,1);
INSERT INTO wine_variety VALUES (615,20,2);
INSERT INTO wine_variety VALUES (616,17,1);
INSERT INTO wine_variety VALUES (617,11,1);
INSERT INTO wine_variety VALUES (617,13,2);
INSERT INTO wine_variety VALUES (618,17,1);
INSERT INTO wine_variety VALUES (619,16,1);
INSERT INTO wine_variety VALUES (620,5,1);
INSERT INTO wine_variety VALUES (621,12,1);
INSERT INTO wine_variety VALUES (621,11,2);
INSERT INTO wine_variety VALUES (621,13,3);
INSERT INTO wine_variety VALUES (622,3,1);
INSERT INTO wine_variety VALUES (622,4,2);
INSERT INTO wine_variety VALUES (623,17,1);
INSERT INTO wine_variety VALUES (624,11,1);
INSERT INTO wine_variety VALUES (624,3,2);
INSERT INTO wine_variety VALUES (625,17,1);
INSERT INTO wine_variety VALUES (626,11,1);
INSERT INTO wine_variety VALUES (626,3,2);
INSERT INTO wine_variety VALUES (627,14,1);
INSERT INTO wine_variety VALUES (628,6,1);
INSERT INTO wine_variety VALUES (628,7,2);
INSERT INTO wine_variety VALUES (629,15,1);
INSERT INTO wine_variety VALUES (630,5,1);
INSERT INTO wine_variety VALUES (631,11,1);
INSERT INTO wine_variety VALUES (631,13,2);
INSERT INTO wine_variety VALUES (632,18,1);
INSERT INTO wine_variety VALUES (633,16,1);
INSERT INTO wine_variety VALUES (634,19,1);
INSERT INTO wine_variety VALUES (634,21,2);
INSERT INTO wine_variety VALUES (635,1,1);
INSERT INTO wine_variety VALUES (636,13,1);
INSERT INTO wine_variety VALUES (637,14,1);
INSERT INTO wine_variety VALUES (638,5,1);
INSERT INTO wine_variety VALUES (639,19,1);
INSERT INTO wine_variety VALUES (639,21,2);
INSERT INTO wine_variety VALUES (640,14,1);
INSERT INTO wine_variety VALUES (641,14,1);
INSERT INTO wine_variety VALUES (642,19,1);
INSERT INTO wine_variety VALUES (642,21,2);
INSERT INTO wine_variety VALUES (643,19,1);
INSERT INTO wine_variety VALUES (643,21,2);
INSERT INTO wine_variety VALUES (644,14,1);
INSERT INTO wine_variety VALUES (645,17,1);
INSERT INTO wine_variety VALUES (646,14,1);
INSERT INTO wine_variety VALUES (647,19,1);
INSERT INTO wine_variety VALUES (647,20,2);
INSERT INTO wine_variety VALUES (648,14,1);
INSERT INTO wine_variety VALUES (649,14,1);
INSERT INTO wine_variety VALUES (650,14,1);
INSERT INTO wine_variety VALUES (651,14,1);
INSERT INTO wine_variety VALUES (652,2,1);
INSERT INTO wine_variety VALUES (653,17,1);
INSERT INTO wine_variety VALUES (654,1,1);
INSERT INTO wine_variety VALUES (655,19,1);
INSERT INTO wine_variety VALUES (655,21,2);
INSERT INTO wine_variety VALUES (656,15,1);
INSERT INTO wine_variety VALUES (657,8,1);
INSERT INTO wine_variety VALUES (658,1,1);
INSERT INTO wine_variety VALUES (659,6,1);
INSERT INTO wine_variety VALUES (659,7,2);
INSERT INTO wine_variety VALUES (660,12,1);
INSERT INTO wine_variety VALUES (660,11,2);
INSERT INTO wine_variety VALUES (660,13,3);
INSERT INTO wine_variety VALUES (661,18,1);
INSERT INTO wine_variety VALUES (662,8,1);
INSERT INTO wine_variety VALUES (663,14,1);
INSERT INTO wine_variety VALUES (664,19,1);
INSERT INTO wine_variety VALUES (664,21,2);
INSERT INTO wine_variety VALUES (665,15,1);
INSERT INTO wine_variety VALUES (666,11,1);
INSERT INTO wine_variety VALUES (666,3,2);
INSERT INTO wine_variety VALUES (667,3,1);
INSERT INTO wine_variety VALUES (667,4,2);
INSERT INTO wine_variety VALUES (668,1,1);
INSERT INTO wine_variety VALUES (669,11,1);
INSERT INTO wine_variety VALUES (669,3,2);
INSERT INTO wine_variety VALUES (670,16,1);
INSERT INTO wine_variety VALUES (671,9,1);
INSERT INTO wine_variety VALUES (672,5,1);
INSERT INTO wine_variety VALUES (672,3,2);
INSERT INTO wine_variety VALUES (672,4,3);
INSERT INTO wine_variety VALUES (673,13,1);
INSERT INTO wine_variety VALUES (674,19,1);
INSERT INTO wine_variety VALUES (674,20,2);
INSERT INTO wine_variety VALUES (675,2,1);
INSERT INTO wine_variety VALUES (676,17,1);
INSERT INTO wine_variety VALUES (677,18,1);
INSERT INTO wine_variety VALUES (678,19,1);
INSERT INTO wine_variety VALUES (678,20,2);
INSERT INTO wine_variety VALUES (679,17,1);
INSERT INTO wine_variety VALUES (680,5,1);
INSERT INTO wine_variety VALUES (681,1,1);
INSERT INTO wine_variety VALUES (682,19,1);
INSERT INTO wine_variety VALUES (682,21,2);
INSERT INTO wine_variety VALUES (683,8,1);
INSERT INTO wine_variety VALUES (684,16,1);
INSERT INTO wine_variety VALUES (685,11,1);
INSERT INTO wine_variety VALUES (685,13,2);
INSERT INTO wine_variety VALUES (686,19,1);
INSERT INTO wine_variety VALUES (686,21,2);
INSERT INTO wine_variety VALUES (687,19,1);
INSERT INTO wine_variety VALUES (687,21,2);
INSERT INTO wine_variety VALUES (688,12,1);
INSERT INTO wine_variety VALUES (688,11,2);
INSERT INTO wine_variety VALUES (688,13,3);
INSERT INTO wine_variety VALUES (689,5,1);
INSERT INTO wine_variety VALUES (690,9,1);
INSERT INTO wine_variety VALUES (691,17,1);
INSERT INTO wine_variety VALUES (692,14,1);
INSERT INTO wine_variety VALUES (693,5,1);
INSERT INTO wine_variety VALUES (693,3,2);
INSERT INTO wine_variety VALUES (693,4,3);
INSERT INTO wine_variety VALUES (694,8,1);
INSERT INTO wine_variety VALUES (695,11,1);
INSERT INTO wine_variety VALUES (695,3,2);
INSERT INTO wine_variety VALUES (696,18,1);
INSERT INTO wine_variety VALUES (697,16,1);
INSERT INTO wine_variety VALUES (698,8,1);
INSERT INTO wine_variety VALUES (699,6,1);
INSERT INTO wine_variety VALUES (699,10,2);
INSERT INTO wine_variety VALUES (700,5,1);
INSERT INTO wine_variety VALUES (700,3,2);
INSERT INTO wine_variety VALUES (700,4,3);
INSERT INTO wine_variety VALUES (701,3,1);
INSERT INTO wine_variety VALUES (701,4,2);
INSERT INTO wine_variety VALUES (702,14,1);
INSERT INTO wine_variety VALUES (703,6,1);
INSERT INTO wine_variety VALUES (703,10,2);
INSERT INTO wine_variety VALUES (704,16,1);
INSERT INTO wine_variety VALUES (705,6,1);
INSERT INTO wine_variety VALUES (705,10,2);
INSERT INTO wine_variety VALUES (706,3,1);
INSERT INTO wine_variety VALUES (706,4,2);
INSERT INTO wine_variety VALUES (707,8,1);
INSERT INTO wine_variety VALUES (708,6,1);
INSERT INTO wine_variety VALUES (708,7,2);
INSERT INTO wine_variety VALUES (709,19,1);
INSERT INTO wine_variety VALUES (709,21,2);
INSERT INTO wine_variety VALUES (710,15,1);
INSERT INTO wine_variety VALUES (711,8,1);
INSERT INTO wine_variety VALUES (712,11,1);
INSERT INTO wine_variety VALUES (712,3,2);
INSERT INTO wine_variety VALUES (713,5,1);
INSERT INTO wine_variety VALUES (714,17,1);
INSERT INTO wine_variety VALUES (715,19,1);
INSERT INTO wine_variety VALUES (715,21,2);
INSERT INTO wine_variety VALUES (716,6,1);
INSERT INTO wine_variety VALUES (716,10,2);
INSERT INTO wine_variety VALUES (717,1,1);
INSERT INTO wine_variety VALUES (718,14,1);
INSERT INTO wine_variety VALUES (719,5,1);
INSERT INTO wine_variety VALUES (719,3,2);
INSERT INTO wine_variety VALUES (719,4,3);
INSERT INTO wine_variety VALUES (720,14,1);
INSERT INTO wine_variety VALUES (721,17,1);
INSERT INTO wine_variety VALUES (722,8,1);
INSERT INTO wine_variety VALUES (723,9,1);
INSERT INTO wine_variety VALUES (724,11,1);
INSERT INTO wine_variety VALUES (724,13,2);
INSERT INTO wine_variety VALUES (725,18,1);
INSERT INTO wine_variety VALUES (726,14,1);
INSERT INTO wine_variety VALUES (727,15,1);
INSERT INTO wine_variety VALUES (728,5,1);
INSERT INTO wine_variety VALUES (728,3,2);
INSERT INTO wine_variety VALUES (728,4,3);
INSERT INTO wine_variety VALUES (729,2,1);
INSERT INTO wine_variety VALUES (730,9,1);
INSERT INTO wine_variety VALUES (731,18,1);
INSERT INTO wine_variety VALUES (732,11,1);
INSERT INTO wine_variety VALUES (732,3,2);
INSERT INTO wine_variety VALUES (733,12,1);
INSERT INTO wine_variety VALUES (734,1,1);
INSERT INTO wine_variety VALUES (735,15,1);
INSERT INTO wine_variety VALUES (736,12,1);
INSERT INTO wine_variety VALUES (737,11,1);
INSERT INTO wine_variety VALUES (737,3,2);
INSERT INTO wine_variety VALUES (738,19,1);
INSERT INTO wine_variety VALUES (738,21,2);
INSERT INTO wine_variety VALUES (739,5,1);
INSERT INTO wine_variety VALUES (739,3,2);
INSERT INTO wine_variety VALUES (739,4,3);
INSERT INTO wine_variety VALUES (740,8,1);
INSERT INTO wine_variety VALUES (741,6,1);
INSERT INTO wine_variety VALUES (741,7,2);
INSERT INTO wine_variety VALUES (742,9,1);
INSERT INTO wine_variety VALUES (743,19,1);
INSERT INTO wine_variety VALUES (743,20,2);
INSERT INTO wine_variety VALUES (744,14,1);
INSERT INTO wine_variety VALUES (745,16,1);
INSERT INTO wine_variety VALUES (746,3,1);
INSERT INTO wine_variety VALUES (746,4,2);
INSERT INTO wine_variety VALUES (747,11,1);
INSERT INTO wine_variety VALUES (747,13,2);
INSERT INTO wine_variety VALUES (748,11,1);
INSERT INTO wine_variety VALUES (748,13,2);
INSERT INTO wine_variety VALUES (749,8,1);
INSERT INTO wine_variety VALUES (750,6,1);
INSERT INTO wine_variety VALUES (750,7,2);
INSERT INTO wine_variety VALUES (751,14,1);
INSERT INTO wine_variety VALUES (752,19,1);
INSERT INTO wine_variety VALUES (752,20,2);
INSERT INTO wine_variety VALUES (753,19,1);
INSERT INTO wine_variety VALUES (753,21,2);
INSERT INTO wine_variety VALUES (754,19,1);
INSERT INTO wine_variety VALUES (754,20,2);
INSERT INTO wine_variety VALUES (755,12,1);
INSERT INTO wine_variety VALUES (756,2,1);
INSERT INTO wine_variety VALUES (757,5,1);
INSERT INTO wine_variety VALUES (758,8,1);
INSERT INTO wine_variety VALUES (759,3,1);
INSERT INTO wine_variety VALUES (759,4,2);
INSERT INTO wine_variety VALUES (760,13,1);
INSERT INTO wine_variety VALUES (761,14,1);
INSERT INTO wine_variety VALUES (762,13,1);
INSERT INTO wine_variety VALUES (763,17,1);
INSERT INTO wine_variety VALUES (764,5,1);
INSERT INTO wine_variety VALUES (765,3,1);
INSERT INTO wine_variety VALUES (765,4,2);
INSERT INTO wine_variety VALUES (766,6,1);
INSERT INTO wine_variety VALUES (766,7,2);
INSERT INTO wine_variety VALUES (767,12,1);
INSERT INTO wine_variety VALUES (768,17,1);
INSERT INTO wine_variety VALUES (769,5,1);
INSERT INTO wine_variety VALUES (769,3,2);
INSERT INTO wine_variety VALUES (769,4,3);
INSERT INTO wine_variety VALUES (770,6,1);
INSERT INTO wine_variety VALUES (770,10,2);
INSERT INTO wine_variety VALUES (771,5,1);
INSERT INTO wine_variety VALUES (771,3,2);
INSERT INTO wine_variety VALUES (771,4,3);
INSERT INTO wine_variety VALUES (772,14,1);
INSERT INTO wine_variety VALUES (773,16,1);
INSERT INTO wine_variety VALUES (774,11,1);
INSERT INTO wine_variety VALUES (774,13,2);
INSERT INTO wine_variety VALUES (775,19,1);
INSERT INTO wine_variety VALUES (775,20,2);
INSERT INTO wine_variety VALUES (776,18,1);
INSERT INTO wine_variety VALUES (777,19,1);
INSERT INTO wine_variety VALUES (777,21,2);
INSERT INTO wine_variety VALUES (778,14,1);
INSERT INTO wine_variety VALUES (779,16,1);
INSERT INTO wine_variety VALUES (780,2,1);
INSERT INTO wine_variety VALUES (781,1,1);
INSERT INTO wine_variety VALUES (782,1,1);
INSERT INTO wine_variety VALUES (783,17,1);
INSERT INTO wine_variety VALUES (784,6,1);
INSERT INTO wine_variety VALUES (784,10,2);
INSERT INTO wine_variety VALUES (785,6,1);
INSERT INTO wine_variety VALUES (785,7,2);
INSERT INTO wine_variety VALUES (786,11,1);
INSERT INTO wine_variety VALUES (786,13,2);
INSERT INTO wine_variety VALUES (787,14,1);
INSERT INTO wine_variety VALUES (788,12,1);
INSERT INTO wine_variety VALUES (788,11,2);
INSERT INTO wine_variety VALUES (788,13,3);
INSERT INTO wine_variety VALUES (789,16,1);
INSERT INTO wine_variety VALUES (790,6,1);
INSERT INTO wine_variety VALUES (790,7,2);
INSERT INTO wine_variety VALUES (791,16,1);
INSERT INTO wine_variety VALUES (792,2,1);
INSERT INTO wine_variety VALUES (793,18,1);
INSERT INTO wine_variety VALUES (794,8,1);
INSERT INTO wine_variety VALUES (795,8,1);
INSERT INTO wine_variety VALUES (796,3,1);
INSERT INTO wine_variety VALUES (796,4,2);
INSERT INTO wine_variety VALUES (797,17,1);
INSERT INTO wine_variety VALUES (798,19,1);
INSERT INTO wine_variety VALUES (798,21,2);
INSERT INTO wine_variety VALUES (799,19,1);
INSERT INTO wine_variety VALUES (799,20,2);
INSERT INTO wine_variety VALUES (800,1,1);
INSERT INTO wine_variety VALUES (801,15,1);
INSERT INTO wine_variety VALUES (802,1,1);
INSERT INTO wine_variety VALUES (803,3,1);
INSERT INTO wine_variety VALUES (803,4,2);
INSERT INTO wine_variety VALUES (804,6,1);
INSERT INTO wine_variety VALUES (804,7,2);
INSERT INTO wine_variety VALUES (805,13,1);
INSERT INTO wine_variety VALUES (806,11,1);
INSERT INTO wine_variety VALUES (806,3,2);
INSERT INTO wine_variety VALUES (807,1,1);
INSERT INTO wine_variety VALUES (808,6,1);
INSERT INTO wine_variety VALUES (808,7,2);
INSERT INTO wine_variety VALUES (809,15,1);
INSERT INTO wine_variety VALUES (810,11,1);
INSERT INTO wine_variety VALUES (810,3,2);
INSERT INTO wine_variety VALUES (811,19,1);
INSERT INTO wine_variety VALUES (811,20,2);
INSERT INTO wine_variety VALUES (812,19,1);
INSERT INTO wine_variety VALUES (812,20,2);
INSERT INTO wine_variety VALUES (813,12,1);
INSERT INTO wine_variety VALUES (813,11,2);
INSERT INTO wine_variety VALUES (814,5,1);
INSERT INTO wine_variety VALUES (814,3,2);
INSERT INTO wine_variety VALUES (814,4,3);
INSERT INTO wine_variety VALUES (815,16,1);
INSERT INTO wine_variety VALUES (816,12,1);
INSERT INTO wine_variety VALUES (817,3,1);
INSERT INTO wine_variety VALUES (817,4,2);
INSERT INTO wine_variety VALUES (818,6,1);
INSERT INTO wine_variety VALUES (818,7,2);
INSERT INTO wine_variety VALUES (819,1,1);
INSERT INTO wine_variety VALUES (820,14,1);
INSERT INTO wine_variety VALUES (821,9,1);
INSERT INTO wine_variety VALUES (822,15,1);
INSERT INTO wine_variety VALUES (823,18,1);
INSERT INTO wine_variety VALUES (824,6,1);
INSERT INTO wine_variety VALUES (824,10,2);
INSERT INTO wine_variety VALUES (825,5,1);
INSERT INTO wine_variety VALUES (826,19,1);
INSERT INTO wine_variety VALUES (826,21,2);
INSERT INTO wine_variety VALUES (827,15,1);
INSERT INTO wine_variety VALUES (828,12,1);
INSERT INTO wine_variety VALUES (828,11,2);
INSERT INTO wine_variety VALUES (829,3,1);
INSERT INTO wine_variety VALUES (829,4,2);
INSERT INTO wine_variety VALUES (830,8,1);
INSERT INTO wine_variety VALUES (831,12,1);
INSERT INTO wine_variety VALUES (831,11,2);
INSERT INTO wine_variety VALUES (831,13,3);
INSERT INTO wine_variety VALUES (832,19,1);
INSERT INTO wine_variety VALUES (832,21,2);
INSERT INTO wine_variety VALUES (833,11,1);
INSERT INTO wine_variety VALUES (833,13,2);
INSERT INTO wine_variety VALUES (834,19,1);
INSERT INTO wine_variety VALUES (834,20,2);
INSERT INTO wine_variety VALUES (835,16,1);
INSERT INTO wine_variety VALUES (836,12,1);
INSERT INTO wine_variety VALUES (836,11,2);
INSERT INTO wine_variety VALUES (837,16,1);
INSERT INTO wine_variety VALUES (838,5,1);
INSERT INTO wine_variety VALUES (839,3,1);
INSERT INTO wine_variety VALUES (839,4,2);
INSERT INTO wine_variety VALUES (840,15,1);
INSERT INTO wine_variety VALUES (841,19,1);
INSERT INTO wine_variety VALUES (841,20,2);
INSERT INTO wine_variety VALUES (842,12,1);
INSERT INTO wine_variety VALUES (842,11,2);
INSERT INTO wine_variety VALUES (843,19,1);
INSERT INTO wine_variety VALUES (843,21,2);
INSERT INTO wine_variety VALUES (844,2,1);
INSERT INTO wine_variety VALUES (845,12,1);
INSERT INTO wine_variety VALUES (845,11,2);
INSERT INTO wine_variety VALUES (846,17,1);
INSERT INTO wine_variety VALUES (847,1,1);
INSERT INTO wine_variety VALUES (848,16,1);
INSERT INTO wine_variety VALUES (849,15,1);
INSERT INTO wine_variety VALUES (850,13,1);
INSERT INTO wine_variety VALUES (851,15,1);
INSERT INTO wine_variety VALUES (852,13,1);
INSERT INTO wine_variety VALUES (853,1,1);
INSERT INTO wine_variety VALUES (854,5,1);
INSERT INTO wine_variety VALUES (854,3,2);
INSERT INTO wine_variety VALUES (854,4,3);
INSERT INTO wine_variety VALUES (855,13,1);
INSERT INTO wine_variety VALUES (856,18,1);
INSERT INTO wine_variety VALUES (857,14,1);
INSERT INTO wine_variety VALUES (858,12,1);
INSERT INTO wine_variety VALUES (858,11,2);
INSERT INTO wine_variety VALUES (858,13,3);
INSERT INTO wine_variety VALUES (859,15,1);
INSERT INTO wine_variety VALUES (860,8,1);
INSERT INTO wine_variety VALUES (861,18,1);
INSERT INTO wine_variety VALUES (862,19,1);
INSERT INTO wine_variety VALUES (862,21,2);
INSERT INTO wine_variety VALUES (863,12,1);
INSERT INTO wine_variety VALUES (863,11,2);
INSERT INTO wine_variety VALUES (863,13,3);
INSERT INTO wine_variety VALUES (864,9,1);
INSERT INTO wine_variety VALUES (865,2,1);
INSERT INTO wine_variety VALUES (866,5,1);
INSERT INTO wine_variety VALUES (866,3,2);
INSERT INTO wine_variety VALUES (866,4,3);
INSERT INTO wine_variety VALUES (867,3,1);
INSERT INTO wine_variety VALUES (867,4,2);
INSERT INTO wine_variety VALUES (868,14,1);
INSERT INTO wine_variety VALUES (869,18,1);
INSERT INTO wine_variety VALUES (870,19,1);
INSERT INTO wine_variety VALUES (870,21,2);
INSERT INTO wine_variety VALUES (871,2,1);
INSERT INTO wine_variety VALUES (872,15,1);
INSERT INTO wine_variety VALUES (873,18,1);
INSERT INTO wine_variety VALUES (874,12,1);
INSERT INTO wine_variety VALUES (874,11,2);
INSERT INTO wine_variety VALUES (874,13,3);
INSERT INTO wine_variety VALUES (875,3,1);
INSERT INTO wine_variety VALUES (875,4,2);
INSERT INTO wine_variety VALUES (876,18,1);
INSERT INTO wine_variety VALUES (877,14,1);
INSERT INTO wine_variety VALUES (878,5,1);
INSERT INTO wine_variety VALUES (878,3,2);
INSERT INTO wine_variety VALUES (878,4,3);
INSERT INTO wine_variety VALUES (879,18,1);
INSERT INTO wine_variety VALUES (880,19,1);
INSERT INTO wine_variety VALUES (880,20,2);
INSERT INTO wine_variety VALUES (881,15,1);
INSERT INTO wine_variety VALUES (882,19,1);
INSERT INTO wine_variety VALUES (882,21,2);
INSERT INTO wine_variety VALUES (883,19,1);
INSERT INTO wine_variety VALUES (883,20,2);
INSERT INTO wine_variety VALUES (884,12,1);
INSERT INTO wine_variety VALUES (884,11,2);
INSERT INTO wine_variety VALUES (885,12,1);
INSERT INTO wine_variety VALUES (885,11,2);
INSERT INTO wine_variety VALUES (885,13,3);
INSERT INTO wine_variety VALUES (886,19,1);
INSERT INTO wine_variety VALUES (886,20,2);
INSERT INTO wine_variety VALUES (887,6,1);
INSERT INTO wine_variety VALUES (887,10,2);
INSERT INTO wine_variety VALUES (888,2,1);
INSERT INTO wine_variety VALUES (889,3,1);
INSERT INTO wine_variety VALUES (889,4,2);
INSERT INTO wine_variety VALUES (890,18,1);
INSERT INTO wine_variety VALUES (891,12,1);
INSERT INTO wine_variety VALUES (891,11,2);
INSERT INTO wine_variety VALUES (891,13,3);
INSERT INTO wine_variety VALUES (892,19,1);
INSERT INTO wine_variety VALUES (892,21,2);
INSERT INTO wine_variety VALUES (893,5,1);
INSERT INTO wine_variety VALUES (893,3,2);
INSERT INTO wine_variety VALUES (893,4,3);
INSERT INTO wine_variety VALUES (894,14,1);
INSERT INTO wine_variety VALUES (895,12,1);
INSERT INTO wine_variety VALUES (895,11,2);
INSERT INTO wine_variety VALUES (896,1,1);
INSERT INTO wine_variety VALUES (897,19,1);
INSERT INTO wine_variety VALUES (897,20,2);
INSERT INTO wine_variety VALUES (898,11,1);
INSERT INTO wine_variety VALUES (898,13,2);
INSERT INTO wine_variety VALUES (899,19,1);
INSERT INTO wine_variety VALUES (899,20,2);
INSERT INTO wine_variety VALUES (900,14,1);
INSERT INTO wine_variety VALUES (901,19,1);
INSERT INTO wine_variety VALUES (901,21,2);
INSERT INTO wine_variety VALUES (902,2,1);
INSERT INTO wine_variety VALUES (903,19,1);
INSERT INTO wine_variety VALUES (903,21,2);
INSERT INTO wine_variety VALUES (904,16,1);
INSERT INTO wine_variety VALUES (905,12,1);
INSERT INTO wine_variety VALUES (906,12,1);
INSERT INTO wine_variety VALUES (907,6,1);
INSERT INTO wine_variety VALUES (907,7,2);
INSERT INTO wine_variety VALUES (908,17,1);
INSERT INTO wine_variety VALUES (909,11,1);
INSERT INTO wine_variety VALUES (909,3,2);
INSERT INTO wine_variety VALUES (910,11,1);
INSERT INTO wine_variety VALUES (910,13,2);
INSERT INTO wine_variety VALUES (911,11,1);
INSERT INTO wine_variety VALUES (911,13,2);
INSERT INTO wine_variety VALUES (912,2,1);
INSERT INTO wine_variety VALUES (913,19,1);
INSERT INTO wine_variety VALUES (913,21,2);
INSERT INTO wine_variety VALUES (914,16,1);
INSERT INTO wine_variety VALUES (915,3,1);
INSERT INTO wine_variety VALUES (915,4,2);
INSERT INTO wine_variety VALUES (916,3,1);
INSERT INTO wine_variety VALUES (916,4,2);
INSERT INTO wine_variety VALUES (917,18,1);
INSERT INTO wine_variety VALUES (918,16,1);
INSERT INTO wine_variety VALUES (919,12,1);
INSERT INTO wine_variety VALUES (920,8,1);
INSERT INTO wine_variety VALUES (921,8,1);
INSERT INTO wine_variety VALUES (922,3,1);
INSERT INTO wine_variety VALUES (922,4,2);
INSERT INTO wine_variety VALUES (923,1,1);
INSERT INTO wine_variety VALUES (924,6,1);
INSERT INTO wine_variety VALUES (924,10,2);
INSERT INTO wine_variety VALUES (925,14,1);
INSERT INTO wine_variety VALUES (926,6,1);
INSERT INTO wine_variety VALUES (926,7,2);
INSERT INTO wine_variety VALUES (927,14,1);
INSERT INTO wine_variety VALUES (928,1,1);
INSERT INTO wine_variety VALUES (929,19,1);
INSERT INTO wine_variety VALUES (929,21,2);
INSERT INTO wine_variety VALUES (930,1,1);
INSERT INTO wine_variety VALUES (931,8,1);
INSERT INTO wine_variety VALUES (932,19,1);
INSERT INTO wine_variety VALUES (932,20,2);
INSERT INTO wine_variety VALUES (933,19,1);
INSERT INTO wine_variety VALUES (933,20,2);
INSERT INTO wine_variety VALUES (934,9,1);
INSERT INTO wine_variety VALUES (935,13,1);
INSERT INTO wine_variety VALUES (936,12,1);
INSERT INTO wine_variety VALUES (936,11,2);
INSERT INTO wine_variety VALUES (936,13,3);
INSERT INTO wine_variety VALUES (937,5,1);
INSERT INTO wine_variety VALUES (937,3,2);
INSERT INTO wine_variety VALUES (937,4,3);
INSERT INTO wine_variety VALUES (938,5,1);
INSERT INTO wine_variety VALUES (939,19,1);
INSERT INTO wine_variety VALUES (939,20,2);
INSERT INTO wine_variety VALUES (940,19,1);
INSERT INTO wine_variety VALUES (940,21,2);
INSERT INTO wine_variety VALUES (941,17,1);
INSERT INTO wine_variety VALUES (942,19,1);
INSERT INTO wine_variety VALUES (942,21,2);
INSERT INTO wine_variety VALUES (943,12,1);
INSERT INTO wine_variety VALUES (944,14,1);
INSERT INTO wine_variety VALUES (945,12,1);
INSERT INTO wine_variety VALUES (945,11,2);
INSERT INTO wine_variety VALUES (945,13,3);
INSERT INTO wine_variety VALUES (946,5,1);
INSERT INTO wine_variety VALUES (946,3,2);
INSERT INTO wine_variety VALUES (946,4,3);
INSERT INTO wine_variety VALUES (947,11,1);
INSERT INTO wine_variety VALUES (947,13,2);
INSERT INTO wine_variety VALUES (948,12,1);
INSERT INTO wine_variety VALUES (948,11,2);
INSERT INTO wine_variety VALUES (949,15,1);
INSERT INTO wine_variety VALUES (950,2,1);
INSERT INTO wine_variety VALUES (951,6,1);
INSERT INTO wine_variety VALUES (951,7,2);
INSERT INTO wine_variety VALUES (952,6,1);
INSERT INTO wine_variety VALUES (952,7,2);
INSERT INTO wine_variety VALUES (953,15,1);
INSERT INTO wine_variety VALUES (954,6,1);
INSERT INTO wine_variety VALUES (954,7,2);
INSERT INTO wine_variety VALUES (955,16,1);
INSERT INTO wine_variety VALUES (956,15,1);
INSERT INTO wine_variety VALUES (957,8,1);
INSERT INTO wine_variety VALUES (958,8,1);
INSERT INTO wine_variety VALUES (959,8,1);
INSERT INTO wine_variety VALUES (960,19,1);
INSERT INTO wine_variety VALUES (960,21,2);
INSERT INTO wine_variety VALUES (961,5,1);
INSERT INTO wine_variety VALUES (962,19,1);
INSERT INTO wine_variety VALUES (962,21,2);
INSERT INTO wine_variety VALUES (963,11,1);
INSERT INTO wine_variety VALUES (963,13,2);
INSERT INTO wine_variety VALUES (964,12,1);
INSERT INTO wine_variety VALUES (964,11,2);
INSERT INTO wine_variety VALUES (964,13,3);
INSERT INTO wine_variety VALUES (965,12,1);
INSERT INTO wine_variety VALUES (965,11,2);
INSERT INTO wine_variety VALUES (966,19,1);
INSERT INTO wine_variety VALUES (966,20,2);
INSERT INTO wine_variety VALUES (967,11,1);
INSERT INTO wine_variety VALUES (967,13,2);
INSERT INTO wine_variety VALUES (968,5,1);
INSERT INTO wine_variety VALUES (969,17,1);
INSERT INTO wine_variety VALUES (970,5,1);
INSERT INTO wine_variety VALUES (971,17,1);
INSERT INTO wine_variety VALUES (972,5,1);
INSERT INTO wine_variety VALUES (973,18,1);
INSERT INTO wine_variety VALUES (974,1,1);
INSERT INTO wine_variety VALUES (975,11,1);
INSERT INTO wine_variety VALUES (975,3,2);
INSERT INTO wine_variety VALUES (976,5,1);
INSERT INTO wine_variety VALUES (976,3,2);
INSERT INTO wine_variety VALUES (976,4,3);
INSERT INTO wine_variety VALUES (977,12,1);
INSERT INTO wine_variety VALUES (977,11,2);
INSERT INTO wine_variety VALUES (978,16,1);
INSERT INTO wine_variety VALUES (979,19,1);
INSERT INTO wine_variety VALUES (979,21,2);
INSERT INTO wine_variety VALUES (980,12,1);
INSERT INTO wine_variety VALUES (980,11,2);
INSERT INTO wine_variety VALUES (980,13,3);
INSERT INTO wine_variety VALUES (981,5,1);
INSERT INTO wine_variety VALUES (982,19,1);
INSERT INTO wine_variety VALUES (982,20,2);
INSERT INTO wine_variety VALUES (983,16,1);
INSERT INTO wine_variety VALUES (984,19,1);
INSERT INTO wine_variety VALUES (984,20,2);
INSERT INTO wine_variety VALUES (985,1,1);
INSERT INTO wine_variety VALUES (986,14,1);
INSERT INTO wine_variety VALUES (987,11,1);
INSERT INTO wine_variety VALUES (987,13,2);
INSERT INTO wine_variety VALUES (988,17,1);
INSERT INTO wine_variety VALUES (989,12,1);
INSERT INTO wine_variety VALUES (990,19,1);
INSERT INTO wine_variety VALUES (990,21,2);
INSERT INTO wine_variety VALUES (991,9,1);
INSERT INTO wine_variety VALUES (992,6,1);
INSERT INTO wine_variety VALUES (992,10,2);
INSERT INTO wine_variety VALUES (993,6,1);
INSERT INTO wine_variety VALUES (993,7,2);
INSERT INTO wine_variety VALUES (994,8,1);
INSERT INTO wine_variety VALUES (995,1,1);
INSERT INTO wine_variety VALUES (996,19,1);
INSERT INTO wine_variety VALUES (996,20,2);
INSERT INTO wine_variety VALUES (997,5,1);
INSERT INTO wine_variety VALUES (998,11,1);
INSERT INTO wine_variety VALUES (998,13,2);
INSERT INTO wine_variety VALUES (999,1,1);
INSERT INTO wine_variety VALUES (1000,12,1);
INSERT INTO wine_variety VALUES (1001,8,1);
INSERT INTO wine_variety VALUES (1002,16,1);
INSERT INTO wine_variety VALUES (1003,9,1);
INSERT INTO wine_variety VALUES (1004,11,1);
INSERT INTO wine_variety VALUES (1004,3,2);
INSERT INTO wine_variety VALUES (1005,17,1);
INSERT INTO wine_variety VALUES (1006,8,1);
INSERT INTO wine_variety VALUES (1007,15,1);
INSERT INTO wine_variety VALUES (1008,3,1);
INSERT INTO wine_variety VALUES (1008,4,2);
INSERT INTO wine_variety VALUES (1009,16,1);
INSERT INTO wine_variety VALUES (1010,12,1);
INSERT INTO wine_variety VALUES (1010,11,2);
INSERT INTO wine_variety VALUES (1010,13,3);
INSERT INTO wine_variety VALUES (1011,1,1);
INSERT INTO wine_variety VALUES (1012,9,1);
INSERT INTO wine_variety VALUES (1013,16,1);
INSERT INTO wine_variety VALUES (1014,14,1);
INSERT INTO wine_variety VALUES (1015,5,1);
INSERT INTO wine_variety VALUES (1015,3,2);
INSERT INTO wine_variety VALUES (1015,4,3);
INSERT INTO wine_variety VALUES (1016,12,1);
INSERT INTO wine_variety VALUES (1016,11,2);
INSERT INTO wine_variety VALUES (1017,12,1);
INSERT INTO wine_variety VALUES (1018,18,1);
INSERT INTO wine_variety VALUES (1019,5,1);
INSERT INTO wine_variety VALUES (1020,19,1);
INSERT INTO wine_variety VALUES (1020,20,2);
INSERT INTO wine_variety VALUES (1021,2,1);
INSERT INTO wine_variety VALUES (1022,15,1);
INSERT INTO wine_variety VALUES (1023,9,1);
INSERT INTO wine_variety VALUES (1024,5,1);
INSERT INTO wine_variety VALUES (1025,12,1);
INSERT INTO wine_variety VALUES (1025,11,2);
INSERT INTO wine_variety VALUES (1026,9,1);
INSERT INTO wine_variety VALUES (1027,16,1);
INSERT INTO wine_variety VALUES (1028,11,1);
INSERT INTO wine_variety VALUES (1028,13,2);
INSERT INTO wine_variety VALUES (1029,19,1);
INSERT INTO wine_variety VALUES (1029,20,2);
INSERT INTO wine_variety VALUES (1030,6,1);
INSERT INTO wine_variety VALUES (1030,7,2);
INSERT INTO wine_variety VALUES (1031,17,1);
INSERT INTO wine_variety VALUES (1032,14,1);
INSERT INTO wine_variety VALUES (1033,8,1);
INSERT INTO wine_variety VALUES (1034,18,1);
INSERT INTO wine_variety VALUES (1035,16,1);
INSERT INTO wine_variety VALUES (1036,2,1);
INSERT INTO wine_variety VALUES (1037,13,1);
INSERT INTO wine_variety VALUES (1038,19,1);
INSERT INTO wine_variety VALUES (1038,20,2);
INSERT INTO wine_variety VALUES (1039,19,1);
INSERT INTO wine_variety VALUES (1039,20,2);
INSERT INTO wine_variety VALUES (1040,18,1);
INSERT INTO wine_variety VALUES (1041,19,1);
INSERT INTO wine_variety VALUES (1041,20,2);
INSERT INTO wine_variety VALUES (1042,12,1);
INSERT INTO wine_variety VALUES (1042,11,2);
INSERT INTO wine_variety VALUES (1043,6,1);
INSERT INTO wine_variety VALUES (1043,10,2);
INSERT INTO wine_variety VALUES (1044,16,1);
INSERT INTO wine_variety VALUES (1045,16,1);
INSERT INTO wine_variety VALUES (1046,6,1);
INSERT INTO wine_variety VALUES (1046,10,2);
INSERT INTO wine_variety VALUES (1047,14,1);
INSERT INTO wine_variety VALUES (1048,5,1);
INSERT INTO wine_variety VALUES (1048,3,2);
INSERT INTO wine_variety VALUES (1048,4,3);

INSERT INTO winery VALUES (1,'Hanshaw Estates Winery',2);
INSERT INTO winery VALUES (2,'De Morton and Sons Wines',5);
INSERT INTO winery VALUES (3,'Jones''s Premium Wines',3);
INSERT INTO winery VALUES (4,'Borg Daze Premium Wines',5);
INSERT INTO winery VALUES (5,'Binns Group',6);
INSERT INTO winery VALUES (6,'Davie Brook Vineyard',3);
INSERT INTO winery VALUES (7,'Eglington Creek Premium Wines',4);
INSERT INTO winery VALUES (8,'McKay Station Vineyard',4);
INSERT INTO winery VALUES (9,'Dennis and Sons Wines',5);
INSERT INTO winery VALUES (10,'Beard Brothers Vineyard',4);
INSERT INTO winery VALUES (11,'Rowley Brook Group',10);
INSERT INTO winery VALUES (12,'Borg Creek',10);
INSERT INTO winery VALUES (13,'Bickley Station',6);
INSERT INTO winery VALUES (14,'Ryan Estates Premium Wines',7);
INSERT INTO winery VALUES (15,'Waugh',4);
INSERT INTO winery VALUES (16,'Rogerson Station Group',9);
INSERT INTO winery VALUES (17,'Grabowski''s Vineyard',10);
INSERT INTO winery VALUES (18,'Greenfield Brothers',2);
INSERT INTO winery VALUES (19,'Anderson and Sons Premium Wines',4);
INSERT INTO winery VALUES (20,'Durham Hill Winery',8);
INSERT INTO winery VALUES (21,'Parker Station',4);
INSERT INTO winery VALUES (22,'Durham Brook Group',3);
INSERT INTO winery VALUES (23,'Buettner Hill',9);
INSERT INTO winery VALUES (24,'Grabowski Gully Premium Wines',9);
INSERT INTO winery VALUES (25,'Borg Creek Vineyard',6);
INSERT INTO winery VALUES (26,'Williams''s Wines',7);
INSERT INTO winery VALUES (27,'Jones Gully Vineyard',2);
INSERT INTO winery VALUES (28,'Bickley and Sons Premium Wines',5);
INSERT INTO winery VALUES (29,'Durham Ridge',7);
INSERT INTO winery VALUES (30,'Rogerson and Sons',3);
INSERT INTO winery VALUES (31,'Rowley Gully Group',4);
INSERT INTO winery VALUES (32,'Bell Daze Wines',9);
INSERT INTO winery VALUES (33,'Lane Gully Premium Wines',5);
INSERT INTO winery VALUES (34,'Gosk Estates Vineyard',10);
INSERT INTO winery VALUES (35,'Rowley Brothers Vineyard',8);
INSERT INTO winery VALUES (36,'Lane Ridge Group',2);
INSERT INTO winery VALUES (37,'De Morton Wines',7);
INSERT INTO winery VALUES (38,'Bickley Vineyard',8);
INSERT INTO winery VALUES (39,'Gosk Ridge Wines',5);
INSERT INTO winery VALUES (40,'Hayne Creek',8);
INSERT INTO winery VALUES (41,'Dennis''s',2);
INSERT INTO winery VALUES (42,'Ryan Brothers Winery',10);
INSERT INTO winery VALUES (43,'Rowley Vineyard',10);
INSERT INTO winery VALUES (44,'Grabowski Brook Winery',8);
INSERT INTO winery VALUES (45,'Beard Hill Vineyard',9);
INSERT INTO winery VALUES (46,'Grabowski Station Group',10);
INSERT INTO winery VALUES (47,'Eglington Ridge Winery',8);
INSERT INTO winery VALUES (48,'Greenfield Vineyard',9);
INSERT INTO winery VALUES (49,'Jones and Sons Winery',5);
INSERT INTO winery VALUES (50,'Anderson Daze Group',3);
INSERT INTO winery VALUES (51,'Anderson Station Winery',6);
INSERT INTO winery VALUES (52,'Parker Creek Wines',4);
INSERT INTO winery VALUES (53,'Dennis''s Wines',6);
INSERT INTO winery VALUES (54,'Pearce and Sons Winery',5);
INSERT INTO winery VALUES (55,'Macdonald Brook Vineyard',7);
INSERT INTO winery VALUES (56,'Hanshaw Estates',6);
INSERT INTO winery VALUES (57,'Pearce Daze Vineyard',2);
INSERT INTO winery VALUES (58,'Anderson and Sons Wines',4);
INSERT INTO winery VALUES (59,'Rowley Creek',5);
INSERT INTO winery VALUES (60,'Pearce Creek Wines',5);
INSERT INTO winery VALUES (61,'Macdonald Estates Vineyard',5);
INSERT INTO winery VALUES (62,'Doswell Hill Premium Wines',2);
INSERT INTO winery VALUES (63,'Anderson Daze Wines',7);
INSERT INTO winery VALUES (64,'Pearce Ridge Wines',10);
INSERT INTO winery VALUES (65,'Eglington Gully Vineyard',3);
INSERT INTO winery VALUES (66,'Borg Brothers Group',4);
INSERT INTO winery VALUES (67,'Doswell Vineyard',7);
INSERT INTO winery VALUES (68,'Bell Daze Premium Wines',7);
INSERT INTO winery VALUES (69,'Hanshaw Ridge',8);
INSERT INTO winery VALUES (70,'Lane Estates Group',3);
INSERT INTO winery VALUES (71,'Grehan Group',4);
INSERT INTO winery VALUES (72,'Macdonald and Sons',8);
INSERT INTO winery VALUES (73,'Hubel Daze Winery',8);
INSERT INTO winery VALUES (74,'Rowley Gully Wines',7);
INSERT INTO winery VALUES (75,'Lord Gully Premium Wines',9);
INSERT INTO winery VALUES (76,'Gosk',10);
INSERT INTO winery VALUES (77,'Binns Hill',10);
INSERT INTO winery VALUES (78,'Bickley Daze Group',9);
INSERT INTO winery VALUES (79,'Durham Station',3);
INSERT INTO winery VALUES (80,'Eglington Ridge Vineyard',5);
INSERT INTO winery VALUES (81,'Binns Wines',4);
INSERT INTO winery VALUES (82,'Grehan Daze',5);
INSERT INTO winery VALUES (83,'De Morton Vineyard',7);
INSERT INTO winery VALUES (84,'Williams Estates Group',8);
INSERT INTO winery VALUES (85,'Ryan Gully Vineyard',9);
INSERT INTO winery VALUES (86,'Davie Brook Winery',8);
INSERT INTO winery VALUES (87,'Scally''s Group',9);
INSERT INTO winery VALUES (88,'Pearce Brook Wines',5);
INSERT INTO winery VALUES (89,'Jones Brook Winery',5);
INSERT INTO winery VALUES (90,'Lord Daze',7);
INSERT INTO winery VALUES (91,'De Morton Station Wines',3);
INSERT INTO winery VALUES (92,'Williams Daze Vineyard',6);
INSERT INTO winery VALUES (93,'Beard Ridge Premium Wines',2);
INSERT INTO winery VALUES (94,'Gosk Group',6);
INSERT INTO winery VALUES (95,'Binns Premium Wines',2);
INSERT INTO winery VALUES (96,'Scally Gully Wines',5);
INSERT INTO winery VALUES (97,'Borg Gully Winery',3);
INSERT INTO winery VALUES (98,'Lane''s Vineyard',5);
INSERT INTO winery VALUES (99,'De Morton and Sons Vineyard',5);
INSERT INTO winery VALUES (100,'Dennis Brook Group',2);
INSERT INTO winery VALUES (101,'Bell',5);
INSERT INTO winery VALUES (102,'Eglington and Sons Vineyard',3);
INSERT INTO winery VALUES (103,'Jones Creek Wines',10);
INSERT INTO winery VALUES (104,'Jones Creek Group',5);
INSERT INTO winery VALUES (105,'Rowley Station',2);
INSERT INTO winery VALUES (106,'Scally Brothers',9);
INSERT INTO winery VALUES (107,'Buonopane Estates Wines',4);
INSERT INTO winery VALUES (108,'Lord Station Vineyard',6);
INSERT INTO winery VALUES (109,'Macdonald Gully Vineyard',5);
INSERT INTO winery VALUES (110,'Grehan''s Vineyard',2);
INSERT INTO winery VALUES (111,'Dennis and Sons Premium Wines',2);
INSERT INTO winery VALUES (112,'Buettner Station Vineyard',9);
INSERT INTO winery VALUES (113,'Buettner Estates',10);
INSERT INTO winery VALUES (114,'Buettner Creek Wines',4);
INSERT INTO winery VALUES (115,'Ryan Estates Vineyard',8);
INSERT INTO winery VALUES (116,'Gosk Creek Premium Wines',9);
INSERT INTO winery VALUES (117,'Durham Creek',9);
INSERT INTO winery VALUES (118,'Grehan Brothers Wines',4);
INSERT INTO winery VALUES (119,'Ryan Hill',9);
INSERT INTO winery VALUES (120,'Buettner Daze Premium Wines',3);
INSERT INTO winery VALUES (121,'Ryan Ridge Winery',8);
INSERT INTO winery VALUES (122,'Borg Hill Premium Wines',9);
INSERT INTO winery VALUES (123,'Macdonald Brothers Wines',8);
INSERT INTO winery VALUES (124,'Bickley and Sons Vineyard',3);
INSERT INTO winery VALUES (125,'Gosk Brothers Group',5);
INSERT INTO winery VALUES (126,'Falconer Brook Vineyard',9);
INSERT INTO winery VALUES (127,'Falconer''s Vineyard',2);
INSERT INTO winery VALUES (128,'Hanshaw Brothers Group',10);
INSERT INTO winery VALUES (129,'Bickley Estates Wines',10);
INSERT INTO winery VALUES (130,'Lord Vineyard',2);
INSERT INTO winery VALUES (131,'Grabowski Ridge',6);
INSERT INTO winery VALUES (132,'Grabowski Brothers',3);
INSERT INTO winery VALUES (133,'Buonopane Vineyard',2);
INSERT INTO winery VALUES (134,'Bickley Brothers',7);
INSERT INTO winery VALUES (135,'Dennis Hill Vineyard',6);
INSERT INTO winery VALUES (136,'Scally Station Premium Wines',2);
INSERT INTO winery VALUES (137,'Greenfield''s Group',4);
INSERT INTO winery VALUES (138,'Greenfield Ridge Premium Wines',9);
INSERT INTO winery VALUES (139,'Greenfield Wines',5);
INSERT INTO winery VALUES (140,'Greenfield Group',5);
INSERT INTO winery VALUES (141,'Rowley Estates Vineyard',9);
INSERT INTO winery VALUES (142,'Doswell Daze Wines',4);
INSERT INTO winery VALUES (143,'Lane Creek Premium Wines',5);
INSERT INTO winery VALUES (144,'Buonopane Brothers Wines',5);
INSERT INTO winery VALUES (145,'Rogerson Ridge',8);
INSERT INTO winery VALUES (146,'Bickley Gully',3);
INSERT INTO winery VALUES (147,'Borg Premium Wines',5);
INSERT INTO winery VALUES (148,'Grabowski Vineyard',7);
INSERT INTO winery VALUES (149,'Buettner',2);
INSERT INTO winery VALUES (150,'Ryan Daze Winery',3);
INSERT INTO winery VALUES (151,'Buonopane Creek Winery',9);
INSERT INTO winery VALUES (152,'Pearce Estates Winery',8);
INSERT INTO winery VALUES (153,'De Morton and Sons Winery',4);
INSERT INTO winery VALUES (154,'Williams Creek Premium Wines',2);
INSERT INTO winery VALUES (155,'Beard Brothers Premium Wines',10);
INSERT INTO winery VALUES (156,'Gosk Gully',4);
INSERT INTO winery VALUES (157,'Durham Ridge Winery',9);
INSERT INTO winery VALUES (158,'Jones Ridge Wines',5);
INSERT INTO winery VALUES (159,'Anderson Brothers Group',3);
INSERT INTO winery VALUES (160,'Hayne Hill Winery',5);
INSERT INTO winery VALUES (161,'Jones Daze Wines',4);
INSERT INTO winery VALUES (162,'Williams and Sons Wines',4);
INSERT INTO winery VALUES (163,'De Morton Creek Winery',2);
INSERT INTO winery VALUES (164,'Lord Estates Winery',10);
INSERT INTO winery VALUES (165,'Falconer Daze Premium Wines',2);
INSERT INTO winery VALUES (166,'Buonopane and Sons Group',8);
INSERT INTO winery VALUES (167,'Hanshaw Hill',5);
INSERT INTO winery VALUES (168,'Davie Hill Wines',9);
INSERT INTO winery VALUES (169,'Greenfield Brothers Winery',3);
INSERT INTO winery VALUES (170,'Macdonald''s Group',7);
INSERT INTO winery VALUES (171,'Jones Creek',10);
INSERT INTO winery VALUES (172,'Grabowski Gully Vineyard',10);
INSERT INTO winery VALUES (173,'Ryan and Sons Group',10);
INSERT INTO winery VALUES (174,'Hayne Wines',6);
INSERT INTO winery VALUES (175,'Jones',8);
INSERT INTO winery VALUES (176,'Binns Hill Vineyard',4);
INSERT INTO winery VALUES (177,'Greenfield Estates',7);
INSERT INTO winery VALUES (178,'Greenfield Estates Winery',3);
INSERT INTO winery VALUES (179,'Korab Estates Premium Wines',5);
INSERT INTO winery VALUES (180,'Falconer',2);
INSERT INTO winery VALUES (181,'Anderson''s Wines',7);
INSERT INTO winery VALUES (182,'Waugh Ridge Winery',10);
INSERT INTO winery VALUES (183,'Lord Ridge Vineyard',10);
INSERT INTO winery VALUES (184,'Lord Daze Vineyard',10);
INSERT INTO winery VALUES (185,'Rowley Hill Wines',4);
INSERT INTO winery VALUES (186,'Waugh Gully Vineyard',4);
INSERT INTO winery VALUES (187,'Korab Hill Vineyard',9);
INSERT INTO winery VALUES (188,'Lane Wines',6);
INSERT INTO winery VALUES (189,'Waugh Estates Wines',2);
INSERT INTO winery VALUES (190,'Borg''s',7);
INSERT INTO winery VALUES (191,'Jones Brook Vineyard',3);
INSERT INTO winery VALUES (192,'Bickley''s',4);
INSERT INTO winery VALUES (193,'Grehan Ridge Winery',6);
INSERT INTO winery VALUES (194,'Davie Station Group',5);
INSERT INTO winery VALUES (195,'De Morton Hill Group',7);
INSERT INTO winery VALUES (196,'Anderson Creek Group',8);
INSERT INTO winery VALUES (197,'Waugh Brook Premium Wines',8);
INSERT INTO winery VALUES (198,'Hayne Brothers Premium Wines',6);
INSERT INTO winery VALUES (199,'Rogerson Gully Premium Wines',9);
INSERT INTO winery VALUES (200,'Buettner''s Premium Wines',2);
INSERT INTO winery VALUES (201,'Doswell Estates Vineyard',10);
INSERT INTO winery VALUES (202,'Grehan Creek',5);
INSERT INTO winery VALUES (203,'Doswell Premium Wines',2);
INSERT INTO winery VALUES (204,'Rogerson Gully',7);
INSERT INTO winery VALUES (205,'Parker Station Vineyard',9);
INSERT INTO winery VALUES (206,'Ryan and Sons Vineyard',2);
INSERT INTO winery VALUES (207,'Hubel Ridge Winery',3);
INSERT INTO winery VALUES (208,'Grehan Station Vineyard',4);
INSERT INTO winery VALUES (209,'Borg Brook Winery',3);
INSERT INTO winery VALUES (210,'Rogerson Estates Winery',6);
INSERT INTO winery VALUES (211,'Durham Estates',9);
INSERT INTO winery VALUES (212,'Rowley Premium Wines',10);
INSERT INTO winery VALUES (213,'Anderson''s Winery',10);
INSERT INTO winery VALUES (214,'Rogerson''s Group',5);
INSERT INTO winery VALUES (215,'Doswell Brook',4);
INSERT INTO winery VALUES (216,'Waugh Gully Wines',4);
INSERT INTO winery VALUES (217,'Durham and Sons Premium Wines',8);
INSERT INTO winery VALUES (218,'Scally Daze Vineyard',6);
INSERT INTO winery VALUES (219,'Gosk and Sons Wines',2);
INSERT INTO winery VALUES (220,'Eglington Winery',7);
INSERT INTO winery VALUES (221,'Bickley Hill Winery',5);
INSERT INTO winery VALUES (222,'McKay and Sons Group',7);
INSERT INTO winery VALUES (223,'Hanshaw Station Vineyard',7);
INSERT INTO winery VALUES (224,'Macdonald Hill Wines',3);
INSERT INTO winery VALUES (225,'Scally Gully',4);
INSERT INTO winery VALUES (226,'Grehan Gully',6);
INSERT INTO winery VALUES (227,'Scally Winery',3);
INSERT INTO winery VALUES (228,'Rowley Ridge Winery',9);
INSERT INTO winery VALUES (229,'Hayne Daze Group',6);
INSERT INTO winery VALUES (230,'Durham Premium Wines',3);
INSERT INTO winery VALUES (231,'Beard and Sons Vineyard',4);
INSERT INTO winery VALUES (232,'Hanshaw and Sons',7);
INSERT INTO winery VALUES (233,'Doswell Estates Premium Wines',8);
INSERT INTO winery VALUES (234,'Rowley Ridge Group',7);
INSERT INTO winery VALUES (235,'Parker Brothers Winery',7);
INSERT INTO winery VALUES (236,'Hayne Station Group',10);
INSERT INTO winery VALUES (237,'McKay Ridge Winery',9);
INSERT INTO winery VALUES (238,'Scally Hill Vineyard',6);
INSERT INTO winery VALUES (239,'Anderson Ridge Wines',6);
INSERT INTO winery VALUES (240,'Hayne''s Premium Wines',8);
INSERT INTO winery VALUES (241,'Anderson''s Group',3);
INSERT INTO winery VALUES (242,'Lord''s Winery',7);
INSERT INTO winery VALUES (243,'Macdonald Hill Vineyard',9);
INSERT INTO winery VALUES (244,'Lord Ridge',4);
INSERT INTO winery VALUES (245,'Binns Station Group',5);
INSERT INTO winery VALUES (246,'McKay Ridge Group',10);
INSERT INTO winery VALUES (247,'Durham Hill Vineyard',5);
INSERT INTO winery VALUES (248,'Buettner Daze Winery',10);
INSERT INTO winery VALUES (249,'Hayne Vineyard',10);
INSERT INTO winery VALUES (250,'Rogerson Estates Wines',2);
INSERT INTO winery VALUES (251,'Davie Hill Premium Wines',3);
INSERT INTO winery VALUES (252,'Grehan''s Group',2);
INSERT INTO winery VALUES (253,'McKay and Sons',2);
INSERT INTO winery VALUES (254,'Borg and Sons',8);
INSERT INTO winery VALUES (255,'Grabowski and Sons Wines',6);
INSERT INTO winery VALUES (256,'Davie Brook Group',9);
INSERT INTO winery VALUES (257,'Waugh Creek',5);
INSERT INTO winery VALUES (258,'Bell Winery',8);
INSERT INTO winery VALUES (259,'Gosk Winery',7);
INSERT INTO winery VALUES (260,'Dennis Winery',9);
INSERT INTO winery VALUES (261,'Williams Brothers Vineyard',3);
INSERT INTO winery VALUES (262,'Rowley Creek Winery',2);
INSERT INTO winery VALUES (263,'Rogerson and Sons Winery',4);
INSERT INTO winery VALUES (264,'Bickley Ridge Winery',5);
INSERT INTO winery VALUES (265,'Binns Creek Premium Wines',5);
INSERT INTO winery VALUES (266,'Rogerson Hill Group',4);
INSERT INTO winery VALUES (267,'Rowley Daze Premium Wines',3);
INSERT INTO winery VALUES (268,'Borg Gully',6);
INSERT INTO winery VALUES (269,'Macdonald Ridge Vineyard',10);
INSERT INTO winery VALUES (270,'Dennis Gully Wines',3);
INSERT INTO winery VALUES (271,'Borg Brothers',4);
INSERT INTO winery VALUES (272,'Pearce Ridge Premium Wines',7);
INSERT INTO winery VALUES (273,'Binns Daze Premium Wines',4);
INSERT INTO winery VALUES (274,'Scally Brothers Group',8);
INSERT INTO winery VALUES (275,'Waugh Brothers Vineyard',10);
INSERT INTO winery VALUES (276,'Lane Hill Wines',3);
INSERT INTO winery VALUES (277,'Williams Creek Group',4);
INSERT INTO winery VALUES (278,'Korab Estates Winery',6);
INSERT INTO winery VALUES (279,'Anderson Daze Vineyard',9);
INSERT INTO winery VALUES (280,'Doswell Gully Winery',8);
INSERT INTO winery VALUES (281,'Williams Brook Premium Wines',7);
INSERT INTO winery VALUES (282,'Beard Daze Winery',9);
INSERT INTO winery VALUES (283,'Hubel''s',9);
INSERT INTO winery VALUES (284,'Parker Hill Premium Wines',5);
INSERT INTO winery VALUES (285,'Eglington Vineyard',2);
INSERT INTO winery VALUES (286,'Grabowski Estates Winery',8);
INSERT INTO winery VALUES (287,'Buonopane Brook Winery',6);
INSERT INTO winery VALUES (288,'Rogerson''s Winery',7);
INSERT INTO winery VALUES (289,'Greenfield Brothers Wines',2);
INSERT INTO winery VALUES (290,'Durham',2);
INSERT INTO winery VALUES (291,'Korab Station Wines',8);
INSERT INTO winery VALUES (292,'De Morton Gully Vineyard',6);
INSERT INTO winery VALUES (293,'Pearce Winery',7);
INSERT INTO winery VALUES (294,'McKay Daze Vineyard',9);
INSERT INTO winery VALUES (295,'Doswell Gully Wines',9);
INSERT INTO winery VALUES (296,'Jones Estates',9);
INSERT INTO winery VALUES (297,'Ryan',5);
INSERT INTO winery VALUES (298,'Rowley Brook Winery',3);
INSERT INTO winery VALUES (299,'Grabowski Creek Vineyard',10);
INSERT INTO winery VALUES (300,'Ryan Estates Group',3);

INSERT INTO titles VALUES (1,'Mr');
INSERT INTO titles VALUES (2,'Mrs');
INSERT INTO titles VALUES (3,'Miss');
INSERT INTO titles VALUES (4,'Ms');
INSERT INTO titles VALUES (5,'Dr');
INSERT INTO titles VALUES (6,'Prof');
INSERT INTO titles VALUES (7,'Rev');

INSERT INTO countries VALUES (1, 'Afghanistan');
INSERT INTO countries VALUES (2, 'Albania');
INSERT INTO countries VALUES (3, 'Algeria');
INSERT INTO countries VALUES (4, 'American Samoa');
INSERT INTO countries VALUES (5, 'Andorra');
INSERT INTO countries VALUES (6, 'Angola');
INSERT INTO countries VALUES (7, 'Anguilla');
INSERT INTO countries VALUES (8, 'Antigua & Barbuda');
INSERT INTO countries VALUES (9, 'Argentina');
INSERT INTO countries VALUES (10, 'Armenia');
INSERT INTO countries VALUES (11, 'Aruba');
INSERT INTO countries VALUES (12, 'Australia');
INSERT INTO countries VALUES (13, 'Austria');
INSERT INTO countries VALUES (14, 'Azerbaijan');
INSERT INTO countries VALUES (15, 'Bahamas');
INSERT INTO countries VALUES (16, 'Bahrain');
INSERT INTO countries VALUES (17, 'Bangladesh');
INSERT INTO countries VALUES (18, 'Barbados');
INSERT INTO countries VALUES (19, 'Belarus');
INSERT INTO countries VALUES (20, 'Belgium');
INSERT INTO countries VALUES (21, 'Belize');
INSERT INTO countries VALUES (22, 'Benin');
INSERT INTO countries VALUES (23, 'Bermuda');
INSERT INTO countries VALUES (24, 'Bhutan');
INSERT INTO countries VALUES (25, 'Bolivia');
INSERT INTO countries VALUES (26, 'Bosnia-Herzegovina');
INSERT INTO countries VALUES (27, 'Botswana');
INSERT INTO countries VALUES (28, 'Brazil');
INSERT INTO countries VALUES (29, 'British Virgin Is.');
INSERT INTO countries VALUES (30, 'Brunei');
INSERT INTO countries VALUES (31, 'Bulgaria');
INSERT INTO countries VALUES (32, 'Burkina Faso');
INSERT INTO countries VALUES (33, 'Burundi');
INSERT INTO countries VALUES (34, 'Cambodia');
INSERT INTO countries VALUES (35, 'Cameroon');
INSERT INTO countries VALUES (36, 'Canada');
INSERT INTO countries VALUES (37, 'Canary Is.');
INSERT INTO countries VALUES (38, 'Cape Verde');
INSERT INTO countries VALUES (39, 'Central Africa');
INSERT INTO countries VALUES (40, 'Chad');
INSERT INTO countries VALUES (41, 'Chile');
INSERT INTO countries VALUES (42, 'China');
INSERT INTO countries VALUES (43, 'Cocos I.');
INSERT INTO countries VALUES (44, 'Colombia');
INSERT INTO countries VALUES (45, 'Congo (Republic of the)');
INSERT INTO countries VALUES (46, 'Corsica');
INSERT INTO countries VALUES (47, 'Costa Rica');
INSERT INTO countries VALUES (48, 'Cote d''Ivoire');
INSERT INTO countries VALUES (49, 'Crete');
INSERT INTO countries VALUES (50, 'Croatia');
INSERT INTO countries VALUES (51, 'Cuba');
INSERT INTO countries VALUES (52, 'Cyprus');
INSERT INTO countries VALUES (53, 'Czech Republic');
INSERT INTO countries VALUES (54, 'Dem. Rep. of Congo');
INSERT INTO countries VALUES (55, 'Denmark');
INSERT INTO countries VALUES (56, 'Djibouti');
INSERT INTO countries VALUES (57, 'Dominica');
INSERT INTO countries VALUES (58, 'Dominican Republic');
INSERT INTO countries VALUES (59, 'DPR of Korea');
INSERT INTO countries VALUES (60, 'Easter I.');
INSERT INTO countries VALUES (61, 'Ecuador');
INSERT INTO countries VALUES (62, 'Egypt');
INSERT INTO countries VALUES (63, 'El Salvador');
INSERT INTO countries VALUES (64, 'England');
INSERT INTO countries VALUES (65, 'Equatorial Guinea');
INSERT INTO countries VALUES (66, 'Eritrea');
INSERT INTO countries VALUES (67, 'Estonia');
INSERT INTO countries VALUES (68, 'Ethiopia');
INSERT INTO countries VALUES (69, 'Fed. Rep. of Germany');
INSERT INTO countries VALUES (70, 'Fiji');
INSERT INTO countries VALUES (71, 'Finland');
INSERT INTO countries VALUES (72, 'France');
INSERT INTO countries VALUES (73, 'French Guiana');
INSERT INTO countries VALUES (74, 'French Polynesia');
INSERT INTO countries VALUES (75, 'Gabon');
INSERT INTO countries VALUES (76, 'Galapagos Is.');
INSERT INTO countries VALUES (77, 'Georgia');
INSERT INTO countries VALUES (78, 'Ghana');
INSERT INTO countries VALUES (79, 'Gibraltar');
INSERT INTO countries VALUES (80, 'Greece');
INSERT INTO countries VALUES (81, 'Greenland');
INSERT INTO countries VALUES (82, 'Grenada');
INSERT INTO countries VALUES (83, 'Guadeloupe');
INSERT INTO countries VALUES (84, 'Guam');
INSERT INTO countries VALUES (85, 'Guatemala');
INSERT INTO countries VALUES (86, 'Guernsey');
INSERT INTO countries VALUES (87, 'Guinea');
INSERT INTO countries VALUES (88, 'Guinea-Bissau');
INSERT INTO countries VALUES (89, 'Guyana');
INSERT INTO countries VALUES (90, 'Haiti');
INSERT INTO countries VALUES (91, 'Honduras');
INSERT INTO countries VALUES (92, 'Hong Kong');
INSERT INTO countries VALUES (93, 'Hungary');
INSERT INTO countries VALUES (94, 'Iceland');
INSERT INTO countries VALUES (95, 'India');
INSERT INTO countries VALUES (96, 'Indonesia');
INSERT INTO countries VALUES (97, 'Iran');
INSERT INTO countries VALUES (98, 'Iraq');
INSERT INTO countries VALUES (99, 'Ireland');
INSERT INTO countries VALUES (100, 'Isle of Man');
INSERT INTO countries VALUES (101, 'Israel');
INSERT INTO countries VALUES (102, 'Italy');
INSERT INTO countries VALUES (103, 'Jamaica');
INSERT INTO countries VALUES (104, 'Japan');
INSERT INTO countries VALUES (105, 'Jersey');
INSERT INTO countries VALUES (106, 'Jordan');
INSERT INTO countries VALUES (107, 'Kazakhstan');
INSERT INTO countries VALUES (108, 'Kenya');
INSERT INTO countries VALUES (109, 'Kuwait');
INSERT INTO countries VALUES (110, 'Kyrgyzstan');
INSERT INTO countries VALUES (111, 'Laos');
INSERT INTO countries VALUES (112, 'Latvia');
INSERT INTO countries VALUES (113, 'Lebanon');
INSERT INTO countries VALUES (114, 'Lesotho');
INSERT INTO countries VALUES (115, 'Liberia');
INSERT INTO countries VALUES (116, 'Libya');
INSERT INTO countries VALUES (117, 'Liechtenstein');
INSERT INTO countries VALUES (118, 'Lithuania');
INSERT INTO countries VALUES (119, 'Luxembourg');
INSERT INTO countries VALUES (120, 'Macao');
INSERT INTO countries VALUES (121, 'Macedonia');
INSERT INTO countries VALUES (122, 'Madagascar');
INSERT INTO countries VALUES (123, 'Malawi');
INSERT INTO countries VALUES (124, 'Malaysia');
INSERT INTO countries VALUES (125, 'Maldives');
INSERT INTO countries VALUES (126, 'Mali');
INSERT INTO countries VALUES (127, 'Malta');
INSERT INTO countries VALUES (128, 'Mauritania');
INSERT INTO countries VALUES (129, 'Mauritius');
INSERT INTO countries VALUES (130, 'Mexico');
INSERT INTO countries VALUES (131, 'Micronesia');
INSERT INTO countries VALUES (132, 'Moldovia');
INSERT INTO countries VALUES (133, 'Monaco');
INSERT INTO countries VALUES (134, 'Mongolia');
INSERT INTO countries VALUES (135, 'Montserrat');
INSERT INTO countries VALUES (136, 'Morocco');
INSERT INTO countries VALUES (137, 'Mozambique');
INSERT INTO countries VALUES (138, 'Myanmar');
INSERT INTO countries VALUES (139, 'Namibia');
INSERT INTO countries VALUES (140, 'Nauru');
INSERT INTO countries VALUES (141, 'Nepal');
INSERT INTO countries VALUES (142, 'Netherlands');
INSERT INTO countries VALUES (143, 'New Caledonia');
INSERT INTO countries VALUES (144, 'New Zealand');
INSERT INTO countries VALUES (145, 'Nicaragua');
INSERT INTO countries VALUES (146, 'Niger');
INSERT INTO countries VALUES (147, 'Nigeria');
INSERT INTO countries VALUES (148, 'Northern Ireland');
INSERT INTO countries VALUES (149, 'Norway');
INSERT INTO countries VALUES (150, 'Oman');
INSERT INTO countries VALUES (151, 'Pakistan');
INSERT INTO countries VALUES (152, 'Panama');
INSERT INTO countries VALUES (153, 'Papua New Guinea');
INSERT INTO countries VALUES (154, 'Paraguay');
INSERT INTO countries VALUES (155, 'Peru');
INSERT INTO countries VALUES (156, 'Philippines');
INSERT INTO countries VALUES (157, 'Poland');
INSERT INTO countries VALUES (158, 'Portugal');
INSERT INTO countries VALUES (159, 'Puerto Rico');
INSERT INTO countries VALUES (160, 'Qatar');
INSERT INTO countries VALUES (161, 'Republic of Korea');
INSERT INTO countries VALUES (162, 'Revillagigedo');
INSERT INTO countries VALUES (163, 'Romania');
INSERT INTO countries VALUES (164, 'Russia');
INSERT INTO countries VALUES (165, 'Rwanda');
INSERT INTO countries VALUES (166, 'Samoa');
INSERT INTO countries VALUES (167, 'San Marino');
INSERT INTO countries VALUES (168, 'Sardinia');
INSERT INTO countries VALUES (169, 'Saudi Arabia');
INSERT INTO countries VALUES (170, 'Scotland');
INSERT INTO countries VALUES (171, 'Senegal');
INSERT INTO countries VALUES (172, 'Serbia and Montenegro');
INSERT INTO countries VALUES (173, 'Seychelles');
INSERT INTO countries VALUES (174, 'Sierra Leone');
INSERT INTO countries VALUES (175, 'Singapore');
INSERT INTO countries VALUES (176, 'Slovak Republic');
INSERT INTO countries VALUES (177, 'Slovenia');
INSERT INTO countries VALUES (178, 'Solomon Is.');
INSERT INTO countries VALUES (179, 'Somalia');
INSERT INTO countries VALUES (180, 'South Africa');
INSERT INTO countries VALUES (181, 'Spain');
INSERT INTO countries VALUES (182, 'Sri Lanka');
INSERT INTO countries VALUES (183, 'stine');
INSERT INTO countries VALUES (184, 'St. Kitts & Nevis');
INSERT INTO countries VALUES (185, 'St. Lucia');
INSERT INTO countries VALUES (186, 'St. Vincent');
INSERT INTO countries VALUES (187, 'Sudan');
INSERT INTO countries VALUES (188, 'Suriname');
INSERT INTO countries VALUES (189, 'Swaziland');
INSERT INTO countries VALUES (190, 'Sweden');
INSERT INTO countries VALUES (191, 'Switzerland');
INSERT INTO countries VALUES (192, 'Syria');
INSERT INTO countries VALUES (193, 'Taiwan');
INSERT INTO countries VALUES (194, 'Tajikistan');
INSERT INTO countries VALUES (195, 'Tanzania');
INSERT INTO countries VALUES (196, 'Thailand');
INSERT INTO countries VALUES (197, 'The Gambia');
INSERT INTO countries VALUES (198, 'Togo');
INSERT INTO countries VALUES (199, 'Tonga');
INSERT INTO countries VALUES (200, 'Trinidad & Tobago');
INSERT INTO countries VALUES (201, 'Tunisia');
INSERT INTO countries VALUES (202, 'Turkey');
INSERT INTO countries VALUES (203, 'Turkmenistan');
INSERT INTO countries VALUES (204, 'Tuvalu');
INSERT INTO countries VALUES (205, 'Uganda');
INSERT INTO countries VALUES (206, 'Ukraine');
INSERT INTO countries VALUES (207, 'United Arab Emirates');
INSERT INTO countries VALUES (208, 'United States of America');
INSERT INTO countries VALUES (209, 'Uruguay');
INSERT INTO countries VALUES (210, 'Uzbekistan');
INSERT INTO countries VALUES (211, 'Vanuatu');
INSERT INTO countries VALUES (212, 'Vatican');
INSERT INTO countries VALUES (213, 'Venezuela');
INSERT INTO countries VALUES (214, 'Vietnam');
INSERT INTO countries VALUES (215, 'Virgin Is.');
INSERT INTO countries VALUES (216, 'Wales');
INSERT INTO countries VALUES (217, 'Yemen');
INSERT INTO countries VALUES (218, 'Zambia');
INSERT INTO countries VALUES (219, 'Zimbabwe');

create user 'winestores'@'localhost' identified by 'xpto_1234';
create user 'winestores'@'127.0.0.1' identified by 'xpto_1234';

grant all on winestore to 'winestores'@'localhost';
grant all on winestore to 'winestores'@'127.0.0.1';
